(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    100133,       2936]
NotebookOptionsPosition[     96343,       2812]
NotebookOutlinePosition[     97064,       2843]
CellTagsIndexPosition[     96991,       2838]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.4  Improper Integrals Involving Trigonometric \
Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tLet ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " be polynomials of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "1"}]}]]],
 ".  We can show (but omit the proof) that if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}], "\[NotEqual]", "0"}]]],
 "  for all real ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"P", ".", "V", ".", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "x", ")"}], "cos", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", " ", "x"}], ")"}]}], 
      RowBox[{"Q", 
       RowBox[{"(", "x", ")"}]}]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", ".", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "x", ")"}], "sin", 
       RowBox[{"(", 
        RowBox[{"\[Alpha]", " ", "x"}], ")"}]}], 
      RowBox[{"Q", 
       RowBox[{"(", "x", ")"}]}]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]]],
 "  \n\nare convergent improper integrals.  You may encounter integrals of \
this type in the study of ",
 StyleBox[ButtonBox["Fourier",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " ",
 StyleBox[ButtonBox["transforms",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FourierTransform.html"], None}],
  FontVariations->{"Underline"->True}],
 " and ",
 StyleBox[ButtonBox["Fourier integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FourierTransform.html"], None}],
  FontVariations->{"Underline"->True}],
 ".  We now show how to evaluate them."
}], "Text"],

Cell[TextData[{
 "\tParticularly important is our use of the identities\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", " ", "x"}], ")"}]}], " ", "=", " ", 
   RowBox[{"Re", "[", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "x"}]], "]"}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sin", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", " ", "x"}], ")"}]}], " ", "=", " ", 
   RowBox[{"Im", "[", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "x"}]], "]"}]}]]],
 "  \n\nwhere  ",
 Cell[BoxData["\[Alpha]"]],
 "  is a positive real number.  The crucial step in the proof of Theorem 8.4 \
wouldn't hold if we were to use  ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", " ", "z"}], ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"sin", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", " ", "z"}], ")"}]}]]],
 "  are used instead of  ",
 Cell[BoxData[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "z"}]]]],
 ", as you will see when you get to Lemma 8.1."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.4 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Contour Integration for Improper Trig. Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ContourIntegration.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " be polynomials with real coefficients, of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}], "\[NotEqual]", "0"}]]],
 "  for all real ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " .  If  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", ">", "0"}]]],
 "  and  \n\n",
 StyleBox["(8-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "z"}]], " ", "P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ",    then\n\n",
 StyleBox["(8-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], "cos", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", " ", "x"}], ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", "2"}], "\[Pi]", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "k"], " ", 
     RowBox[{"Im", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "j"]}], "]"}], ")"}]}]}]}]}]]],
 ",    and  \n\t\n",
 StyleBox["(8-14)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], "sin", 
      RowBox[{"(", 
       RowBox[{"\[Alpha]", " ", "x"}], ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{"2", "\[Pi]", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "k"], " ", 
     RowBox[{"Re", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "j"]}], "]"}], ")"}]}]}]}]}]]],
 ",\n  \nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie in the upper half plane and  ",
 Cell[BoxData[
  RowBox[{"Re", 
   RowBox[{"(", 
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      SubscriptBox["z", "j"]}], "]"}], ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"Im", 
   RowBox[{"(", 
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      SubscriptBox["z", "j"]}], "]"}], ")"}]}]]],
 "  are the real and imaginary parts of  ",
 Cell[BoxData[
  RowBox[{"Res", "[", 
   RowBox[{"f", ",", 
    SubscriptBox["z", "j"]}], "]"}]]],
 ",  respectively.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{387, 236},
  ImageMargins->0],
 StyleBox["  \n\n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.4",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/\
integralstrigonometricimproper/IntegralsTrigImproperFigures/mat0804.gif"], 
    None}],
  FontWeight->"Bold"],
 "  The poles  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "x", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "x", ")"}]}]], "cos", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", " ", "x"}], ")"}]}]]],
 "  or  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "x", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "x", ")"}]}]], "sin", 
   RowBox[{"(", 
    RowBox[{"\[Alpha]", " ", "x"}], ")"}]}]]],
 "  that lie in the upper half-plane. "
}], "Text",
 CellChangeTimes->{{3.399464159625*^9, 3.399464196078125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.4",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell["\<\
\tThe proof of Theorem 8.4 is similar to the proof of Theorem 8.3.  Before \
turning to the proof, we illustrate how to use Theorem 8.4. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 8.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", "."}]]],
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{
    FractionBox[
     RowBox[{"x", " ", "sin", " ", "x"}], 
     RowBox[{
      SuperscriptBox["x", "2"], "+", "4"}]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]],
  CellChangeTimes->{{3.39946149396875*^9, 3.399461498875*^9}}],
 ". "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399461571609375*^9, 3.399461607421875*^9}, {
  3.399461748484375*^9, 3.39946174953125*^9}},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{688, 154},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The function",
 " ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " ",
 "in Equation ",
 StyleBox["(8-12)",
  FontColor->RGBColor[0, 0, 1]],
 " is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
     RowBox[{
      SuperscriptBox["z", "2"], " ", "+", " ", "4"}]], "=", 
    FractionBox[
     RowBox[{"z", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]]],
 ",  which has a simple pole at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 "  in the upper half-plane.  Calculating the residue yields \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
       FractionBox[
        RowBox[{"z", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", 
         RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
       FractionBox[
        RowBox[{"z", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
        RowBox[{"z", "+", 
         RowBox[{"2", "\[ImaginaryI]"}]}]]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "\[ImaginaryI]"}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"2", "\[ImaginaryI]"}], ")"}]}]]}], 
       RowBox[{
        RowBox[{"2", "\[ImaginaryI]"}], "+", 
        RowBox[{"2", "\[ImaginaryI]"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "\[ImaginaryI]"}], ")"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "2"}]]}], 
      RowBox[{"4", "\[ImaginaryI]"}]]}], "\[IndentingNewLine]", 
    " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{" ", "1"}], 
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", "2"]}]]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "Using Equation ",
 StyleBox["(8-14)",
  FontColor->RGBColor[0, 0, 1]],
 " gives \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       FractionBox[
        RowBox[{"x", " ", "sin", " ", "x"}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", "4"}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", "  ", 
    RowBox[{"2", "\[Pi]", "  ", "Re", 
     RowBox[{"(", 
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", 
        SubscriptBox["z", "1"]}], "]"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "\[Pi]", "  ", "Re", 
     RowBox[{"(", 
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", 
        RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{"2", 
         SuperscriptBox["\[ExponentialE]", "2"]}]], ")"}]}], "  ", "=", "  ", 
     
     RowBox[{"2", "\[Pi]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{" ", "1"}], 
        RowBox[{"2", 
         SuperscriptBox["\[ExponentialE]", "2"]}]], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    FractionBox["\[Pi]", 
     SuperscriptBox["\[ExponentialE]", "2"]]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{{3.39946172825*^9, 3.39946173734375*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the functions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "x", "]"}], "=", 
   FractionBox[
    RowBox[{"x", " ", 
     RowBox[{"Sin", "[", "x", "]"}]}], 
    RowBox[{
     SuperscriptBox["x", "2"], " ", "+", " ", "4"}]]}]],
  AspectRatioFixed->False],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"z", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", "4"}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities of  f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "g", ",", "Res1", ",", "Res2", ",", "solset", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     FractionBox[
      RowBox[{"x", " ", 
       RowBox[{"Sin", "[", "x", "]"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], " ", "+", " ", "4"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "4"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946181415625*^9},
 AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399461818796875*^9, 3.399461821390625*^9}, 
   3.40005793484375*^9, {3.400057981046875*^9, 3.400057983796875*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residue at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ", \nand then use the residue calculus to compute the value of the integral.\
\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
   3.400312490734375*^9}, {3.400313108703125*^9, 3.400313117296875*^9}, {
   3.400313155375*^9, 3.40031316934375*^9}, {3.4003132215*^9, 
   3.400313230171875*^9}, 3.400313464703125*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{"2", "\[Pi]", "  ", 
      RowBox[{"Re", "[", "Res2", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<]] = \>\"", ",", 
      RowBox[{"Re", "[", "Res2", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Magenta", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "2"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "2"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", "segment", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi] Re[\>\"", ",", "Res2", " ", ",", 
      "\"\<] = \>\"", ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the semicircle \!\(\*SubscriptBox[\(C\), \(R\)]\) \
and interval [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = 2\[Pi] Re[\>\"", ",", "Res2", ",", 
      "\"\<] = \>\"", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399461826140625*^9, 3.399461847375*^9}, {
   3.400057940625*^9, 3.4000579409375*^9}, {3.4000579975*^9, 
   3.400058011109375*^9}, 3.4003136135625*^9}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral of  f[z] for this problem is  g[z],  but it cannot be used \
in any meaningful way to solve the problem at hand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral] \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g[\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399461854421875*^9}],

Cell[TextData[{
 "This looks good, however it ",
 StyleBox["cannot",
  FontColor->RGBColor[1, 0, 1]],
 " be used to solve for the definite integral. This does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " agree with the answer obtained with the residue calculus."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399461858453125*^9},
 AspectRatioFixed->False],

Cell["\<\
However, the definite integral will produce the following result.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", "\n"}]}]], "Input",\

 CellChangeTimes->{3.399461862984375*^9}],

Cell["Which is also the correct answer.", "Text"],

Cell["The PrincipalValue option can also be used.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399461867625*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", "."}]]],
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{
    FractionBox[
     RowBox[{"cos", " ", "x"}], 
     RowBox[{
      SuperscriptBox["x", "4"], "+", "4"}]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]],
  CellChangeTimes->{{3.39946149396875*^9, 3.399461498875*^9}}],
 ".   "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399461511546875*^9, 3.399461557109375*^9}},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{691, 154},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in Equation ",
 StyleBox["(8-12)",
  FontColor->RGBColor[0, 0, 1]],
 " is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], 
     RowBox[{
      SuperscriptBox["z", "4"], "+", "4"}]], " ", "=", "  ", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}]}]]}]}]]],
 ",  which has simple poles at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 "  in the upper half-plane.  We get the residues with the aid of \
L'H\[OHat]pital's rule:  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "+", "1", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", 
         RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
        RowBox[{
         SuperscriptBox["z", "4"], "+", "4"}]]}], "  ", "=", "  ", 
      RowBox[{"'", 
       RowBox[{
        FractionBox["0", "0"], "'"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", "1", ")"}], 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], 
         "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]]}]}], 
       RowBox[{"4", 
        SuperscriptBox["z", "3"]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", 
           RowBox[{"(", 
            RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}]}]}], ")"}], 
        " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
       RowBox[{"4", " ", 
        SuperscriptBox["z", "3"]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", 
           RowBox[{"(", 
            RowBox[{
            "1", "+", "\[ImaginaryI]", "-", "1", "-", "\[ImaginaryI]"}], 
            ")"}]}]}], ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}]]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "3"]}]], "  ", "=", 
      "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", "1", ")"}], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "3"]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]], 
       RowBox[{
        RowBox[{"-", "8"}], "+", 
        RowBox[{"8", " ", "\[ImaginaryI]"}]}]], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]]}], "16"]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]]}], "16"], "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "1"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", " ", "1"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", " ", "1"}]}], ")"}]}], 
       "16"]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"sin", " ", "1"}], " ", "-", 
      RowBox[{"cos", " ", "1"}], "  ", "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", "1"}], " ", "+", 
         RowBox[{"sin", " ", "1"}]}], " ", ")"}]}]}], 
     RowBox[{"16", "\[ExponentialE]"}]]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Similarly,\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "-", "\[ImaginaryI]"}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], "  ", "\n"}], "\[IndentingNewLine]", 
  RowBox[{"                               ", 
   RowBox[{"=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "z"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "+", "1", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}]}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                               ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"cos", " ", "1"}], " ", "-", " ", 
      RowBox[{"sin", " ", "1"}], " ", "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", "1"}], " ", "+", 
         RowBox[{"sin", " ", "1"}]}], " ", ")"}]}]}], 
     RowBox[{"16", "\[ExponentialE]"}]]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{{3.399463620890625*^9, 3.399463624453125*^9}}],

Cell[TextData[{
 "Using Equation ",
 StyleBox["(8-13)",
  FontColor->RGBColor[0, 0, 1]],
 ", we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       FractionBox[
        RowBox[{"cos", " ", "x"}], 
        RowBox[{
         SuperscriptBox["x", "4"], "+", "4"}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"-", "2"}], "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Im", 
        RowBox[{"(", 
         RowBox[{"Res", "[", 
          RowBox[{"f", ",", 
           SubscriptBox["z", "1"]}], "]"}], ")"}]}], " ", "+", " ", 
       RowBox[{"Im", 
        RowBox[{"(", 
         RowBox[{"Res", "[", 
          RowBox[{"f", ",", 
           SubscriptBox["z", "2"]}], "]"}], ")"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", "2"}], "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Im", 
        RowBox[{"(", 
         RowBox[{"Res", "[", 
          RowBox[{"f", ",", 
           RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], ")"}]}], " ", "+", 
       " ", 
       RowBox[{"Im", 
        RowBox[{"(", 
         RowBox[{"Res", "[", 
          RowBox[{"f", ",", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}], "]"}], ")"}]}]}], 
      ")"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"-", "2"}], "\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Im", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           RowBox[{"sin", " ", "1"}], " ", "-", 
           RowBox[{"cos", " ", "1"}], "  ", "-", " ", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"cos", " ", "1"}], " ", "+", 
              RowBox[{"sin", " ", "1"}]}], " ", ")"}]}]}], 
          RowBox[{"16", "\[ExponentialE]"}]], ")"}]}], " ", "+", " ", 
       RowBox[{"Im", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           RowBox[{"cos", " ", "1"}], " ", "-", " ", 
           RowBox[{"sin", " ", "1"}], " ", "-", " ", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"cos", " ", "1"}], " ", "+", 
              RowBox[{"sin", " ", "1"}]}], " ", ")"}]}]}], 
          RowBox[{"16", "\[ExponentialE]"}]], ")"}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "  ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"cos", " ", "1"}], " ", "+", 
            RowBox[{"sin", " ", "1"}]}], " ", ")"}]}], 
         RowBox[{"16", "\[ExponentialE]"}]], " ", "+", " ", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"-", "  ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"cos", " ", "1"}], " ", "+", 
             RowBox[{"sin", " ", "1"}]}], " ", ")"}]}]}], 
         RowBox[{"16", "\[ExponentialE]"}]]}], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"-", "  ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"cos", " ", "1"}], " ", "+", 
           RowBox[{"sin", " ", "1"}]}], " ", ")"}]}], 
        RowBox[{"8", "\[ExponentialE]"}]], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"cos", " ", "1"}], " ", "+", 
        RowBox[{"sin", " ", "1"}]}], " ", ")"}]}], 
     RowBox[{"4", "\[ExponentialE]"}]]}]}]}]],
 "  "
}], "Text",
 CellChangeTimes->{{3.39946166246875*^9, 3.399461686484375*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the functions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "x", "]"}], "=", 
   FractionBox[
    RowBox[{"Cos", "[", "x", "]"}], 
    RowBox[{
     SuperscriptBox["x", "4"], "+", "4"}]]}]],
  AspectRatioFixed->False],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]], 
    RowBox[{
     SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities of  f[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "g", ",", "Res1", ",", "Res2", ",", "Res3", ",", 
      "Res4", ",", "solset", ",", "val"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     FractionBox[
      RowBox[{"Cos", "[", "x", "]"}], 
      RowBox[{
       SuperscriptBox["x", "4"], " ", "+", " ", "4"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]], 
      RowBox[{
       SuperscriptBox["z", "4"], " ", "+", " ", "4"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "1"], "]"}]}], "]"}], ";"}], " ", " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<  =  \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "2"], "]"}]}], "]"}], ";"}], " ", " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\< =  \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "3"], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<  = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "4"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39946188765625*^9, {3.39946192678125*^9, 3.399461984546875*^9}},
 AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<,  Is  Im(\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "1"], "]"}], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "2"], "]"}], ",", "\"\<,   Is  Im(\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "2"], "]"}], ",", "\"\<) > 0 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "3"], "]"}], ",", "\"\<,   Is  Im(\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "3"], "]"}], ",", "\"\<) > 0 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "4"], "]"}], ",", "\"\<,  Is  Im(\>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       SubscriptBox["Z", "4"], "]"}], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399461994359375*^9, 3.399462105703125*^9}, 
   3.400057946359375*^9, {3.400058046390625*^9, 3.400058057328125*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman"], 
     StyleBox[
      RowBox[{
       StyleBox[" ",
        FontFamily->"Times New Roman"], " "}]], 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 ", \nand then use the residue calculus to compute the value of the integral.\
\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
   3.400312490734375*^9}, {3.400313108703125*^9, 3.400313117296875*^9}, {
   3.400313155375*^9, 3.40031316934375*^9}, {3.4003132215*^9, 
   3.400313230171875*^9}, 3.400313464703125*^9, {3.400313511078125*^9, 
   3.400313517484375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res4", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "4"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{
       RowBox[{"-", " ", "2"}], " ", "\[Pi]", " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"Im", "[", "Res2", "]"}], " ", "+", " ", 
         RowBox[{"Im", "[", "Res4", "]"}]}], " ", ")"}]}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<] = \>\"", ",", "Res4"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<]] = \>\"", ",", 
      RowBox[{"Im", "[", "Res2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Im[Res[f,\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<]] = \>\"", ",", 
      RowBox[{"Im", "[", "Res4", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "4"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", "segment", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = - 2\[Pi](Im[\>\"", ",", "Res2", " ", ",", 
      "\"\<] + Im[\>\"", ",", " ", "Res4", " ", ",", "\"\<])\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = - 2\[Pi](\>\"", ",", 
      RowBox[{"Im", "[", "Res2", "]"}], " ", ",", "\"\< + (\>\"", ",", " ", 
      RowBox[{"Im", "[", "Res4", "]"}], " ", ",", "\"\<))\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = - 2\[Pi](\>\"", ",", 
      RowBox[{
       RowBox[{"Im", "[", "Res2", "]"}], "  ", "+", "  ", 
       RowBox[{"Im", "[", "Res4", "]"}]}], " ", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the semicircle \!\(\*SubscriptBox[\(C\), \(R\)]\) \
and interval [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x \>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<= - 2\[Pi](Im[\>\"", ",", "Res2", " ", ",", "\"\<] + Im[\>\"", ",", 
      " ", "Res4", " ", ",", "\"\<])\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<= \>\"", ",", "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946211725*^9, 3.399462138984375*^9}, {
  3.400058068109375*^9, 3.40005808615625*^9}}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The integral of  F[x] for this problem is  g[x],  but it cannot be used \
in any meaningful way to solve the problem at hand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral] \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      g[\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946214575*^9}],

Cell[TextData[{
 "This looks good, however it ",
 StyleBox["cannot",
  FontColor->RGBColor[1, 0, 1]],
 " be used to solve for the definite integral. This does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " agree with the answer obtained with the residue calculus."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399462150078125*^9},
 AspectRatioFixed->False],

Cell["\<\
However, the definite integral will produce the following result.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", "\n"}]}]], "Input",\

 CellChangeTimes->{3.39946215371875*^9}],

Cell["Which is also the correct answer.", "Text"],

Cell["The PrincipalValue option can also be used.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3994621573125*^9}]
}, Closed]],

Cell[TextData[{
 "\tWe are almost ready to give the proof of Theorem 8.4, but first we need \
one preliminary result known as ",
 StyleBox[ButtonBox["Jordan's",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jordan.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " lemma.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Lemma 8.1, (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Jordan's Lemma",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/JordansLemma.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(z)",
  FontFamily->"Courier New"],
 " are polynomials of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "1"}]}]]],
 ".  If  ",
 Cell[BoxData[
  SubscriptBox["C", "R"]]],
 "  is the upper semicircle ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"R", " ", 
     SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], "  ", "for", 
     "  ", "0"}], " ", "\[LessEqual]", " ", "\[Theta]", " ", "\[LessEqual]", 
    " ", 
    RowBox[{"2", "\[Pi]"}]}]}]]],
 ",  then\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " "}], 
     RowBox[{"R", " ", "\[Rule]", " ", "\[Infinity]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "R"]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]z"], " ", "P", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "z", ")"}]}]], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Lemma 8.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Residue Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy Principal Value",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.\
html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Hilbert Transformation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/HilbertTransBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399461769140625*^9, 3.399461769265625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{988, 627},
WindowMargins->{{13, Automatic}, {Automatic, 0}},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[19645, 550, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[93921, 2727, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 96702, 2825}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 147, 3, 29, "Text"],
Cell[1055, 37, 2215, 76, 109, "Text"],
Cell[3273, 115, 1182, 37, 122, "Text"],
Cell[4458, 154, 4535, 167, 241, "Text",
 Evaluatable->False],
Cell[8996, 323, 10231, 206, 297, "Text"],
Cell[CellGroupData[{
Cell[19252, 533, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[19396, 539, 246, 9, 29, "Text",
 Evaluatable->False],
Cell[19645, 550, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[19994, 562, 161, 3, 26, "Text"],
Cell[20158, 567, 695, 23, 37, "Text",
 Evaluatable->False],
Cell[20856, 592, 2205, 39, 168, "Text",
 Evaluatable->False],
Cell[23064, 633, 3731, 121, 301, "Text"],
Cell[26798, 756, 1792, 55, 203, "Text"],
Cell[CellGroupData[{
Cell[28615, 815, 186, 7, 29, "Text"],
Cell[28804, 824, 649, 25, 42, "Text"],
Cell[29456, 851, 3258, 94, 431, "Input"],
Cell[32717, 947, 103, 2, 29, "Text",
 Evaluatable->False],
Cell[32823, 951, 3948, 107, 172, "Input"],
Cell[36774, 1060, 646, 15, 101, "Text",
 Evaluatable->False],
Cell[37423, 1077, 5458, 151, 478, "Input"],
Cell[42884, 1230, 280, 8, 29, "Text",
 Evaluatable->False],
Cell[43167, 1240, 1934, 54, 248, "Input"],
Cell[45104, 1296, 285, 8, 29, "Text"],
Cell[45392, 1306, 499, 13, 85, "Input"],
Cell[45894, 1321, 89, 2, 29, "Text"],
Cell[45986, 1325, 729, 20, 118, "Input"],
Cell[46718, 1347, 49, 0, 29, "Text"],
Cell[46770, 1349, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[46878, 1353, 739, 20, 105, "Input"]
}, Closed]],
Cell[47632, 1376, 639, 22, 34, "Text",
 Evaluatable->False],
Cell[48274, 1400, 2380, 42, 168, "Text",
 Evaluatable->False],
Cell[50657, 1444, 7715, 233, 517, "Text"],
Cell[58375, 1679, 1899, 55, 166, "Text"],
Cell[60277, 1736, 4234, 127, 248, "Text"],
Cell[CellGroupData[{
Cell[64536, 1867, 186, 7, 29, "Text"],
Cell[64725, 1876, 586, 23, 42, "Text"],
Cell[65314, 1901, 4685, 130, 511, "Input"],
Cell[70002, 2033, 103, 2, 29, "Text",
 Evaluatable->False],
Cell[70108, 2037, 6814, 179, 252, "Input"],
Cell[76925, 2218, 1065, 30, 101, "Text",
 Evaluatable->False],
Cell[77993, 2250, 8644, 232, 713, "Input"],
Cell[86640, 2484, 280, 8, 29, "Text",
 Evaluatable->False],
Cell[86923, 2494, 1930, 54, 248, "Input"],
Cell[88856, 2550, 285, 8, 29, "Text"],
Cell[89144, 2560, 499, 13, 85, "Input"],
Cell[89646, 2575, 89, 2, 29, "Text"],
Cell[89738, 2579, 728, 20, 118, "Input"],
Cell[90469, 2601, 49, 0, 29, "Text"],
Cell[90521, 2603, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[90629, 2607, 740, 20, 105, "Input"]
}, Closed]],
Cell[91384, 2630, 407, 12, 26, "Text",
 Evaluatable->False],
Cell[91794, 2644, 1711, 62, 99, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[93530, 2710, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[93674, 2716, 244, 9, 29, "Text",
 Evaluatable->False],
Cell[93921, 2727, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[94270, 2739, 281, 7, 26, "Text"],
Cell[94554, 2748, 294, 10, 29, "Text"],
Cell[94851, 2760, 299, 10, 29, "Text"],
Cell[95153, 2772, 307, 10, 29, "Text"],
Cell[95463, 2784, 301, 10, 29, "Text"],
Cell[95767, 2796, 249, 5, 29, "Text"],
Cell[96019, 2803, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
