(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    191785,       5611]
NotebookOptionsPosition[    186239,       5437]
NotebookOutlinePosition[    187034,       5470]
CellTagsIndexPosition[    186960,       5465]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.5  Indented Contour Integrals",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIf ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " is continuous on the interval  ",
 Cell[BoxData[
  RowBox[{"b", "<", "x", "\[LessEqual]", "c"}]]],
 ", but discontinuous at ",
 StyleBox["b",
  FontFamily->"Courier New"],
 ", then the improper integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"b", ",", "c"}], "]"}]]],
 " is defined by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "b", "c"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"r", " ", "\[Rule]", " ", 
      SuperscriptBox["b", "+"]}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "r", "c"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]]],
 "\n\nprovided that the limit exists.  Similarly, if ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " is continuous on the interval  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "x", "<", "b"}]]],
 ", but discontinuous at ",
 StyleBox["b",
  FontFamily->"Courier New"],
 ", then the improper integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "b"}], "]"}]]],
 " is defined by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", " ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"r", " ", "\[Rule]", " ", 
      SuperscriptBox["b", "-"]}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "r"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]]],
 "\n\nprovided that the limit exists.  For example,  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "9"], 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", 
       SqrtBox["x"]}]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"r", " ", "\[Rule]", " ", 
       SuperscriptBox["0", "+"]}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "r", "9"], " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", 
         SqrtBox["x"]}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"r", " ", "\[Rule]", " ", 
         SuperscriptBox["0", "+"]}]], 
       SqrtBox["x"]}], 
      UnderoverscriptBox["\[VerticalSeparator]", 
       RowBox[{"x", "=", "r"}], 
       RowBox[{"x", "=", "9"}]]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"3", " ", "-", " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"r", " ", "\[Rule]", " ", 
          SuperscriptBox["0", "+"]}]], 
        SqrtBox["x"]}]}], " ", "=", "  ", "3"}]}]}]}]]],
 ". \n"
}], "Text"],

Cell[TextData[{
 "\tIf we let ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " be continuous for all values of ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " in the interval ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "c"}], "]"}]]],
 ",  except at the value ",
 Cell[BoxData[
  RowBox[{"x", "=", "b"}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"a", "<", "b", "<", "c"}]]],
 ".  The Cauchy principal value of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"a", ",", "c"}], "]"}]]],
 " is defined by\n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "a", "c"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"r", " ", "\[Rule]", " ", 
      SuperscriptBox["0", "+"]}]], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "a", 
        RowBox[{"b", "-", "r"}]], " ", 
       RowBox[{"f", 
        RowBox[{"(", "x", ")"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "+", "  ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"b", "+", "r"}], "c"], " ", 
       RowBox[{"f", 
        RowBox[{"(", "x", ")"}], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", ")"}]}]}]]],
 ",  \n\t\nprovided that the limit exists. "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", ".", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "1"}], "8"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "3"}]]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztmb9vEzEUx93c5Zo2tEl/psmlbYqYoGz8DcDChMQeVUjtgEClEmJokSoE
SPwubfkl+AeQkNiRyN6FDcTKxMTCwkLI8/me7asdvzulrao2Su58X3+e/Z79
7ORyl5ori1evNVeWFpqNC8vNG4tLCzcb568vdySvj7G+L4yxDw0G5XanKA7t
zrvdggMo2ctv4JTjjXqRwltvR9BcWsgTEAIx1NiT7vYPeo1Qjgv2EA+W3IST
z6JYiDjz9XrRleew3TLUS0MvylWJP0HP/GSnUVa7+jP5yhij+5pjDOdY9Ok0
fCXq23qQXW1e4hD6FDLRusujbWw9fwDkVjS3VBKXVWuHHGBmw011lbR2XA6m
xF+oC8ONb+BAkfDniPtkPJ4wN/4M8YCCP0W8n4I/hpNPxh8hXqDgD3FkBin4
AzjlAS9S8PuIn6DgdxEvUfB1OAVK68y9J9xBmxGe/YIU68BlvYrWYzbrXTvz
Ko7wMJDxHp267zU4TWU1rACOW3SKZc+ta5TpOCaPSQIp8i9+cbqEK4OQnVzj
8CiU+LKvoVaHEk/0GVyONdTqqM0YWpbcvOKwl1xznc8AOhzV+lqtZShMC3Xc
5kZCq4sWVM0SxZQZDc3ytKGFqhk94xiUcu+HIjRoJo9rmAl1ejzpQ7+NaSZ+
oClhcnUkWyKbQjcFksLj0JDzszZzUs6P2ybTNEm1VEmYjFWi7jGxNGlxQM3h
HH4nTtpCkzvCtKE0g6UQx1iOdojTK+dCHePDsmF3Jz2MTbm/h1e0DbFbcOLq
KTgMGGa6qnSW6KJi0Ew3iKrGoLHOZ5IfhSZuSev8mE0Le2Qb+1wyxDF1NIdi
yJFE72xxVuH6G6hnj8mjRn4Hdb635EdQr1DIe6CuUchlUDco5GVQP1HIi6B+
ppDnQP1KIU+D+oNCzoH6k0Ly1f6LQk6A+jsi+Z9H1vt5aVMG9U9ks20gu1sX
Qf3rsOYSt6lATQHq/2XocQKuA65GzaZvYlRvIoiakH++BjbDsm5YcEzHMFzn
ES868CG49hEfcuBFHS858EEdLzvwAbj2EB914AUdH3Pg/To+7sADHZ9w4Hkd
n6TgOcQrDtzXcdc3q6fj1d7iOR2v9RZn3BtQ+YfXhHQbrlNspEf1vSZ3PUTy
iJxsbzodJ5915dNYJGIKiLamx135OE4m8egPjxT7ZsLQ8pjLdHuzy9a10ybw
5BRDalkgX4NiZHavkHhhGBH917p6N3jY69/rmSdUXm7tf/ktZjdXTyo+mu6z
Z7tZcdVHdS6bR6zvP1XiMPU=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{447, 171},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Evaluating the integrals and computing limits gives  \n\n\t\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "8"], 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["x", 
         RowBox[{"1", "/", "3"}]]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"r", " ", "\[Rule]", " ", 
       SuperscriptBox["0", "+"]}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "1"}], 
         RowBox[{"-", "r"}]], 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["x", 
           RowBox[{"1", "/", "3"}]]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "+", "  ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "r", "8"], 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["x", 
           RowBox[{"1", "/", "3"}]]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"r", " ", "\[Rule]", " ", 
        SuperscriptBox["0", "+"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"3", " "}], "2"], 
         SuperscriptBox["x", 
          RowBox[{"2", "/", "3"}]]}], 
        UnderoverscriptBox["\[VerticalSeparator]", 
         RowBox[{"x", "=", 
          RowBox[{"-", "1"}]}], 
         RowBox[{"-", "r"}]], "  ", 
        RowBox[{
         RowBox[{"+", "  ", 
          FractionBox[
           RowBox[{"3", " "}], "2"]}], 
         SuperscriptBox["x", 
          RowBox[{"2", "/", "3"}]]}], 
        UnderoverscriptBox["\[VerticalSeparator]", 
         RowBox[{"x", "=", "r"}], "8"]}], " ", ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"r", " ", "\[Rule]", " ", 
        SuperscriptBox["0", "+"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"3", " "}], "2"], 
         SuperscriptBox["r", 
          RowBox[{"2", "/", "3"}]]}], "  ", "-", "  ", 
        FractionBox[
         RowBox[{"3", " "}], "2"], "  ", "+", "  ", "6", "  ", "-", "  ", 
        RowBox[{
         FractionBox[
          RowBox[{"3", " "}], "2"], 
         SuperscriptBox["r", 
          RowBox[{"2", "/", "3"}]]}]}], " ", ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"3", " "}], "2"], 
        SuperscriptBox["0", 
         RowBox[{"2", "/", "3"}]]}], "  ", "-", "  ", 
       FractionBox[
        RowBox[{"3", " "}], "2"], "  ", "+", "  ", "6", "  ", "-", "  ", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " "}], "2"], 
        SuperscriptBox["0", 
         RowBox[{"2", "/", "3"}]]}]}], " ", ")"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"3", " "}], "2"]}], "  ", "+", "  ", "6"}], " ", ")"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                ", 
   RowBox[{"=", "  ", 
    FractionBox["9", "2"]}]}]}]],
 "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "We must guide ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and write an appropriate form of the anti-derivative."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "3"}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     RowBox[{
      FractionBox["3", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["x", "2"], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F'[x] = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "'"}], "[", "x", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"PowerExpand", "[", 
       RowBox[{
        RowBox[{"F", "'"}], "[", "x", "]"}], "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946255578125*^9}],

Cell[TextData[{
 "The integrand is discontinuous at x = 0 where it has a singularity.  \
Indeed, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a branch cut for  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "3"}]]}]]],
 "  along the negative x-axis and maps these points onto the ray ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", "[", "w", "]"}], "=", 
   FractionBox["\[Pi]", "3"]}]]],
 ".  Hence the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "=", 
   FractionBox["1", 
    SuperscriptBox["x", 
     RowBox[{"1", "/", "3"}]]]}]]],
 "  does not have the graph as taught in elementary calculus.  We must use \
the following function  h[x]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"x_", "/;", " ", 
       RowBox[{"x", ">", "0"}]}], "]"}], ":=", 
     FractionBox["1", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "3"}]]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"x_", "/;", " ", 
       RowBox[{"x", "<", "0"}]}], "]"}], ":=", 
     FractionBox[
      RowBox[{"-", "1"}], 
      SuperscriptBox[
       RowBox[{"Abs", "[", "x", "]"}], 
       RowBox[{"1", "/", "3"}]]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g11", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"h", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.001"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"h", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.001", ",", "8"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "Blue"}], "}"}]}]}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.15"}]}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Pink", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.16", ",", "8"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Cyan", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "8"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Blue", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", "g3", ",", "g11", ",", "g22", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.15"}], ",", "\"\<-r  \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.16", ",", "\"\< r\>\""}], "}"}], ",", "1", ",", "2", 
          ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}], "}"}],
         ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", 
      FractionBox["1", "2"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<        s = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946256125*^9, 3.399462566109375*^9}, {3.3994625995*^9,
   3.399462612875*^9}, {3.399462648*^9, 3.399462650640625*^9}, {
  3.39946272396875*^9, 3.3994627373125*^9}, {3.400058202296875*^9, 
  3.400058202625*^9}, {3.4000582533125*^9, 3.40005825525*^9}, {
  3.4000583111875*^9, 3.40005841021875*^9}, {3.400058575984375*^9, 
  3.400058579625*^9}, {3.400314160046875*^9, 3.400314169546875*^9}}],

Cell["Now we pursue the Cauchy principal value of the integral.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<\[DifferentialD]x  =  \!\(\*UnderscriptBox[\(lim\), \(r \[Rule] \
0\)]\) ( \!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(-r\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x  +  \!\(\*SubsuperscriptBox[\(\[Integral]\), \(r\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x )\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<\[DifferentialD]x  =  \!\(\*UnderscriptBox[\(lim\), \(r \[Rule] \
0\)]\) ((\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "r"}]], ",", "\"\< + (\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\<)\>\"", ",", 
      UnderoverscriptBox["\"\<|\>\"", "r", "8"], ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<\[DifferentialD]x  =  \!\(\*UnderscriptBox[\(lim\), \(r \[Rule] \
0\)]\) ((\>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"-", "r"}], "]"}], "-", " ", 
       RowBox[{"F", "[", 
        RowBox[{"-", "1"}], "]"}]}], ",", "\"\<) + (\>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", "8", "]"}], "-", " ", 
       RowBox[{"F", "[", "r", "]"}]}], ",", "\"\<))\>\""}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\<\[DifferentialD]x  =  \!\(\*UnderscriptBox[\(lim\), \(r \[Rule] \
0\)]\) (\>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"-", "r"}], "]"}], "-", " ", 
       RowBox[{"F", "[", 
        RowBox[{"-", "1"}], "]"}], "+", 
       RowBox[{"F", "[", "8", "]"}], "-", " ", 
       RowBox[{"F", "[", "r", "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", "\"\<\[DifferentialD]x  =  \>\"", 
      ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"F", "[", 
          RowBox[{"-", "r"}], "]"}], "-", " ", 
         RowBox[{"F", "[", 
          RowBox[{"-", "1"}], "]"}], "+", 
         RowBox[{"F", "[", "8", "]"}], "-", " ", 
         RowBox[{"F", "[", "r", "]"}]}], ",", 
        RowBox[{"r", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946275859375*^9}],

Cell[TextData[{
 StyleBox["Warning.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The following computations will not produce the principal value of the \
real integral.  Indeed, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a branch cut for  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"g", "[", "z", "]"}], "=", 
    FractionBox[
     RowBox[{"3", " ", 
      SuperscriptBox["z", 
       RowBox[{"2", "/", "3"}]]}], "2"]}]}]]],
 "  along the negative x-axis and maps these points onto the ray ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", "[", "w", "]"}], "=", 
   FractionBox[
    RowBox[{"2", " ", "\[Pi]"}], "3"]}]]],
 ",  in particular ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"-", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["3", "4"]}], "+", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SqrtBox["3"]}], "4"]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "8"}], "1"], 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[8] = \>\"", ",", 
      RowBox[{"g", "[", "8", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[-1] = \>\"", ",", " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"g", "[", 
        RowBox[{"-", "8"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The following answers are suspect because\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<the branch cuts occur on the negative x-axis.\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = g[8]-g[-1] = (\>\"", ",", 
      RowBox[{"g", "[", "8", "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"g", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{
       RowBox[{"g", "[", "8", "]"}], " ", "-", " ", 
       RowBox[{"g", "[", 
        RowBox[{"-", "1"}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{
       RowBox[{"g", "[", "8", "]"}], " ", "-", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"g", "[", 
         RowBox[{"-", "1"}], "]"}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946276971875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Correction.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The following choice for the form for the indefinite integral will produce \
the desired computation."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], "=", 
     FractionBox["1", 
      SuperscriptBox["x", 
       RowBox[{"1", "/", "3"}]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     RowBox[{
      FractionBox["3", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["x", "2"], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[8] = \>\"", ",", 
      RowBox[{"F", "[", "8", "]"}], ",", "\"\<,     F[-1] = \>\"", ",", " ", 
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"F", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "8"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "6"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "8", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "6", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      s = F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", 
      "\"\< \[DifferentialD]x = F[8]-F[-1] = (\>\"", ",", 
      RowBox[{"F", "[", "8", "]"}], " ", ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \(8\)]\)\>\"", ",",
       
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{
       RowBox[{"F", "[", "8", "]"}], " ", "-", " ", 
       RowBox[{"F", "[", 
        RowBox[{"-", "1"}], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994627783125*^9, 3.399462781328125*^9}, {
  3.400058595109375*^9, 3.400058610546875*^9}}],

Cell["Which is also the correct answer.", "Text"],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The PrincipalValue option does ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " give and answer to this problem."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     RowBox[{
      FractionBox["3", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["x", "2"], ")"}], 
       RowBox[{"1", "/", "3"}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399462796265625*^9, 3.399462816875*^9}}],

Cell[TextData[{
 "We are done.\n",
 "\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Observe that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "8"], 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["x", 
        RowBox[{"1", "/", "3"}]]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"P", ".", "V", ".", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "1"}], "1"], 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["x", 
          RowBox[{"1", "/", "3"}]]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "+", "   ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "1", "8"], 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["x", 
         RowBox[{"1", "/", "3"}]]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{"0", "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "1", "8"], 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["x", 
         RowBox[{"1", "/", "3"}]]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g11", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"h", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.01"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "Red"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g22", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"h", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.01", ",", "8"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.0075", "]"}], ",", "Blue"}], "}"}]}]}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "0.001"}]}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Pink", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.001", ",", "8"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Cyan", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h", "[", "x", "]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "8"}], "}"}], ",", " ", 
       RowBox[{"Filling", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "2", "}"}], ",", 
            RowBox[{"{", "Blue", "}"}]}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", "g11", ",", "g22", ",", "g3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.15"}], ",", "\"\<-r  \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.16", ",", "\"\< r\>\""}], "}"}], ",", "1", ",", "2", 
          ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}], "}"}],
         ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", " ", 
      FractionBox["1", "2"]}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \>\"", ",", 
      "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x = P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(1\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x + \!\(\*SubsuperscriptBox[\(\[Integral]\), \(1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \>\"", ",", 
      "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x =  0 + \!\(\*SubsuperscriptBox[\(\[Integral]\), \(1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       \>\"", ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x =  \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "1", "8"], 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["x", 
          RowBox[{"1", "/", "3"}]]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \>\"", ",", 
      "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(8\)]\)\!\(\*FractionBox[\(1\), SuperscriptBox[\(x\), \(1/3\)]]\)\
\[DifferentialD]x =  \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "1", "8"], 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["x", 
          RowBox[{"1", "/", "3"}]]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994628265625*^9, 3.39946288675*^9}, {
  3.39946292028125*^9, 3.3994629324375*^9}, {3.40005820921875*^9, 
  3.400058209484375*^9}, {3.40005844959375*^9, 3.40005850315625*^9}, {
  3.40005861740625*^9, 3.4000586239375*^9}, {3.400314175109375*^9, 
  3.4003141814375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tIn this section we show how to use residues to evaluate the Cauchy \
principal value of the integral of ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " over ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], ")"}]]],
 " when the integrand ",
 StyleBox["f(x)",
  FontFamily->"Courier New"],
 " has simple poles on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis.  We state our main results and then look at some examples before \
giving proofs."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 " where ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " are polynomials with real coefficients of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, and  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "2"}]}]]],
 ".  If ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " has simple zeros at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "L"]}]]],
 " on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 "-axis, then  \n\n",
 StyleBox["(8-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "k"], 
      RowBox[{"Res", "[", 
       RowBox[{
        FractionBox["P", "Q"], ",", 
        SubscriptBox["z", "j"]}], "]"}]}]}], "  ", "+", "  ", 
    RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "L"], 
      RowBox[{"Res", "[", 
       RowBox[{
        FractionBox["P", "Q"], ",", 
        SubscriptBox["t", "j"]}], "]"}]}]}]}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 " are the poles of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie in the upper half-plane.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.5",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{529, 297},
  ImageMargins->0],
 StyleBox["  \n\n\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.6",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/integralsindentedcontour/\
IntegralsIndentedContourFigures/mat0806.gif"], None}],
  FontWeight->"Bold"],
 "  The poles ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "L"]}]]],
 " of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " that lie on the x-axis and the poles ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 " that lie above the semicircles ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["C", "L"]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39946423115625*^9, 3.39946428934375*^9}}],

Cell[TextData[{
 StyleBox["Theorem 8.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " be polynomials, of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "1"}]}]]],
 " and let ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " have simple zeros at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "L"]}]]],
 "  on the x-axis.  If ",
 Cell[BoxData["\[Alpha]"]],
 " is a positive real number and if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "z"}]], " ", "P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ", then we can compute the Cauchy Principal Value (P.V.) of the following \
integrals \n\n",
 StyleBox["(8-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], "cos", " ", "\[Alpha]", " ", "x", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "2"}], "\[Pi]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "k"], 
      RowBox[{"Im", 
       RowBox[{"(", 
        RowBox[{"Res", "[", 
         RowBox[{"f", ",", 
          SubscriptBox["z", "j"]}], "]"}], ")"}]}]}]}], "  ", "-", "  ", 
    RowBox[{"\[Pi]", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "L"], 
      RowBox[{"Im", 
       RowBox[{"(", 
        RowBox[{"Res", "[", 
         RowBox[{"f", ",", 
          SubscriptBox["t", "j"]}], "]"}], ")"}]}]}]}]}]}]]],
 ",  \n\t\n\t\tand  \n\t\n",
 StyleBox["(8-22)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], "sin", " ", "\[Alpha]", " ", "x", " ", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"2", "\[Pi]", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "k"], 
      RowBox[{"Re", 
       RowBox[{"(", 
        RowBox[{"Res", "[", 
         RowBox[{"f", ",", 
          SubscriptBox["z", "j"]}], "]"}], ")"}]}]}]}], "  ", "+", "  ", 
    RowBox[{"\[Pi]", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "L"], 
      RowBox[{"Re", 
       RowBox[{"(", 
        RowBox[{"Res", "[", 
         RowBox[{"f", ",", 
          SubscriptBox["t", "j"]}], "]"}], ")"}]}]}]}]}]}]]],
 ",    \n\nwhere ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 " are the poles of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie in the upper half plane.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.6",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " The formulas in these theorems give the Cauchy principal value of the \
integral, which pays special attention to the manner in which any limits are \
taken.  They are similar to those in Sections 8.3 and 8.4, except here we add \
one-half of the value of each residue at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["t", "r"]}]]],
 " on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 "-axis."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", "."}]]],
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{
    FractionBox["x", 
     RowBox[{
      SuperscriptBox["x", "3"], "-", "8"}]], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]]],
 "  by using complex analysis.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399462979359375*^9, 3.39946298834375*^9}},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{539, 165},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The integrand  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{"Q", 
       RowBox[{"(", "z", ")"}]}]], "  ", "=", "  ", 
     FractionBox["z", 
      RowBox[{
       SuperscriptBox["z", "3"], "-", "8"}]]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    FractionBox["z", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", 
        RowBox[{"2", " ", "z"}], "+", "4"}], 
       ")"}]}]]}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    FractionBox["z", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}]}]]}]}]}]],
 "  \n\nhas simple poles at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "=", "2"}]]],
 "  on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     SqrtBox["3"]}]}]}]]],
 "  in the upper half-plane.  Computing the residues we get\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "2"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "2"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], 
       FractionBox["z", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "+", 
           RowBox[{"2", " ", "z"}], "+", "4"}], ")"}]}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", "2"}]], " ", 
       FractionBox["z", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", 
          RowBox[{"2", " ", "z"}], "+", "4"}], ")"}]]}], "  ", "=", "  ", 
      RowBox[{
       FractionBox["2", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["2", "2"], "+", 
          RowBox[{"2", "\[Cross]", "2"}], "+", "4"}], ")"}]], "  ", "=", "  ",
        
       FractionBox["2", 
        RowBox[{"(", 
         RowBox[{"4", "+", "4", "+", "4"}], ")"}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    FractionBox["1", "6"]}]}]}]],
 "  \n\t\t\t\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["3"]}]}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1", "-", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1", "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], ")"}], 
       FractionBox["z", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "+", "1", "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "+", "1", "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}]}]], " ", 
      FractionBox["z", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "+", "1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}], "-", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}], "+", "1", "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}]}]], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SqrtBox["3"]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          SqrtBox["3"]}], ")"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}], 
       RowBox[{
        RowBox[{"-", "6"}], "-", 
        RowBox[{"6", " ", "\[ImaginaryI]", " ", 
         SqrtBox["3"]}]}]], "  ", "=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], "+", 
           RowBox[{"6", " ", "\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], "-", 
           RowBox[{"6", " ", "\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], "+", 
           RowBox[{"6", " ", "\[ImaginaryI]", " ", 
            SqrtBox["3"]}]}], ")"}]}]], "  ", "=", "  ", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "12"}], "-", 
         RowBox[{"12", " ", "\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], "144"]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["3"]}]}], "12"]}]}]}]]
}], "Text"],

Cell[TextData[{
 "By Theorem 8.5,  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      FractionBox["x", 
       RowBox[{
        SuperscriptBox["x", "3"], "-", "8"}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Res", "[", 
       RowBox[{
        FractionBox["P", "Q"], ",", 
        SubscriptBox["z", "1"]}], "]"}]}], " ", "+", " ", 
     RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Res", "[", 
       RowBox[{
        FractionBox["P", "Q"], ",", 
        SubscriptBox["t", "1"]}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "-", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], "12"], ")"}]}], " ", "+", " ", 
     RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       FractionBox["1", "6"], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "-", " ", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["3"]}]}], "6"], ")"}]}], " ", "+", " ", 
     RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       FractionBox["1", "6"], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    RowBox[{"\[Pi]", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], " ", 
        SqrtBox["3"]}], "6"], ")"}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                     ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[Pi]", 
      SqrtBox["3"]}], "6"]}]}]}]],
 "    "
}], "Text",
 CellChangeTimes->{{3.399462997953125*^9, 3.39946305615625*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["z", 
    RowBox[{
     SuperscriptBox["z", "3"], " ", "-", " ", "8"}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "solset", ",", "val"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["z", 
      RowBox[{
       SuperscriptBox["z", "3"], " ", "-", " ", "8"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"z", ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"z", ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399463066421875*^9},
 AspectRatioFixed->False],

Cell["\<\
Which poles lie in the upper half plane ?  Which poles lie on the real axis ?\
\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{" ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,         Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?         \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<,         Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) = 0 ?         \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) = 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) = 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946245690625*^9, 3.399462457171875*^9}, 
   3.399463071171875*^9, 3.400058218765625*^9, {3.4000587534375*^9, 
   3.40005876453125*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     SubscriptBox["z", "3"]}], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox["3"]}]}]}]}]]],
 ",  \nand use the residue calculus to compute the value of the integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
  3.400312490734375*^9}, {3.4003143224375*^9, 3.400314349984375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res3", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "3"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", "  ", "Res3"}], "+", 
      RowBox[{"\[Pi]", " ", "\[ImaginaryI]", "  ", "Res1"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", "Res3"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "Res3", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "3"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               SubscriptBox["Z", "1"], "]"}], ",", 
              RowBox[{"Im", "[", 
               SubscriptBox["Z", "1"], "]"}]}], "}"}], ",", "0.2", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"centers", ",", "contour", ",", "segment", ",", "dots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{"ComplexExpand", "[", "Res3", "]"}], " ", ",", 
      "\"\<) + \[Pi]\[ImaginaryI](\>\"", ",", " ", "Res1", " ", ",", 
      "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = \[Pi]\[ImaginaryI](\>\"", ",", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"ComplexExpand", "[", "Res3", "]"}]}], " ", "+", " ", 
       "Res1"}], " ", ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The indented contour is the semicircle \!\(\*SubscriptBox[\(C\), \
\(R\)]\) portions of [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<and a little indent semicircle around the pole on the x-axis,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", "val", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946246225*^9, 3.39946246246875*^9}, {3.39946308925*^9,
   3.399463123390625*^9}, {3.400058224875*^9, 3.400058225109375*^9}, {
  3.4000586825625*^9, 3.4000586978125*^9}, {3.400058733046875*^9, 
  3.400058735328125*^9}}],

Cell["Which is also the correct answer.", "Text"],

Cell["The PrincipalValue option can also be used.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], "=", 
     FractionBox["x", 
      RowBox[{
       SuperscriptBox["x", "3"], "-", "8"}]]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"int", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"F", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "int"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399462376921875*^9, 3.399462378734375*^9}, {
   3.399462495625*^9, 3.39946250046875*^9}, 3.399463131328125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Evaluate  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", "."}]]],
 Cell[BoxData[
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox["t", 
     RowBox[{
      SuperscriptBox["t", "3"], "-", "8"}]], 
    RowBox[{"\[DifferentialD]", "t"}]}]}]]],
 "  by using a computer algebra system.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399463169453125*^9, 3.3994631818125*^9}},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzVmslPFEEUxouehU32VTEyLC6AhhhMPIiJF+QiCRcPHoyZECIkKggIuKAJ
HkFP3owxmujJgwcPxoQY4wZEZVHc4r7/F+NUVc+bnuaroWvomQkNdHXe+73v
1dLddHVXR3Cop/t4cKi3KxhoHwj29/R2DQb29w2ETZ4MxjKGGWO3Aowfh8KH
5i4U/g2N8B23uH+8yAuDp7opDTO88HCDn1w+OroqoVlRCEoc8T+vzcY3r+mx
cuEtF4RnmraQrJ74G5cBz3nh47BHGHwxOSKlH4jmJJBoeXV9tqwWF8yarZd1
GnRcdpyUxupTztCAokCDvOv0ZJcAXpAeiRwOZ1FDstT4Xz31KV546WQsZNHz
MrL5gS1TL4tmpZKLn5dNDts6VGeLzVaol0AU2dzehq/AEj29CdLbC64tTbEr
JLZr9WLXSKyRH4kLvFhP4jYv/Ny+Ry/wDg3jbr3AuxTYohd4jwKb9QLv88Lg
9h16gQ944aH+RYFC9qLEp8iwzQn+kAxbnOCPyFDvBH9Mhlon+FPQC9VOAp+R
wRE+DfJsdBI4AwKrnATOkgHhfrts+McMfAEyVupJvAQSFXoSr4BEuZ7EHJAo
S7nEPJAo1ZNYABLolhlHYhFIoFtmciVeA4milEu8ARLof21yJZaABHpGiyPx
Fkjkp1ziHZDIS7nEeyCBHryTK/EBSKB5mpwMeWO4EN269VR8sSpmhcZdl/oI
pNDUMLVS53gRnUmIeUoTPxJPhdFJWI0LKWuBbhPIX2epmk3eYw681RbetptZ
rWbTBacG1aA1aBIarzX1mjnRw52iOfLRi42BCGPtdkCD8+aYHTBMJ4dXM1dt
wpHp6JlGTT5gvUCWdZ5Lp0gAdEQW4Ny/Rpy2yHqZGDTWBjXWZqvTalAsZwBb
QCsv++Ry+gt6sl7AedSyn4ELvT5Ks2w39TKLfdUlZxlslBfdET+L+vOBzQNs
R/jOXkO+ycmUfC1lq/xOYGsAlUevbZ02HE3mUV70AFaWuqojW53DvDkrjO0X
l+sl+4N9BS5f6mTRYKNbwpqU/Ranz1Igi26j6D3e2FqU/Q5cnjUou/xpgf/k
Al4+/7AfwGWkXepn5KS1uISDMdhXOStJZUKpSE3yQfhZSf0ShT/GZQmNE/k7
cm4ySxQLFagj/vBCeAoBdEZC6MsP0nQPR5U5nS68COCjruHFAB9R4yUAH1bj
pQA/pcbLAD6kxssBPugaXgHwATVeCfCTanw9wPvV+AaA96nxKoCfUOPi04j4
eBEH2kTQMTWEZoG9aryGNONAdQQdVUObCepWQ1v5XtyfgmqoiaDDaqiZoENq
qIWgg2pIfNcU9/1ONdRKSgfU0D6+F7f9NjXUzvfiY26rhKKLadA3jk7C5WfU
FZbaoOmD6KA8LiE/QCZjIc6kdLq76MYqmpwFNmaGZC2mmbQMWYILZ0wJpytc
VsJFnksWKLrkBSs94cVq1qtMqi+FZLnmgAsN2XWJz+Pzy1zatmALdOaapwvh
hjQI2QSX24nHOpHmsjT8A42ZULDC4LUMu252lvEfDJe/1A==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{374, 165},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Computer algebra systems such as Mathematica or MAPLE give the \
indefinite integral   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["t", 
      RowBox[{
       SuperscriptBox["t", "3"], "-", "8"}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"Arctan", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "t"}], 
         SqrtBox["3"]], ")"}]}], 
      RowBox[{"2", " ", 
       SqrtBox["3"]}]], " ", "+", " ", 
     FractionBox[
      RowBox[{"Log", 
       RowBox[{"(", 
        RowBox[{"t", "-", "2"}], ")"}]}], "6"], "  ", "-", " ", 
     FractionBox[
      RowBox[{"Log", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["t", "2"], "+", 
         RowBox[{"2", " ", "t"}], "+", "4"}], ")"}]}], "12"]}], "   ", "=", 
    "  ", 
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ".  \n\nHowever, for real numbers, we should write the second term as  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"Log", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"t", "-", "2"}], ")"}], "2"], "]"}], "12"]]],
 "  and use the equivalent formula:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", 
       RowBox[{"(", "t", ")"}]}], "  ", "=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{"Arctan", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "+", "t"}], 
           SqrtBox["3"]], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], " ", "+", " ", 
       FractionBox[
        RowBox[{"Log", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"t", "-", "2"}], ")"}], "2"], "]"}], "12"], "  ", "-", " ",
        
       FractionBox[
        RowBox[{"Log", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["t", "2"], "+", 
           RowBox[{"2", " ", "t"}], "+", "4"}], ")"}]}], "12"]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "             ", 
    RowBox[{
     RowBox[{"=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{"Arctan", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "+", "t"}], 
           SqrtBox["3"]], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], " ", "+", " ", 
       FractionBox[
        RowBox[{"Log", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"t", "-", "2"}], ")"}], "2"], "]"}], "12"], "  ", "-", " ",
        
       FractionBox[
        RowBox[{"Log", "[", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"t", "+", "2"}], ")"}], "2"], "]"}], "12"]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "            ", 
    RowBox[{
     RowBox[{"=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{"Arctan", 
         RowBox[{"(", 
          FractionBox[
           RowBox[{"1", "+", "t"}], 
           SqrtBox["3"]], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], "   ", "+", "  ", 
       RowBox[{
        FractionBox["1", "12"], "  ", 
        RowBox[{"Log", "[", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"t", "-", "2"}], ")"}], "2"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"t", "+", "2"}], ")"}], "2"]], "]"}]}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "            ", 
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"Arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", "t"}], 
          SqrtBox["3"]], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]], "   ", "+", "  ", 
      RowBox[{
       FractionBox["1", "12"], "  ", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"t", "-", "2"}], 
           RowBox[{"t", "+", "2"}]], ")"}], "2"], "]"}]}]}]}]}]}]]],
 "    \n"
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{371, 260},
  ImageMargins->0],
 StyleBox["  \n\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/integralsindentedcontour/\
IntegralsIndentedContourFigures/mat0805.gif"], None}],
  FontWeight->"Bold"],
 "  Graph of  ",
 Cell[BoxData[
  RowBox[{"s", " ", "=", " ", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{"\[Integral]", 
     RowBox[{
      FractionBox["t", 
       RowBox[{
        SuperscriptBox["t", "3"], "-", "8"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39946432178125*^9, 3.39946432290625*^9}, {
  3.399464353375*^9, 3.39946436040625*^9}}],

Cell[TextData[{
 "\tThis antiderivative has the property that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"t", "\[Rule]", "2"}]], " ", 
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
   RowBox[{"-", "\[Infinity]"}]}]]],
 ",  as shown in Figure 8.5.  We also compute  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"t", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"t", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"Arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", "t"}], 
          SqrtBox["3"]], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]], "   ", "+", "  ", 
      RowBox[{
       FractionBox["1", "12"], "  ", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"t", "-", "2"}], 
           RowBox[{"t", "+", "2"}]], ")"}], "2"], "]"}]}]}], 
     ")"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["lim", 
       RowBox[{"t", "\[Rule]", "\[Infinity]"}]], "  ", 
      FractionBox[
       RowBox[{"Arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", "t"}], 
          SqrtBox["3"]], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]]}], " ", "+", 
     RowBox[{
      SubscriptBox["lim", 
       RowBox[{"t", "\[Rule]", "\[Infinity]"}]], " ", 
      RowBox[{
       FractionBox["1", "12"], "  ", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["4", 
            RowBox[{"t", "+", "2"}]]}], ")"}], "2"], 
        "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      FractionBox["\[Pi]", "2"], 
      RowBox[{"2", " ", 
       SqrtBox["3"]}]], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "12"], "  ", 
      RowBox[{"Log", "[", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "0"}], ")"}], "2"], "]"}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[Pi]", 
      SqrtBox["3"]}], 
     RowBox[{"12", " "}]]}]}]}]],
 "  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"-", "\[Infinity]"}]}]], " ", 
    RowBox[{"g", 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"-", "\[Infinity]"}]}]], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"Arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", "t"}], 
          SqrtBox["3"]], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]], "   ", "+", "  ", 
      RowBox[{
       FractionBox["1", "12"], "  ", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"t", "-", "2"}], 
           RowBox[{"t", "+", "2"}]], ")"}], "2"], "]"}]}]}], 
     ")"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["lim", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"-", "\[Infinity]"}]}]], "  ", 
      FractionBox[
       RowBox[{"Arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "+", "t"}], 
          SqrtBox["3"]], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]]}], "   ", "+", 
     RowBox[{
      SubscriptBox["lim", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"-", "\[Infinity]"}]}]], "  ", 
      RowBox[{
       FractionBox["1", "12"], "  ", 
       RowBox[{"Log", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["4", 
            RowBox[{"t", "+", "2"}]]}], ")"}], "2"], 
        "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], 
      RowBox[{"2", " ", 
       SqrtBox["3"]}]], " ", "+", " ", 
     RowBox[{
      FractionBox["1", "12"], "  ", 
      RowBox[{"Log", "[", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "0"}], ")"}], "2"], "]"}]}]}]}], 
   "  "}], "\[IndentingNewLine]", 
  RowBox[{"                             ", 
   RowBox[{"=", "  ", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Pi]", 
       SqrtBox["3"]}], 
      RowBox[{"12", " "}]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "The Cauchy principal limit at  ",
 Cell[BoxData[
  RowBox[{"t", "=", "2"}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{"r", "\[Rule]", "0"}]]],
 "  is  \n\n",
 Cell[BoxData[
  RowBox[{"\t\t", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"r", "\[Rule]", 
         SuperscriptBox["0", "+"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"g", 
          RowBox[{"(", 
           RowBox[{"2", "+", "r"}], ")"}]}], "-", 
         RowBox[{"g", 
          RowBox[{"(", 
           RowBox[{"2", "-", "r"}], ")"}]}]}], ")"}]}], " ", "=", " ", 
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"r", "\[Rule]", 
         SuperscriptBox["0", "+"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"ArcTan", 
           FractionBox[
            RowBox[{"3", "+", "r"}], 
            SqrtBox["3"]]}], 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]], "+", 
         FractionBox[
          RowBox[{"Log", 
           FractionBox[
            SuperscriptBox["r", "2"], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"4", "+", "r"}], ")"}], "2"]]}], "12"], " ", "-", 
         FractionBox[
          RowBox[{"ArcTan", 
           FractionBox[
            RowBox[{"3", "-", "r"}], 
            SqrtBox["3"]]}], 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]], "-", 
         FractionBox[
          RowBox[{"Log", 
           FractionBox[
            SuperscriptBox["r", "2"], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"4", "-", "r"}], ")"}], "2"]]}], "12"]}], ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    "                                                                         \
      ", 
    RowBox[{
     RowBox[{"=", " ", 
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"r", "\[Rule]", 
         SuperscriptBox["0", "+"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"ArcTan", 
           FractionBox[
            RowBox[{"3", "+", "r"}], 
            SqrtBox["3"]]}], 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]], "-", 
         FractionBox[
          RowBox[{"ArcTan", 
           FractionBox[
            RowBox[{"3", "-", "r"}], 
            SqrtBox["3"]]}], 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]], "+", 
         RowBox[{
          FractionBox["1", "12"], " ", "Log", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"4", "-", "r"}], ")"}], "2"], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"4", "+", "r"}], ")"}], "2"]]}]}], ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    "                                                                         \
      ", 
    RowBox[{
     RowBox[{"=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{"ArcTan", 
         FractionBox["3", 
          SqrtBox["3"]]}], 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], "-", 
       FractionBox[
        RowBox[{"ArcTan", 
         FractionBox["3", 
          SqrtBox["3"]]}], 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]], "+", 
       RowBox[{
        FractionBox["1", "12"], " ", "Log", " ", "1"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    "                                                                         \
      ", 
    RowBox[{"=", "  ", "0"}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Therefore the Cauchy principal value of the improper integral is  \n\n\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["t", 
        RowBox[{
         SuperscriptBox["t", "3"], "-", "8"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "   ", "=", "   ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"r", " ", "\[Rule]", " ", 
       SuperscriptBox["0", "+"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "\[Infinity]"}], 
         RowBox[{"2", "-", "r"}]], " ", 
        RowBox[{
         FractionBox["t", 
          RowBox[{
           SuperscriptBox["t", "3"], "-", "8"}]], 
         RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "+", "  ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"2", "+", "r"}], "\[Infinity]"], " ", 
        RowBox[{
         FractionBox["t", 
          RowBox[{
           SuperscriptBox["t", "3"], "-", "8"}]], 
         RowBox[{"\[DifferentialD]", "t"}]}]}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"t", "\[Rule]", "\[Infinity]"}]], " ", 
       RowBox[{"g", 
        RowBox[{"(", "t", ")"}]}]}], " ", "-", " ", 
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"r", "\[Rule]", 
         SuperscriptBox["0", "+"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"g", 
          RowBox[{"(", 
           RowBox[{"2", "+", "r"}], ")"}]}], "-", 
         RowBox[{"g", 
          RowBox[{"(", 
           RowBox[{"2", "-", "r"}], ")"}]}]}], ")"}]}], " ", "-", " ", 
      RowBox[{
       SubscriptBox["lim", 
        RowBox[{"t", "\[Rule]", 
         RowBox[{"-", "\[Infinity]"}]}]], " ", 
       RowBox[{"g", 
        RowBox[{"(", "t", ")"}]}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", 
        SqrtBox["3"]}], 
       RowBox[{"12", " "}]], " ", "-", " ", "0", " ", "-", " ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "\[Pi]"}], 
        SqrtBox["3"]}], 
       RowBox[{"12", " "}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                 ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{"\[Pi]", 
      SqrtBox["3"]}], 
     RowBox[{"6", " "}]]}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox["z", 
    RowBox[{
     SuperscriptBox["z", "3"], " ", "-", " ", "8"}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "solset", ",", "val"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox["z", 
      RowBox[{
       SuperscriptBox["z", "3"], " ", "-", " ", "8"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399463204640625*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Warning.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 "  The indefinite integral of f[x] is g[x], but it ",
 StyleBox["cannot",
  FontColor->RGBColor[1, 0, 1]],
 " be used in any meaningful way to solve the problem at hand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "\[Infinity]"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\<\[DifferentialD]x = \>\"", ",", 
      
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< g[\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \
\[Infinity]\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< g[\[Infinity]] = \>\"", ",", "lim1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[-\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \(-\
\[Infinity]\)\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[-\[Infinity]] = \>\"", ",", "lim2"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<    The following answer is suspect\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<because of singularities on the real axis.\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]] - g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"lim1", "-", "lim2"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]] - g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"lim1", "-", "lim2"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]] - g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"lim1", "-", "lim2"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399463211328125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Warning.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 " The following computation will ",
 StyleBox["not",
  FontColor->RGBColor[1, 0, 1]],
 " produce the correct answer."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<    The following answer is suspect\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<because of singularities on the real axis.\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946323209375*^9}],

Cell[TextData[{
 "\n",
 StyleBox["Correction.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The indefinite integral of g[x] can be written in an algebraic form that \
will produce the correct answer for real functions."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\<\[DifferentialD]x = \>\"", ",", 
      
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"ArcTan", "[", 
        FractionBox[
         RowBox[{"1", "+", "x"}], 
         SqrtBox["3"]], "]"}], 
       RowBox[{"2", " ", 
        SqrtBox["3"]}]], "+", 
      RowBox[{
       FractionBox["1", "12"], " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "x"}], ")"}], "2"], 
         RowBox[{"4", "+", 
          RowBox[{"2", " ", "x"}], "+", 
          SuperscriptBox["x", "2"]}]], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", " ", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", "\[Infinity]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"Limit", "[", 
      RowBox[{
       RowBox[{"g", "[", "x", "]"}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", "\[Infinity]"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The following version of g[x] will produce the correct result.\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\<\[DifferentialD]x = \>\"", ",", 
      
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< g[\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \
\[Infinity]\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< g[\[Infinity]] = \>\"", ",", "lim1"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<g[-\[Infinity]] =  \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] \(-\
\[Infinity]\)\)]\) (\>\"", ",", 
      RowBox[{"g", "[", "x", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[-\[Infinity]] = \>\"", ",", "lim2"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"g", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Magenta"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "20", ",", "10"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "\[Pi]"}], 
           RowBox[{"4", " ", 
            SqrtBox["3"]}]], ",", 
          FractionBox["\[Pi]", 
           RowBox[{"4", " ", 
            SqrtBox["3"]}]], ",", 
          FractionBox["\[Pi]", 
           RowBox[{"4", " ", 
            SqrtBox["3"]}]]}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[x] = \>\"", ",", 
     RowBox[{"g", "[", "x", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = (\>\"", 
      ",", "lim1", ",", "\"\<) - (\>\"", ",", "lim2", ",", "\"\<)\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"lim1", "-", "lim2"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"N", "[", 
       RowBox[{"lim1", "-", "lim2"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946325309375*^9, 3.39946325771875*^9}, {
  3.400058230625*^9, 3.4000582309375*^9}},
 AspectRatioFixed->True],

Cell["Which is also the correct answer.", "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built in \"PrincipalValue\" option to evaluate this definite integral ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val", ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946326634375*^9}],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", "."}]]],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      RowBox[{"sin", "  ", "x"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], " ", "+", " ", "4"}], ")"}]}]], " ", 
     RowBox[{"\[DifferentialD]", "x"}]}]}], "  ", "=", " ", 
   RowBox[{
    FractionBox["\[Pi]", "5"], "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "1"}], " ", "-", " ", 
      FractionBox["1", 
       SuperscriptBox["\[ExponentialE]", "2"]]}], ")"}]}]}]],
  CellChangeTimes->{{3.3994635033125*^9, 3.39946351853125*^9}}],
 ".   "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.39946352396875*^9, 3.39946354109375*^9}},
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{575, 165},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]], "=", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "z"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "+", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]]],
 "  has simple poles at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["t", "1"], "=", "1"}]]],
 "  on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 "  in the upper half-plane.  Computing the residues we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", "1"}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", "1"}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", "1"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", "1"}]], " ", 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]]}], "  ", "=",
       "  ", 
      FractionBox[
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["1", "2"], " ", "+", " ", "4"}], ")"}]]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      RowBox[{"cos", " ", "1"}], "  ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "sin", " ", "1"}]}], "5"]}]}]}]],
 "  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", 
         RowBox[{"2", "\[ImaginaryI]"}]}]], " ", 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}], "  ", "=", "  ", 
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"2", "\[ImaginaryI]"}], ")"}]}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "\[ImaginaryI]"}], "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "\[ImaginaryI]"}], "+", 
          RowBox[{"2", "\[ImaginaryI]"}]}], ")"}]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "2"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "8"}], "-", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]], "  ", "=", "  ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "2"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "-", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "8"}], "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}]}]], "   ", "=", "  ", 
       
       FractionBox[
        RowBox[{
         RowBox[{"-", "8"}], "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], 
        RowBox[{"80", 
         SuperscriptBox["\[ExponentialE]", "2"]}]]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                          ", 
   RowBox[{"=", "   ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}], 
     RowBox[{"20", 
      SuperscriptBox["\[ExponentialE]", "2"]}]]}]}]}]]
}], "Text"],

Cell[TextData[{
 "By Theorem 8.6,\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", "4"}], ")"}]}]], "sin", "  ",
        "x", " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["z", "1"]}], "]"}], ")"}]}], "  ", "+", "  ", 
     RowBox[{"\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         SubscriptBox["t", "1"]}], "]"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", 
         RowBox[{"2", "\[ImaginaryI]"}]}], "]"}], ")"}]}], "  ", "+", "  ", 
     RowBox[{"\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       RowBox[{"Res", "[", 
        RowBox[{"f", ",", "1"}], "]"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}], 
        RowBox[{"20", 
         SuperscriptBox["\[ExponentialE]", "2"]}]], ")"}]}], "  ", "+", "  ", 
     
     RowBox[{"\[Pi]", "  ", "Re", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"cos", " ", "1"}], "  ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "sin", " ", "1"}]}], "5"], ")"}]}]}]}],
    "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", 
      FractionBox[
       RowBox[{"-", "2"}], 
       RowBox[{"20", 
        SuperscriptBox["\[ExponentialE]", "2"]}]]}], "  ", "+", "  ", 
     RowBox[{"\[Pi]", " ", 
      FractionBox[
       RowBox[{"cos", " ", "1"}], "5"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["\[Pi]", "5"], "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"cos", " ", "1"}], " ", "-", " ", 
       FractionBox["1", 
        SuperscriptBox["\[ExponentialE]", "2"]]}], ")"}]}]}]}]}]],
 "   \n"
}], "Text",
 CellChangeTimes->{{3.399463558421875*^9, 3.39946356959375*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "z"}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "g", ",", "Res1", ",", "Res2", ",", "solset", ",", "val"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"Sin", "[", "x", "]"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], " ", "+", " ", "4"}], ")"}]}]]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "z"}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], " ", "+", " ", "4"}], ")"}]}]]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          RowBox[{"f", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The singularities are\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399463343203125*^9},
 AspectRatioFixed->False],

Cell["\<\
Which poles lie in the upper half plane ?  Which poles lie on the real axis ?\
\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,   Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,    Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) > 0 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) = 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) = 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<,    Is  Im(\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<) = 0 ?    \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "\[Equal]", "0"}]}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399463350609375*^9, 3.399463352921875*^9}, {
  3.400058837*^9, 3.400058874671875*^9}}],

Cell[TextData[{
 "\nYou must look carefully at the above list and make the proper choice. \n\
We see that we should compute the residues at  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman"], "  ", 
     SubscriptBox["z", "3"]}], "=", "1"}]}]]],
 ",  \nand use the residue calculus to compute the value of the integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.40031153525*^9, 3.40031161475*^9}, {3.4003124795625*^9, 
  3.400312490734375*^9}, {3.4003143224375*^9, 3.400314349984375*^9}, {
  3.40031442240625*^9, 3.400314427171875*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Res3", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "3"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      RowBox[{"2", " ", "\[Pi]", " ", 
       RowBox[{"Re", "[", "Res2", "]"}]}], "+", 
      RowBox[{"\[Pi]", " ", 
       RowBox[{"Re", "[", " ", "Res3", "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<] = \>\"", ",", "Res3"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<]] = \>\"", ",", 
      RowBox[{"Re", "[", "Res2", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Re[Res[f,\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<]] = \>\"", ",", 
      RowBox[{"Re", "[", "Res3", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], "-", "0.05"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.3"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               SubscriptBox["Z", "3"], "]"}], ",", 
              RowBox[{"Im", "[", 
               SubscriptBox["Z", "3"], "]"}]}], "}"}], ",", "0.2", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"centers", ",", "contour", ",", "segment", ",", "dots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi] Re[\>\"", ",", "Res2", " ", ",", 
      "\"\<] + \[Pi] Re[\>\"", ",", " ", "Res3", " ", ",", "\"\<]\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi](\>\"", ",", 
      RowBox[{"Re", "[", "Res2", " ", "]"}], ",", "\"\<) + \[Pi](\>\"", ",", 
      RowBox[{"Re", "[", " ", "Res3", "]"}], " ", ",", "\"\<)\>\""}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The indented contour is the semicircle \!\(\*SubscriptBox[\(C\), \
\(R\)]\) portions of [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<and a little indent semicircle around the pole on the x-axis,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"Chop", "[", 
       RowBox[{"N", "[", "val", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946335759375*^9, 3.39946338115625*^9}, {
  3.40005889034375*^9, 3.400058918390625*^9}, {3.40005895546875*^9, 
  3.400058955796875*^9}}],

Cell[TextData[{
 StyleBox["Warning.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The indefinite integral of F[x] is g[x], but it cannot be used in any \
meaningful way to solve the problem at hand."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "x_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[x] = \[Integral]\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\<\[DifferentialD]x = \>\"", ",", 
      
      RowBox[{"g", "[", "x", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< g[\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", "\[Infinity]", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"g", "[", 
       RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<    The following answer is suspect\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<because of singularities on the real axis.\>\"", "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{
       RowBox[{"g", "[", "\[Infinity]", "]"}], " ", "-", " ", 
       RowBox[{"g", "[", 
        RowBox[{"-", "\[Infinity]"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[\[Infinity]]-g[-\[Infinity]] = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"g", "[", "\[Infinity]", "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"-", "\[Infinity]"}], "]"}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946338590625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built in \"PrincipalValue\" option to evaluate the definite integral ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F0", "[", "x", "]"}], "=", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Sin", "[", "x", "]"}], " ", 
       RowBox[{"Apart", "[", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"4", "+", 
            SuperscriptBox["x", "2"]}], ")"}]}]], "]"}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"val1", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       SubscriptBox[
        RowBox[{"F0", "[", "x", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
       
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"val2", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       SubscriptBox[
        RowBox[{"F0", "[", "x", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
       
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"val3", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       SubscriptBox[
        RowBox[{"F0", "[", "x", "]"}], 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], ",", 
       
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"val1", "+", "val2", "+", "val3"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-\[Infinity]\), \(\
\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"F", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"N", "[", 
       RowBox[{"val1", "+", "val2", "+", "val3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3994633905625*^9}],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell["\<\
\tThe proofs of Theorems 8.5 and 8.6 depend on the following result.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Lemma 8.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " have a simple pole at the point  ",
 Cell[BoxData[
  SubscriptBox["t", "0"]]],
 "  on the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 "-axis.  If the contour is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "r"], ":", "z"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["t", "0"], "+", 
     RowBox[{"r", " ", 
      SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], "  ", "for",
       "  ", "0"}]}], " ", "\[LessEqual]", " ", "\[Theta]", " ", 
    "\[LessEqual]", " ", "\[Pi]"}]}]]],
 ",  then \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox[
     RowBox[{"lim", " "}], 
     RowBox[{"r", " ", "\[Rule]", " ", "0"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      SubscriptBox["C", "r"]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      SubscriptBox["t", "0"]}], "]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Lemma 8.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Residue Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy Principal Value",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.\
html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399463596921875*^9, 3.399463597078125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{968, 636},
WindowMargins->{{4, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[43046, 1351, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[66410, 1913, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[184121, 5364, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 186579, 5449}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 119, 2, 29, "Text"],
Cell[1027, 36, 3129, 107, 254, "Text"],
Cell[4159, 145, 1489, 52, 124, "Text"],
Cell[5651, 199, 458, 18, 36, "Text",
 Evaluatable->False],
Cell[6112, 219, 1473, 27, 185, "Text",
 Evaluatable->False],
Cell[7588, 248, 3794, 118, 305, "Text"],
Cell[CellGroupData[{
Cell[11407, 370, 186, 7, 29, "Text"],
Cell[11596, 379, 153, 5, 29, "Text"],
Cell[11752, 386, 1311, 41, 222, "Input"],
Cell[13066, 429, 744, 24, 54, "Text"],
Cell[13813, 455, 4856, 138, 307, "Input"],
Cell[18672, 595, 73, 0, 29, "Text"],
Cell[18748, 597, 3198, 81, 228, "Input"],
Cell[21949, 680, 958, 35, 72, "Text"],
Cell[22910, 717, 3516, 100, 423, "Input"],
Cell[26429, 819, 213, 6, 29, "Text"],
Cell[26645, 827, 3087, 87, 335, "Input"],
Cell[29735, 916, 49, 0, 29, "Text"],
Cell[29787, 918, 273, 10, 29, "Text",
 Evaluatable->False],
Cell[30063, 930, 1032, 29, 139, "Input"],
Cell[31098, 961, 1293, 44, 72, "Text"],
Cell[32394, 1007, 6040, 164, 357, "Input"]
}, Closed]],
Cell[38449, 1174, 545, 18, 44, "Text"],
Cell[38997, 1194, 3631, 136, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[42653, 1334, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[42797, 1340, 246, 9, 29, "Text",
 Evaluatable->False],
Cell[43046, 1351, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[43395, 1363, 17606, 350, 347, "Text"],
Cell[61004, 1715, 4988, 177, 221, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[66017, 1896, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[66161, 1902, 246, 9, 29, "Text",
 Evaluatable->False],
Cell[66410, 1913, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[66759, 1925, 1245, 41, 44, "Text"],
Cell[68007, 1968, 573, 20, 36, "Text",
 Evaluatable->False],
Cell[68583, 1990, 2522, 44, 179, "Text",
 Evaluatable->False],
Cell[71108, 2036, 8219, 270, 694, "Text"],
Cell[79330, 2308, 2297, 69, 322, "Text"],
Cell[CellGroupData[{
Cell[81652, 2381, 186, 7, 29, "Text"],
Cell[81841, 2390, 284, 12, 37, "Text"],
Cell[82128, 2404, 3270, 94, 387, "Input"],
Cell[85401, 2500, 150, 5, 29, "Text",
 Evaluatable->False],
Cell[85554, 2507, 6565, 173, 312, "Input"],
Cell[92122, 2682, 804, 23, 103, "Text",
 Evaluatable->False],
Cell[92929, 2707, 8885, 239, 681, "Input"],
Cell[101817, 2948, 49, 0, 29, "Text"],
Cell[101869, 2950, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[101977, 2954, 1022, 28, 138, "Input"]
}, Closed]],
Cell[103014, 2985, 508, 18, 33, "Text",
 Evaluatable->False],
Cell[103525, 3005, 1741, 31, 179, "Text",
 Evaluatable->False],
Cell[105269, 3038, 4041, 135, 507, "Text"],
Cell[109313, 3175, 7978, 147, 320, "Text"],
Cell[117294, 3324, 4907, 169, 515, "Text"],
Cell[122204, 3495, 3529, 118, 310, "Text"],
Cell[125736, 3615, 2757, 88, 222, "Text"],
Cell[CellGroupData[{
Cell[128518, 3707, 186, 7, 29, "Text"],
Cell[128707, 3716, 284, 12, 37, "Text"],
Cell[128994, 3730, 893, 28, 147, "Input"],
Cell[129890, 3760, 322, 10, 29, "Text",
 Evaluatable->False],
Cell[130215, 3772, 3167, 90, 428, "Input"],
Cell[133385, 3864, 223, 8, 29, "Text"],
Cell[133611, 3874, 1306, 36, 191, "Input"],
Cell[134920, 3912, 292, 9, 47, "Text",
 Evaluatable->False],
Cell[135215, 3923, 5842, 170, 633, "Input"],
Cell[141060, 4095, 49, 0, 29, "Text"],
Cell[141112, 4097, 246, 8, 29, "Text"],
Cell[141361, 4107, 840, 22, 105, "Input"],
Cell[142204, 4131, 49, 0, 29, "Text"]
}, Closed]],
Cell[142268, 4134, 1019, 34, 40, "Text",
 Evaluatable->False],
Cell[143290, 4170, 2477, 43, 179, "Text",
 Evaluatable->False],
Cell[145770, 4215, 6772, 215, 499, "Text"],
Cell[152545, 4432, 2943, 85, 274, "Text"],
Cell[CellGroupData[{
Cell[155513, 4521, 186, 7, 29, "Text"],
Cell[155702, 4530, 475, 18, 46, "Text"],
Cell[156180, 4550, 3967, 118, 481, "Input"],
Cell[160150, 4670, 150, 5, 29, "Text",
 Evaluatable->False],
Cell[160303, 4677, 6493, 172, 312, "Input"],
Cell[166799, 4851, 784, 21, 101, "Text",
 Evaluatable->False],
Cell[167586, 4874, 8982, 242, 721, "Input"],
Cell[176571, 5118, 272, 8, 29, "Text",
 Evaluatable->False],
Cell[176846, 5128, 2497, 70, 307, "Input"],
Cell[179346, 5200, 245, 8, 29, "Text"],
Cell[179594, 5210, 2655, 77, 225, "Input"],
Cell[182252, 5289, 49, 0, 29, "Text"]
}, Closed]],
Cell[182316, 5292, 139, 4, 26, "Text",
 Evaluatable->False],
Cell[182458, 5298, 1247, 45, 75, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[183730, 5347, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[183874, 5353, 244, 9, 29, "Text",
 Evaluatable->False],
Cell[184121, 5364, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[184470, 5376, 281, 7, 26, "Text"],
Cell[184754, 5385, 294, 10, 29, "Text"],
Cell[185051, 5397, 299, 10, 29, "Text"],
Cell[185353, 5409, 307, 10, 29, "Text"],
Cell[185663, 5421, 249, 5, 29, "Text"],
Cell[185915, 5428, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
