(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    117318,       3263]
NotebookOptionsPosition[    114216,       3164]
NotebookOutlinePosition[    114829,       3191]
CellTagsIndexPosition[    114755,       3186]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.6  Integrands with Branch Points",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tWe now show how to evaluate certain improper real integrals involving the \
integrand  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    SuperscriptBox["x", "\[Alpha]"], " ", "P", 
    RowBox[{"(", "x", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}]]]],
 ".  Since the complex function  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "\[Alpha]"], " "}]]],
 "  is multivalued, so we must first specify the branch to be used."
}], "Text"],

Cell[TextData[{
 "\tLet ",
 Cell[BoxData["\[Alpha]"]],
 " be a real number with ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Alpha]", "<", "1"}]]],
 ".  In this section we use the branch of ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "\[Alpha]"], " "}]]],
 " corresponding to the branch of the logarithm ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", 
    RowBox[{" ", "0"}]], 
   RowBox[{"(", "z", ")"}]}]]],
 " (see Equation ",
 StyleBox["(5-20)",
  FontColor->RGBColor[0, 0, 1]],
 ") as follows:\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "\[Alpha]"], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["log", 
         RowBox[{" ", "0"}]], 
        RowBox[{"(", "z", ")"}]}], ")"}]}]], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{"ln", "|", "z", "|", " ", 
         RowBox[{
          RowBox[{"+", " ", "\[ImaginaryI]"}], " ", 
          SubscriptBox["arg", 
           RowBox[{" ", "0"}]], "z"}]}], ")"}]}]], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[Alpha]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ln", " ", "r"}], " ", "+", " ", "\[ImaginaryI]\[Theta]"}], 
         ")"}]}]], " ", "=", " ", 
      RowBox[{
       SuperscriptBox["r", "\[Alpha]"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"cos", " ", "\[Alpha]", " ", "\[Theta]"}], " ", "+", " ", 
         RowBox[{
         "\[ImaginaryI]", " ", "sin", " ", "\[Alpha]", " ", "\[Theta]"}]}], 
        ")"}]}]}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Theta]", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  Note that this is not the traditional principal branch of ",
 Cell[BoxData[
  SuperscriptBox["z", "\[Alpha]"]]],
 " and that, as defined, the function ",
 Cell[BoxData[
  SuperscriptBox["z", "\[Alpha]"]]],
 " is analytic in the domain ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"z", "=", 
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "\[ImaginaryI]\[Theta]"], ":", " ", 
       RowBox[{"r", ">", "0"}]}]}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"0", "<", "\[Theta]", "<", 
     RowBox[{"2", "\[Pi]"}]}]}], " ", "}"}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["P(x)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " be polynomials of degree ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ", respectively, where  ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", 
   RowBox[{"m", "+", "2"}]}]]],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "x", ")"}]}], "\[NotEqual]", 
   RowBox[{"0", "  ", 
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", "x"}], ">", "0"}]]],
 ",  and ",
 StyleBox["Q(x)",
  FontFamily->"Courier New"],
 " has a zero of order at most ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " at the origin, and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "\[Alpha]"], " ", "P", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}]]}], ",", 
   RowBox[{
    RowBox[{
     StyleBox["where",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "0"}], " ", "<", " ", "\[Alpha]", "<", 
    " ", "1"}]}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["x", "\[Alpha]"], " ", "P", 
        RowBox[{"(", "x", ")"}]}], 
       RowBox[{"Q", 
        RowBox[{"(", "x", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
     RowBox[{"1", " ", "-", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "2", "\[Pi]"}]]}]], " ",
     
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "k"], 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "j"]}], "]"}]}]}]}]]],
 ",  \n\n where  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the non-zero poles of  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}]]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{429, 397},
  ImageMargins->0],
 StyleBox["  \n\n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.7",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/integralsbranchpoints/\
IntegralsBranchPointsFigures/mat0807.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " that encloses the nonzero poles  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  of  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}]]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39946438475*^9, 3.39946441921875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.7",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox["Example 8.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Evaluate",
 "  ",
 Cell[BoxData[
  RowBox[{"P", ".", "V", ".", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox["x", "\[Alpha]"], 
      RowBox[{"x", 
       RowBox[{"(", 
        RowBox[{"x", " ", "+", " ", "1"}], ")"}]}]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Alpha]", "<", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{519, 199},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SuperscriptBox["x", "\[Alpha]"], 
    RowBox[{"x", 
     RowBox[{"(", 
      RowBox[{"x", " ", "+", " ", "1"}], ")"}]}]]}]]],
 "  has a nonzero pole at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"-", "1"}]}]]],
 ", and the denominator has a zero of order at most ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " (in fact, exactly ",
 StyleBox["1",
  FontFamily->"Courier New"],
 ") at the origin.  Calculating the residue we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{"f", ",", 
      RowBox[{"-", "1"}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], "f", 
      RowBox[{"(", "z", ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"-", "1"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox[
        SuperscriptBox["x", "\[Alpha]"], 
        RowBox[{"x", 
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", "1"}], ")"}]}]]}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", 
         RowBox[{"-", "1"}]}]], 
       FractionBox[
        SuperscriptBox["x", "\[Alpha]"], "x"]}], "  ", "=", "  ", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Alpha]"], 
       RowBox[{"-", "1"}]]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "\[Alpha]"], 
       RowBox[{"-", "1"}]], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]], ")"}], "\[Alpha]"], 
        " "}], 
       RowBox[{"-", "1"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                         ", 
   RowBox[{"=", "  ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "\[Pi]"}]], " "}], 
     RowBox[{"-", "1"}]]}]}]}]],
 "\n\nUsing Theorem 8.7, we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
      RowBox[{
       FractionBox[
        SuperscriptBox["x", "\[Alpha]"], 
        RowBox[{"x", 
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", "1"}], ")"}]}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
      RowBox[{"1", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "2", "\[Pi]"}]]}]], 
     " ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "1"]}], "]"}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "2", "\[Pi]"}]]}]], 
      " ", 
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", 
        RowBox[{"-", "1"}]}], "]"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
        RowBox[{"1", " ", "-", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "2", "\[Pi]"}]]}]], 
       " ", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "\[Pi]"}]], " "}], 
         RowBox[{"-", "1"}]], ")"}]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", "  ", "\[Alpha]", " ", "\[Pi]"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Alpha]", " ", 
          "\[Pi]"}]]}]]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]",
  
  RowBox[{"                                      ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox["\[Pi]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", "  ", "\[Alpha]", " ", "\[Pi]"}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Alpha]", " ", "\[Pi]"}]]}], 
       
       RowBox[{"2", " ", "\[ImaginaryI]"}]]]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                      ", 
   RowBox[{"=", "  ", 
    FractionBox["\[Pi]", 
     RowBox[{"sin", " ", "\[Alpha]", " ", "\[Pi]"}]]}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    SuperscriptBox["z", "\[Alpha]"], 
    RowBox[{"z", 
     RowBox[{"(", 
      RowBox[{"z", " ", "+", " ", "1"}], ")"}]}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " isolated singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", "0"}]}]}], ";", 
    RowBox[{"Remove", "[", 
     RowBox[{"x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "P", ",", "Q", ",", "Res1", ",", "solset", ",", "val"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], "=", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", "z_", "]"}], "=", 
     RowBox[{"z", 
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "\[Alpha]"], " ", 
       RowBox[{"P", "[", "z", "]"}]}], 
      RowBox[{"Q", "[", "z", "]"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(P[z]\), \(Q[z]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"P", "[", "z", "]"}], 
       RowBox[{"Q", "[", "z", "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       FractionBox[
        RowBox[{"P", "[", "z", "]"}], 
        RowBox[{"Q", "[", "z", "]"}]], "]"}], "\[Equal]", "0"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          FractionBox[
           RowBox[{"P", "[", "z", "]"}], 
           RowBox[{"Q", "[", "z", "]"}]], "]"}], "\[Equal]", "0"}], ",", 
        "z"}], "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The singularities of \!\(\*FractionBox[\(P[z]\), \(Q[z]\)]\) \
are\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"z", ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3994649215*^9},
 AspectRatioFixed->False],

Cell["Which pole(s) are non-zero ?", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\< \[NotEqual] 0 ? \>\"", ",", 
      RowBox[{
       SubscriptBox["Z", "1"], "\[NotEqual]", "0"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is   \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\< \[NotEqual] 0 ? \>\"", ",", 
      RowBox[{
       SubscriptBox["Z", "2"], "\[NotEqual]", "0"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399464926546875*^9, 3.39946492884375*^9}, 
   3.40005915971875*^9, {3.40005928309375*^9, 3.400059284765625*^9}}],

Cell[TextData[{
 "\nCompute the residues at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"-", "1"}]}]]],
 ",  and use the residue calculus to compute the value of the integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.400314722*^9, 3.400314723375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res1", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "1"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Res1", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"Res1", ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Res1", "=", 
     RowBox[{"TrigToExp", "[", "Res1", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<] = \>\"", ",", "Res1"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}], 
       RowBox[{"1", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Alpha]", " ", "2", "\[Pi]"}]]}]], "  ",
       "Res1"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Magenta", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "1"], "]"}], ",", 
           RowBox[{
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "1"], "]"}], "+", "0.2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
         RowBox[{"Circle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", "2", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}]}], "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "segment", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = \!\(\*FractionBox[\(2  \[Pi]\\\ \
\[ImaginaryI]\), \(1\\\  - \\\ \*SuperscriptBox[\(\[ExponentialE]\), \(\
\[ImaginaryI]\\\ \[Alpha]\\\ 2  \[Pi]\)]\)]\)(\>\"", ",", " ", "Res1", " ", 
      ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", 
      RowBox[{"FullSimplify", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The contour is the circle \!\(\*SubscriptBox[\(C\), \(R\)]\) and \
two segments near [0,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<and a little semicircle around the origin in quadrants II & \
III,\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       
      RowBox[{"FullSimplify", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399464931484375*^9, 3.399464950171875*^9}, {
  3.40005916528125*^9, 3.400059165578125*^9}, {3.40005924878125*^9, 
  3.400059274234375*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built in \"PrincipalValue\" option to evaluate this definite integral ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", "<", 
          RowBox[{"Re", "[", "\[Alpha]", "]"}], "<", "1"}], "}"}]}], ",", 
       RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", ",",
       "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399464955640625*^9}],

Cell["Which is also the correct answer.", "Text"]
}, Closed]],

Cell["\<\
\tWe can apply the preceding ideas to other multivalued functions.  \
\>", "Text"],

Cell[TextData[{
 StyleBox["Example 8.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Evaluate",
 "  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"ln", " ", "x"}], 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", 
        SuperscriptBox["a", "2"]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Log", "[", "a", "]"}]}], 
    RowBox[{"2", " ", "a"}]]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{"a", ">", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{692, 199},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We use the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["log", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]], " ", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", 
     SuperscriptBox["a", "2"]}]]}]]],
 ".  Recall that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["log", 
     RowBox[{"-", 
      FractionBox["\[Pi]", "2"]}]], " ", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", "|", "z", "|", " ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", 
      SubscriptBox["arg", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}]], " ", 
      RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"ln", " ", "r"}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}]}]}]]],
 ",  \n\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], "<", "\[Theta]", "\[LessEqual]", 
   FractionBox[
    RowBox[{"3", "\[Pi]"}], "2"]}]]],
 ".  The path",
 " ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " ",
 "of integration will consist of the segments ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"[", 
    RowBox[{
     RowBox[{"-", "R"}], ",", 
     RowBox[{"-", "r"}]}], "]"}], " ", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "[", 
    RowBox[{"r", ",", "R"}], "]"}]}]]],
 " of the x axis together with the upper semicircles  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "r"], ":", " ", "z"}], " ", "=", " ", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "R"], ":", " ", "z"}], " ", "=", " ", 
   RowBox[{"R", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"0", "\[LessEqual]", "\[Theta]", "\[LessEqual]", "\[Pi]"}]]],
 ",  as shown in Figure 8.8."
}], "Text"],

Cell[TextData[{
 StyleBox["\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{388, 224},
  ImageMargins->0],
 StyleBox["  \n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.8",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/integralsbranchpoints/\
IntegralsBranchPointsFigures/mat0808.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " for the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["log", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]], " ", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], " ", "+", " ", 
     SuperscriptBox["a", "2"]}]]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.399464428015625*^9, 3.399464443046875*^9}}],

Cell[TextData[{
 "\tWe chose the branch  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]], " ", 
   RowBox[{"(", "z", ")"}]}]]],
 "  because it is analytic on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and its interior, hence so is the function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " which has a simple pole in the upper half-plane at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"a", " ", "\[ImaginaryI]"}]}]]],
 ". \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       SubscriptBox["z", "1"]}], "]"}], "  ", "=", "  ", 
     RowBox[{"Res", "[", 
      RowBox[{"f", ",", 
       RowBox[{"a", " ", "\[ImaginaryI]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "\n", "                        ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"a", " ", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}]}], "\[IndentingNewLine]", "\n", 
    "                        ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"a", " ", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}], 
       FractionBox[
        RowBox[{
         SubscriptBox["log", 
          RowBox[{"-", 
           FractionBox["\[Pi]", "2"]}]], " ", 
         RowBox[{"(", "z", ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", 
           RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{"z", "-", 
           RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}]}]]}]}]}], 
    "\[IndentingNewLine]", "\n", "                        ", 
    RowBox[{"=", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        RowBox[{"a", " ", "\[ImaginaryI]"}]}]], " ", 
      FractionBox[
       RowBox[{
        SubscriptBox["log", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}]], " ", 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}]]}]}], 
    "\[IndentingNewLine]", "\n", "                        ", 
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["log", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}]], " ", 
        RowBox[{"(", 
         RowBox[{"a", " ", "\[ImaginaryI]"}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "\[ImaginaryI]"}], "+", 
         RowBox[{"a", " ", "\[ImaginaryI]"}]}], ")"}]], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        SubscriptBox["log", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}]], " ", 
        RowBox[{"(", 
         RowBox[{"a", " ", "\[ImaginaryI]"}], ")"}]}], 
       RowBox[{"2", "a", " ", "\[ImaginaryI]"}]]}]}], "\n", 
    "\[IndentingNewLine]", "                        ", 
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"ln", " ", "a"}], "  ", "+", "  ", 
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["arg", 
          RowBox[{"-", 
           FractionBox["\[Pi]", "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"a", " ", "\[ImaginaryI]"}], ")"}]}]}], 
       RowBox[{"2", "a", " ", "\[ImaginaryI]"}]], "  ", "=", "   ", 
      FractionBox[
       RowBox[{
        RowBox[{"ln", " ", "a"}], "  ", "+", "  ", 
        RowBox[{"\[ImaginaryI]", " ", 
         FractionBox["\[Pi]", "2"]}]}], 
       RowBox[{"2", "a", " ", "\[ImaginaryI]"}]]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "                       ", 
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{"ln", " ", "a"}], 
       RowBox[{"2", "a", " ", "\[ImaginaryI]"}]], " ", "+", 
      FractionBox["\[Pi]", 
       RowBox[{"4", "a"}]]}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "This choice enables us to apply the residue theorem properly (see the \
hypotheses of Theorem 8.1), and we get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", "C"}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", 
        SubscriptBox["z", "1"]}], "]"}]}], "  ", "=", "  ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", " ", 
      RowBox[{"Res", "[", 
       RowBox[{"f", ",", 
        RowBox[{"a", " ", "\[ImaginaryI]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", " ", "a"}], 
         RowBox[{"2", "a", " ", "\[ImaginaryI]"}]], " ", "+", 
        FractionBox["\[Pi]", 
         RowBox[{"4", "a"}]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Pi]", " ", "ln", " ", "a"}], "a"], " ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       SuperscriptBox["\[Pi]", "2"], 
       RowBox[{"2", "a"}]]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "Keeping in mind the branch of logarithm that we're using, we then have  \n\n\
",
 StyleBox["(8-33)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", "C"}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "R"}], 
       RowBox[{"-", "r"}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", "x", ")"}], 
       RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["\[ContourIntegral]", 
       RowBox[{" ", 
        RowBox[{"-", 
         SubscriptBox["C", "r"]}]}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "+", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "r", "R"], " ", 
      RowBox[{"f", 
       RowBox[{"(", "x", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["\[ContourIntegral]", 
       RowBox[{" ", 
        SubscriptBox["C", "R"]}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "R"}], 
        RowBox[{"-", "r"}]], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", "|", "x", "|", " ", 
          RowBox[{
           RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "\[Pi]"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[ContourIntegral]", 
        RowBox[{" ", 
         RowBox[{"-", 
          SubscriptBox["C", "r"]}]}]], " ", 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], " ", 
        RowBox[{"\[DifferentialD]", "z"}]}]}], " ", "+", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "r", "R"], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", " ", "x"}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["\[ContourIntegral]", 
        RowBox[{" ", 
         SubscriptBox["C", "R"]}]], " ", 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}], " ", 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], "\[IndentingNewLine]", 
    " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Pi]", " ", "ln", " ", "a"}], "a"], " ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       SuperscriptBox["\[Pi]", "2"], 
       RowBox[{"2", "a"}]]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "If  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["R", "2"], ">", 
   SuperscriptBox["r", "2"]}]]],
 ",  then by the ML inequality (Theorem 6.3) \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       SubscriptBox["C", "R"]}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}], "|"}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"ln", " ", "R"}], "  ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}], 
       RowBox[{
        RowBox[{
         SuperscriptBox["R", "2"], 
         SuperscriptBox[
          RowBox[{"\[ExponentialE]", " "}], "\[ImaginaryI]2\[Theta]"]}], " ", 
        "+", " ", 
        SuperscriptBox["a", "2"]}]], "\[ImaginaryI]", " ", "R", " ", 
      SuperscriptBox[
       RowBox[{"\[ExponentialE]", " "}], "\[ImaginaryI]\[Theta]"], " ", 
      RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}], "|", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "                            ", 
    RowBox[{"\[LessEqual]", "  ", 
     FractionBox[
      RowBox[{"R", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ln", " ", "R"}], "  ", "+", " ", "\[Pi]"}], ")"}], 
       "\[Pi]"}], 
      RowBox[{
       SuperscriptBox["R", "2"], " ", "-", " ", 
       SuperscriptBox["a", "2"]}]]}]}]}]]],
 "\n\nand L'H\[OHat]pital's rule yields  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"R", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       SubscriptBox["C", "R"]}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], " ", "=", " ", "0"}]]],
 ".  A similar computation shows that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"r", "\[Rule]", "0"}]], " ", 
    RowBox[{
     SubscriptBox["\[ContourIntegral]", 
      RowBox[{" ", 
       SubscriptBox["C", "r"]}]], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], " ", 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], " ", "=", " ", "0"}]]],
 ".  \nWe use these results when we take limits Equations ",
 StyleBox["(8-33)",
  FontColor->RGBColor[0, 0, 1]],
 " to get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "\[Infinity]"}], "0"], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", "|", "x", "|", " ", 
          RowBox[{
           RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "\[Pi]"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", " ", "x"}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox[
     UnderscriptBox[
      UnderscriptBox["lim", " "], 
      RowBox[{"R", "\[Rule]", "\[Infinity]"}]], 
     RowBox[{"r", "\[Rule]", "0"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "R"}], 
        RowBox[{"-", "r"}]], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", "|", "x", "|", " ", 
          RowBox[{
           RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "\[Pi]"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "r", "R"], " ", 
       RowBox[{
        FractionBox[
         RowBox[{"ln", " ", "x"}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["a", "2"]}]], " ", 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], 
     ")"}]}]}], "\[IndentingNewLine]", 
  RowBox[{
   "                                                                          \
    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubscriptBox["\[ContourIntegral]", 
       RowBox[{" ", "C"}]], " ", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}], " ", 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{
   "                                                                          \
    ", 
   RowBox[{"=", "   ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Pi]", " ", "ln", " ", "a"}], "a"], " ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       SuperscriptBox["\[Pi]", "2"], 
       RowBox[{"2", "a"}]]}]}]}]}]}]],
 "   \n\nEquating the real parts in this equation gives  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"-", "\[Infinity]"}], "0"], " ", 
        RowBox[{
         FractionBox[
          RowBox[{"ln", "|", "x", "|", " ", 
           RowBox[{
            RowBox[{"+", " ", "\[ImaginaryI]"}], " ", "\[Pi]"}]}], 
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", 
           SuperscriptBox["a", "2"]}]], 
         RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
        RowBox[{
         FractionBox[
          RowBox[{"ln", " ", "x"}], 
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", 
           SuperscriptBox["a", "2"]}]], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ")"}]}], "  ", "=", " ", 
    FractionBox[
     RowBox[{"\[Pi]", " ", "ln", " ", "a"}], "a"]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P", ".", "V", ".", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
        RowBox[{
         FractionBox[
          RowBox[{"ln", " ", "x"}], 
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", 
           SuperscriptBox["a", "2"]}]], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
        RowBox[{
         FractionBox[
          RowBox[{"ln", " ", "x"}], 
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", 
           SuperscriptBox["a", "2"]}]], " ", 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], ")"}]}], "  ", "=", " ", 
    FractionBox[
     RowBox[{"\[Pi]", " ", "ln", " ", "a"}], "a"]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"ln", " ", "x"}], 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", 
        SuperscriptBox["a", "2"]}]], " ", 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], "  ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "ln", " ", "a"}], 
    RowBox[{"2", "a"}]]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the function and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"Log", "[", "z", "]"}], 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "+", " ", 
     SuperscriptBox["x", "2"]}]]}]],
  AspectRatioFixed->True],
 "  and ",
 "locate the",
 " isolated singularities."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", 
      RowBox[{"x", "=", 
       RowBox[{"a", "=", "0"}]}]}]}], ";", 
    RowBox[{"Remove", "[", 
     RowBox[{"a", ",", "x", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "P", ",", "Q", ",", "Res1", ",", "solset", ",", "val"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "z_", "]"}], "=", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Q", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", 
      SuperscriptBox["a", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", "z", "]"}], " ", 
       RowBox[{"P", "[", "z", "]"}]}], 
      RowBox[{"Q", "[", "z", "]"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*FractionBox[\(P[z]\), \(Q[z]\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"P", "[", "z", "]"}], 
       RowBox[{"Q", "[", "z", "]"}]]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Denominator", "[", 
       FractionBox[
        RowBox[{"P", "[", "z", "]"}], 
        RowBox[{"Q", "[", "z", "]"}]], "]"}], "\[Equal]", "0"}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Sort", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Denominator", "[", 
          FractionBox[
           RowBox[{"P", "[", "z", "]"}], 
           RowBox[{"Q", "[", "z", "]"}]], "]"}], "\[Equal]", "0"}], ",", 
        "z"}], "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The singularities of \!\(\*FractionBox[\(P[z]\), \(Q[z]\)]\) \
are\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"z", ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
       "]"}], "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3994649968125*^9},
 AspectRatioFixed->False],

Cell["Which poles lie in the upper half plane ?  ", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", "2"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<For example, if  a = 2.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is  Im(\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<) > 0 ?  \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<,  Is  Im(\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<) > 0 ?   \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Im", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], ">", "0"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399465001546875*^9, 3.399465003078125*^9}, {
  3.40005917090625*^9, 3.40005917128125*^9}, {3.400059336265625*^9, 
  3.400059337625*^9}}],

Cell[TextData[{
 "\nCompute the residues at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ",  and use the residue calculus to compute the value of the integral.\n"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.400314750921875*^9, 3.400314751984375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Res2", " ", "=", " ", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", 
         SubscriptBox["Z", "2"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{"2", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "Res2"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<] = \>\"", ",", "Res2"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Magenta", ",", 
         RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{"Im", "[", 
             SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            SubscriptBox["Z", "2"], "]"}], ",", 
           RowBox[{"Im", "[", 
            SubscriptBox["Z", "2"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.2"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "3", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.01", "]"}], ",", "Red", ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", "0.2", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"segment", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.015", "]"}], ",", "Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "3"}], ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.25"}], ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.25", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "segment", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3.1"}], ",", "3.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "3.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", 
      "\"\<) \[DifferentialD]z = 2\[Pi]\[ImaginaryI](\>\"", ",", "Res2", " ", 
      ",", "\"\<)\>\""}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) (\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<) \[DifferentialD]z = \>\"", 
      ",", 
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The indented contour is the semicircle \!\(\*SubscriptBox[\(C\), \
\(R\)]\) portions of [-R,R],\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<and a little indent semicircle around the origin on the \
x-axis,\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<taken with the positive orientation.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Let R\[Rule]\[Infinity] to obtain the Cauchy Principal Value of the \
integral.\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399465008703125*^9, 3.39946508678125*^9}, {
  3.400059176203125*^9, 3.400059176421875*^9}, {3.400059304421875*^9, 
  3.400059328640625*^9}}],

Cell[TextData[{
 "\nFurther analysis must be done.  As shown in the text, the limit of the \
integrals taken over the semicircles are both zero.\nUse the fact that when x \
is negative  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", "[", "x", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"|", "x", "|"}], "]"}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}]}]]],
 ".  Then use this parameterize the line segment on the negative x-axis and \
obtain  \n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "\[Infinity]"}], "0"], 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"|", "x", "|"}], "]"}], "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["2", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "+", " ", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", "+", " ", 
          SuperscriptBox["2", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", ")"}]}], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Pi]", " ", 
      RowBox[{"Log", "[", "2", "]"}]}], "2"], "+", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      SuperscriptBox["\[Pi]", "2"]}], "4"]}]}]]],
 ".  \n\nEquating the real parts in the above equation we obtain  \n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"Log", "[", "x", "]"}], 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", 
        SuperscriptBox["2", "2"]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Log", "[", "2", "]"}]}], "4"]}]]],
 ".  \n\nwhich is the correct value when  a = 2.  Similar computations will \
establish the general result."
}], "Text",
 CellChangeTimes->{3.400314917453125*^9}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built in \"PrincipalValue\" option to evaluate this definite integral \
with specific values of  a."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"a", "=", "2"}], ",", 
      RowBox[{"a", "\[LessEqual]", "5"}], ",", 
      RowBox[{"a", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"val", " ", "=", " ", 
        RowBox[{"Integrate", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0", "<", 
             RowBox[{"Re", "[", "\[Alpha]", "]"}], "<", "1"}], "}"}]}], ",", 
          RowBox[{"PrincipalValue", "\[Rule]", "True"}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<a = \>\"", ",", "a"}], "]"}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<P.V.\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\>\"", ",", 
         RowBox[{"f", "[", "x", "]"}], ",", "\"\< \[DifferentialD]x = \>\"", 
         ",", "val"}], "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<\!\(\*FractionBox[\(\[Pi]\\\ \\\ Log[a]\), \(2  a\)]\) = \>\"", 
         ",", 
         FractionBox[
          RowBox[{"\[Pi]", " ", 
           RowBox[{"Log", "[", "a", "]"}]}], 
          RowBox[{"2", "a"}]]}], "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}]}], "  ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946509284375*^9}],

Cell[TextData[{
 "Which leads us to conjecture the general result  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", ".", "V", ".", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
     RowBox[{
      FractionBox[
       RowBox[{"Log", "[", "z", "]"}], 
       RowBox[{
        SuperscriptBox["x", "2"], " ", "+", " ", 
        SuperscriptBox["a", "2"]}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", 
     RowBox[{"Log", "[", "a", "]"}]}], 
    RowBox[{"2", " ", "a"}]]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{"a", ">", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " do the integration. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\<   Example using a = 2\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(2\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["2", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(3\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["3", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(4\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["4", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(5\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["5", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(a\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{"Log", "[", "x", "]"}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["a", "2"]}]], 
        RowBox[{"\[DifferentialD]", "x"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubsuperscriptBox[\(\[Integral]\), \(0\), \
\(\[Infinity]\)]\)\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\(x\), \(2\
\)] + \*SuperscriptBox[\(a\), \(2\)]\)]\)\[DifferentialD]x = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
         RowBox[{
          FractionBox[
           RowBox[{"Log", "[", "x", "]"}], 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["a", "2"]}]], 
          RowBox[{"\[DifferentialD]", "x"}]}]}], ",", 
        RowBox[{"a", ">", "0"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946510934375*^9, 3.399465110375*^9}}],

Cell["\<\
However, we might not be able to use the anti-derivative for the computation.\
\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x_", "]"}], " ", "=", " ", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{"Log", "[", "x", "]"}], 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["2", "2"]}]], 
       RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "x_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"f", "[", "x", "]"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x] = \>\"", ",", 
      RowBox[{"f", "[", "x", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<F[x] = \[Integral]\!\(\*FractionBox[\(Log[x]\), \(\*SuperscriptBox[\
\(x\), \(2\)] + \*SuperscriptBox[\(2\), \(2\)]\)]\)\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[x] = \>\"", ",", 
      RowBox[{"F", "[", "x", "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{3.39946512215625*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], " ", "=", " ", 
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox[
      RowBox[{"Log", "[", "x", "]"}], 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["2", "2"]}]], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", "x_", "]"}], " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"f", "[", "x", "]"}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lim", "=", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"F", "[", "x", "]"}], ",", 
     RowBox[{"x", "\[Rule]", "0"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F", "[", "x", "]"}], ",", 
     FractionBox[
      RowBox[{"\[Pi]", " ", 
       RowBox[{"Log", "[", "2.", "]"}]}], "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1000"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.25"}], ",", "0.55"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"Ticks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "1000", ",", "200"}], "]"}], ",", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", "0.5", ",", "0.25"}], "]"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[x] = \>\"", ",", 
    RowBox[{"F", "[", "x", "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<      F[0] = \!\(\*UnderscriptBox[\(lim\), \(x \[Rule] 0\)]\) \
F[x]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<      F[0] = \>\"", ",", "lim"}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(3\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "3"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(4\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "4"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(5\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "5"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(6\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "6"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(7\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "7"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(8\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "8"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<F[1.0*\!\(\*SuperscriptBox[\(10\), \(9\)]\)] = \>\"", ",", 
    RowBox[{"Chop", "[", 
     RowBox[{"F", "[", 
      RowBox[{"1.0", "*", 
       SuperscriptBox["10", "9"]}], "]"}], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\< \!\(\*FractionBox[\(\[Pi]\\\ Log[2]\), \(4\)]\) = \>\"", ",", 
    RowBox[{"N", "[", 
     FractionBox[
      RowBox[{"\[Pi]", " ", 
       RowBox[{"Log", "[", "2", "]"}]}], "4"], "]"}]}], " ", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<      F[\[Infinity]] = \>\"", ",", 
     RowBox[{"F", "[", "\[Infinity]", "]"}]}], " ", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.399465128640625*^9, {3.4000591814375*^9, 3.400059181609375*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Residue Calculus",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ResidueCalcBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Contour Integrals",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ContourIntegralBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Cauchy Principal Value",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/CauchyPrincipalValuelBib.\
html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Hilbert Transformation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/HilbertTransBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.3994648981875*^9, 3.399464898578125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{995, 640},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[24039, 591, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 114556, 3176}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 122, 2, 29, "Text"],
Cell[1030, 36, 470, 15, 59, "Text"],
Cell[1503, 53, 2739, 90, 127, "Text"],
Cell[4245, 145, 3473, 130, 152, "Text",
 Evaluatable->False],
Cell[7721, 277, 15900, 293, 458, "Text"],
Cell[CellGroupData[{
Cell[23646, 574, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[23790, 580, 246, 9, 29, "Text",
 Evaluatable->False],
Cell[24039, 591, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[24388, 603, 640, 26, 55, "Text",
 Evaluatable->False],
Cell[25031, 631, 2506, 44, 213, "Text",
 Evaluatable->False],
Cell[27540, 677, 5930, 180, 579, "Text"],
Cell[CellGroupData[{
Cell[33495, 861, 186, 7, 29, "Text"],
Cell[33684, 870, 347, 14, 40, "Text"],
Cell[34034, 886, 3646, 108, 502, "Input"],
Cell[37683, 996, 91, 2, 29, "Text",
 Evaluatable->False],
Cell[37777, 1000, 3833, 103, 172, "Input"],
Cell[41613, 1105, 323, 10, 65, "Text",
 Evaluatable->False],
Cell[41939, 1117, 7334, 198, 657, "Input"],
Cell[49276, 1317, 246, 8, 29, "Text"],
Cell[49525, 1327, 894, 23, 106, "Input"],
Cell[50422, 1352, 49, 0, 29, "Text"]
}, Closed]],
Cell[50486, 1355, 92, 2, 26, "Text"],
Cell[50581, 1359, 735, 29, 37, "Text",
 Evaluatable->False],
Cell[51319, 1390, 2677, 47, 213, "Text",
 Evaluatable->False],
Cell[53999, 1439, 2518, 89, 176, "Text"],
Cell[56520, 1530, 8898, 166, 296, "Text"],
Cell[65421, 1698, 4207, 128, 418, "Text"],
Cell[69631, 1828, 1507, 44, 163, "Text"],
Cell[71141, 1874, 3128, 96, 169, "Text"],
Cell[74272, 1972, 7594, 229, 502, "Text"],
Cell[CellGroupData[{
Cell[81891, 2205, 186, 7, 29, "Text"],
Cell[82080, 2214, 352, 14, 37, "Text"],
Cell[82435, 2230, 3692, 109, 500, "Input"],
Cell[86130, 2341, 106, 2, 29, "Text",
 Evaluatable->False],
Cell[86239, 2345, 4164, 113, 212, "Input"],
Cell[90406, 2460, 344, 10, 65, "Text",
 Evaluatable->False],
Cell[90753, 2472, 6175, 168, 495, "Input"],
Cell[96931, 2642, 2318, 66, 229, "Text"],
Cell[99252, 2710, 274, 9, 29, "Text"],
Cell[99529, 2721, 1672, 41, 215, "Input"],
Cell[101204, 2764, 640, 22, 37, "Text"],
Cell[101847, 2788, 193, 8, 29, "Text"],
Cell[102043, 2798, 4131, 107, 308, "Input"],
Cell[106177, 2907, 103, 3, 29, "Text"],
Cell[106283, 2912, 1186, 36, 164, "Input"],
Cell[107472, 2950, 4658, 138, 467, "Input"]
}, Closed]],
Cell[112145, 3091, 281, 7, 26, "Text"],
Cell[112429, 3100, 294, 10, 29, "Text"],
Cell[112726, 3112, 299, 10, 29, "Text"],
Cell[113028, 3124, 307, 10, 29, "Text"],
Cell[113338, 3136, 301, 10, 29, "Text"],
Cell[113642, 3148, 249, 5, 29, "Text"],
Cell[113894, 3155, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
