(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    137231,       3927]
NotebookOptionsPosition[    132510,       3770]
NotebookOutlinePosition[    133480,       3809]
CellTagsIndexPosition[    133406,       3804]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["8.7  The Argument Principle and Rouch\[EAcute]'s \
Theorem",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
\tWe now derive two results based on Cauchy's residue theorem. They have \
important practical applications and pertain only to functions all of whose \
isolated singularities are poles.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Definition 8.3 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Meromorphic Function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MeromorphicFunction.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "      A function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is said to be meromorphic in a domain",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["D",
  FontFamily->"Courier New"],
 " provided the only singularities of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " are isolated poles and removable singularities."
}], "Text"],

Cell[TextData[{
 "\tWe make three important observations relating to this definition.\n\n",
 StyleBox["(i).",
  FontColor->RGBColor[0, 0, 1]],
 "   \tAnalytic functions are a special case of meromorphic functions.\n\n",
 StyleBox["(ii).",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " \tRational functions ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ", where ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(z)",
  FontFamily->"Courier New"],
 " are polynomials, are meromorphic in the entire complex plane.\n\n",
 StyleBox["(iii).",
  FontColor->RGBColor[0, 0, 1]],
 " \tBy definition, meromorphic functions have no essential singularities."
}], "Text"],

Cell[TextData[{
 "\tSuppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic at each point on a simple closed contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is meromorphic in the domain that is the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  We assert without proof that Theorem 7.13 can be extended to meromorphic \
functions so that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has at most a finite number of zeros that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".   Since the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"f", 
     RowBox[{"(", "x", ")"}]}]]}]]],
 "  is also meromorphic, it can have only a finite number of zeros inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", and so ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " can have at most a finite number of poles that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".\n\n\tTheorem 8.8, known as the argument principle, is useful in \
determining the number of zeros and poles that a function has."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.8 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Argument Principle",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ArgumentPrinciple.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " be meromorphic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is meromorphic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " and that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed positively oriented contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " such that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has no zeros or poles  (",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", 
   RowBox[{"0", "  ", "and", "  ", "f", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "\[Infinity]"}]]],
 ")  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ".  Then\n\n",
 StyleBox["(8-34)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["Z", "f"], " ", "-", " ", 
    SubscriptBox["P", "f"]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  SubscriptBox["Z", "f"]]],
 "  is the number of zeros of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and  ",
 Cell[BoxData[
  SubscriptBox["P", "f"]]],
 "  is the number of poles that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.8",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 8.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is analytic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  Let ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " be a simple closed positively oriented contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " such that for ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "\[Element]", "C"}], ",", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "0"}]}]]],
 ".  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   SubscriptBox["Z", "f"]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  SubscriptBox["Z", "f"]]],
 "  is the number of zeros of ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " that lie inside ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Corollary 8.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 8.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Certain feedback control systems in engineering must be stable.  A test \
for stability involves the function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"G", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"1", "+", 
    RowBox[{"F", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ", where ",
 StyleBox["F(z)",
  FontFamily->"Courier New"],
 " is a rational function.  If ",
 StyleBox["G(z)",
  FontFamily->"Courier New"],
 " does not have any zeros in the region ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{
     RowBox[{"Re", 
      RowBox[{"(", "z", ")"}]}], "\[GreaterEqual]", "0"}]}], "}"}]]],
 ", then the system is stable.  We determine the number of zeros of ",
 StyleBox["G(z)",
  FontFamily->"Courier New"],
 "  by writing ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ", where ",
 StyleBox["P(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["Q(z)",
  FontFamily->"Courier New"],
 " are polynomials with no common zero.  Then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"G", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}], "+", 
     RowBox[{"P", 
      RowBox[{"(", "z", ")"}]}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ", and we can check for the zeros of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}], "+", 
   RowBox[{"P", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " by using Theorem 8.8.  We select a value",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["R",
  FontFamily->"Courier New"],
 " so that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"G", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "0"}]]],
 " for ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"z", ":", 
    RowBox[{"|", "z", "|", 
     RowBox[{">", "R"}]}]}], "}"}]]],
 " and then integrate along the contour consisting of the right half of the \
circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "R"], 
   RowBox[{"(", "0", ")"}]}]]],
 " and the line segment between ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", "R", "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], " ", "-", 
   RowBox[{"\[ImaginaryI]", " ", "R"}]}]]],
 ". This method is known as the Nyquist stability criterion."
}], "Text"],

Cell[TextData[{
 "\tWhy do we label Theorem 8.8 as the argument principle?  The answer lies \
with a fascinating application known as the winding number. \nRecall that a \
branch of the logarithm function, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], " ", 
   RowBox[{"(", "z", ")"}]}]]],
 ", is defined by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], " ", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"ln", "|", "z", "|", " ", 
     RowBox[{
      RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", 
      SubscriptBox["arg", "\[Alpha]"], " ", 
      RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"ln", " ", "r"}], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]}]}]}]]],
 ",  \n\n\nwhere  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{"r", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Phi]", "\[LessEqual]", 
   RowBox[{"2", "\[Pi]"}]}]]],
 ".  Loosely speaking, suppose that for some branch of the logarithm, the \
composite function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], " ", 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], ")"}]}]]],
 " were analytic in a simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " containing the contour ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  This would imply that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], " ", 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], ")"}]}]]],
 " is an antiderivative of the function ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]]]],
 " for all ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "D"}]]],
 ".  Theorems 6.9 and 8.8 would then tell us that, as ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " winds around the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", the quantity ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["log", "\[Alpha]"], " ", 
    RowBox[{"(", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"ln", "|", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "|", " ", 
    RowBox[{
     RowBox[{"+", "  ", "\[ImaginaryI]"}], " ", 
     SubscriptBox["arg", "\[Alpha]"], " ", "f", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 " would change by ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["Z", "f"], "-", 
     SubscriptBox["P", "f"]}], ")"}]}]]],
 ".  Since ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["Z", "f"], "-", 
     SubscriptBox["P", "f"]}], ")"}]}]]],
 " is purely imaginary, this result tells us that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["arg", "\[Alpha]"], " ", "f", 
   RowBox[{"(", "z", ")"}]}]]],
 " would change by ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["Z", "f"], "-", 
     SubscriptBox["P", "f"]}], ")"}]}]]],
 " radians.  In other words, as ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " winds around ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", the integral ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}]}]]],
 " would count how many times the curve ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " winds around the origin."
}], "Text"],

Cell[TextData[{
 "\tUnfortunately, we can't always claim that ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["log", "\[Alpha]"], " ", 
   RowBox[{"(", 
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], ")"}]}]]],
 " is an antiderivative of the function ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]]]],
 " for all ",
 Cell[BoxData[
  RowBox[{"z", " ", "\[Epsilon]", " ", "D"}]]],
 ".  If it were, the Cauchy-Goursat theorem would imply that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], " ", "=", " ", "0"}]]],
 ".  Nevertheless, the heuristics that we gave - indicating that ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
   RowBox[{
    SubscriptBox["\[Integral]", "C"], " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "z", ")"}]}], 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}]], 
     RowBox[{"\[DifferentialD]", "z"}]}]}]}]]],
 " counts how many times the curve ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " winds around the origin - still hold true, as shown in the book."
}], "Text"],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{573, 343},
  ImageMargins->0],
 StyleBox["  \n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.10",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0810.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The points ",
 Cell[BoxData[
  SubscriptBox["z", "k"]]],
 " on the contour ",
 Cell[BoxData["C"]],
 " that winds around ",
 Cell[BoxData[
  SuperscriptBox["z", "*"]]],
 "."
}], "Text",
 CellChangeTimes->{{3.39946452915625*^9, 3.399464529765625*^9}, {
  3.3994645688125*^9, 3.399464607359375*^9}}],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{563, 495},
  ImageMargins->0],
 StyleBox["\n\n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.11",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0811.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The points ",
 Cell[BoxData[
  SubscriptBox["w", "k"]]],
 " on the contour ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " that winds around ",
 Cell[BoxData["0"]],
 "."
}], "Text",
 CellChangeTimes->{{3.39946453209375*^9, 3.3994645323125*^9}, {
  3.399464600015625*^9, 3.39946461534375*^9}}],

Cell[TextData[{
 StyleBox["Example 8.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The image of the circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "2"], 
   RowBox[{"(", "0", ")"}]}]]],
 " under ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "z"}]}]],
  AspectRatioFixed->True],
 " is the curve ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"4", "cos", " ", "2", "t"}], "+", 
        RowBox[{"2", "cos", " ", "t"}]}], ",", 
       RowBox[{
        RowBox[{"4", "sin", " ", "2", "t"}], "+", 
        RowBox[{"2", "sin", " ", "t"}]}]}], ")"}], ":", " ", 
     RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
      RowBox[{"2", "\[Pi]"}]}]}]}], "}"}]]],
 "shown in Figure 8.12.  \nNote that the image curve  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["C", "2"], 
     RowBox[{"(", "0", ")"}]}], ")"}]}]]],
 "  winds twice around the origin. We check this by computing\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SubsuperscriptBox["C", "2", "+"], 
       RowBox[{"(", "0", ")"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", 
      RowBox[{
       SubsuperscriptBox["C", "2", "+"], 
       RowBox[{"(", "0", ")"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", "z"}], "+", "1"}], 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ". \n\nThe residues of the integrand are at ",
 StyleBox["0",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["-1",
  FontFamily->"Courier New"],
 ". Thus \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
     RowBox[{
      SubscriptBox["\[Integral]", 
       RowBox[{
        SubsuperscriptBox["C", "2", "+"], 
        RowBox[{"(", "0", ")"}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"2", "z"}], "+", "1"}], 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"2", "z"}], "+", "1"}], 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}]], ",", "0"}], "]"}], " ", "+", 
     " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"2", "z"}], "+", "1"}], 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}]], ",", "1"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                        ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"1", " ", "+", " ", "1"}], "  ", "=", "  ", "2"}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{533, 206},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 8.12",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/rouchetheorem/\
RoucheTheoremFigures/mat0812.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The image curve  ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["C", "2"], 
     RowBox[{"(", "0", ")"}]}], ")"}]}]]],
 "  under  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", "2"], "+", "z"}]}]}]],
  AspectRatioFixed->True],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "We consider the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "2"], "+", "z"}]}]],
  AspectRatioFixed->True],
 "  and evaluate the integral  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "=", " ", "N"}]]],
 ",\nwhere ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Theta]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      SuperscriptBox["z", "2"], "+", "z"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "\[Theta]_", "]"}], " ", "=", " ", 
     RowBox[{"2", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "\[Theta]_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
        RowBox[{"f", "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val", " ", "=", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
        RowBox[{"f", "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]], 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}], 
       RowBox[{"\[DifferentialD]", "\[Theta]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              z[\[Theta]] = \>\"", ",", 
      RowBox[{"z", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           f[z[\[Theta]]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<             z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \(f[z[\[Theta]]]\)]\) \
z'[\[Theta]] = \>\"", ",", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"f", "'"}], "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
        RowBox[{"f", "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]], " ", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "\[Theta]", "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[\[Theta]] = \[Integral]\!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \
\(f[z[\[Theta]]]\)]\)z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", "\[Theta]", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[2\[Pi]] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\<,    F[0] = \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      "\"\<\!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \
\(f[z[\[Theta]]]\)]\)z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"2", "\[Pi]"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"F", "[", "0", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"2", "\[Pi]"}], "]"}], "-", 
       RowBox[{"F", "[", "0", "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      "\"\<\!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \
\(f[z[\[Theta]]]\)]\)z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      "val"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      UnderoverscriptBox["\"\<\[Integral]\>\"", "0", 
       RowBox[{"2", "\[Pi]"}]], ",", 
      "\"\<\!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \
\(f[z[\[Theta]]]\)]\)z'[\[Theta]]\[DifferentialD]\[Theta] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"center", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"0", "+", "0.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"center", ",", "contour", ",", "dot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \>\"", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"f", "'"}], "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], 
      RowBox[{"f", "[", 
       RowBox[{"z", "[", "\[Theta]", "]"}], "]"}]], ",", 
     "\"\< \[DifferentialD]z = \>\"", ",", 
     RowBox[{"ComplexExpand", "[", "val", "]"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The contour is the circle C: |z| = 2,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<with positive orientation.\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The desired integral is\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*FractionBox[\(1\), \(2  \[Pi]\[ImaginaryI]\)]\) \
\!\(\*UnderscriptBox[\(\[ContourIntegral]\), \(C\)]\) \
\!\(\*FractionBox[\(\(f'\)[z[\[Theta]]]\), \(f[z[\[Theta]]]\)]\) \
\[DifferentialD]z = \>\"", ",", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
       RowBox[{"ComplexExpand", "[", "val", "]"}]}], ",", "\"\<,\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<which is the winding number for the curve C.\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"f", "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], "]"}], ",", 
       RowBox[{"Im", "[", 
        RowBox[{"f", "[", 
         RowBox[{"z", "[", "\[Theta]", "]"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4.5"}], ",", "6.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "5.5"}], ",", "5.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "5"}], ",", "5", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "6", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image curve f(C) of the circle C:|z| = 2\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
   "Print", "[", 
    "\"\<winds around the origin in the w-plane N = 2 times.\>\"", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994651910625*^9, 3.3994651985*^9}, {
  3.40005995078125*^9, 3.4000599510625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tFinally, we note that if ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "-", "a"}]}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"g", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ", and thus we can generalize what we've just said to compute how many times \
the curve ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " winds around the point ",
 StyleBox["a",
  FontFamily->"Courier New"],
 ". Theorem 8.9 summarizes our discussion."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.9 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Winding Number",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/WindingNumberContour.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is meromorphic in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed, positively oriented contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " such that for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "\[Element]", "C"}], ",", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "\[NotEqual]", "\[Infinity]"}]]],
 ", then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"W", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "C", ")"}]}], ",", "a"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "z", ")"}]}], 
       RowBox[{
        RowBox[{"f", 
         RowBox[{"(", "z", ")"}]}], "-", "a"}]], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]]],
 ",  \n\nknown as the winding number of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " about ",
 StyleBox["a",
  FontFamily->"Courier New"],
 ", counts the number of times the curve ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " winds around the point ",
 StyleBox["a",
  FontFamily->"Courier New"],
 ".  If ",
 Cell[BoxData[
  RowBox[{"a", "=", "0"}]]],
 ", the integral counts the number of times the curve ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "C", ")"}]}]]],
 " winds around the origin."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 8.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 8.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Letting ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", "z"}]],
  AspectRatioFixed->True],
 " in Theorem 8.9 gives \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"W", 
    RowBox[{"(", 
     RowBox[{"C", ",", "a"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
     RowBox[{
      SubscriptBox["\[Integral]", "C"], " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"z", "-", "a"}]], 
       RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
    RowBox[{"{", GridBox[{
       {
        RowBox[{"1", ","}], 
        RowBox[{
         RowBox[{
          StyleBox["if",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " ", "a", " ", 
          StyleBox["lies",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[" ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["inside",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " ", "C"}], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["   ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["or",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], " "}]},
       {
        RowBox[{"0", ","}], 
        RowBox[{
         RowBox[{
          StyleBox["if",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " ", "a", " ", 
          StyleBox["lies",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[" ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["outside",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], " ", "C"}], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox["      ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]],
  AspectRatioFixed->True],
 "  \n\nwhich counts the number of times the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " winds around the point ",
 StyleBox["a",
  FontFamily->"Courier New"],
 ".  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is not a simple closed curve, but crosses itself perhaps several times, we \
can show (but omit the proof) that ",
 Cell[BoxData[
  RowBox[{"W", 
   RowBox[{"(", 
    RowBox[{"C", ",", "a"}], ")"}]}]],
  AspectRatioFixed->True],
 " still gives the number of times the curve ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " winds around the point ",
 StyleBox["a",
  FontFamily->"Courier New"],
 ". Thus winding number is indeed an appropriate term."
}], "Text"],

Cell["\<\
\tWe close this section with a result that will help us gain information \
about the location of the zeros and poles of meromorphic functions.\
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 8.10 (Rouche's Theorem).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are meromorphic functions defined in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simply closed contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " have no zeros or poles for ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ".  If the strict inequality ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       RowBox[{"g", 
        RowBox[{"(", "z", ")"}]}], "|"}]}]}]}]}]]],
 "  holds for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 " , then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "f"], "-", 
    SubscriptBox["P", "f"]}], "=", 
   RowBox[{
    SubscriptBox["Z", "g"], "-", 
    SubscriptBox["P", "g"]}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Theorem 8.10",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 8.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Suppose that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " are analytic functions defined in the simply connected domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a simple closed contour in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " have no zeros for ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ".  If the strict inequality  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       RowBox[{"g", 
        RowBox[{"(", "z", ")"}]}], "|"}]}]}]}]}]]],
 "  holds for all ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["Z", "f"], "=", 
   SubscriptBox["Z", "g"]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 StyleBox["Proof of Corollary 8.2",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 StyleBox[" is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Remark 8.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Theorem 8.10 is usually stated with the requirement that ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " satisfy the condition  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "|", 
   RowBox[{"<", 
    RowBox[{"|", 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}]}], "|"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "C"}]]],
 ".  The improved theorem that we gave was discovered by Irving Glicksberg \
(see the American Mathematical Monthly, 83 (1976), pp. 186-187). The weaker \
version is adequate for most purposes, however, as the following examples \
illustrate."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 8.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that al four zeros of the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "4"], "-", 
    RowBox[{"7", "z"}], "-", "1"}]}]]],
 "  lie in the disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "2"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", " ", "2"}]}]}], "}"}]}]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{606, 206},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"-", " ", 
    SuperscriptBox["z", "4"]}]}]]],
 ".  Then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "7"}], "z"}], "-", "1"}]}]]],
 ",  and at points on the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "2"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", 
      RowBox[{"|", "z", "|"}]}], "=", " ", "2"}], "}"}]}]]],
 "  we have the relation  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"|", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], "+", 
       RowBox[{"g", 
        RowBox[{"(", "z", ")"}]}]}], "|"}], "  ", "=", "  ", 
     RowBox[{"|", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "7"}], "z"}], " ", "-", " ", "1"}], "|"}]}], " ", 
    StyleBox[",",
     FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "                                  ", 
    RowBox[{"\[LessEqual]", "  ", 
     RowBox[{"|", 
      RowBox[{
       RowBox[{"-", "7"}], "z"}], "|", " ", 
      RowBox[{"+", " ", 
       RowBox[{"|", 
        RowBox[{"-", "1"}], "|"}]}]}]}], "  ", 
    StyleBox[",",
     FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "                                  ", 
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"7", "|", "z", "|", 
       RowBox[{"+", "  ", "1"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"7", "\[Cross]", "2"}], "+", "1"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{
    RowBox[{"=", "  ", "15"}], "  ", 
    StyleBox[",",
     FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "                                  ", 
    RowBox[{
     RowBox[{"<", "  ", "16"}], "   ", "=", "  ", 
     RowBox[{
      RowBox[{"|", " ", 
       SuperscriptBox["z", "4"], "|"}], "  ", "=", "  ", 
      RowBox[{"|", 
       RowBox[{"-", " ", 
        SuperscriptBox["z", "4"]}], "|"}]}]}], "  ", 
    StyleBox[",",
     FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "                                  ", 
    RowBox[{"=", "  ", 
     RowBox[{"|", 
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], "|"}]}], "  ", 
    StyleBox[",",
     FontColor->GrayLevel[1]]}]}]}]],
 "    \n\nOf course, if  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "|", " ", 
   RowBox[{"<", " ", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "|"}]}]}]]],
 ",  then as we indicated in Remark 8.5 we certainly have  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "|", " ", 
   RowBox[{"<", " ", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "|", 
     RowBox[{"+", 
      RowBox[{"|", 
       RowBox[{"g", 
        RowBox[{"(", "z", ")"}]}], "|"}]}]}]}]}]]],
 ",  so that the conditions for applying Corollary 8.2 are satisfied on the \
circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "2"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  The function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has a zero of order 4 at the origin, so ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " must have four zeros inside ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "2"], 
   RowBox[{"(", "0", ")"}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the functions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "4"], "  ", "and", "  ", 
     RowBox[{"g", "[", "z", "]"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "4"], "-", 
     RowBox[{"7", "z"}], "-", "1"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     SuperscriptBox["z", "4"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "4"], "-", 
      RowBox[{"7", "z"}], "-", "1"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39946522046875*^9}],

Cell[TextData[{
 "Show that at points on the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "2"}]]],
 " we have the relation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "-", 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}]}]}], "|"}], " ", "=", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{
      RowBox[{"7", "z"}], "+", "1"}], "|", " ", 
     RowBox[{"\[LessEqual]", 
      RowBox[{"|", 
       RowBox[{"7", "z"}], "|", 
       RowBox[{"+", " ", "1"}]}]}]}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"7", 
       RowBox[{"(", "2", ")"}]}], "+", "1"}], "=", 
     RowBox[{
      RowBox[{"15", "<", "16"}], "=", 
      RowBox[{"|", 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], "|"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"2", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "-", 
         RowBox[{"g", "[", 
          RowBox[{"2", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"f", "[", 
         RowBox[{"2", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "16.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "16", ",", "4"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The graphs of\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|f[2\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ \
\[Theta]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        RowBox[{"2", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}], ",", 
      "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"f", "[", 
          RowBox[{"2", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "]"}], ",", 
        
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|f[2\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ \
\[Theta]\)]\)]] - g[2\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\\\ \[Theta]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"2", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}], "-", 
        RowBox[{"g", "[", 
         RowBox[{"2", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "]"}]}], "]"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<for  0 \[LessEqual] \[Theta] \[LessEqual] 2\[Pi].\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39946522421875*^9, 3.39946522840625*^9}, 
   3.400059956328125*^9}],

Cell[TextData[{
 "The function  f(z)  has a zero of order  4  at the origin, and the \
hypothesis of Rouche's Theorem holds true for the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "2"}]]],
 ".  Therefore,  g(z)  has four zeros inside ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "2"}]]],
 ".  \n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can verify this by using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the zeros of  f(z)  and  g(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset1", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset2", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset1", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset2", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399465234140625*^9}],

Cell[TextData[{
 "Find out which zeros of g(z) lie inside the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<| < 2 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<| < 2 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<| < 2 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<| < 2 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], "<", "2"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399465238171875*^9, 3.3994652409375*^9}, {
  3.400059961765625*^9, 3.400059961984375*^9}}],

Cell[TextData[{
 "Therefore,  g(z)  has four zeros inside ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "2"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 8.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the polynomial  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    SuperscriptBox["z", "4"], "-", 
    RowBox[{"7", "z"}], "-", "1"}]}]]],
 "  has one zero in the disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["D", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", " ", "1"}]}]}], "}"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{606, 206},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Let ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"7", "z"}], "+", "1"}]}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}]}], "=", 
   SuperscriptBox["z", "4"]}]]],
 ".  At points on the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "1"], 
    RowBox[{"(", "0", ")"}]}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ":", 
      RowBox[{"|", "z", "|"}]}], "=", " ", "1"}], "}"}]}]]],
 "  we have the relation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"|", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], "+", 
      RowBox[{"g", 
       RowBox[{"(", "z", ")"}]}]}], "|"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"|", 
      SuperscriptBox["z", "4"], "|"}], "   ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "                              ", 
     RowBox[{"=", "  ", "1"}]}]}], "  ", 
   StyleBox[",",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]", " ", 
   "\[IndentingNewLine]", "                                  ", 
   RowBox[{"<", "  ", "6"}], "   ", 
   StyleBox[",",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"7", "  ", "-", "  ", "1"}], "  ", "=", "  ", 
     RowBox[{"|", 
      RowBox[{"7", "z"}], "|", " ", 
      RowBox[{"-", " ", 
       RowBox[{"|", "1", "|"}]}]}]}]}], " ", 
   StyleBox[",",
    FontColor->GrayLevel[1]], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "                                  ", 
   RowBox[{"\[LessEqual]", "  ", 
    RowBox[{"|", 
     RowBox[{
      RowBox[{"7", "z"}], " ", "-", " ", "1"}], "|"}]}], "  ", 
   StyleBox[",",
    FontColor->GrayLevel[1]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{"|", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "|"}]}], "  ", 
   StyleBox[",",
    FontColor->GrayLevel[1]]}]]],
 "  \n\nThe function ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " has one zero at the point ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox["1", "7"]}]]],
 " in the disk ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ", and the hypotheses of Corollary 8.2 hold on the circle ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["C", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 ".  Therefore ",
 StyleBox["g(z)",
  FontFamily->"Courier New"],
 " has one zero inside ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["D", "1"], 
   RowBox[{"(", "0", ")"}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Explore ",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 StyleBox["Solution 8.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]
}], "Text"],

Cell[TextData[{
 "Enter the functions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "7"}], "z"}], "-", 
     RowBox[{"1", "  ", "and", "  ", 
      RowBox[{"g", "[", "z", "]"}]}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "4"], "-", 
     RowBox[{"7", "z"}], "-", "1"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "g"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "7"}], "z"}], "-", "1"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", "4"], "-", 
      RowBox[{"7", "z"}], "-", "1"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399465260875*^9}],

Cell[TextData[{
 "Show that at points on the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 " we have the relation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], "-", 
     RowBox[{"g", 
      RowBox[{"(", "z", ")"}]}]}], "|"}], " ", "=", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{
      RowBox[{"7", "z"}], "+", "1"}], "|", " ", 
     RowBox[{"\[LessEqual]", 
      RowBox[{"|", 
       RowBox[{"7", "z"}], "|", 
       RowBox[{"+", " ", "1"}]}]}]}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"7", 
       RowBox[{"(", "2", ")"}]}], "+", "1"}], "=", 
     RowBox[{
      RowBox[{"15", "<", "16"}], "=", 
      RowBox[{"|", 
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], "|"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "[", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "-", 
         RowBox[{"g", "[", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"f", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "8.3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"2", "\[Pi]"}], ",", 
          FractionBox["\[Pi]", "2"]}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "16", ",", "4"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The graphs of\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|f[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ \
\[Theta]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"f", "[", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}], ",", 
      "\"\< = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{"f", "[", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}], "]"}]}], "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<|f[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ \
\[Theta]\)]\)] - g[\!\(\*SuperscriptBox[\(\[ExponentialE]\), \
\(\[ImaginaryI]\\\ \[Theta]\)]\)]| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "-", 
        RowBox[{"g", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], "]"}], ",", 
      "\"\< = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"f", "[", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}], "-", 
          RowBox[{"g", "[", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], "]"}]}], "]"}], ",", 
        
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Im", ",", "Re"}], "}"}]}]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<for  0 \[LessEqual] \[Theta] \[LessEqual] 2\[Pi].\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994652645625*^9, 3.399465269921875*^9}, 
   3.40005996759375*^9}],

Cell[TextData[{
 "The function  f(z)  has a zero at ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   FractionBox[
    RowBox[{"-", "1"}], "7"]}]]],
 "  in the unit disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1"}]}]]],
 ",  and the hypothesis of Rouche's Theorem holds true for the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  Therefore,  g(z)  has one zero inside ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  \n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We can verify this by using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the zeros of  f(z)  and  g(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset1", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset2", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "[", "z", "]"}], "\[Equal]", "0"}], ",", "z"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset1", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset2", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399465273328125*^9}],

Cell[TextData[{
 "Find out which zeros of g(z) lie inside the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"z", ",", 
       SubscriptBox["solset2", 
        RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "1"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "2"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "3"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              SubscriptBox["Z", "4"], "]"}], ",", 
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}]}], "}"}], "]"}]}], "}"}]}], "}"}],
       "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"centers", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "1"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "1"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "2"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "2"], "]"}], "-", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "3"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "3"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\)\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Re", "[", 
             SubscriptBox["Z", "4"], "]"}], ",", 
            RowBox[{
             RowBox[{"Im", "[", 
              SubscriptBox["Z", "4"], "]"}], "+", "0.1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"dots", ",", "centers", ",", "contour", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The zeros of g[z] = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "1"], ",", "\"\<| < 1 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "2"], ",", "\"\<| < 1 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "3"], ",", "\"\<| < 1 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<, Is |\>\"", ",", 
      SubscriptBox["Z", "4"], ",", "\"\<| < 1 ? \>\"", ",", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Abs", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}], "<", "1"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399465277734375*^9, 3.399465280171875*^9}, {
  3.400059973078125*^9, 3.4000599733125*^9}}],

Cell[TextData[{
 "Therefore,  g(z)  has one zero inside ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Argument Principle",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ArgumentPrincipleBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Rouche's Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/RoucheTheoremBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399465293015625*^9, 3.399465293125*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{980, 632},
WindowMargins->{{6, Automatic}, {Automatic, 1}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[6758, 246, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[8812, 329, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[71194, 1873, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[79346, 2152, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[81380, 2238, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 132850, 3782}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 146, 3, 29, "Text"],
Cell[1054, 37, 210, 4, 47, "Text"],
Cell[1267, 43, 753, 25, 47, "Text"],
Cell[2023, 70, 901, 30, 145, "Text"],
Cell[2927, 102, 1226, 39, 109, "Text"],
Cell[4156, 143, 2184, 82, 127, "Text"],
Cell[CellGroupData[{
Cell[6365, 229, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[6509, 235, 246, 9, 29, "Text",
 Evaluatable->False],
Cell[6758, 246, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[7107, 258, 1285, 50, 106, "Text"],
Cell[CellGroupData[{
Cell[8417, 312, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[8561, 318, 248, 9, 29, "Text",
 Evaluatable->False],
Cell[8812, 329, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9161, 341, 2691, 101, 114, "Text"],
Cell[11855, 444, 3953, 138, 225, "Text"],
Cell[15811, 584, 1576, 55, 81, "Text"],
Cell[17390, 641, 11398, 203, 378, "Text"],
Cell[28791, 846, 18935, 326, 548, "Text"],
Cell[47729, 1174, 3514, 124, 229, "Text",
 Evaluatable->False],
Cell[51246, 1300, 4397, 75, 220, "Text",
 Evaluatable->False],
Cell[55646, 1377, 739, 28, 29, "Text"],
Cell[CellGroupData[{
Cell[56410, 1409, 186, 7, 29, "Text"],
Cell[56599, 1418, 905, 36, 55, "Text",
 Evaluatable->False],
Cell[57507, 1456, 10524, 289, 983, "Input"]
}, Closed]],
Cell[68046, 1748, 655, 26, 44, "Text"],
Cell[68704, 1776, 2148, 81, 145, "Text"],
Cell[CellGroupData[{
Cell[70877, 1861, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[71021, 1867, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[71194, 1873, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[71543, 1885, 5820, 182, 130, "Text"],
Cell[77366, 2069, 166, 3, 29, "Text"],
Cell[77535, 2074, 1392, 57, 49, "Text"],
Cell[CellGroupData[{
Cell[78952, 2135, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[79096, 2141, 247, 9, 29, "Text",
 Evaluatable->False],
Cell[79346, 2152, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[79695, 2164, 1265, 53, 46, "Text"],
Cell[CellGroupData[{
Cell[80985, 2221, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[81129, 2227, 248, 9, 29, "Text",
 Evaluatable->False],
Cell[81380, 2238, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[81729, 2250, 873, 29, 62, "Text"],
Cell[82605, 2281, 621, 25, 29, "Text",
 Evaluatable->False],
Cell[83229, 2308, 3140, 54, 220, "Text",
 Evaluatable->False],
Cell[86372, 2364, 3814, 133, 312, "Text"],
Cell[CellGroupData[{
Cell[90211, 2501, 186, 7, 29, "Text"],
Cell[90400, 2510, 338, 13, 29, "Text"],
Cell[90741, 2525, 1057, 31, 172, "Input"],
Cell[91801, 2558, 824, 32, 29, "Text"],
Cell[92628, 2592, 3539, 99, 217, "Input"],
Cell[96170, 2693, 555, 18, 83, "Text"],
Cell[96728, 2713, 1173, 36, 192, "Input"],
Cell[97904, 2751, 230, 9, 29, "Text",
 Evaluatable->False],
Cell[98137, 2762, 8817, 236, 472, "Input"],
Cell[106957, 3000, 193, 8, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[107165, 3011, 615, 25, 26, "Text",
 Evaluatable->False],
Cell[107783, 3038, 2843, 49, 220, "Text",
 Evaluatable->False],
Cell[110629, 3089, 2791, 98, 300, "Text"],
Cell[CellGroupData[{
Cell[113445, 3191, 186, 7, 29, "Text"],
Cell[113634, 3200, 381, 15, 29, "Text"],
Cell[114018, 3217, 1103, 34, 172, "Input"],
Cell[115124, 3253, 824, 32, 29, "Text"],
Cell[115951, 3287, 3940, 106, 217, "Input"],
Cell[119894, 3395, 717, 26, 89, "Text"],
Cell[120614, 3423, 1173, 36, 192, "Input"],
Cell[121790, 3461, 230, 9, 29, "Text",
 Evaluatable->False],
Cell[122023, 3472, 8817, 236, 472, "Input"],
Cell[130843, 3710, 191, 8, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[131049, 3721, 281, 7, 26, "Text"],
Cell[131333, 3730, 302, 10, 29, "Text"],
Cell[131638, 3742, 296, 10, 29, "Text"],
Cell[131937, 3754, 249, 5, 29, "Text"],
Cell[132189, 3761, 317, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
