(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    435038,      13913]
NotebookOptionsPosition[    421323,      13526]
NotebookOutlinePosition[    422612,      13573]
CellTagsIndexPosition[    422537,      13568]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 9  z-transforms and applications",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\t\n\n\tThe ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform is useful for the manipulation of discrete data sequences and \
has acquired a new significance in the formulation and analysis of \
discrete-time systems.  It is used extensively today in the areas of applied \
mathematics, digital signal processing, control theory, population science, \
economics.  These discrete models are solved with difference equations in a \
manner that is analogous to solving continuous models with differential \
equations.  The role played by the z-transform in the solution of difference \
equations corresponds to that played by the Laplace transforms in the \
solution of differential equations. "
}], "Text"],

Cell[TextData[StyleBox["9.1  The  z-transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe function notation for sequences is used in the study and application \
of z-transforms.  Consider a function  ",
 Cell[BoxData[
  RowBox[{"x", "[", "t", "]"}]]],
 "  defined for  ",
 Cell[BoxData[
  RowBox[{"t", "\[GreaterEqual]", "0"}]]],
 "  that is sampled at times  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"t", "=", "T"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "T", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"2", "T"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"3", "T"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "..."}]]],
 ",  where  ",
 Cell[BoxData["T"]],
 "  is the sampling period (or rate).   We can write the sample as a sequence \
using the notation  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", 
      RowBox[{"n", " ", "T"}], "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 ".  Without loss of generality we will set  ",
 Cell[BoxData[
  RowBox[{"T", "=", "1"}]]],
 "  and consider real sequences such as,  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], " ", "=", " ", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 ".  The definition of the z-transform involves an infinite series of the \
reciprocals  ",
 Cell[BoxData[
  SuperscriptBox["z", 
   RowBox[{"-", "n"}]]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["z-transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/Z-Transform.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], " ", "=", " ", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform is defined as follows \n\n",
 StyleBox["(9-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubsuperscriptBox[
      RowBox[{"{", 
       SubscriptBox["x", "n"], "}"}], 
      RowBox[{"n", "=", "0"}], "\[Infinity]"], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}]}]}]]],
 ",  \n\nwhich is a series involving powers of  ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 ".  \n\n",
 StyleBox["Remark 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform is defined at points ",
 Cell[BoxData[
  RowBox[{"z", "\[Element]", "\[DoubleStruckCapitalC]"}]]],
 " where the Laurent series ",
 StyleBox["(9-1)",
  FontColor->RGBColor[0, 0, 1]],
 " converges.  The ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform region of convergence (ROC) for the Laurent series is chosen to \
be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"\[GreaterEqual]", " ", "R"}]}]]],
 ",    where    ",
 Cell[BoxData[
  RowBox[{"R", "  ", "=", "  ", 
   RowBox[{"lim", " ", "sup", " ", 
    RadicalBox[
     RowBox[{"|", 
      SubscriptBox["x", "n"], "|"}], "n"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The sequence notation  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["x", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  is used in mathematics to study difference equations and the function \
notation  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{"x", "[", "n", "]"}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  is used by engineers for signal processing.  It's a good idea to know \
both notations.  \n",
 StyleBox["Remark 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In the applications, the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], " ", "=", " ", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  will be used for inputs and the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["y", "n"], " ", "=", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  will be used for outputs.  We will also use the notations \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["x", "n"], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"x", "[", "n", "]"}], "]"}], "  ", "=", "  ", 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ",  and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["y", "n"], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"y", "[", "n", "]"}], "]"}], "  ", "=", "  ", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 9.1 (Inverse z-transform)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   Let  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  be the",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the sequence  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], " ", "=", " ", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  defined in the region  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"R", "<"}], "|", "z", "|"}]]],
 ".  Then ",
 Cell[BoxData[
  SubscriptBox["x", "n"]]],
 " is given by the formula  \n\n",
 StyleBox["(9-2)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
      RowBox[{
       UnderscriptBox["\[ClockwiseContourIntegral]", "C"], "  ", 
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}]}]]],
 ",  \n\t\t\nwhere ",
 Cell[BoxData["C"]],
 " is any positively oriented simple closed curve that lies in the region  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"R", "<"}], "|", "z", "|"}]]],
 "  and winds around the origin.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.1  Admissible form of a z-transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tFormulas for  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 " do not arise in a vacuum.  In an introductory course they are expressed as \
linear combinations of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transforms corresponding to elementary functions such as  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{"S", " ", "=", " ", 
   RowBox[{"{", 
    StyleBox[
     RowBox[{
      RowBox[{"\[Delta]", "[", "n", "]"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False}]}],
     FontColor->GrayLevel[0]], 
    StyleBox["}",
     FontColor->GrayLevel[1]]}]}]]],
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "[", "n", "]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "n"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"a", " ", "n"}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{"n", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["n", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["n", "m"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", " ", 
    SuperscriptBox["b", "n"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"n", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"a", " ", "n"}]]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["b", "n"], 
   RowBox[{"Sin", "[", 
    RowBox[{"a", " ", "n"}], "]"}]}]]],
 Cell[BoxData[
  StyleBox[",",
   FontFamily->"Times New Roman",
   FontSize->12,
   FontWeight->"Plain",
   FontSlant->"Plain",
   FontVariations->{"StrikeThrough"->False,
   "Underline"->False},
   FontColor->GrayLevel[0]]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["b", "n"], 
    RowBox[{"Cos", "[", 
     RowBox[{"a", " ", "n"}], "]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Sinh", "[", 
    RowBox[{"a", " ", "n"}], "]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Cosh", "[", 
    RowBox[{"a", " ", "n"}], "]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 Cell[BoxData[
  RowBox[{
   StyleBox["{",
    FontColor->GrayLevel[1]], 
   StyleBox[
    RowBox[{"etc", "."}],
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], "}"}]]],
 ".   \n\nIn Table 9.1, we will see that the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform of each function in  ",
 Cell[BoxData["S"]],
 "  is a rational function of the complex variable  ",
 Cell[BoxData["z"],
  AspectRatioFixed->True],
 ".  It can be shown that a linear combination of rational functions is a \
rational function.  Therefore, for the examples and applications considered \
in this book we can restrict the",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transforms to be rational functions.  This restriction is emphasized this \
in the following definition."
}], "Text"],

Cell[TextData[{
 StyleBox["Definition 9.2 (Admissible z-transform)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Given the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "n"}]]}]}]}]]],
 "  we say that ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 " is an admissible ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform, provided that it is a rational function, that is  \n\n",
 StyleBox["(9-3)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", 
      RowBox[{"(", "z", ")"}]}], 
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}]], "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], "+", 
        RowBox[{
         SubscriptBox["b", "1"], 
         SuperscriptBox["z", "1"]}], "+", 
        RowBox[{
         SubscriptBox["b", "2"], 
         SuperscriptBox["z", "2"]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["b", 
        RowBox[{"p", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{"p", "-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["b", "p"], 
       SuperscriptBox["z", "p"]}]}], 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["a", "0"], "+", 
        RowBox[{
         SubscriptBox["a", "1"], 
         SuperscriptBox["z", "1"]}], "+", 
        RowBox[{
         SubscriptBox["a", "2"], 
         SuperscriptBox["z", "2"]}], "+"}], "..."}], "+", 
      RowBox[{
       SubscriptBox["a", 
        RowBox[{"q", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{"q", "-", "1"}]]}], "+", 
      RowBox[{
       SubscriptBox["a", "q"], 
       SuperscriptBox["z", "q"]}]}]]}]}]]],
 ", \n\nwhere ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", "z", ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "Q", 
   RowBox[{"(", "z", ")"}]}]]],
 ", are polynomials of degree ",
 Cell[BoxData[
  RowBox[{"p", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "q"}]]],
 ", respectively.  \n\n\tFrom our knowledge of rational functions, we see \
that an admissible ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform is defined everywhere in the complex plane except at a finite \
number of isolated singularities that are poles and occur at the points where \
 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]],
  AspectRatioFixed->True],
 ".  The Laurent series expansion in  ",
 StyleBox["(9-1)",
  FontColor->RGBColor[0, 0, 1]],
 " can be obtained by a partial fraction manipulation and followed by \
geometric series expansions in powers of ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 ".  However, the signal feature of formula ",
 StyleBox["(9-3)",
  FontColor->RGBColor[0, 0, 1]],
 " is the calculation of the inverse ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform via residues.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 9.2 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Cauchy's Residue Theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ResidueTheorem.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[")",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  D  be a simply connected domain, and let  C  be a simple closed \
positively oriented contour that lies in  D.  If  f(z)  is analytic inside  C \
 and on  C,  except at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  that lie inside  C,  then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], 
    RowBox[{
     SubscriptBox["\[Integral]", "C"], " ", 
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}], 
      RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j", "=", "1"}], "k"], " ", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SubscriptBox["z", "j"]}], "]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.2 is in the book (see Theorem \
8.1).",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 9.1 (Inverse z-transform)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   Let  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  be the",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the sequence ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["x", "n"], "}"}]]],
 ".  Then ",
 Cell[BoxData[
  SubscriptBox["x", "n"]]],
 " is given by the formula  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "   ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "k"], 
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        SubscriptBox["z", "j"]}], "]"}]}]}]}]}]]],
 ".  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Corollary 9.2 (Inverse z-transform)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "   Let  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  be the",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the sequence.  If   ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]],
  AspectRatioFixed->True],
 "  has simple poles at the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  then  ",
 Cell[BoxData[
  SubscriptBox["x", "n"]]],
 " is given by the formula  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "k"], 
      RowBox[{"(", " ", 
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", " ", 
          SubscriptBox["z", "j"]}]], "  ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "j"]}], ")"}], "X", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}]}], " ", ")"}]}]}]}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  Find the",
  FontFamily->"Times New Roman"],
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the",
 StyleBox[" unit pulse or impulse sequence   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Delta]", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{"{", GridBox[{
       {"1", 
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[
           RowBox[{"  ", 
            StyleBox[" ",
             FontWeight->"Plain"]}]], "n"}], "=", "0"}]},
       {"0", 
        StyleBox[
         RowBox[{"otherwise", "   "}],
         FontFamily->"Times New Roman",
         FontSize->12,
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.1.  This follows trivially from Equation ",
 StyleBox["(9-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubscriptBox["x", "n"], "]"}], "  ", "=", "   ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
        RowBox[{"0", 
         SuperscriptBox["z", 
          RowBox[{"-", "n"}]]}]}]}], "  ", "=", "  ", "1"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"KroneckerDelta", "[", "n", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<     X[z] = 1 +  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\
\[Infinity]\)]\) \!\(\*SubscriptBox[\(x\), \(n\)]\) \
\!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<     X[z] = 1 +  \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 1\), \(\
\[Infinity]\)]\) 0 \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \[GothicCapitalZ][\!\(\*SubscriptBox[\(x\), \(n\)]\)] = \>\"", 
      ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     \[GothicCapitalZ][ \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< ] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473509734375*^9, 3.399473550484375*^9}, {
  3.40006010325*^9, 3.4000601035*^9}, {3.40034611290625*^9, 
  3.400346122203125*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can easily find the inverse of  X[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   \!\(\*SubscriptBox[\(x\), \(n\)]\)  = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)[X[z]] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"X", "[", "z", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473556078125*^9, 3.39947355734375*^9}, 
   3.4003461383125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  The",
  FontFamily->"Times New Roman"],
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the",
 StyleBox[" unit-step sequence   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"u", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{"{", GridBox[{
       {"1", 
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[
           RowBox[{
            StyleBox[" ",
             FontFamily->"Times New Roman",
             FontSize->12,
             FontSlant->"Plain",
             FontVariations->{"StrikeThrough"->False,
             "Underline"->False},
             FontColor->GrayLevel[0]], "  "}]], "n"}], "\[GreaterEqual]", 
         "0"}]},
       {"0", 
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[
           RowBox[{"   ", 
            StyleBox[" ",
             FontWeight->"Plain"]}],
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["n",
           FontFamily->"Courier New"]}], 
         StyleBox["<",
          FontFamily->"Courier New"], 
         StyleBox["0",
          FontFamily->"Courier New"]}]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]]],
 "  is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["z", 
    RowBox[{"z", " ", "-", " ", "1"}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.2.  From Equation ",
 StyleBox["(9-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "   ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox["z", 
       RowBox[{"-", "n"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]], ")"}], "n"]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]], "  ", "=", "  ", 
     FractionBox["z", 
      RowBox[{"z", "-", "1"}]]}]}]}]}]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"UnitStep", "[", "n", "]"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<    X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) 1 \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    X[z] = \>\"", ",", 
      FractionBox["1", 
       RowBox[{"1", "-", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    \[GothicCapitalZ][{\>\"", ",", "1", ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    \[GothicCapitalZ][ \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\< ] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994735645*^9, 3.39947357765625*^9}, {
   3.4000601098125*^9, 3.400060110078125*^9}, 3.400060473078125*^9, 
   3.400346143953125*^9}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In the above figure we have used the ",
 Cell[BoxData["FillingListPlot"],
  CellChangeTimes->{3.400060548515625*^9}],
 " option ",
 Cell[BoxData[
  RowBox[{"Filling", "\[Rule]", "Axis"}]],
  CellChangeTimes->{3.400060548515625*^9}],
 " which draws the grey lines from the axes to the points of the sequence.  \
This is the preferred of signal processing engineers to display sequences.  \
On some occasions we might display the points without the \"grey lines.\""
}], "Text",
 CellChangeTimes->{{3.400060491765625*^9, 3.400060742203125*^9}}],

Cell[TextData[{
 "We can use residues to find the inverse.\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]], 
    FractionBox["z", 
     RowBox[{"z", "-", "1"}]]}]}]]],
 " \n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ",", "1"}], "]"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]], 
     FractionBox["z", 
      RowBox[{"z", "-", "1"}]]}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", "1"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   "InverseViaResidues", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473582359375*^9, 3.399473612015625*^9}, {
  3.400346155703125*^9, 3.40034616403125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", "1"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZResidue", "[", 
     RowBox[{
      SubscriptBox["z", "1"], ",", "1"}], "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", "lim"}], " ",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"lim", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473583578125*^9, 3.399473608375*^9}, {
  3.400346200875*^9, 3.400346212890625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 "The",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the sequence",
 StyleBox["   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "="}]]],
 "  ",
 Cell[BoxData[
  SuperscriptBox["b", "n"]]],
 "   is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["z", 
    RowBox[{"z", " ", "-", " ", "b"}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.3.  From Definition 9.1 \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}], "  ", "=", "   ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["b", "n"], 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{"(", 
        FractionBox[
         SuperscriptBox["b", "n"], 
         SuperscriptBox["z", "n"]], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["b", "z"], ")"}], "n"]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       FractionBox["b", "z"]}]], "  ", "=", "  ", 
     FractionBox["z", 
      RowBox[{"z", " ", "-", " ", "b"}]]}]}]}]}]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "n", ",", "x", ",", "X"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["b", "n"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["b", "z"]}], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473621828125*^9, 3.39947362296875*^9}, {
  3.40034623825*^9, 3.40034624134375*^9}}],

Cell[TextData[{
 "We can explore the situation when  ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   FractionBox["4", "5"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   FractionBox["6", "5"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"b", "=", 
     FractionBox["4", "5"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["b", "n"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.01"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["b", "z"]}], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947362671875*^9, 3.39947367515625*^9}, {
   3.400060116375*^9, 3.400060116609375*^9}, 3.40006078846875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"b", "=", 
     FractionBox["6", "5"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["b", "n"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.01"}], ",", "7"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["b", "z"]}], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473681921875*^9, 3.399473700890625*^9}, {
   3.40006012315625*^9, 3.40006012353125*^9}, 3.40006079753125*^9}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "X", ",", "Z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", "b"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   "InverseViaResidues", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473705421875*^9, 3.399473712921875*^9}, {
  3.40034625796875*^9, 3.400346262734375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", "b"}]]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZResidue", "[", 
     RowBox[{
      SubscriptBox["z", "1"], ",", "1"}], "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", "lim"}], " ",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"lim", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947370871875*^9, 3.39947371203125*^9}, {
  3.400346271859375*^9, 3.400346274234375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 "The",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the",
 StyleBox[" exponential sequence   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"a", " ", "n"}]]}]]],
 "   is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["z", 
    RowBox[{"z", "-", 
     SuperscriptBox["\[ExponentialE]", "a"]}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.4.  From Definition 9.1  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}], "  ", "=", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "n"}]], 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{"(", 
        FractionBox[
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"a", " ", "n"}]], 
         SuperscriptBox["z", "n"]], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", "a"], "z"], ")"}], "n"]}]}]}], 
    " ", "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["\[ExponentialE]", "a"], "z"]}]], "  ", "=", "  ", 
     FractionBox["z", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", "a"]}]]}]}]}]}]],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "x", ",", "X", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "n"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   {\!\(\*SubscriptBox[\(x\), \
\(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)  = \>\"",
       ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"a", " ", "n"}]], "z"]}], ")"}]}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947372746875*^9, 3.399473728796875*^9}, {
  3.40034628396875*^9, 3.400346289546875*^9}}],

Cell[TextData[{
 "We can explore the situation when  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{"-", 
    FractionBox["1", "10"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["1", "10"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     FractionBox[
      RowBox[{"-", "1"}], "10"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "n"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.01"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"a", " ", "n"}]], "z"]}], ")"}]}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473733890625*^9, 3.3994737554375*^9}, {
   3.400060129171875*^9, 3.4000601294375*^9}, 3.400060819671875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     FractionBox["1", "10"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "n"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "10.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.01"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "10", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"a", " ", "n"}]], "z"]}], ")"}]}]}], " ", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947376*^9, 3.3994737745625*^9}, {3.400060134671875*^9,
    3.40006013490625*^9}, 3.400060828203125*^9}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", "a"]}]]}], ";"}], "  ", 
   "\[IndentingNewLine]", "InverseViaResidues", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994737784375*^9, 3.399473785328125*^9}, {
  3.400346302296875*^9, 3.400346306640625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox["z", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", "a"]}]]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ZResidue", "[", 
     RowBox[{
      SubscriptBox["z", "1"], ",", "1"}], "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", "lim"}], " ",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      RowBox[{"PowerExpand", "[", "lim", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"lim", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473779578125*^9, 3.399473786421875*^9}, {
  3.400346312671875*^9, 3.4003463141875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.2  Properties of the z-transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tGiven that   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["x", "n"], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"x", "[", "n", "]"}], "]"}], " ", "=", " ", 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["y", "n"], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"y", "[", "n", "]"}], "]"}], " ", "=", " ", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  We have the following properties: \n\t\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["    ",
  FontWeight->"Bold"],
 "Linearity.\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], " ", 
      SubscriptBox["x", "n"]}], "+", 
     RowBox[{
      SubscriptBox["c", "2"], 
      SubscriptBox["y", "n"]}]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], " ", 
       RowBox[{"x", "[", "n", "]"}]}], "+", 
      RowBox[{
       SubscriptBox["c", "2"], 
       RowBox[{"y", "[", "n", "]"}]}]}], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], " ", "X", 
      RowBox[{"(", "z", ")"}]}], "+", 
     RowBox[{
      SubscriptBox["c", "2"], "Y", 
      RowBox[{"(", "z", ")"}]}]}]}]}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["   ",
  FontWeight->"Bold"],
 "Delay Shift.\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "N"}], "]"}], 
     RowBox[{"u", "[", 
      RowBox[{"n", "-", "N"}], "]"}]}], "]"}], "  ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"-", "N"}]]}]}]]],
 ".  \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["  ",
  FontWeight->"Bold"],
 "Advance Shift.\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "N"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "N"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        RowBox[{"x", "[", "0", "]"}], " ", "-", " ", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], " ", "-", " ", 
        RowBox[{
         RowBox[{"x", "[", "2", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "-"}], "..."}], "-", " ", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"N", "-", "1"}], "]"}], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"-", "N"}], "+", "1"}]]}]}], ")"}]}]}]]],
 ",   or\n\n\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["x", 
     RowBox[{"n", "+", "N"}]], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "N"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        SubscriptBox["x", "0"], " ", "-", " ", 
        RowBox[{
         SubscriptBox["x", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}], " ", "-", " ", 
        RowBox[{
         SubscriptBox["x", "2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "2"}]]}], "-"}], "..."}], "-", " ", 
      RowBox[{
       SubscriptBox["x", 
        RowBox[{"N", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{
         RowBox[{"-", "N"}], "+", "1"}]]}]}], ")"}]}]}]]],
 "\n\n",
 StyleBox["(iv)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["   ",
  FontWeight->"Bold"],
 "Multiplication by ",
 Cell[BoxData["n"]],
 ".\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"n", " ", 
     SubscriptBox["x", "n"]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"n", " ", 
      RowBox[{"x", "[", "n", "]"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "z"}], " ", 
     FractionBox["d", "dz"], "X", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  T",
  FontFamily->"Times New Roman"],
 "he",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transform of the ",
 StyleBox["sequence   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{"a", " ", "n"}], ")"}]}]}]]],
 "   is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       RowBox[{"cos", 
        RowBox[{"(", "a", ")"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"2", " ", "z", " ", "cos", 
      RowBox[{"(", "a", ")"}]}], "+", "1"}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.5.\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubscriptBox["x", "n"], "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"\[GothicCapitalZ]", "[", 
      RowBox[{"cos", 
       RowBox[{"(", 
        RowBox[{"a", " ", "n"}], ")"}]}], "]"}], "  ", "=", "  ", 
     RowBox[{"\[GothicCapitalZ]", "[", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]]}]}], 
      "]"}]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[GothicCapitalZ]", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"\[GothicCapitalZ]", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]], "]"}]}]}], 
      "  ", "=", "  ", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox["z", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]]}]]}], "+", 
       RowBox[{
        FractionBox["1", "2"], 
        FractionBox["z", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}]]}]}]}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]], " ", 
        "+", " ", 
        FractionBox[
         RowBox[{"z", 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"z", " ", "-", " ", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]]}], " ", 
       ")"}]}]}], "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "z"}], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]], "  ", 
      "=", "  ", 
      FractionBox[
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "a"}]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], "2"]}], ")"}]}], 
       
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", " ", "-", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]]}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"cos", 
          RowBox[{"(", "a", ")"}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]], "  ", "=",
      "  ", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"cos", 
          RowBox[{"(", "a", ")"}]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "z", " ", "cos", 
        RowBox[{"(", "a", ")"}]}], "+", "1"}]]}]}]}]}]],
 "    \n\n",
 StyleBox["Remark 9.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  When using the residue theorem to compute inverse",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transforms, the complex form is preferred, i. e. \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    SubscriptBox["x", "n"], "]"}], "  ", "=", "  ", 
   FractionBox[
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "z"}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "a"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "a"}]]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]]}], ")"}]}]]}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "x", ",", "X", ",", "X3"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", " ", "n"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     RowBox[{"ZTransform", "[", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X3", "[", "z_", "]"}], "=", 
     RowBox[{"X", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(x\), \(n\)]\)  = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*SubscriptBox[\(x\), \(n\)]\)  = \!\(\*FractionBox[\(1\), \(2\
\)]\)(\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\[ImaginaryI]\\\ a\\\ \
n\)]\) + \!\(\*SuperscriptBox[\(\[ExponentialE]\), \(\(-\[ImaginaryI]\)\\\ \
a\\\ n\)]\))\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zt1", "=", 
     RowBox[{"ZTransform", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]], ",", "n", ",", "z"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"num1", "=", 
     RowBox[{"Numerator", "[", "zt1", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"den1", "=", 
     RowBox[{"Denominator", "[", "zt1", "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zt2", "=", 
     RowBox[{"ZTransform", "[", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]], ",", "n", ",",
        "z"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"num2", "=", 
     RowBox[{
      RowBox[{"Numerator", "[", "zt2", "]"}], "/", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "a"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"den2", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"Denominator", "[", "zt2", "]"}], "/", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "a"}]]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zt2", " ", "=", 
     RowBox[{"num2", "/", "den2"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        RowBox[{"zt1", "+", "zt2"}], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          RowBox[{"num1", " ", "den2"}], "+", 
          RowBox[{"num2", " ", "den1"}]}], 
         RowBox[{"den1", " ", "den2"}]], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"num1", " ", "den2"}], "+", 
           RowBox[{"num2", " ", "den1"}]}], "]"}], 
         RowBox[{"den1", " ", "den2"}]], ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"ComplexExpand", "[", 
           RowBox[{
            RowBox[{"num1", " ", "den2"}], "+", 
            RowBox[{"num2", " ", "den1"}]}], "]"}], 
          RowBox[{"ComplexExpand", "[", 
           RowBox[{"den1", " ", "den2"}], "]"}]], ")"}]}], " ", "]"}]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473821453125*^9, 3.3994738233125*^9}, {
  3.40034632671875*^9, 3.400346333734375*^9}}],

Cell[TextData[{
 "Some more details.\n\nWe could sum the z-transforms of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "x", ",", "X", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X1", "[", "z_", "]"}], " ", "=", 
     RowBox[{"X", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], "z"]}], ")"}]}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473831*^9, 3.399473837265625*^9}, {
  3.400346341921875*^9, 3.40034634684375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "x", ",", "X", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]]}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X2", "[", "z_", "]"}], " ", "=", 
     RowBox[{"X", "[", "z", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "a"}]], "z"]}], ")"}]}]}], 
     " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473834421875*^9, 3.39947384046875*^9}, {
  3.4003463519375*^9, 3.400346357125*^9}}],

Cell["Now we can add the above two results.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", " ", "n"}], "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \
\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "a", " ", "n"}]]}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] + \
\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{
       FractionBox["1", "2"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "n"}]]}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \
\(\[Infinity]\)]\)]\>\""}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", " ", "n"}], "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{
       RowBox[{"X1", "[", "z", "]"}], "+", 
       RowBox[{"X2", "[", "z", "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", " ", "n"}], "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"X1", "[", "z", "]"}], "+", 
        RowBox[{"X2", "[", "z", "]"}]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Which agrees with our previous computation\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"a", " ", "n"}], "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X3", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473844171875*^9, 3.399473845328125*^9}}],

Cell[TextData[{
 "We can explore the situation when  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["\[Pi]", "6"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     FractionBox["\[Pi]", "6"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", " ", "n"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "12"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "12.3"}], "}"}], ",", "All"}], "}"}]}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "12", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947384896875*^9, 3.399473867609375*^9}, {
   3.40006013996875*^9, 3.400060140171875*^9}, 3.4000608599375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     FractionBox["\[Pi]", "4"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      RowBox[{"a", " ", "n"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pts", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{"x", "[", "n", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "12"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"pts", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "12.3"}], "}"}], ",", "All"}], "}"}]}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "12", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Transpose", "[", "pts", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
        ",", "\"\<...\>\""}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Form the series\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  X[z] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(\
\[Infinity]\)]\) \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\< \!\(\*SuperscriptBox[\(z\), \(-n\)]\)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the z-transform\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[GothicCapitalZ][{\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", 
      "\"\<\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\)] = \>\
\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994738798125*^9, 3.39947389396875*^9}, {
   3.400060145921875*^9, 3.400060146109375*^9}, 3.400060867078125*^9}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can find the inverse of  X[z]  using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "a"}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a"}]], "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}]]}], 
    ";"}], "  ", "\[IndentingNewLine]", "InverseViaResidues", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "n_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"MapAll", "[", 
       RowBox[{"PowerExpand", ",", 
        RowBox[{"s", "[", "n", "]"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947390009375*^9, 3.39947390396875*^9}, {
  3.400346370359375*^9, 3.40034637275*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "a"}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a"}]], "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}]]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim1", "=", 
     RowBox[{"PowerExpand", "[", " ", 
      RowBox[{"ZResidue", "[", 
       RowBox[{
        SubscriptBox["z", "1"], ",", "1"}], "]"}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim2", "=", 
     RowBox[{"PowerExpand", "[", " ", 
      RowBox[{"ZResidue", "[", 
       RowBox[{
        SubscriptBox["z", "2"], ",", "1"}], "]"}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      RowBox[{"lim1", "+", "lim2"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"lim1", "+", "lim2"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
      RowBox[{"FullSimplify", "[", 
       RowBox[{"lim1", "+", "lim2"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"FullSimplify", "[", 
           RowBox[{"lim1", "+", "lim2"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947390165625*^9, 3.399473907078125*^9}, 
   3.40034638725*^9}],

Cell[TextData[{
 "We are really done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can find the let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " find the inverse of  X[z]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "a"}]], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "a"}]], "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "a"}]], " ", "z"}]}], ")"}]}]]}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   a = \>\"", ",", "a"}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"x", "[", "n", "]"}], "]"}], ",", 
       RowBox[{"n", "\[Element]", "Integers"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"CoefficientList", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"X", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "\[Infinity]", ",", "9"}], "}"}]}], "]"}], 
         "]"}], ",", 
        FractionBox["1", "z"]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947391471875*^9, 3.39947392084375*^9}, 
   3.40034639828125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"Cos", "[", "a", "]"}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", " ", "z", " ", 
        RowBox[{"Cos", "[", "a", "]"}]}], "+", "1"}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   a = \>\"", ",", "a"}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"x", "[", "n", "]"}], "]"}], ",", 
       RowBox[{"n", "\[Element]", "Integers"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"CoefficientList", "[", 
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"X", "[", "z", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "\[Infinity]", ",", "9"}], "}"}]}], "]"}], 
         "]"}], ",", 
        FractionBox["1", "z"]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n] = \>\"", ",", 
      RowBox[{"TrigReduce", "[", 
       RowBox[{"x", "[", "n", "]"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947392396875*^9, 3.399473925328125*^9}, 
   3.400346402859375*^9}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In the preceding figure we have used the ",
 Cell[BoxData["FillingListPlot"],
  CellChangeTimes->{3.400060548515625*^9}],
 " option ",
 Cell[BoxData[
  RowBox[{"Filling", "\[Rule]", "Axis"}]],
  CellChangeTimes->{3.400060548515625*^9}],
 " which draws the grey lines from the axes to the points of the sequence.  \
This is the preferred of signal processing engineers to display sequences.  \
On some occasions we might display the points without the \"grey lines.\""
}], "Text",
 CellChangeTimes->{{3.400060491765625*^9, 3.400060742203125*^9}, {
   3.40006110771875*^9, 3.400061109671875*^9}, 3.400061140140625*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.3  Table of z-transforms",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  \n\n\tWe list the following table of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transforms.  It can also be used to find the inverse z-transform.   \n\t\n\
\t\t\t",
 Cell[BoxData[GridBox[{
    {"  ", 
     StyleBox["Sequence",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"z", "-", "transform"}],
      FontWeight->"Bold"]},
    {"1", 
     RowBox[{"\[Delta]", "[", "n", "]"}], "1"},
    {"2", 
     RowBox[{"u", "[", "n", "]"}], 
     FractionBox["z", 
      RowBox[{"z", " ", "-", " ", "1"}]]},
    {"3", 
     SuperscriptBox["b", "n"], 
     FractionBox["z", 
      RowBox[{"z", " ", "-", " ", "b"}]]},
    {"4", 
     RowBox[{
      SuperscriptBox["b", 
       RowBox[{"n", "-", "1"}]], 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], 
     FractionBox["1", 
      RowBox[{"z", " ", "-", " ", "b"}]]},
    {"5", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"a", " ", "n"}]], 
     FractionBox["z", 
      RowBox[{"z", " ", "-", " ", 
       SuperscriptBox["\[ExponentialE]", "a"]}]]},
    {"6", "n", 
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}], "2"]]},
    {"7", 
     SuperscriptBox["n", "2"], 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "+", " ", "1"}], ")"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}], "3"]]},
    {"8", 
     RowBox[{
      SuperscriptBox["b", "n"], " ", "n"}], 
     FractionBox[
      RowBox[{"b", " ", "z"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "b"}], ")"}], "2"]]},
    {"9", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"a", " ", "n"}]], " ", "n"}], 
     FractionBox[
      RowBox[{"z", " ", 
       SuperscriptBox["\[ExponentialE]", "a"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", 
         SuperscriptBox["\[ExponentialE]", "a"]}], ")"}], "2"]]},
    {"10", 
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{"a", " ", "n"}], ")"}]}], 
     FractionBox[
      RowBox[{"sin", 
       RowBox[{"(", "a", ")"}], "z"}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", "cos", 
        RowBox[{"(", "a", ")"}], "z"}], " ", "+", "1"}]]},
    {"11", 
     RowBox[{
      SuperscriptBox["b", "n"], " ", "sin", 
      RowBox[{"(", 
       RowBox[{"a", " ", "n"}], ")"}]}], 
     FractionBox[
      RowBox[{"sin", 
       RowBox[{"(", "a", ")"}], "b", " ", "z", " "}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", "cos", 
        RowBox[{"(", "a", ")"}], " ", "b", " ", "z"}], " ", "+", 
       SuperscriptBox["b", "2"]}]]},
    {"12", 
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{"a", " ", "n"}], ")"}]}], 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"cos", 
          RowBox[{"(", "a", ")"}]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", "cos", 
        RowBox[{"(", "a", ")"}], " ", "z"}], " ", "+", "1"}]]},
    {"13", 
     RowBox[{
      SuperscriptBox["b", "n"], " ", "cos", 
      RowBox[{"(", 
       RowBox[{"a", " ", "n"}], ")"}]}], 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"b", " ", "cos", 
          RowBox[{"(", "a", ")"}]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", "cos", 
        RowBox[{"(", "a", ")"}], " ", "b", " ", "z"}], " ", "+", 
       SuperscriptBox["b", "2"]}]]}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
     "RowsIndexed" -> {}}]]],
 "  \n\t\n\t\t\t",
 StyleBox["Table 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 "transforms of some common sequences. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "n", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fun", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"KroneckerDelta", "[", "n", "]"}], ",", 
       RowBox[{"UnitStep", "[", "n", "]"}], ",", 
       SuperscriptBox["b", "n"], ",", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"a", " ", "n"}]], ",", "n", ",", 
       SuperscriptBox["n", "2"], ",", 
       SuperscriptBox["n", "3"], ",", 
       RowBox[{"n", " ", 
        SuperscriptBox["b", "n"]}], ",", 
       RowBox[{"n", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"a", " ", "n"}]]}], ",", 
       SqrtBox["n"], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"a", " ", "n"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["b", "n"], 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "n"}], "]"}]}], ",", 
       RowBox[{"n", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "n"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"a", " ", "n"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["b", "n"], 
        RowBox[{"Cos", "[", 
         RowBox[{"a", " ", "n"}], "]"}]}], ",", 
       RowBox[{"n", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", " ", "n"}], "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"trz", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"ZTransform", "[", 
       RowBox[{"fun", ",", "n", ",", "z"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"TableForm", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"fun", ",", "trz"}], "}"}], "]"}], ",", 
      RowBox[{"TableHeadings", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{"{", 
          RowBox[{"\"\<sequence\>\"", ",", "\"\<z-transform\>\""}], "}"}]}], 
        "}"}]}]}], " ", "]"}], " ", "]"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399473972125*^9, 3.3994739735625*^9}, {
  3.3994740343125*^9, 3.399474040984375*^9}, {3.400346415640625*^9, 
  3.400346432234375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Theorem 9.3 (Residues at Poles)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n",
  FontColor->RGBColor[1, 0, 1]],
 "\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " has a simple pole at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then the residue is   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     SubscriptBox["z", "0"]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}], "f", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " has a pole of order ",
 Cell[BoxData["2"]],
 " at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then the residue is   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     SubscriptBox["z", "0"]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", " ", "\[Rule]", " ", 
      SubscriptBox["z", "0"]}]], 
    RowBox[{
     FractionBox["d", "dz"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "0"]}], ")"}], "2"], "f", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  \tIf ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " has a pole of order ",
 Cell[BoxData["3"]],
 " at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  then the residue is   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     SubscriptBox["z", "0"]}], "]"}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "!"}]], 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", 
       SubscriptBox["z", "0"]}]], 
     RowBox[{
      FractionBox[
       SuperscriptBox["d", "2"], 
       SuperscriptBox["dz", "2"]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "0"]}], ")"}], "3"], "f", 
        RowBox[{"(", "z", ")"}]}], ")"}]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.3 is in the book (see Theorem \
8.2).",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Subroutines for finding the inverse z-transform",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InverseViaResidues", ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "n_", "]"}], "=", 
       RowBox[{"InverseZTransform", "[", 
        RowBox[{
         RowBox[{"X", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"S", "[", "z_", "]"}], "=", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"X", "[", "z", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "\[Infinity]", ",", "9"}], "}"}]}], "]"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Given the z-transform\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<   X[z] = \>\"", ",", 
        RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<   X[z] = \>\"", ",", 
        RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<The sequence is\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<{\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"CoefficientList", "[", 
           RowBox[{
            RowBox[{"Normal", "[", 
             RowBox[{"S", "[", "z", "]"}], "]"}], ",", 
            FractionBox["1", "z"]}], "]"}], ",", "\"\<...\>\""}], "]"}]}], 
       " ", "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Using residues\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<   X[z] = \>\"", ",", 
        RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"zsolve", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Denominator", "[", 
           RowBox[{"Together", "[", 
            RowBox[{"X", "[", "z", "]"}], "]"}], "]"}], "\[Equal]", "0"}], 
         ",", "z"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"zsolve", "=", 
       RowBox[{"Union", "[", "zsolve", "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["z", "2"], "=", 
       RowBox[{
        SubscriptBox["z", "1"], "=", 
        SubscriptBox["zsolve", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "zsolve", "]"}], "\[Equal]", "2"}], ",", 
        RowBox[{
         SubscriptBox["z", "2"], "=", 
         SubscriptBox["zsolve", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}]}], 
       " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "=!=", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The poles are\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"X", "[", "z", "]"}], 
              SuperscriptBox["z", 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], "+", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"X", "[", "z", "]"}], 
              SuperscriptBox["z", 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
           SubscriptBox["z", "2"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<The solution is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"X", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \
Residue[X[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),{z,\!\(\*SubscriptBox[\(z\), \(1\)]\)}] + \
Residue[X[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),{z,\!\(\*SubscriptBox[\(z\), \(2\)]\)}] \>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \
Residue[X[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),{z,\>\"", ",", 
           SubscriptBox["z", "1"], ",", 
           
           "\"\<}] + Residue[X[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),{z,\
\>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<}] \>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = Residue[\>\"", ",", 
           RowBox[{
            RowBox[{"X", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<,{z,\>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<}] + Residue[\>\"", ",", 
           RowBox[{
            RowBox[{"X", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<,{z,\>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<}]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = (\>\"", ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"X", "[", "z", "]"}], 
              SuperscriptBox["z", 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], ",", "\"\<) + (\>\"",
            ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"X", "[", "z", "]"}], 
              SuperscriptBox["z", 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}], ",", "\"\<)\>\""}], 
          " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "\[Equal]", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The pole is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{"Residue", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"X", "[", "z", "]"}], 
             SuperscriptBox[
              RowBox[{"z", " "}], 
              RowBox[{"n", "-", "1"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              SubscriptBox["z", "1"]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"X", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \
Residue[X[z]\!\(\*SuperscriptBox[\(\(z\)\(\\\ \)\), \(n - \
1\)]\),{z,\!\(\*SubscriptBox[\(z\), \(1\)]\)}]\>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \
Residue[X[z]\!\(\*SuperscriptBox[\(\(z\)\(\\\ \)\), \(n - 1\)]\),{z,\>\"", 
           ",", 
           SubscriptBox["z", "1"], ",", "\"\<}]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = Residue[\>\"", ",", 
           RowBox[{
            RowBox[{"X", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<,{z,\>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<}]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(x\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";"}]}], " ", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ZResidue", "[", 
    RowBox[{"Z0_", ",", "m_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       SubscriptBox["Z", "0"], "=", "Z0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", "f", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", "z_", "]"}], "=", 
       RowBox[{
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]], 
        RowBox[{"X", "[", "z", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z", "-", 
               SubscriptBox["Z", "0"]}], ")"}], 
             RowBox[{"f", "[", "z", "]"}]}], ",", 
            RowBox[{"z", "\[Rule]", 
             SubscriptBox["Z", "0"]}]}], " ", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     X[z] = \>\"", ",", 
           RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     f[z] = \>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<       \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
           SubscriptBox["Z", "0"]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Res[f,\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
           
           SubscriptBox["\"\<lim\>\"", 
            "\"\<z\[Rule]\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""], ",", 
           "\"\< (z-\!\(\*SubscriptBox[\(z\), \(0\)]\))f[z]\>\""}], "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< (z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<)f[z]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< (z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<)\>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"z", "-", 
              SubscriptBox["Z", "0"]}], ")"}], 
            RowBox[{"f", "[", "z", "]"}]}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z", "-", 
               SubscriptBox["Z", "0"]}], ")"}], 
             RowBox[{"f", "[", "z", "]"}]}], "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", "lim"}], " ", 
          "]"}], ";"}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", "\[Equal]", "2"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
           RowBox[{
            RowBox[{"Simplify", "[", 
             RowBox[{
              SubscriptBox["\[PartialD]", "z"], 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"z", "-", 
                   SubscriptBox["Z", "0"]}], ")"}], "2"], 
                RowBox[{"f", "[", "z", "]"}]}], ")"}]}], "]"}], ",", 
            RowBox[{"z", "\[Rule]", 
             SubscriptBox["Z", "0"]}]}], " ", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     X[z] = \>\"", ",", 
           RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     f[z] = \>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<       \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
           SubscriptBox["Z", "0"]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Res[f,\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", 
            "\"\<z\[Rule]\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""], ",", 
           "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \
\(z\)]\)((z-\!\(\*SubscriptBox[\(z\), \(0\)]\)\!\(\*SuperscriptBox[\()\), \(2\
\)]\)f[z]\>\""}], "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\)((z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", 
           "\"\<\!\(\*SuperscriptBox[\()\), \(2\)]\)f[z]\>\""}], "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\)((z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", 
           "\"\<\!\(\*SuperscriptBox[\()\), \(2\)]\)\>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\)(\>\"", ",", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"z", "-", 
               SubscriptBox["Z", "0"]}], ")"}], "2"], 
            RowBox[{"f", "[", "z", "]"}]}], ",", "\"\<)\>\""}], " ", "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(z\)]\)(\>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z", "-", 
                SubscriptBox["Z", "0"]}], ")"}], "2"], 
             RowBox[{"f", "[", "z", "]"}]}], "]"}], ",", "\"\<)\>\""}], " ", 
          "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{
             SubscriptBox["\[PartialD]", "z"], 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"z", "-", 
                  SubscriptBox["Z", "0"]}], ")"}], "2"], 
               RowBox[{"f", "[", "z", "]"}]}], ")"}]}], "]"}]}], " ", "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", "lim"}], " ", 
          "]"}], ";"}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m", "\[Equal]", "3"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"lim", " ", "=", " ", 
          RowBox[{"Limit", "[", 
           RowBox[{
            RowBox[{"Simplify", "[", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"2", "!"}]], 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"z", ",", "z"}]], 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"z", "-", 
                    SubscriptBox["Z", "0"]}], ")"}], "3"], 
                 RowBox[{"f", "[", "z", "]"}]}], ")"}]}]}], "]"}], ",", 
            RowBox[{"z", "\[Rule]", 
             SubscriptBox["Z", "0"]}]}], " ", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     X[z] = \>\"", ",", 
           RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     f[z] = \>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<       \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
           SubscriptBox["Z", "0"]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Res[f,\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
           
           SubscriptBox["\"\<lim\>\"", 
            "\"\<z\[Rule]\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z, z\)]\)((z-\!\(\*SubscriptBox[\(z\), \
\(0\)]\)\!\(\*SuperscriptBox[\()\), \(3\)]\)f[z]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z, z\)]\)((z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", 
           "\"\<\!\(\*SuperscriptBox[\()\), \(3\)]\)f[z]\>\""}], "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z, z\)]\)((z-\>\"", ",", 
           SubscriptBox["Z", "0"], ",", 
           "\"\<\!\(\*SuperscriptBox[\()\), \(3\)]\)\>\"", ",", 
           RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z, z\)]\)(\>\"", ",", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"z", "-", 
               SubscriptBox["Z", "0"]}], ")"}], "3"], 
            RowBox[{"f", "[", "z", "]"}]}], ",", "\"\<)\>\""}], " ", "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z, z\)]\)(\>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z", "-", 
                SubscriptBox["Z", "0"]}], ")"}], "3"], 
             RowBox[{"f", "[", "z", "]"}]}], "]"}], ",", "\"\<)\>\""}], " ", 
          "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", 
           "\"\< \!\(\*FractionBox[\(1\), \(2!\)]\)\!\(\*SubscriptBox[\(\
\[PartialD]\), \(z\)]\)(\>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{
             SubscriptBox["\[PartialD]", "z"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"z", "-", 
                  SubscriptBox["Z", "0"]}], ")"}], "3"], 
               RowBox[{"f", "[", "z", "]"}]}], ")"}]}], "]"}], ",", 
           "\"\<)\>\""}], " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
           SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
           SubscriptBox["\"\<\>\"", 
            SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"2", "!"}]], 
            RowBox[{"Simplify", "[", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"z", ",", "z"}]], 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"z", "-", 
                   SubscriptBox["Z", "0"]}], ")"}], "3"], 
                RowBox[{"f", "[", "z", "]"}]}], ")"}]}], "]"}]}]}], " ", 
          "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Res[f,\>\"", ",", 
           SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", "lim"}], " ", 
          "]"}], ";"}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", " ", "lim", " ", "]"}], ";"}]}], " ", "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["  Find t",
  FontFamily->"Times New Roman"],
 "he inverse z-transform   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       RowBox[{"2", "z"}], "-", "1"}]], "]"}]}]}]]],
 ".   Use (a) series, (b) table of z-transforms, (c) residues.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Solution 9.6 (a).  Method of series.  \n\n\tExpand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"2", "z"}], 
    RowBox[{
     RowBox[{"2", "z"}], "-", "1"}]]}]]],
 " in a series involving powers of ",
 Cell[BoxData[
  FractionBox["1", "z"]]],
 ".  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["z", 
     RowBox[{"z", " ", "-", 
      FractionBox["1", 
       RowBox[{" ", "2"}]]}]], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{" ", "2"}]], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}]], " ", "=", " ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{" ", "2"}]], 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}], ")"}], "n"]}], " ", "=", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["2", "n"]], 
        SuperscriptBox["z", 
         RowBox[{"-", "n"}]]}]}]}]}]}]}]]],
 " \n\t\t\nThe sequence of coefficients in the Laurent series is what we \
desire, and we see that  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
    FractionBox["1", 
     SuperscriptBox["2", "n"]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.6 (b).  Writing  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox["z", 
    RowBox[{"z", " ", "-", 
     FractionBox["1", 
      RowBox[{" ", "2"}]]}]]}]]],
 "  we identify  ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   FractionBox["1", 
    RowBox[{" ", "2"}]]}]]],
 "  and use line 3 in the Table 9.1 to obtain \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["b", "n"], " ", "=", " ", 
     FractionBox["1", 
      SuperscriptBox["2", "n"]]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Solution 9.6 (c).  Writing  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox["z", 
    RowBox[{"z", " ", "-", 
     FractionBox["1", 
      RowBox[{" ", "2"}]]}]]}]]],
 "  we see that  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]]],
 "  has a simple pole at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{" ", "2"}]]}]]],
 ".  Using the Corollary 9.1 for finding the inverse z-transform we obtain  \n\
\n\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "0"]}], "]"}], " ", "=", "  ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{
         FractionBox["z", 
          RowBox[{"z", " ", "-", 
           FractionBox["1", 
            RowBox[{" ", "2"}]]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        FractionBox["1", 
         RowBox[{" ", "2"}]]}], "]"}], " ", "=", "  ", 
      RowBox[{"Res", "[", 
       RowBox[{
        FractionBox[
         SuperscriptBox["z", "n"], 
         RowBox[{"z", " ", "-", 
          FractionBox["1", 
           RowBox[{" ", "2"}]]}]], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        FractionBox["1", 
         RowBox[{" ", "2"}]]}], "]"}]}]}]}]}]]],
 " \n\t\t\nUsing  the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 "  and value  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{" ", "2"}]]}]]],
 "  in Corollary 9.2 we get  \n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", 
        SubscriptBox["z", "0"]}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], ")"}], "f", 
       RowBox[{"(", "z", ")"}]}]}], " ", "=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox["lim", 
        RowBox[{"z", " ", "\[Rule]", 
         FractionBox["1", 
          RowBox[{" ", "2"}]]}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox["1", 
           RowBox[{" ", "2"}]]}], ")"}], 
        FractionBox[
         SuperscriptBox["z", "n"], 
         RowBox[{"z", " ", "-", 
          FractionBox["1", 
           RowBox[{" ", "2"}]]}]]}]}], " ", "=", " ", 
      RowBox[{
       RowBox[{
        UnderscriptBox["lim", 
         RowBox[{"z", " ", "\[Rule]", 
          FractionBox["1", 
           RowBox[{" ", "2"}]]}]], " ", 
        SuperscriptBox["z", "n"]}], " ", "=", " ", 
       FractionBox["1", 
        SuperscriptBox["2", "n"]]}]}]}]}]}]]],
 ".   "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"X", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", "z"}], 
      RowBox[{
       RowBox[{"2", "z"}], "-", "1"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "\[Infinity]", ",", "9"}], "}"}]}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   X[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The sequence is\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"CoefficientList", "[", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"S", "[", "z", "]"}], "]"}], ",", 
          FractionBox["1", "z"]}], "]"}], ",", "\"\<...\>\""}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{x[n]\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\) = \
\>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"CoefficientList", "[", 
         RowBox[{
          RowBox[{"Normal", "[", 
           RowBox[{"S", "[", "z", "]"}], "]"}], ",", 
          FractionBox["1", "z"]}], "]"}], ",", "\"\<...\>\""}], "]"}]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474069390625*^9, 3.399474071171875*^9}, {
  3.400346461078125*^9, 3.400346466484375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], "=", 
     FractionBox["1", 
      RowBox[{" ", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "f", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]], 
      RowBox[{"X", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lim", " ", "=", " ", 
     RowBox[{"Limit", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["Z", "0"]}], ")"}], 
        RowBox[{"f", "[", "z", "]"}]}], ",", 
       RowBox[{"z", "\[Rule]", 
        SubscriptBox["Z", "0"]}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"s", "[", "n_", "]"}], "=", "lim"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       \!\(\*SubscriptBox[\(z\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["Z", "0"]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\!\(\*SubscriptBox[\(z\), \(0\)]\)] = \>\"", ",", 
      SubscriptBox["\"\<lim\>\"", 
       "\"\<z\[Rule]\!\(\*SubscriptBox[\(z\), \(0\)]\)\>\""], ",", 
      "\"\< (z-\!\(\*SubscriptBox[\(z\), \(0\)]\))f[z]\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
      SubscriptBox["\"\<\>\"", 
       SubscriptBox["Z", "0"]], ",", "\"\< (z-\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<)f[z]\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
      SubscriptBox["\"\<\>\"", 
       SubscriptBox["Z", "0"]], ",", "\"\< (z-\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<)\>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
      SubscriptBox["\"\<\>\"", 
       SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SubscriptBox["Z", "0"]}], ")"}], 
       RowBox[{"f", "[", "z", "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", 
      SubscriptBox["\"\<lim\>\"", "\"\<z\[Rule]\>\""], ",", 
      SubscriptBox["\"\<\>\"", 
       SubscriptBox["Z", "0"]], ",", "\"\< \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["Z", "0"]}], ")"}], 
        RowBox[{"f", "[", "z", "]"}]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", "lim"}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The sequence is\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \!\(\*SubscriptBox[\(x\), \(n\)]\) = Res[f,\>\"", ",", 
      SubscriptBox["Z", "0"], ",", "\"\<] = \>\"", ",", "lim"}], " ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  {\!\(\*SubscriptBox[\(x\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\) = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{x[n]\!\(\*SubsuperscriptBox[\(}\), \(n = 0\), \(\[Infinity]\)]\) = \
\>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474073625*^9, 3.399474075890625*^9}}]
}, Closed]],

Cell["\<\
\tThe following two theorems about z-transforms are useful in finding the \
solution to a difference equation.  \
\>", "Text"],

Cell[TextData[{
 StyleBox["Theorem 9.4 (Shifted Sequences & Initial Conditions)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Define the sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], "=", 
     SubscriptBox["x", "n"]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " and let  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     RowBox[{"x", "[", "n", "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"\[GothicCapitalZ]", "[", 
      SubscriptBox["x", "n"], "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["x", "n"], " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "n"}]]}]}]}]}]}]]],
 "  be its z-transform.  Then \n\n\t",
 StyleBox["(i)  \t",
  FontColor->RGBColor[0, 0, 1]],
 "\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubscriptBox["x", 
      RowBox[{"n", "+", "1"}]], "]"}], "  ", "=", "  ", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       SubscriptBox["x", "0"]}], ")"}]}]}]}]]],
 "  \n\n\t",
 StyleBox["(ii) \t",
  FontColor->RGBColor[0, 0, 1]],
 "\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubscriptBox["x", 
      RowBox[{"n", "+", "2"}]], "]"}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["x", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}]}]}]]],
 "   \n\n\t",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "3"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[GothicCapitalZ]", "[", 
     SubscriptBox["x", 
      RowBox[{"n", "+", "3"}]], "]"}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       SubscriptBox["x", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["x", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], " ", "-", " ", 
       RowBox[{
        SubscriptBox["x", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}]}]}]]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 9.5 (Convolution)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["x", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  and  ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["y", "n"], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 "  be sequences with z-transforms  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}], "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ", respectively.  Then  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{
     SubscriptBox["x", "n"], "*", 
     SubscriptBox["y", "n"]}], "]"}], " ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], "Y", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  \n\t\t\nwhere the operation  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "*", 
   SubscriptBox["y", "n"]}]]],
 "  is defined as the convolution sum  ",
 Cell[BoxData[
  RowBox[{
   UnderoverscriptBox["\[Sum]", 
    RowBox[{"i", "=", "0"}], "n"], 
   RowBox[{
    SubscriptBox["x", "i"], 
    SubscriptBox["y", 
     RowBox[{"n", "-", "i"}]]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 9.5 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.4  Properties of the z-transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe following properties of z-transforms listed in Table 9.2 are well \
known in the field of digital signal analysis.  The reader will be asked to \
prove some of these properties in the exercises.  \n\t\n\t\t\t",
 Cell[BoxData[GridBox[{
    {" ", " ", 
     StyleBox["Sequence",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"z", "-", "transform"}],
      FontWeight->"Bold"]},
    {" ", 
     RowBox[{"definition", " "}], 
     RowBox[{
      SubscriptBox["x", "n"], "=", 
      RowBox[{"x", "[", "n", "]"}]}], 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "0"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["x", "n"], 
        SuperscriptBox["z", 
         RowBox[{"-", "n"}]]}]}]}]},
    {"1", "addition", 
     RowBox[{
      SubscriptBox["x", "n"], "+", 
      SubscriptBox["y", "n"]}], 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], "+", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}]}]},
    {"2", 
     RowBox[{"constant", " ", "multiple"}], 
     RowBox[{"c", " ", 
      SubscriptBox["x", "n"]}], 
     RowBox[{"c", " ", "X", 
      RowBox[{"(", "z", ")"}]}]},
    {"3", 
     RowBox[{" ", "linearity"}], 
     RowBox[{
      RowBox[{"c", " ", 
       SubscriptBox["x", "n"]}], "+", 
      RowBox[{"d", " ", 
       SubscriptBox["y", "n"]}]}], 
     RowBox[{
      RowBox[{"c", " ", "X", 
       RowBox[{"(", "z", ")"}]}], "+", 
      RowBox[{"d", " ", "Y", 
       RowBox[{"(", "z", ")"}]}]}]},
    {"4", 
     RowBox[{"delayed", " ", "unit", " ", "step"}], 
     RowBox[{"u", "[", 
      RowBox[{"n", "-", "m"}], "]"}], 
     FractionBox[
      SuperscriptBox["z", 
       RowBox[{"1", "-", "m"}]], 
      RowBox[{"z", "-", "1"}]]},
    {"5", 
     RowBox[{"time", " ", "delay", " ", "1", " ", "tap"}], 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"n", "-", "1"}]], 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], 
     RowBox[{
      FractionBox["1", "z"], "X", 
      RowBox[{"(", "z", ")"}]}]},
    {"6", 
     RowBox[{"time", " ", "delayed", " ", "shift"}], 
     RowBox[{
      SubscriptBox["x", 
       RowBox[{"n", "-", "m"}]], 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "m"}], "]"}]}], 
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"-", "m"}]], "X", 
      RowBox[{"(", "z", ")"}]}]},
    {"7", 
     RowBox[{"forward", " ", "1", " ", "tap"}], 
     SubscriptBox["x", 
      RowBox[{"n", "+", "1"}]], 
     RowBox[{"z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        SubscriptBox["x", "0"]}], ")"}]}]},
    {"8", 
     RowBox[{"forward", " ", "2", " ", "taps"}], 
     SubscriptBox["x", 
      RowBox[{"n", "+", "2"}]], 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
        SubscriptBox["x", "0"], " ", "-", " ", 
        RowBox[{
         SubscriptBox["x", "1"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]},
    {"9", 
     RowBox[{" ", 
      RowBox[{"time", " ", "forward"}]}], 
     SubscriptBox["x", 
      RowBox[{"n", "+", "m"}]], 
     RowBox[{
      SuperscriptBox["z", "m"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", 
         RowBox[{"(", "z", ")"}]}], "-", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"i", "=", "0"}], 
          RowBox[{"m", "-", "1"}]], 
         RowBox[{
          SubscriptBox["x", "i"], 
          SuperscriptBox["z", 
           RowBox[{"-", "i"}]]}]}]}], ")"}]}]},
    {"10", 
     RowBox[{" ", 
      RowBox[{"complex", " ", "translation"}]}], 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"a", " ", "n"}]], 
      SubscriptBox["x", "n"]}], 
     RowBox[{"X", 
      RowBox[{"(", 
       RowBox[{"z", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "a"}]]}], ")"}]}]},
    {"11", 
     RowBox[{"frequency", " ", "scale"}], 
     RowBox[{
      SuperscriptBox["b", "n"], " ", 
      SubscriptBox["x", "n"]}], 
     RowBox[{"X", 
      RowBox[{"(", 
       FractionBox["z", "b"], ")"}]}]},
    {"12", 
     RowBox[{"differentiation", " "}], 
     RowBox[{"n", " ", 
      SubscriptBox["x", "n"]}], 
     RowBox[{
      RowBox[{"-", " ", "z"}], " ", 
      RowBox[{"X", "'"}], 
      RowBox[{"(", "z", ")"}]}]},
    {"13", "integration", 
     RowBox[{
      FractionBox["1", "n"], 
      SubscriptBox["x", "n"]}], 
     RowBox[{"-", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"X", 
          RowBox[{"(", "z", ")"}]}], "z"], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]},
    {"14", 
     RowBox[{"integration", " ", "shift"}], 
     RowBox[{
      FractionBox["1", 
       RowBox[{"n", "+", "m"}]], 
      SubscriptBox["x", "n"]}], 
     RowBox[{
      RowBox[{"-", " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "m"}]]}], 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"X", 
          RowBox[{"(", "z", ")"}]}], 
         SuperscriptBox["z", 
          RowBox[{"m", "+", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]},
    {"15", 
     RowBox[{"discrete", " ", "time", " ", "convolution", " "}], 
     RowBox[{
      RowBox[{
       SubscriptBox["x", "n"], "*", 
       SubscriptBox["y", "n"]}], "=", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "n"], 
       RowBox[{
        SubscriptBox["x", "i"], 
        SubscriptBox["y", 
         RowBox[{"n", "-", "i"}]]}]}]}], 
     RowBox[{"X", 
      RowBox[{"(", "z", ")"}], "Y", 
      RowBox[{"(", "z", ")"}]}]},
    {"16", 
     RowBox[{" ", 
      RowBox[{
       RowBox[{"convolution", " ", "with", "  ", 
        SubscriptBox["y", "n"]}], "\[Equal]", "1"}]}], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "n"], 
      SubscriptBox["x", "i"]}], 
     RowBox[{
      FractionBox["z", 
       RowBox[{"z", "-", "1"}]], " ", "X", 
      RowBox[{"(", "z", ")"}]}]},
    {"17", 
     RowBox[{" ", 
      RowBox[{"initial", " ", "time"}]}], 
     SubscriptBox["x", "0"], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", "\[Infinity]"}]], " ", 
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}]}]},
    {"18", 
     RowBox[{"final", " ", "value", " "}], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
      SubscriptBox["x", "n"]}], 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", "1"}]], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "X", 
       RowBox[{"(", "z", ")"}]}]}]}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
     "RowsIndexed" -> {}}]]],
 "  \n\t\n\t\t\t",
 StyleBox["Table 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Some properties of the z-transform. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "X", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Differentiation property\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<        X(z) = \[GothicCapitalZ][{\!\(\*SuperscriptBox[\(a\), \
\(n\)]\)}] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        SuperscriptBox["a", "n"], ",", "n", ",", "z"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       X'(z) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "z"], " ", 
       RowBox[{"ZTransform", "[", 
        RowBox[{
         SuperscriptBox["a", "n"], ",", "n", ",", "z"}], "]"}]}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    -z X'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"-", "z"}], " ", 
       RowBox[{"Together", "[", 
        RowBox[{
         SubscriptBox["\[PartialD]", "z"], " ", 
         RowBox[{"ZTransform", "[", 
          RowBox[{
           SuperscriptBox["a", "n"], ",", "n", ",", "z"}], "]"}]}], "]"}]}]}],
      " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    -z X'(z) = \>\"", ",", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "z"], " ", 
         RowBox[{"ZTransform", "[", 
          RowBox[{
           SuperscriptBox["a", "n"], ",", "n", ",", "z"}], "]"}]}]}], "]"}]}],
      " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \[GothicCapitalZ][n \!\(\*SuperscriptBox[\(a\), \(n\)]\)] = \>\
\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"n", " ", 
         SuperscriptBox["a", "n"]}], ",", "n", ",", "z"}], "]"}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \[GothicCapitalZ][n \!\(\*SuperscriptBox[\(a\), \(n\)]\)] = -z \
X'(z) ?\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{"n", " ", 
         SuperscriptBox["a", "n"]}], ",", "n", ",", "z"}], "]"}], " ", 
      "\[Equal]", " ", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"-", "z"}], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "z"], " ", 
         RowBox[{"ZTransform", "[", 
          RowBox[{
           SuperscriptBox["a", "n"], ",", "n", ",", "z"}], "]"}]}]}], "]"}]}],
      "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947408696875*^9, 3.399474088515625*^9}, {
  3.400346490765625*^9, 3.400346497109375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"b", ",", "n", ",", "X", ",", "z"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Frequency scale\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X(z) = \[GothicCapitalZ][{n}] = \>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{"n", ",", "n", ",", "z"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Replace  z \[Rule] \!\(\*FractionBox[\(z\), \(b\)]\)\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         X(\!\(\*FractionBox[\(z\), \(b\)]\)) = \>\"", ",", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"ZTransform", "[", 
         RowBox[{"n", " ", ",", "n", ",", "z"}], "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         FractionBox["z", "b"]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         X(\!\(\*FractionBox[\(z\), \(b\)]\)) = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"ZTransform", "[", 
          RowBox[{"n", " ", ",", "n", ",", "z"}], "]"}], ",", 
         RowBox[{"z", "\[Rule]", 
          FractionBox["z", "b"]}]}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \[GothicCapitalZ][{\!\(\*SuperscriptBox[\(b\), \(n\)]\) n}] = \
\>\"", ",", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox["b", "n"], " ", "n"}], ",", "n", ",", "z"}], "]"}]}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \[GothicCapitalZ][{\!\(\*SuperscriptBox[\(b\), \(n\)]\) n}] = \
X(\!\(\*FractionBox[\(z\), \(b\)]\)) ?\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"ZTransform", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox["b", "n"], " ", "n"}], ",", "n", ",", "z"}], "]"}], 
      "\[Equal]", 
      RowBox[{"Together", "[", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"ZTransform", "[", 
          RowBox[{"n", " ", ",", "n", ",", "z"}], "]"}], ",", 
         RowBox[{"z", "\[Rule]", 
          FractionBox["z", "b"]}]}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474094109375*^9, 3.39947409609375*^9}, {
  3.400346509875*^9, 3.400346518921875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "n"], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{"n", "+", "1"}]}]}]]],
 ".   Use convolution to show that the z-transform is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"W", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SuperscriptBox["z", "2"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "1"}], ")"}], "2"]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution 9.7.\n\n\tLet both  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["y", "n"]}], "=", "1"}]}]]],
 "  be the unit step sequence, and both  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["z", 
    RowBox[{"(", 
     RowBox[{"z", "-", "1"}], ")"}]]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["z", 
    RowBox[{"(", 
     RowBox[{"z", "-", "1"}], ")"}]]}]]],
 ".  Then  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"W", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}], "Y", 
     RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox["z", 
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}]], 
      FractionBox["z", 
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}]]}], "  ", "=", "   ", 
     FractionBox[
      SuperscriptBox["z", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "1"}], ")"}], "2"]]}]}]}]]],
 ",  \n\nso that  ",
 Cell[BoxData[
  SubscriptBox["w", "n"]]],
 "  is given by the convolution  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "n"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "n"], "*", 
     SubscriptBox["y", "n"]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "n"], 
      RowBox[{
       SubscriptBox["x", "i"], 
       SubscriptBox["y", 
        RowBox[{"n", "-", "i"}]]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "n"], " ", "1"}], " ", "=", " ", 
      RowBox[{"n", "+", "1"}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["9.1.5  Application to signal processing",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tDigital signal processing often involves the design of finite impulse \
response (FIR) filters.  A simple 3-point FIR filter can be described as\n\t\n\
",
 StyleBox["(9-4)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "+", " ", 
    RowBox[{"a", " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}]}]]],
 ".  \n\nHere, we choose real coefficients ",
 Cell[BoxData[
  RowBox[{"a", " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "b"}]]],
 " so that the homogeneous difference equation  \n\n",
 StyleBox["(9-5)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "+", " ", 
    RowBox[{"a", " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "2"}], "]"}]}]}], "  ", "=", "  ", "0"}]]],
 "  \n\nhas solutions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"x", "[", "n", "]"}]}], "=", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}]}]}]}]]],
 ".  That is, if the linear combination  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["c", "2"], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}]}]}]}]]],
 "  is input on the right side of the FIR filter equation, the output ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " on the left side of the equation will be zero.  "
}], "Text"],

Cell[TextData[{
 "\tApplying the time delay property to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transforms of each term in ",
 StyleBox["(9-4)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}], " ", "+", " ", 
    RowBox[{"a", " ", "X", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], " ", "+", "  ", 
    RowBox[{"b", " ", "X", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}], " ", "=", " ", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  Factoring, we get \n\n",
 StyleBox["(9-6)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["z", 
        RowBox[{"-", "2"}]]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], "H", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ",  where \n\n",
 StyleBox["(9-7)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{"1", "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]]],
 " \n\nrepresents the filter transfer function.  Now, in order for the filter \
to suppress the inputs ",
 Cell[BoxData[
  RowBox[{"cos", 
   RowBox[{"(", 
    RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "sin", 
   RowBox[{"(", 
    RowBox[{"\[Omega]", " ", "\[Pi]", " ", "n"}], ")"}]}]]],
 ", we must have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "1"}]]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "\[Pi]"}]], " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "\[Pi]"}]], 
        " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "\[Pi]"}]]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "\[Pi]"}]]}], 
      ")"}]}]}]}]]],
 "  \n\nand an easy calculation reveals that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"a", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", " ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "\[Pi]"}]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "\[Pi]"}]]}], 
      ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Omega]", " ", "\[Pi]"}], "]"}]}]}]}]]],
 ",   and \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"b", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "\[Pi]"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "\[Pi]"}]]}], 
    " ", "=", " ", "1"}]}]]],
 ". \n\nA complete discussion of this process is given in Section 9.3 of this \
chapter. "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["(FIR filter design)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 StyleBox["Use residues to find the inverse",
  FontFamily->"Times New Roman"],
 " ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-",
 StyleBox["transform   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 " ",
 StyleBox["  of   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox["2"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}], "+", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]], " ", "=", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}]]}]}]]],
 StyleBox[".  \nThen, write down the FIR filter equation that suppresses ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 ".",
 StyleBox["  ",
  FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.8.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Writing  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    SuperscriptBox["z", "2"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}]}]]}]]],
 "  we see that  ",
 Cell[BoxData[
  RowBox[{"X", 
   RowBox[{"(", "z", ")"}]}]]],
 "  has simple poles at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"\[Pi]", "/", "4"}]}]], "  ", "and", "  ", 
     SubscriptBox["z", "2"]}], " ", "=", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{"\[Pi]", "/", "4"}]}]]}]}]]],
 ".  Using the Corollaries 9.1 and 9.2 we compute the residues    \n\n\t\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SubscriptBox["z", "1"]}], "]"}], " ", "=", "  ", 
    RowBox[{"Res", "[", 
     RowBox[{
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "+", "1"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}]}]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "+", "1"}]], 
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], 
       RowBox[{"n", "+", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "n", " ", 
       RowBox[{"\[Pi]", "/", "4"}]}]]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "The residue at the pole  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], " ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     RowBox[{"\[Pi]", "/", "4"}]}]]}]]],
 "  is computed similarly.\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SubscriptBox["z", "2"]}], "]"}], " ", "=", "  ", 
    RowBox[{"Res", "[", 
     RowBox[{
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "+", "1"}]], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}]}]], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
      FractionBox[
       SuperscriptBox["z", 
        RowBox[{"n", "+", "1"}]], 
       RowBox[{"z", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], 
       RowBox[{"n", "+", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]]}]], 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", 
       RowBox[{"\[Pi]", "/", "4"}]}]]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Therefore, the sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 "  is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     FractionBox[
      SuperscriptBox["z", "2"], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}]}]], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "1"]}], "]"}], " ", "+", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"X", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "2"]}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        FractionBox["\[ImaginaryI]", "2"]}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "2"], "+", 
        FractionBox["\[ImaginaryI]", "2"]}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], " ", "+", " ", 
     RowBox[{"sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "The following complex calculation can be used to find the coefficients of \
the FIR filter equation\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], "=", " ", 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"\[Pi]", "/", "4"}]}]]}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                                           ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "+", "\[ImaginaryI]"}], 
         SqrtBox["2"]], "+", 
        FractionBox[
         RowBox[{"1", "-", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                           ", 
   RowBox[{"=", "  ", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{
      SqrtBox["2"], 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], " ", "+", " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "2"}]]}]}]}]}]],
 "\n\t\nHence the FIR filter equation is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{"K", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], " ", "-", " ", 
      RowBox[{
       SqrtBox["2"], " ", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}]}], ")"}]}]}]]],
 "  where ",
 Cell[BoxData["K"]],
 " is a constant gain factor.   \n\n",
 StyleBox["Remark 9.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " We leave it as an exercises to substitute  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", "sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 "  into the right hand side and verify that the output ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " becomes identically zero.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.8.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "-", 
       RowBox[{
        SqrtBox["2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474109984375*^9, 3.39947411196875*^9}, {
  3.40034652959375*^9, 3.400346530109375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"filter", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], "-", 
       RowBox[{
        SqrtBox["2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The FIR filter is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the sequence\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-1] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<x[n-2] = \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], ",", "\"\< = \>\"", ",", " ", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute into the filter and get\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "filter", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", "filter", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474151609375*^9, 3.39947415475*^9}, {
  3.400346535484375*^9, 3.4003465359375*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We can explore the effect of using the input sequences \n\n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"m", " ", "\[Pi]"}], "100"], "n"}], "]"}], "   ", "for", "    ",
       "m"}], " ", "=", " ", "10"}]}], ",", "18", ",", "22", ",", "23", ",", 
   "24", ",", "25", " "}]]],
 "\n\nand using the filter  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], "+", 
    RowBox[{"x", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]]],
 " to compute the output sequence. \n\nWe expect that the signals become more \
attenuated as ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"m", " ", "\[Pi]"}], "100"], "\[Rule]", 
   FractionBox["\[Pi]", "4"]}]]],
 ".  \n\nFor this illustration the sequences are defined for all integers n, \
but we will learn in the Section 9.3 that digital filters require that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["x", "n"], "=", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", "0"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{"n", "<", "0"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"FilterIt", " ", ":=", 
     RowBox[{"Module", "[", " ", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
         RowBox[{
          RowBox[{"x", "[", "n", "]"}], "-", 
          RowBox[{
           SqrtBox["2"], " ", 
           RowBox[{"x", "[", 
            RowBox[{"n", "-", "1"}], "]"}]}], "+", 
          RowBox[{"x", "[", 
           RowBox[{"n", "-", "2"}], "]"}]}]}], ";", "  ", 
        "\[IndentingNewLine]", 
        RowBox[{"T", "=", " ", 
         RowBox[{"N", "[", 
          RowBox[{"Table", "[", 
           RowBox[{"i", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "21"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"X", " ", "=", " ", 
         RowBox[{"N", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"x", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "21"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"TX", " ", "=", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"T", ",", "X"}], "}"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"g11", "=", 
         RowBox[{"ListPlot", "[", 
          RowBox[{"TX", ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], "}"}]}], 
           ",", 
           RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"g12", "=", 
         RowBox[{"ListPlot", "[", 
          RowBox[{"TX", ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Red"}], 
             "}"}]}]}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", "g11", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Input   x[n] = \>\"", ",", 
          RowBox[{"x", "[", "n", "]"}]}], "  ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Y", " ", "=", " ", 
         RowBox[{"N", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"y", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", "21"}], "}"}]}], "]"}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"TY", " ", "=", " ", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"T", ",", "Y"}], "}"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"g21", "=", 
         RowBox[{"ListPlot", "[", 
          RowBox[{"TY", ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], "}"}]}],
            ",", 
           RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"g22", "=", 
         RowBox[{"ListPlot", "[", 
          RowBox[{"TY", ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PointSize", "[", "0.02", "]"}], ",", "Blue"}], 
             "}"}]}]}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", "g21", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Output  y[n] = \>\"", ",", 
          RowBox[{"y", "[", "n", "]"}]}], "  ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"graph", "=", 
         RowBox[{"Show", "[", 
          RowBox[{"g12", ",", "g22", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0.4", ",", "22.4"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"0", ",", "20", ",", "5"}], "]"}], ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1", ",", "0.25"}], "]"}]}], 
             "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", "graph", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Red   x[n] = \>\"", ",", 
          RowBox[{"x", "[", "n", "]"}]}], "  ", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
        "Print", "[", 
         "\"\<      y[n] = x[n]-\!\(\*SqrtBox[\(2\)]\) x[n-1]+x[n-2]\>\"", 
         "  ", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Blue  y[n] = \>\"", ",", 
          RowBox[{"y", "[", "n", "]"}]}], "  ", "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994741679375*^9, 3.399474225125*^9}, {
  3.400065853640625*^9, 3.40006587128125*^9}, {3.400065907390625*^9, 
  3.400065967328125*^9}, {3.400066016921875*^9, 3.400066019625*^9}, {
  3.40006605059375*^9, 3.400066088125*^9}, {3.400344626546875*^9, 
  3.400344648078125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"10", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.39947424565625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"18", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.399474248921875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"22", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.399474251171875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"23", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.399474254046875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"24", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.39947425703125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"25", "\[Pi]"}], "100"], "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "FilterIt"}]}]], "Input",
 CellChangeTimes->{3.399474259984375*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.6  First Order Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\t",
  FontFamily->"Times New Roman"],
 "The solution of difference equations is analogous to the solution of \
differential equations.  ",
 StyleBox["Consider the first order homogeneous ",
  FontFamily->"Times New Roman"],
 "equation  ",
 StyleBox["\n\n\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "  ", "-", "  ", 
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 " ",
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData["a"]],
 " ",
 StyleBox["is a constant.  The following method is often used.\n\n",
  FontFamily->"Times New Roman"],
 StyleBox["Trial solution method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tUse the trial solution   ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    SubscriptBox["c", "1"], " ", 
    SuperscriptBox["r", "n"]}]}]]],
 ",   and substitute it into the above equation and get   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", 
      RowBox[{"n", "+", "1"}]]}], " ", "-", " ", 
    RowBox[{"a", " ", 
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"]}]}], "  ", "=", "  ", "0"}]]],
 ".  Then divide through by ",
 Cell[BoxData[
  SuperscriptBox["r", "n"]]],
 " \n\nand simplify to obtain  ",
 Cell[BoxData[
  RowBox[{"r", "=", "a"}]]],
 ".  The general solution to the difference equation is\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], " ", 
    SuperscriptBox["a", "n"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["\t",
  FontFamily->"Times New Roman"],
 "Familiar models of difference equations are given in the table below.   \n\t\
\n\t\t\t",
 Cell[BoxData[GridBox[{
    {
     StyleBox["Model",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"Difference", " ", "Equation"}],
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"S", "olution"}],
      FontWeight->"Bold"]},
    {
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       StyleBox[
        RowBox[{"Exponential", " ", "growth", " ", "or", " ", "decay"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], " ", 
         RowBox[{"y", "[", "n", "]"}]}]}], " ", "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
        RowBox[{
         SubscriptBox["y", "0"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], "n"]}]}], " ", 
       "\[IndentingNewLine]"}]}]},
    {
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       StyleBox[
        RowBox[{
         RowBox[{"Newton", "'"}], "s", " ", "law", " ", "of", " ", 
         "cooling"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"n", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"a", " ", "L"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "a"}], ")"}], " ", 
          RowBox[{"y", "[", "n", "]"}]}]}]}], "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], "=", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "0"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "a"}], ")"}], "n"]}], "+", 
         RowBox[{"L", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", "a"}], ")"}], "n"]}], ")"}]}]}]}], 
       "\[IndentingNewLine]"}]}]},
    {
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       StyleBox[
        RowBox[{"Repeated", " ", "dosage", " ", "drug", " ", "level"}],
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}], " ", 
       "\[IndentingNewLine]"}]}], 
     RowBox[{"\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "0"], " ", 
          SuperscriptBox["a", "n"]}], " ", "+", 
         RowBox[{
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "n"], " ", "-", " ", "1"}], 
           RowBox[{"a", " ", "-", " ", "1"}]], " ", "b"}]}]}], " ", 
       "\[IndentingNewLine]"}]}]},
    {
     RowBox[{"\[IndentingNewLine]", 
      StyleBox[
       RowBox[{"Value", " ", "of", " ", "an", " ", "annuity", " ", "due"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", 
         RowBox[{"n", "+", "1"}], "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], 
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{"y", "[", "n", "]"}], "+", "P"}], ")"}]}]}], 
       "\[IndentingNewLine]", "           ", 
       RowBox[{
        RowBox[{
         StyleBox["where",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", 
         RowBox[{"y", "[", "0", "]"}]}], "=", "0"}]}]}], 
     RowBox[{"\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{" ", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "r"}], ")"}], 
              RowBox[{"1", "+", "n"}]], " ", "-", " ", "1"}]}], "r"], "P"}], 
         " ", "-", " ", "P"}]}], "\[IndentingNewLine]"}]}]}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
     "RowsIndexed" -> {}}]]],
 "   \n\n\t\t\t",
 StyleBox["Table 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Some examples of first order linear difference equations. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["(i)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The exponential growth or decay model  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "r"}], ")"}], " ", 
    RowBox[{"y", "[", "n", "]"}]}]}]]],
 "    has the solution  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "\[Rule]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "r"}], ")"}], "n"], " ", 
    SubscriptBox["y", "0"]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], " ", 
       RowBox[{"y", "[", "n", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"IC", "=", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["\[ScriptY]", "0"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DE", ",", "IC"}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<With the initial condition\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", " ", 
      SubscriptBox["sol", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947426828125*^9, 3.39947426940625*^9}, {
   3.400343742375*^9, 3.400343745546875*^9}, 3.40034467021875*^9}],

Cell[TextData[{
 StyleBox["(ii)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Newton's law of heating and cooling model  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", "L"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "a"}], ")"}], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}]}]]],
 "    has the solution  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "a"}], ")"}], "n"]}], " ", "+", 
    RowBox[{"L", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "a"}], ")"}], "n"]}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "n", ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"a", " ", "L"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "a"}], ")"}], " ", 
        RowBox[{"y", "[", "n", "]"}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IC", "=", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["\[ScriptY]", "0"]}]}], ";"}], "  ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DE", ",", "IC"}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<With the initial condition\>\"", "]"}], ";"}], 
   "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", " ", 
      SubscriptBox["sol", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "  ", 
      RowBox[{"FullSimplify", "[", 
       SubscriptBox["sol", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], " ", 
       "]"}]}], " ", "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947427778125*^9, 3.399474279140625*^9}, {
   3.40034376546875*^9, 3.4003437694375*^9}, 3.40034467928125*^9}],

Cell[TextData[{
 StyleBox["(iii)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The repeated dosage drug level model  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]]],
 "    has the solution  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], " ", 
     SuperscriptBox["a", "n"]}], " ", "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1"}], ")"}], " ", "b"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "n", ",", "y"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IC", "=", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["\[ScriptY]", "0"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DE", ",", "IC"}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<With the initial condition\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", " ", 
      SubscriptBox["sol", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], " ", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", " ", 
      RowBox[{"Collect", "[", 
       RowBox[{
        SubscriptBox["sol", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
        
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", " ", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         SubscriptBox["sol", 
          RowBox[{"\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
         "]"}], ",", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474303328125*^9, 3.399474304640625*^9}, {
   3.40034378025*^9, 3.4003437965*^9}, 3.400344858875*^9, {
   3.40034491821875*^9, 3.40034491859375*^9}}],

Cell[TextData[{
 StyleBox["(iv)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The value of an annuity due is the future value of all payments.  It is \
the sum of the compounded amounts for all payments.   It is given by the \
formula  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}]}], "+", 
      RowBox[{"P", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "2"]}], "+", 
      RowBox[{"P", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "3"]}], "+"}], "..."}], "+", 
    RowBox[{"P", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], 
      RowBox[{"n", "-", "1"}]]}], "+", 
    RowBox[{"P", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], "n"]}]}]}]]],
 "  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"P", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}]}], "r"], "-", "P"}]}]]],
 " "
}], "Text"],

Cell["We can sum the series directly and get", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "n"], 
      RowBox[{"P", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "k"]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{"MapAll", "[", 
      RowBox[{"FullSimplify", ",", "sol"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = \!\(\*UnderoverscriptBox[\(\[Sum]\), \(k = 1\), \(n\)]\) \
P(1+r\!\(\*SuperscriptBox[\()\), \(k\)]\)\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "sol"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"FullSimplify", ",", 
        RowBox[{"Together", "[", 
         RowBox[{"sol", "+", "P"}], "]"}]}], "]"}], "-", "P"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "sol"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947431159375*^9, 3.399474312890625*^9}}],

Cell[TextData[{
 "When written as a difference equation we have \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "r"}], ")"}], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], "+", "P"}], ")"}], "   ", "with", "   ", 
     
     RowBox[{"y", "[", "0", "]"}]}], "=", "0"}]}]]],
 "  \n\t\tor\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], " ", 
      RowBox[{"y", "[", "n", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], "P", "   ", "with", "   ", 
      RowBox[{"y", "[", "0", "]"}]}]}], "=", "0"}]}]]],
 "  \n\nThis is a special case of the repeated dosage drug level model with  \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "0"], "=", "0"}], ",", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"1", "+", "r"}]}], ",", " ", 
   RowBox[{
    RowBox[{"and", "   ", "b"}], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "r"}], ")"}], "P"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "0"], " ", 
      SuperscriptBox["a", "n"]}], "  ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "n"], "-", "1"}], ")"}], " ", "b"}]}]}], 
   "\n"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"0", " ", 
       SuperscriptBox["a", "n"]}], "  ", "+", " ", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"1", "+", "r", "-", "1"}]], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], "n"], "-", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], "P"}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], "n"], "-", "1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], "P"}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], "n"], 
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], "P"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "r"}], ")"}], "P"}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], 
          RowBox[{"n", "+", "1"}]], "P"}], "-", "P", "-", 
        RowBox[{"r", " ", "P"}]}], ")"}]}]}], "\n"}]}], "\[IndentingNewLine]",
  
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], 
          RowBox[{"n", "+", "1"}]], "P"}], "-", "P", "-", 
        RowBox[{"r", " ", "P"}]}], ")"}]}]}], "\[IndentingNewLine]"}]}], "\n",
  
  RowBox[{"           ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "r"], "P", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], 
          RowBox[{"n", "+", "1"}]], "-", "1"}], ")"}]}], " ", "-", " ", 
      RowBox[{
       FractionBox["1", "r"], "r", " ", "P"}]}]}], 
    "\n"}]}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "r"}], ")"}], 
          RowBox[{"n", "+", "1"}]], "-", "1"}], ")"}]}], "r"], " ", "-", "  ",
      "P"}]}]}]}]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["y", "0"], 
         SuperscriptBox["a", "n"]}], " ", "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"a", "-", "1"}]], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "n"], "-", "1"}], ")"}], " ", "b"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "0"], "\[Rule]", "0"}], ",", 
         RowBox[{"a", "\[Rule]", 
          RowBox[{"1", "+", "r"}]}], ",", 
         RowBox[{"b", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}], "P"}]}]}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "sol"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"FullSimplify", ",", 
        RowBox[{"Together", "[", 
         RowBox[{"sol", "+", "P"}], "]"}]}], "]"}], "-", "P"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "sol"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947431871875*^9, 3.39947431975*^9}}],

Cell[TextData[{
 "And ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can solve the difference equation."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "y", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DEeqn", "=", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "1"}], "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], " ", 
        RowBox[{"y", "[", "n", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "r"}], ")"}], "P"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IC", "=", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "0"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DEeqn", ",", 
         RowBox[{
          RowBox[{"y", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"FullSimplify", ",", 
        RowBox[{"Together", "[", 
         RowBox[{
          SubscriptBox["solset", 
           RowBox[{"\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
          "+", "P"}], "]"}]}], "]"}], "-", "P"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DEeqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", "sol"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947432225*^9, 3.3994743236875*^9}, {
  3.40034385534375*^9, 3.400343855640625*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["9.1.7  Methods for Solving First Order Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\t",
 StyleBox["Consider the first order linear constant coefficient difference \
equation",
  FontFamily->"Times New Roman"],
 " (LCCDE)  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "  ", "-", "  ", 
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 "  with the initial condition   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", " ", 
   SubscriptBox["y", "0"]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Trial solution method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tFirst, solve the homogeneous equation   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "  and get   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], 
    SuperscriptBox["a", "n"]}]}]]],
 ".   Then use a trial solution that is appropriate for the sequence ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 " on the right side of the equation and solve to obtain a particular \
solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 ".   Then the general solution is  \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["y", "p"], "[", "n", "]"}]}]}]]],
 ". \n\nThe shortcoming of this method is that an extensive list of \
appropriate trial solutions must be available.  Details can be found in \
difference equations textbooks.  We will emphasize techniques that use the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform.  "
}], "Text"],

Cell[TextData[{
 StyleBox["z-transform method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "\tUse the time forward property  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "]"}], " ", "=", " ", 
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "-", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 "  and take the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform of each term and get\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", 
       SubscriptBox["y", "0"]}], ")"}]}], "  ", "-", "  ", 
    RowBox[{"a", " ", "Y", 
     RowBox[{"(", "z", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "\n\t\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tSolve the equation in (i) for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ". \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tUse partial fractions to expand  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  in a sum of terms, and look up the inverse ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform(s) using Table 1, to get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]]
}], "Text"],

Cell[TextData[{
 StyleBox["Residue method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tPerform steps (i) and (ii) of the above ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform method.  Then find the solution using the formula \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "   ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "k"], 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "i"]}], "]"}]}]}]}]]],
 ".  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Convolution method.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "\tSolve the homogeneous equation   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "   and get   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], 
    SuperscriptBox["a", "n"]}]}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tUse the transfer function   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"a", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}]}]]}]]],
 "  \n\n\tand construct the unit-sample response   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"H", 
      RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
    SuperscriptBox["a", "n"]}]}]]],
 ". \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tConstruct the particular solution   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}], "H", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 ",    \n\n\tin convolution form   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], " ", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], 
      RowBox[{"h", "[", "i", "]"}]}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], " ", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], 
      SuperscriptBox["a", "i"]}]}]}]}]]],
 ".  \n\n",
 StyleBox["(iv)",
  FontColor->RGBColor[0, 0, 1]],
 "\tThe general solution to the nonhomogeneous difference equation is  \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "n"], " ", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "i"}], "]"}], 
       SuperscriptBox["a", "i"]}]}]}]}]}]]],
 ".\n\n ",
 StyleBox["(v) ",
  FontColor->RGBColor[0, 0, 1]],
 "\tThe constant  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["y", "0"], "-", 
    RowBox[{"x", "[", "0", "]"}]}]}]]],
 "  will produce the proper initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", " ", 
   SubscriptBox["y", "0"]}]]],
 ".  Therefore, \n \n \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["y", "0"], "-", 
       RowBox[{"x", "[", "0", "]"}]}], ")"}], 
     SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], " ", 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], 
      SuperscriptBox["a", "i"]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark 9.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The particular solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 "  obtained by using convolution has the initial condition  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "p"], "[", "0", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "0"], 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"0", "-", "i"}], "]"}], 
       RowBox[{"h", "[", "i", "]"}]}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], 
      RowBox[{"h", "[", "0", "]"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"x", "[", "0", "]"}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve the difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
    RowBox[{"2", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   SuperscriptBox["3", "n"]}]]],
 "  with initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", "2"}]]],
 ". \n",
 StyleBox["9 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform and Tables 9.1 - 9.2 to find the solution. \n",
 StyleBox["9 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use residues to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.9.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Solution 9.9 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Take the z-transform of both sides  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "2"}], ")"}]}], " ", "-", 
    " ", 
    RowBox[{"2", " ", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{" ", "z"}], 
    RowBox[{"z", "-", "3"}]]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"]}], "-", 
     RowBox[{"5", " ", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 ".  Then expand and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"2", " ", "+", " ", 
    FractionBox["2", 
     RowBox[{"z", "-", "2"}]], " ", "+", " ", 
    FractionBox["3", 
     RowBox[{"z", "-", "3"}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Find the inverse z-transform of each term \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", "2", "]"}], "  ", "+", "  ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox["2", 
       RowBox[{"z", "-", "2"}]], "]"}], "  ", "+", "  ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox["3", 
       RowBox[{"z", "-", "3"}]], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[Delta]", "[", "n", "]"}]}], "  ", "+", "  ", 
     RowBox[{
      SuperscriptBox["2", "n"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "  ", "+", "  ", 
     RowBox[{
      SuperscriptBox["3", "n"], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}]}]}]}]],
 "   \n\nWhen  ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]]],
 "  we get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", "+", "0", "+", "0"}], " ", "=", " ", "2"}]}]]],
 ",  and when ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 " the expression for ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " simplifies to be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["2", "n"], "+", 
    SuperscriptBox["3", "n"]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 StyleBox["Solution 9.9 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Start with the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"]}], "-", 
     RowBox[{"5", " ", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 "  in part (a).  Then use the Corollaries 9.1 and 9.2 and residues to find  \
",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[GothicCapitalZ]", 
    RowBox[{"-", "1"}]], "[", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "]"}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "2"}], "]"}], " ", "+", " ", 
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "3"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"5", " ", "z"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "3"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "2"}], "]"}], " ", "+", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "-", 
          RowBox[{"5", " ", "z"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "3"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "3"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "2"}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "-", 
         RowBox[{"5", " ", "z"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "3"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "3"}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}], 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "-", 
         RowBox[{"5", " ", "z"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "3"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "2"}]], 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "-", 
         RowBox[{"5", " ", "z"}]}], 
        RowBox[{"z", "-", "3"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "3"}]], 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "-", 
         RowBox[{"5", " ", "z"}]}], 
        RowBox[{"z", "-", "2"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", "2"}], 
       RowBox[{" ", 
        RowBox[{"-", "1"}]}]], 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["3", "1"], 
      SuperscriptBox["3", 
       RowBox[{"n", "-", "1"}]]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], "  ", "+", "  ", 
     SuperscriptBox["3", "n"], "   "}]}]}]}]],
 "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.9.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["9.9 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Use the z-transform and tables to find the solution. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X", ",", "y", ",", "Y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], " ", "=", " ", "2"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["3", "n"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
      RowBox[{"x", "[", "n", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IC", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["y", "0"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", " ", 
     RowBox[{"ZTransform", "[", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<With initial condition\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", "IC"}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Here we have\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<X[z] = \[GothicCapitalZ][\!\(\*SubscriptBox[\(y\), \(n\)]\)] = \
\[GothicCapitalZ][\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Taking the z-transforms we have\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z (Y[z] - \!\(\*SubscriptBox[\(y\), \(0\)]\)) - 2 Y[z] = X[z]\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z (Y[z] - (\>\"", ",", 
      SubscriptBox["y", "0"], ",", "\"\<)) - 2 Y[z] = \>\"", ",", " ", 
      RowBox[{"X", "[", "z", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474343546875*^9, 3.399474345546875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "Y", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", "2"}], ")"}]}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"Y", "[", "z", "]"}]}]}], "\[Equal]", "  ", 
      RowBox[{"ZTransform", "[", 
       RowBox[{
        SuperscriptBox["3", "n"], ",", "n", ",", "z"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve for Y[z]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     SubscriptBox[
      RowBox[{"Solve", "[", 
       RowBox[{"eqn", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], "]"}], 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     RowBox[{"Together", "[", 
      RowBox[{"Y", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     RowBox[{"Apart", "[", 
      RowBox[{"Y", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474348578125*^9, 3.3994743498125*^9}}],

Cell["Find the inverse z-transformations.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[Y[z]] \
= \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947435309375*^9, 3.39947435484375*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could investigate each of the terms. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \>\"", ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      "2", ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{"2", ",", "z", ",", "n"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      FractionBox["3", 
       RowBox[{"z", "-", "3"}]], ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        FractionBox["3", 
         RowBox[{"z", "-", "3"}]], ",", "z", ",", "n"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      FractionBox["2", 
       RowBox[{"z", "-", "2"}]], ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        FractionBox["2", 
         RowBox[{"z", "-", "2"}]], ",", "z", ",", "n"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947435721875*^9, 3.399474358828125*^9}}],

Cell["\<\
The KroneckerDelta and UnitStep[n-1] factors might give us some concern so we \
will check them out when n=0.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 KroneckerDelta[0] = \>\"", ",", 
      RowBox[{"2", " ", 
       RowBox[{"KroneckerDelta", "[", "0", "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(2\), \(0\)]\) UnitStep[0-1] = \>\"", ",", 
      RowBox[{
       SuperscriptBox["2", "0"], " ", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"0", "-", "1"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(3\), \(0\)]\) UnitStep[0-1] = \>\"", ",", 
      RowBox[{
       SuperscriptBox["3", "0"], " ", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"0", "-", "1"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<2 KroneckerDelta[0]+\!\(\*SuperscriptBox[\(2\), \(0\)]\) \
UnitStep[0-1]+\!\(\*SuperscriptBox[\(3\), \(0\)]\) UnitStep[0-1] = \>\"", ",",
       
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"KroneckerDelta", "[", "0", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["2", "0"], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"0", "-", "1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["3", "0"], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"0", "-", "1"}], "]"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474362234375*^9, 3.399474364015625*^9}}],

Cell[TextData[{
 "So the computation is correct when n=0.   When ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "0"}]]],
 " we have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"KroneckerDelta", "[", "n", "]"}], "=", "0"}]]],
 ".  \n\nTherefore the following form of the solution would also be valid."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"KroneckerDelta", "[", "n", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["2", "n"], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["3", "n"], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], "]"}]}]}], ",", 
       RowBox[{"n", "\[GreaterEqual]", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{y[n]} = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the same as\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{y[n]} = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474366875*^9, 3.399474371359375*^9}}],

Cell[TextData[{
 StyleBox["9.9 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Use residues to find the solution. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)2] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 2\)]\
\) \>\"", ",", 
      RowBox[{
       RowBox[{"Together", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"z", "\[Rule]", "2"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)3] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 3\)]\
\) \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}], 
        RowBox[{"Y", "[", "z", "]"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "3"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"z", "\[Rule]", "3"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)2] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\
\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)3]\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"z", "\[Rule]", "2"}]}], "]"}], "+", 
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "3"}], ")"}], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"z", "\[Rule]", "3"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474374296875*^9, 3.399474375734375*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solve the difference equation with",
 StyleBox[" RSolve",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "y", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IC", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "2"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
      SuperscriptBox["3", "n"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DE", ",", "IC"}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<With initial condition\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], " ", "]"}], ";"}],
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994743799375*^9, 3.399474381265625*^9}, 
   3.400343898578125*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve the difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
    RowBox[{"2", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "n"}]]],
 "  with initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", "1"}]]],
 ". \n",
 StyleBox["9.10 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transform and Tables 9.1 - 9.2 to find the solution. \n",
 StyleBox["9.10 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use residues to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Solution 9.10 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Take the z-transform of both sides  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1"}], ")"}]}], " ", "-", 
    " ", 
    RowBox[{"2", " ", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   FractionBox["z", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], "2"]]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "3"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", "z"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "2"], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]]}]]],
 ".  Then expand and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"1", " ", "-", " ", 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "2"]], " ", "-", " ", 
    FractionBox["2", 
     RowBox[{"z", "-", "1"}]], " ", "+", " ", 
    FractionBox["4", 
     RowBox[{"z", "-", "2"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Find the inverse z-transform of each term \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", "1", "]"}], " ", "-", " ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], "2"]], "]"}], " ", "-", " ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox["2", 
       RowBox[{"z", "-", "1"}]], "]"}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox["4", 
       RowBox[{"z", "-", "2"}]], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Delta]", "[", "n", "]"}], "  ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "-", "1"}], ")"}], " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "-", " ", 
    RowBox[{"2", " ", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"4", "*", 
     SuperscriptBox["2", 
      RowBox[{"n", "-", "1"}]], 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"n", "-", "1"}], "]"}]}]}]}]}]],
 " \n\nWhen  ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]]],
 "  we get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"1", "+", "0", "+", "0", " ", "+", "0"}], " ", "=", " ", 
    "1"}]}]]],
 ",  and when ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 " the expression for ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " simplifies to be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "1"}], "-", "n", " ", "+", " ", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "1"}]]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 StyleBox["Solution 9.10 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Start with the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "3"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"2", " ", "z"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "2"], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}]}]]}]]],
 "  in part (a).  Then use the Corollaries 9.1 and 9.2 and residues to find  \
",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[GothicCapitalZ]", 
    RowBox[{"-", "1"}]], "[", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "]"}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "1"}], "]"}], " ", "+", " ", 
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "2"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["z", "3"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"2", " ", "z"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], "2"], 
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "1"}], "]"}], " ", "+", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["z", "3"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"2", " ", "z"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], "2"], 
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "2"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], "2"], 
         FractionBox[
          RowBox[{
           SuperscriptBox["z", "3"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["z", "2"]}], "+", 
           RowBox[{"2", " ", "z"}]}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"z", "-", "1"}], ")"}], "2"], 
           RowBox[{"(", 
            RowBox[{"z", "-", "2"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ")"}]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "2"}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], 
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "3"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"2", " ", "z"}]}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], "2"], 
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], 
      RowBox[{
       FractionBox["d", "dz"], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["z", "3"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["z", "2"]}], "+", 
           RowBox[{"2", " ", "z"}]}], 
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], " ", ")"}]}]}], " ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "2"}]], 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "3"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "+", 
         RowBox[{"2", " ", "z"}]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], "2"]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}], " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}], " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "n"}], "+", "2"}], ")"}], " ", "z"}], "-", 
          RowBox[{"4", " ", "n"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}], "2"]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], " ", ")"}]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["4", "1"], 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"n", "+", "1"}], ")"}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}]}], "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "n"}], "+", "2"}], ")"}], "-", 
        RowBox[{"4", "n"}]}], 
       RowBox[{" ", "1"}]], 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["4", "1"], 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"-", " ", "1"}], "  ", "-", "  ", "n", "  ", "+", "  ", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "1"}]], "   "}]}]}]],
 "    "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.10.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["9.10 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Use the z-transform and tables to find the solution. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X", ",", "y", ",", "Y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], " ", "=", " ", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "n"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
      RowBox[{"x", "[", "n", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IC", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["y", "0"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", " ", 
     RowBox[{"ZTransform", "[", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<With initial condition\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", "IC"}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Here we have\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<X[z] = \[GothicCapitalZ][\!\(\*SubscriptBox[\(y\), \(n\)]\)] = \
\[GothicCapitalZ][\>\"", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Taking the z-transforms we have\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<z (Y[z] - \!\(\*SubscriptBox[\(y\), \(0\)]\)) - 2 Y[z] = X[z]\>\"", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z (Y[z] - (\>\"", ",", 
      SubscriptBox["y", "0"], ",", "\"\<)) - 2 Y[z] = \>\"", ",", " ", 
      RowBox[{"X", "[", "z", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994743894375*^9, 3.39947439134375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "Y", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", "1"}], ")"}]}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"Y", "[", "z", "]"}]}]}], "\[Equal]", "  ", 
      RowBox[{"ZTransform", "[", 
       RowBox[{"n", ",", "n", ",", "z"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve for Y[z]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     SubscriptBox[
      RowBox[{"Solve", "[", 
       RowBox[{"eqn", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], "]"}], 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     RowBox[{"Together", "[", 
      RowBox[{"Y", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", 
     RowBox[{"Apart", "[", 
      RowBox[{"Y", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474393671875*^9, 3.399474394765625*^9}}],

Cell["Find the inverse z-transformations.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[Y[z]] \
= \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474397265625*^9, 3.39947439865625*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could investigate each of the terms. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \>\"", ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      "1", ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{"1", ",", "z", ",", "n"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      FractionBox[
       RowBox[{"-", "1"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], "2"]], ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], "2"]], ",", "z", ",", "n"}], 
       "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      FractionBox[
       RowBox[{"-", "2"}], 
       RowBox[{"z", "-", "1"}]], ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "2"}], 
         RowBox[{"z", "-", "1"}]], ",", "z", ",", "n"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      FractionBox["4", 
       RowBox[{"z", "-", "2"}]], ",", "\"\<] = \>\"", ",", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        FractionBox["4", 
         RowBox[{"z", "-", "2"}]], ",", "z", ",", "n"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474401140625*^9, 3.39947440228125*^9}}],

Cell["\<\
The KroneckerDelta and UnitStep[n-1] factors might give us some concern so we \
will check them out when n=0.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<KroneckerDelta[0] = \>\"", ",", 
      RowBox[{"KroneckerDelta", "[", "0", "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<(0-1) UnitStep[0-1] = \>\"", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0", "-", "1"}], ")"}], " ", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"0", "-", "1"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<2 UnitStep[0-1] = \>\"", ",", 
      RowBox[{"2", " ", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"0", "-", "1"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(2\), \(0 + 1\)]\) UnitStep[0-1] = \>\"", ",",
       
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"0", "+", "1"}]], " ", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"0", "-", "1"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<KroneckerDelta[0]-(0-1) UnitStep[0-1]-2 \
UnitStep[0-1]+\!\(\*SuperscriptBox[\(2\), \(n + 1\)]\) UnitStep[0-1] = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"KroneckerDelta", "[", "0", "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0", "-", "1"}], ")"}], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"0", "-", "1"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"0", "-", "1"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"n", "+", "1"}]], " ", 
        RowBox[{"UnitStep", "[", 
         RowBox[{"0", "-", "1"}], "]"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474404578125*^9, 3.39947440590625*^9}}],

Cell[TextData[{
 "So the computation is correct when n=0.   When ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "0"}]]],
 " we have ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"KroneckerDelta", "[", "n", "]"}], "=", "0"}]]],
 ".  \n\nTherefore the following form of the solution would also be valid."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"KroneckerDelta", "[", "n", "]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"1", "+", "n"}]], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "n"}], "]"}]}]}], ",", 
       RowBox[{"n", "\[GreaterEqual]", "0"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{y[n]} = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which is the same as\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{y[n]} = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474410109375*^9, 3.399474411125*^9}}],

Cell[TextData[{
 StyleBox["9.10 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]],
 "  Use residues to find the solution. "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)1] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 2\)]\
\) \>\"", ",", "\"\<\!\(\*FractionBox[\(d\), \(dz\)]\)\>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], "2"], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ")"}], "]"}]}], "  ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)1] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 2\)]\
\) \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "z"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], "2"], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ")"}]}], "]"}], ",", "\"\< = \>\"", 
      ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{
          SubscriptBox["\[PartialD]", "z"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"z", "-", "1"}], ")"}], "2"], 
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ")"}]}], "]"}], ",", 
        RowBox[{"z", "\[Rule]", "1"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)2] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 3\)]\
\) \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2"}], ")"}], 
        RowBox[{"Y", "[", "z", "]"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"z", "\[Rule]", "2"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)1] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\
\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)2]\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           SubscriptBox["\[PartialD]", "z"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"z", "-", "1"}], ")"}], "2"], 
             RowBox[{"Y", "[", "z", "]"}], 
             SuperscriptBox["z", 
              RowBox[{"n", "-", "1"}]]}], ")"}]}], "]"}], ",", 
         RowBox[{"z", "\[Rule]", "1"}]}], "]"}], "+", 
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "2"}], ")"}], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"z", "\[Rule]", "2"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947441425*^9, 3.39947441546875*^9}}],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  We could let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solve the difference equation with",
 StyleBox[" RSolve",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "y", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IC", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", "0", "]"}], "\[Equal]", "1"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"2", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", "n"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"RSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"DE", ",", "IC"}], "}"}], ",", 
       RowBox[{"y", "[", "n", "]"}], ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<With initial condition\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], " ", "]"}], ";"}],
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474418546875*^9, 3.399474419609375*^9}, 
   3.4003439475*^9}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Given the repeated dosage drug level model  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]]],
 " with the initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   SubscriptBox["y", "0"]}]]],
 ". ",
 StyleBox["\n9.11 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the trial solution method.  \n",
 StyleBox["9.11 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use ",
 StyleBox["z",
  FontFamily->"Courier New"],
 "-transforms to find the solution. \n",
 StyleBox["9.11 (c).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use residues to find the solution. \n",
 StyleBox["9.11 (d).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use convolution to find the solution. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.11.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe first step is to solve the homogeneous equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  The trial solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], "=", 
   SuperscriptBox["r", "n"]}]]],
 ", and substitution produces  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", 
     RowBox[{"n", "+", "1"}]], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["r", "n"]}]}], "=", "0"}]]],
 ", from which we obtain the characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", "-", "a"}], "=", "0"}]]],
 ".  The root is  ",
 Cell[BoxData[
  RowBox[{"r", "=", "a"}]]],
 "  and the homogeneous solution is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["c", "1"], " ", 
     SuperscriptBox["a", "n"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The second step is to find a particular solution to the nonhomogeneous \
equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "p"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}]}], " ", "=", " ", "b"}]]],
 ".  \n\nSince the right hand side is a constant, we try  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "=", "c"}]]],
 ",  and substitution produces  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"c", " ", "-", " ", 
    RowBox[{"a", " ", "c"}]}], " ", "=", " ", "b"}]]],
 ", hence ",
 Cell[BoxData[
  RowBox[{"c", " ", "=", 
   FractionBox["b", 
    RowBox[{"1", "-", "a"}]]}]]],
 ".  The general solution is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", 
     SuperscriptBox["a", "n"]}], "+", 
    FractionBox["b", 
     RowBox[{"1", "-", "a"}]]}]}]}]],
 "\n\nThen  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], " ", 
      SuperscriptBox["a", "0"]}], "+", 
     FractionBox["b", 
      RowBox[{"1", "-", "a"}]]}], " ", "=", " ", 
    SubscriptBox["y", "0"]}]}]]],
 " can be solved for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], " ", "=", " ", 
   RowBox[{
    FractionBox["b", 
     RowBox[{"a", "-", "1"}]], "+", 
    SubscriptBox["y", "0"]}]}]]],
 ".   Substituting this in the previous expression for ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " yields  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["b", 
         RowBox[{"a", "-", "1"}]], "+", 
        SubscriptBox["y", "0"]}], ")"}], " ", 
      SuperscriptBox["a", "n"]}], "  ", "-", "  ", 
     FractionBox["b", 
      RowBox[{"a", "-", "1"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "0"], 
      SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"a", "-", "1"}]], " ", 
      SuperscriptBox["a", "n"], "b"}], "  ", "-", "  ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"a", "-", "1"}]], "b"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1"}], ")"}], "b"}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tStart with the difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]]],
 ".  Take the z-transform of both sides  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["y", "0"]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", "Y", 
     RowBox[{"(", "z", ")"}]}], "+", 
    RowBox[{"b", 
     FractionBox[
      RowBox[{" ", "z"}], 
      RowBox[{"z", "-", "1"}]]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"b", " ", "z"}], "-", 
     RowBox[{"z", " ", 
      SubscriptBox["y", "0"]}], "+", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      SubscriptBox["y", "0"]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "a"}], ")"}]}]]}]]],
 ".  Then expand and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     RowBox[{"(", 
      FractionBox["z", 
       RowBox[{"z", "-", "a"}]], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      FractionBox["1", 
       RowBox[{"z", "-", "a"}]], ")"}]}], "-", 
    RowBox[{
     FractionBox["b", 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      FractionBox["1", 
       RowBox[{"z", "-", "1"}]], ")"}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "Find the inverse z-transform of each term \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "0"], 
      RowBox[{
       SuperscriptBox["\[GothicCapitalZ]", 
        RowBox[{"-", "1"}]], "[", 
       FractionBox["z", 
        RowBox[{"z", "-", "a"}]], "]"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"a", " ", "b"}], 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{
       SuperscriptBox["\[GothicCapitalZ]", 
        RowBox[{"-", "1"}]], "[", 
       FractionBox["1", 
        RowBox[{"z", "-", "a"}]], "]"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["b", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{
       SuperscriptBox["\[GothicCapitalZ]", 
        RowBox[{"-", "1"}]], "[", 
       FractionBox["1", 
        RowBox[{"z", "-", "1"}]], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     RowBox[{"(", 
      SuperscriptBox["a", "n"], ")"}]}], "  ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"a", " ", "b"}], 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", 
        RowBox[{"n", "-", "1"}]], 
       RowBox[{"u", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["b", 
      RowBox[{"a", "-", "1"}]], 
     RowBox[{"(", 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}], ")"}]}]}]}]}]],
 "  \n\nWhen  ",
 Cell[BoxData[
  RowBox[{"n", "=", "0"}]]],
 "  we get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "0"], 
      RowBox[{"(", 
       SuperscriptBox["a", "0"], ")"}]}], "+", "0", "-", "0"}], "=", 
    SubscriptBox["y", "0"]}]}]]],
 ",  and when ",
 Cell[BoxData[
  RowBox[{"n", "\[GreaterEqual]", "1"}]]],
 " the expression for ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " simplifies to be \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], " ", "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], "b"}]}]}]]],
 " "
}], "Text"],

Cell[TextData[StyleBox["Solution 11 (c).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tStart with the formula for the z-transform that we found in part (b):  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"b", " ", "z"}], "-", 
     RowBox[{"z", " ", 
      SubscriptBox["y", "0"]}], "+", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      SubscriptBox["y", "0"]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "a"}], ")"}]}]]}]]],
 ".  Then use the Corollary and residues to find  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[GothicCapitalZ]", 
    RowBox[{"-", "1"}]], "[", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "]"}]]],
 ".  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "1"}], "]"}], " ", "+", " ", 
      RowBox[{"Res", "[", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "a"}], "]"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"b", " ", "z"}], "-", 
          RowBox[{"z", " ", 
           SubscriptBox["y", "0"]}], "+", 
          RowBox[{
           SuperscriptBox["z", "2"], " ", 
           SubscriptBox["y", "0"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "a"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "1"}], "]"}], " ", "+", " ", 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"b", " ", "z"}], "-", 
          RowBox[{"z", " ", 
           SubscriptBox["y", "0"]}], "+", 
          RowBox[{
           SuperscriptBox["z", "2"], " ", 
           SubscriptBox["y", "0"]}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "a"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "a"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "X", 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "a"}]], "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "a"}], ")"}], "X", 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], "  ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox[
        RowBox[{
         RowBox[{"b", " ", "z"}], "-", 
         RowBox[{"z", " ", 
          SubscriptBox["y", "0"]}], "+", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          SubscriptBox["y", "0"]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "a"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "a"}]], "  ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"b", " ", "z"}], "-", 
         RowBox[{"z", " ", 
          SubscriptBox["y", "0"]}], "+", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          SubscriptBox["y", "0"]}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "a"}], ")"}]}]], "X", 
       RowBox[{"(", "z", ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "1"}]], "  ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"b", " ", "z"}], "-", 
         RowBox[{"z", " ", 
          SubscriptBox["y", "0"]}], "+", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          SubscriptBox["y", "0"]}]}], 
        RowBox[{" ", 
         RowBox[{"z", "-", "a"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], "  ", "+", "  ", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "a"}]], "  ", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"b", " ", "z"}], "-", 
         RowBox[{"z", " ", 
          SubscriptBox["y", "0"]}], "+", 
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          SubscriptBox["y", "0"]}]}], 
        RowBox[{"z", "-", "1"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"b", "-", " ", 
        SubscriptBox["y", "0"], "+", 
        SubscriptBox["y", "0"]}], 
       RowBox[{" ", 
        RowBox[{"1", "-", "a"}]}]], 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], "  ", "+", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"b", " ", "a"}], "-", 
        RowBox[{"a", " ", 
         SubscriptBox["y", "0"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], 
         SubscriptBox["y", "0"]}]}], 
       RowBox[{"a", "-", "1"}]], 
      SuperscriptBox["a", 
       RowBox[{"n", "-", "1"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["b", 
      RowBox[{"1", "-", "a"}]], "  ", "+", "  ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["a", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "b"}], "-", 
         RowBox[{"a", " ", 
          SubscriptBox["y", "0"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SubscriptBox["y", "0"]}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "a"}]]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["y", "0"], 
      SuperscriptBox["a", "n"]}], "   ", "+", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["a", "n"], "-", "1", " "}], 
       RowBox[{"a", "-", "1"}]], "b", "  "}]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[StyleBox["Solution 9.11 (d).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "The solution to the homogeneous equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "   is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], 
    SuperscriptBox["a", "n"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "The transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"a", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}]}]]}]]],
 "  and the unit-sample response is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"H", 
      RowBox[{"(", "z", ")"}]}], "]"}], " ", "=", " ", 
    SuperscriptBox["a", "n"]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "The input sequence is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", "b"}]]],
 "  and it's z-transform is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"b", " ", "z"}], 
    RowBox[{"z", "-", "1"}]]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "The particular solution is calculated with the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}], "H", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 "  as follows: \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", "  ", 
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"b", " ", "z"}], 
        RowBox[{"z", "-", "1"}]], ")"}], 
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"a", " ", 
          SuperscriptBox["z", 
           RowBox[{"-", "1"}]]}]}]], ")"}]}], "]"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      RowBox[{"b", " ", "-", " ", 
       FractionBox["b", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}], ")"}]}]], " ", "+", " ", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "a"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "z"}], ")"}]}]]}], "]"}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"\[Delta]", "[", "n", "]"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["b", 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], " ", "b"}], 
       RowBox[{"a", "-", "1"}]], 
      RowBox[{"u", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}]}]}]}]}]],
 "\n\nwhich can be simplified to obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", 
        RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
    RowBox[{"a", "-", "1"}]]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "In convolution form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], "*", 
     RowBox[{"h", "[", "n", "]"}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], 
      RowBox[{"h", "[", "i", "]"}]}]}]}]}]]],
 "  and we have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], " ", 
     RowBox[{"b", " ", 
      SuperscriptBox["a", "i"]}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
     RowBox[{"a", "-", "1"}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "The particular solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 "  obtained by using convolution has the initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "0"], 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"0", "-", "i"}], "]"}], 
      RowBox[{"h", "[", "i", "]"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], 
      RowBox[{"h", "[", "0", "]"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], " ", "=", " ", "b"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The total solution to the nonhomogeneous difference equation is  \n\n\t\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], "n"], " ", 
       RowBox[{"b", " ", 
        SuperscriptBox["a", "i"]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"           ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", 
          RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
      RowBox[{"a", "-", "1"}]], " "}]}]}]}]],
 "  \n"
}], "Text"],

Cell[TextData[{
 "Now we compute  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], " ", "=", " ", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox["a", "0"]}], " ", "+", " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "1"}], ")"}], " ", "b"}], 
       RowBox[{"a", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["c", "1"], " ", "+", " ", "b"}]}]}]}]]],
 ",  and solve for the constant  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["y", "0"], "-", " ", "b"}]}]]],
 "  which will produce the proper initial condition.  Therefore, \n \n \t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["y", "0"], "-", "b"}], ")"}], 
     SuperscriptBox["a", "n"]}], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
     RowBox[{"a", "-", "1"}]]}]}]]],
 ",  \n \n which can be manipulated to yield   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], " ", "b"}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 "\t",
 "An illustration of the dosage model using the parameters",
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    FractionBox["4", "5"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{"b", "=", "1"}]}]]],
 " and initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", "0"}]}]]],
 " is shown in Figure 1 below. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWT1s01AQfokT6kTiT7AgEM0MAxRB07lIMAEz3aIS1A4IGipRaIJKp3aA
hTIDcztTJBAD7HSnM2wMICEmCH733Hv+uXt+zitKVTmK7NPdd3ff3T0/28m1
1vxM+05rfna61bjaad2bmZ2+37hytxOovJIQpadCiM2GkHI/EMNDP/j2n8mD
1OyO/F6eyjL8JSlVpVRG3RihuyClipQ81J1Swd7BCWwggVKIcRCqMXVoUnGD
SFHb+Zz4c4TOo6mcVMIHwuPiQCzjuoolrmxkp2fS3AVOenJ5KzwRoZMwDTZS
qglx3RjdGIt+ebiGodZKfL1qnUfoomt4mWAFx9r/s/9CEnpYByPwstwAftM9
OKSEx1hbRYK/S6lm9HgiTwCeIChRuqYlrq4iB5/DySIAUB9epwt7Yd8r9kfy
BFuol4HsEnbKx5dHuM7+ZjiCakRKsAP8yZdnYMcUwUWlCD7VPT6twr7/7Mdx
Of7kQcdwsf9wBFmlS+0QcCOlHixTyIQ964paJOz6EWmQ/SfNKPXwkVVIsSG4
2Bu4wr7xoFFcq18dQVbpht2T/WQ3Xx1ncRzbCp7jGjyD8/6iYOZHhxS8R8Cp
FzwXjsU+sWNvYhe3eNA4zuizI8gq3bB7kmW/jEV84kGT2I6PjiCrdMPuyQ0k
ualAcNUDhrq/X8fC3yi47VWfcky8+wA6RcZla4jYbXy6KjeDnEJmG3wvb2KN
644gq3RZo72NQV7xoDbSeekIskrXQdAaD5rDdM8dQTpdDaVVHt7FmCuOoB6m
q6PU4+ErGLNrA9LFzPHw1XjtCcc277iGcB+lWzz8BZFHv+VP8Y6vEeQTBHXf
JvkQ6wRVn2DR5ENscPRBGjEyG1VhzU8ibwlHli1Ip1XYHJvflrGIMB67VYNq
26Y+cDoa0VJb0pGIXb9IhlqQB/ynagF5HEDJj3NTtx7xkOBG9c3naqDfp6k7
YuJHe+re16dJ6WGa/kWhbdFiF0zrxC30A5xhWPvOh+qE+WcKIZbyDWApY8bc
KhGlf9Ca4W8=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{397, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["5", "4"], 
     RowBox[{"y", "[", "n", "]"}]}], "+", "1"}]}]]],
 " with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", "0"}]}]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Start with the difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]]],
 ".   The first step is to solve the homogeneous equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  Use the trial solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], "=", 
   SuperscriptBox["r", "n"]}]]],
 ", and construct the homogeneous solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x", ",", "X", ",", "y", ",", "Y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HDE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"a", " ", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", "0"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"eqn1", "=", 
     RowBox[{"ReplaceAll", "[", " ", 
      RowBox[{"HDE", ",", 
       RowBox[{
        RowBox[{"y", "[", "n_", "]"}], "\[Rule]", 
        RowBox[{
         SubscriptBox["c", "1"], " ", 
         SuperscriptBox["r", "n"]}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solset1", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn1", ",", "r"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["c", "1"], 
        SuperscriptBox["r", "n"]}], ",", 
       RowBox[{"r", "\[Rule]", 
        SubscriptBox["solset1", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the homogeneous equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "HDE", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Substitute y[n] \[Rule] \!\(\*SubscriptBox[\(c\), \(1\)]\) \
\!\(\*SuperscriptBox[\(r\), \(n\)]\)\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And obtain the equation\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn1", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve and get\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"r", "\[Rule]", 
      SubscriptBox["solset1", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<The homogeneous solution is\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399474434*^9}],

Cell[TextData[{
 "The second step is to find a particular solution ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 " to the nonhomogeneous equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "p"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}]}], " ", "=", " ", "b"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "1"}], "]"}], " ", "-", 
       RowBox[{"a", " ", 
        RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", "b"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"eqn2", "=", 
     RowBox[{"ReplaceAll", "[", " ", 
      RowBox[{"DE", ",", 
       RowBox[{
        RowBox[{"y", "[", "n_", "]"}], "\[Rule]", "c"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"solset2", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn2", ",", "c"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "n_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{"c", ",", 
       RowBox[{"c", "\[Rule]", 
        SubscriptBox["solset2", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve the homogeneous equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "HDE", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute y[n] \[Rule] c\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<And obtain the equation\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn2", " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve and get\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"c", "\[Rule]", 
      SubscriptBox["solset2", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], "]"}]
     , ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<The particular solution is\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399474438921875*^9}],

Cell[TextData[{
 "The general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
    RowBox[{
     SubscriptBox["y", "p"], "[", "n", "]"}]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "g"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n]  =  \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] + \
\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "g"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474443140625*^9, 3.399474444078125*^9}}],

Cell[TextData[{
 "Then solve for the initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   SubscriptBox["y", "0"]}]]],
 ".   "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn3", "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["y", "g"], "[", "0", "]"}], "\[Equal]", 
      SubscriptBox["\[ScriptY]", "0"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset3", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["y", "g"], "[", "0", "]"}], "\[Equal]", 
        SubscriptBox["\[ScriptY]", "0"]}], ",", 
       SubscriptBox["c", "1"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn3", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", 
     SubscriptBox["solset3", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], " ", "]"}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"Print", "[", "\"\<The general solution is\>\"", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n]  =  \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] + \
\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "g"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "g"], "[", "n", "]"}], ",", 
       SubscriptBox["solset3", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n]  =  \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n]  =  \>\"", ",", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"y", "[", "n", "]"}], ",", " ", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n]  =  \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n]  =  \>\"", ",", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"y", "[", "n", "]"}], "]"}], ",", " ", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474446296875*^9, 3.399474447453125*^9}, {
  3.40034399071875*^9, 3.400344095640625*^9}}],

Cell[TextData[{
 "Which can be written in the desired form   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], "b"}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Start with the difference equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "n", ",", "y"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DE", " ", "=", " ", 
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "1"}], "]"}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"y", "[", "n", "]"}]}], "+", "b"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Given the difference equation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947445365625*^9, 3.399474454609375*^9}, 
   3.400344113125*^9}],

Cell["Take the z-transform of both sides.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "Y", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
         SubscriptBox["y", "0"]}], ")"}]}], " ", "\[Equal]", " ", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Y", "[", "z", "]"}]}], "+", 
       RowBox[{"b", 
        FractionBox["z", 
         RowBox[{"z", "-", "1"}]]}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<The z-transform is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474457546875*^9, 3.39947445859375*^9}}],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"b", " ", "z"}], "-", 
     RowBox[{"z", " ", 
      SubscriptBox["y", "0"]}], "+", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      SubscriptBox["y", "0"]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "a"}], ")"}]}]]}]]],
 ".  Then expand and obtain "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", "Y", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "DE", " ", "]"}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\<The z-transform is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Together", ",", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
             SubscriptBox["\[ScriptY]", "0"]}], ")"}]}], "\[Equal]", 
          RowBox[{
           RowBox[{"a", " ", 
            RowBox[{"Y", "[", "z", "]"}]}], "+", 
           RowBox[{"b", 
            FractionBox[
             RowBox[{" ", "z"}], 
             RowBox[{"z", "-", "1"}]]}]}]}], ",", 
         RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve for Y[z]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Apart", ",", 
       RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[ScriptY]", "0"], 
       FractionBox["z", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "z"}]]}], "+", 
      RowBox[{"Apart", "[", 
       FractionBox[
        RowBox[{"b", " ", "z"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "z"}], ")"}]}]], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474460828125*^9, 3.3994744629375*^9}, {
  3.400344192265625*^9, 3.40034419875*^9}}],

Cell["Find the inverse z-transform.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[Y[z]] \
= \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{"y", "[", "n", "]"}], "]"}], ",", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474465609375*^9, 3.39947446659375*^9}, 
   3.4003442143125*^9}],

Cell[TextData[{
 "Which can be written in the desired form   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], "b"}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (c).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Start with the formula for the z-transform that we found in part (b):  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"b", " ", "z"}], "-", 
     RowBox[{"z", " ", 
      SubscriptBox["y", "0"]}], "+", 
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      SubscriptBox["y", "0"]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "a"}], ")"}]}]]}]]],
 ".  Then use the Corollary and residues to find  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["\[GothicCapitalZ]", 
    RowBox[{"-", "1"}]], "[", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "]"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "a"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[\!\(\*FractionBox[\(b\\\ z - z\\\ \*SubscriptBox[\(y\), \(0\)] \
+ \*SuperscriptBox[\(z\), \(2\)]\\\ \*SubscriptBox[\(y\), \(0\)]\), \(\((z - \
1)\)\\\ \((z - a)\)\)]\)\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] = \>\"", 
      ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[\!\(\*FractionBox[\(b\\\ z - z\\\ \*SubscriptBox[\(y\), \(0\)] \
+ \*SuperscriptBox[\(z\), \(2\)]\\\ \*SubscriptBox[\(y\), \(0\)]\), \(\((z - \
1)\)\\\ \((z - a)\)\)]\)\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),a] = \>\"", 
      ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "a"}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[\!\(\*FractionBox[\(b\\\ z - z\\\ \*SubscriptBox[\(y\), \
\(0\)] + \*SuperscriptBox[\(z\), \(2\)]\\\ \*SubscriptBox[\(y\), \(0\)]\), \(\
\((z - 1)\)\\\ \((z - a)\)\)]\)\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] + \
Res[\!\(\*FractionBox[\(b\\\ z - z\\\ \*SubscriptBox[\(y\), \(0\)] + \
\*SuperscriptBox[\(z\), \(2\)]\\\ \*SubscriptBox[\(y\), \(0\)]\), \(\((z - 1)\
\)\\\ \((z - a)\)\)]\)\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),a]\>\"", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{"y", "[", "n", "]"}], "]"}], ",", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39947447346875*^9, 3.399474474703125*^9}, {
  3.400344224671875*^9, 3.400344265296875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"b", " ", "z"}], "-", 
           RowBox[{"z", " ", 
            SubscriptBox["\[ScriptY]", "0"]}], "+", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", 
            SubscriptBox["\[ScriptY]", "0"]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", "a"}], ")"}]}]], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "a"}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)1] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 2\)]\
\) \>\"", ",", 
      RowBox[{
       RowBox[{"Together", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"z", "\[Rule]", "1"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\)\!\(\*
StyleBox[\",\",
FontFamily->\"Times New Roman\",
FontSize->12,
FontWeight->\"Plain\",
FontSlant->\"Plain\",
FontVariations->{\"StrikeThrough\"->False,
\"Underline\"->False},
FontColor->GrayLevel[0]]\)a] = \!\(\*UnderscriptBox[\(lim\), \(z \[Rule] 3\)]\
\) \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "a"}], ")"}], 
        RowBox[{"Y", "[", "z", "]"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", "a"}], ")"}], 
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"z", "\[Rule]", "a"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"z", "\[Rule]", "1"}]}], "]"}], "+", 
       RowBox[{"Limit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "a"}], ")"}], 
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"z", "\[Rule]", "a"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"Collect", "[", 
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{"y", "[", "n", "]"}], "]"}], ",", 
        SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474477171875*^9, 3.399474478359375*^9}, {
  3.40034427465625*^9, 3.40034428609375*^9}, {3.400344320921875*^9, 
  3.40034432428125*^9}}],

Cell[TextData[{
 "Which can be written in the desired form   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], "b"}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.11 (d).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "The solution to the homogeneous equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "1"}], "]"}], " ", "-", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "   is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], 
    SuperscriptBox["a", "n"]}]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox["a", "n"]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Solve \!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] - a \
\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = 0\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Verify it\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "1"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] - a \
\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", " ", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "1"}], "]"}], ",", "\"\< - \>\"", ",", "a", " ", 
      ",", "\"\< \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] - a \
\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", " ", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "1"}], "]"}], ",", "\"\< - \>\"", ",", 
      RowBox[{"a", " ", 
       RowBox[{
        SubscriptBox["y", "h"], "[", "n", "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] - a \
\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "1"}], "]"}], "-", " ", 
       RowBox[{"a", " ", 
        RowBox[{
         SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474484796875*^9, 3.399474485984375*^9}}],

Cell[TextData[{
 "The transfer function is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"a", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}]}]]}]]],
 "  and the unit-sample response is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", 
      RowBox[{"H", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], " ", "=", " ", 
    SuperscriptBox["a", "n"]}]}]]],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "z_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"a", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"h", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"H", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The transfer function H(z) = \>\"", ",", 
      RowBox[{"H", 
       RowBox[{"(", "z", ")"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Unit-sample response  h[n] = \>\"", ",", 
      RowBox[{"h", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474488234375*^9, 3.399474490828125*^9}}],

Cell[TextData[{
 "The input sequence is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", "b"}]]],
 "  and it's z-transform is   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"b", " ", "z"}], 
    RowBox[{"z", "-", "1"}]]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "b"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "z_", "]"}], "=", 
     RowBox[{"ZTransform", "[", 
      RowBox[{
       RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The input sequence  x[n] = \>\"", ",", 
      RowBox[{"x", "[", "n", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<It's  z-transform   X[z] = \>\"", ",", 
      RowBox[{"X", "[", "z", "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994744933125*^9, 3.399474494484375*^9}}],

Cell[TextData[{
 "The particular solution is calculated with the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", 
     RowBox[{"X", 
      RowBox[{"(", "z", ")"}], "H", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 "  as follows: "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"X", "[", "z", "]"}], 
      RowBox[{"H", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The particular solution is\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(Y[z])\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(X[z]H[z])\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(\>\"", ",", 
      RowBox[{"X", "[", "z", "]"}], ",", 
      RowBox[{"H", "[", "z", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(\>\"", ",", 
      RowBox[{
       RowBox[{"X", "[", "z", "]"}], 
       RowBox[{"H", "[", "z", "]"}]}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(y\), \(p\)]\)[n]} = \>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["y", "p"], "[", "n", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474496828125*^9, 3.399474498109375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Details",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     RowBox[{"Apart", "[", 
      RowBox[{"Y", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*SuperscriptBox[\(\
\[GothicCapitalZ]\), \(-1\)]\)(\>\"", ",", 
      SubscriptBox[
       RowBox[{"Y", "[", "z", "]"}], 
       RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) + \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)(\>\"", 
      ",", 
      SubscriptBox[
       RowBox[{"Y", "[", "z", "]"}], 
       RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",", 
      "\"\<) + \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)(\>\"", 
      ",", 
      SubscriptBox[
       RowBox[{"Y", "[", "z", "]"}], 
       RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], ",", 
      "\"\<)\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Y", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], ",",
         "z", ",", "n"}], "]"}], "+", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Y", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], ",",
         "z", ",", "n"}], "]"}], "+", 
      RowBox[{"InverseZTransform", "[", 
       RowBox[{
        SubscriptBox[
         RowBox[{"Y", "[", "z", "]"}], 
         RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], ",",
         "z", ",", "n"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "0", "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "0", "]"}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "p"], "[", "n", "]"}], ",", 
       RowBox[{"n", ">", "1"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[0] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "p"], "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "p"], "[", "n", "]"}], ",", 
       RowBox[{
        RowBox[{"KroneckerDelta", "[", "n", "]"}], "\[Rule]", "0"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[0] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474500625*^9, 3.39947450184375*^9}}]
}, Open  ]],

Cell[TextData[{
 "In convolution form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n", "]"}], "*", 
     RowBox[{"h", "[", "n", "]"}]}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], 
      RowBox[{"h", "[", "i", "]"}]}]}]}]}]]],
 "  and we have \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "n"], " ", 
     RowBox[{"b", " ", 
      SuperscriptBox["a", "i"]}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
     RowBox[{"a", "-", "1"}]]}]}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"yp", "[", "n_", "]"}], "=", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "n"], 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"n", "-", "i"}], "]"}], 
       RowBox[{"h", "[", "i", "]"}]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(i = 0\), \(n\)]\)x[n-i]h[i]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(i = 0\), \(n\)]\)\>\"", ",", "\"\< \>\"", ",", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "i"}], "]"}], ",", 
      RowBox[{"h", "[", "i", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{"yp", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474505359375*^9, 3.3994745110625*^9}}],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The particular solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 "  obtained by using convolution has the initial condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], "0"], 
     RowBox[{
      RowBox[{"x", "[", 
       RowBox[{"0", "-", "i"}], "]"}], 
      RowBox[{"h", "[", "i", "]"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], 
      RowBox[{"h", "[", "0", "]"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"x", "[", "0", "]"}], " ", "=", " ", "b"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The total solution to the nonhomogeneous difference equation is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox["a", "n"]}], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "n"], " ", 
      RowBox[{"b", " ", 
       SuperscriptBox["a", "i"]}]}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["a", "n"]}], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
     RowBox[{"a", "-", "1"}]]}]}]]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(p\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399474514703125*^9}],

Cell[TextData[{
 "Now we compute  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], " ", "=", " ", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox["a", "0"]}], " ", "+", " ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "1"}], ")"}], " ", "b"}], 
       RowBox[{"a", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["c", "1"], " ", "+", " ", "b"}]}]}]}]]],
 ",  and solve for the constant  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["y", "0"], "-", " ", "b"}]}]]],
 "  which will produce the proper initial condition.  Therefore, \n \n \t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["y", "0"], "-", "b"}], ")"}], 
     SuperscriptBox["a", "n"]}], " ", "+", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"1", "+", "n"}]], "-", "1"}], ")"}], " ", "b"}], 
     RowBox[{"a", "-", "1"}]]}]}]]],
 ",  \n \n which can be arranged to yield   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], 
     SuperscriptBox["a", "n"]}], "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["a", "n"], "-", "1", " "}], 
      RowBox[{"a", "-", "1"}]], " ", "b"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["y", "p"], "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "\[Equal]", 
        SubscriptBox["\[ScriptY]", "0"]}], ",", 
       SubscriptBox["c", "1"]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Substitute  \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]]}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"y", "[", "n", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Together", "[", 
         RowBox[{"y", "[", "n", "]"}], "]"}], "]"}], ",", 
       SubscriptBox["\[ScriptY]", "0"]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399474518734375*^9, 3.399474519578125*^9}, {
  3.400344405484375*^9, 3.40034440853125*^9}}],

Cell[TextData[{
 "We can explore the situation when  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], "=", "0"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["4", "5"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"b", "=", "1"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", 
     FractionBox["4", "5"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["y", "0"], 
       SuperscriptBox["a", "n"]}], " ", "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["a", "n"], "-", "1", " "}], 
        RowBox[{"a", "-", "1"}]], "b"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Figure1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Figure1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"Figure1", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", 
           RowBox[{"m0", "+", "0.4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.15"}], ",", "5.05"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "5", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<n\>\"", ",", "\"\<y[n]\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"Expand", "[", 
       RowBox[{"y", "[", "n", "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994745225*^9, 3.399474561078125*^9}, {
   3.40006015296875*^9, 3.400060153234375*^9}, 3.400060969828125*^9, {
   3.40034359428125*^9, 3.400343599*^9}, 3.40034443084375*^9}],

Cell[TextData[{
 StyleBox["Figure 9.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  The solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", 
    RowBox[{"n", "+", "1"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["5", "4"], 
     RowBox[{"y", "[", "n", "]"}]}], "+", "1"}]}]]],
 " with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", "0"}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["The z-Transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], None}],
  
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[{
 StyleBox[ButtonBox["Nyquist Stability Criterion",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/NyquistStabilityBib.html"], 
    None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[1, 0, 1]],
 "  "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399474636375*^9, 3.39947463690625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{981, 648},
WindowMargins->{{2, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {36, 54}}},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[10444, 360, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[22491, 806, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[134650, 4335, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[181296, 5625, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 422067, 13549}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 128, 2, 29, "Text"],
Cell[1036, 36, 810, 16, 119, "Text"],
Cell[1849, 54, 109, 2, 29, "Text"],
Cell[1961, 58, 2176, 75, 65, "Text"],
Cell[4140, 135, 2427, 85, 199, "Text"],
Cell[6570, 222, 1848, 59, 155, "Text"],
Cell[8421, 283, 1681, 61, 114, "Text"],
Cell[CellGroupData[{
Cell[10127, 348, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[10271, 354, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[10444, 360, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[10793, 372, 5451, 210, 188, "Text"],
Cell[16247, 584, 3650, 128, 215, "Text"],
Cell[19900, 714, 2229, 75, 90, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[22154, 793, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[22298, 799, 190, 5, 29, "Text",
 Evaluatable->False],
Cell[22491, 806, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[22840, 818, 2416, 91, 101, "Text"],
Cell[25259, 911, 2163, 80, 88, "Text"],
Cell[27425, 993, 1275, 46, 43, "Text"],
Cell[28703, 1041, 873, 29, 65, "Text"],
Cell[CellGroupData[{
Cell[29601, 1074, 109, 2, 29, "Text"],
Cell[29713, 1078, 4308, 119, 467, "Input"],
Cell[34024, 1199, 169, 6, 65, "Text"],
Cell[34196, 1207, 1928, 54, 198, "Input"]
}, Closed]],
Cell[36139, 1264, 2166, 76, 40, "Text"],
Cell[38308, 1342, 1298, 45, 151, "Text"],
Cell[CellGroupData[{
Cell[39631, 1391, 109, 2, 29, "Text"],
Cell[39743, 1395, 4345, 120, 460, "Input"],
Cell[44091, 1517, 637, 15, 47, "Text"],
Cell[44731, 1534, 665, 26, 113, "Text"],
Cell[45399, 1562, 178, 6, 65, "Text"],
Cell[45580, 1570, 996, 27, 144, "Input"],
Cell[46579, 1599, 1231, 35, 164, "Input"]
}, Closed]],
Cell[47825, 1637, 588, 28, 33, "Text"],
Cell[48416, 1667, 1512, 50, 162, "Text"],
Cell[CellGroupData[{
Cell[49953, 1721, 109, 2, 29, "Text"],
Cell[50065, 1725, 2997, 84, 356, "Input"],
Cell[53065, 1811, 216, 10, 35, "Text"],
Cell[53284, 1823, 3341, 93, 366, "Input"],
Cell[56628, 1918, 3342, 93, 366, "Input"],
Cell[59973, 2013, 178, 6, 65, "Text"],
Cell[60154, 2021, 1006, 27, 144, "Input"],
Cell[61163, 2050, 1245, 35, 164, "Input"]
}, Closed]],
Cell[62423, 2088, 653, 28, 32, "Text"],
Cell[63079, 2118, 1720, 55, 164, "Text"],
Cell[CellGroupData[{
Cell[64824, 2177, 109, 2, 29, "Text"],
Cell[64936, 2181, 3141, 88, 358, "Input"],
Cell[68080, 2271, 238, 11, 35, "Text"],
Cell[68321, 2284, 3818, 107, 412, "Input"],
Cell[72142, 2393, 3787, 106, 412, "Input"],
Cell[75932, 2501, 178, 6, 65, "Text"],
Cell[76113, 2509, 1071, 28, 164, "Input"],
Cell[77187, 2539, 1507, 42, 184, "Input"]
}, Closed]],
Cell[78709, 2584, 4482, 159, 254, "Text"],
Cell[83194, 2745, 857, 36, 38, "Text"],
Cell[84054, 2783, 7025, 211, 383, "Text"],
Cell[CellGroupData[{
Cell[91104, 2998, 109, 2, 29, "Text"],
Cell[91216, 3002, 4862, 139, 539, "Input"],
Cell[96081, 3143, 535, 19, 71, "Text"],
Cell[96619, 3164, 3286, 93, 402, "Input"],
Cell[99908, 3259, 3339, 95, 402, "Input"],
Cell[103250, 3356, 53, 0, 29, "Text"],
Cell[103306, 3358, 2307, 59, 166, "Input"],
Cell[105616, 3419, 224, 10, 35, "Text"],
Cell[105843, 3431, 3451, 96, 375, "Input"],
Cell[109297, 3529, 3452, 96, 375, "Input"],
Cell[112752, 3627, 178, 6, 65, "Text"],
Cell[112933, 3635, 2439, 68, 203, "Input"],
Cell[115375, 3705, 3060, 85, 243, "Input"],
Cell[118438, 3792, 237, 9, 65, "Text"],
Cell[118678, 3803, 2939, 86, 297, "Input"],
Cell[121620, 3891, 2703, 81, 305, "Input"],
Cell[124326, 3974, 712, 16, 47, "Text"]
}, Closed]],
Cell[125053, 3993, 4146, 143, 482, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[129224, 4140, 99, 2, 29, "Text"],
Cell[129326, 4144, 2264, 64, 167, "Input"]
}, Closed]],
Cell[131605, 4211, 2683, 107, 262, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[134313, 4322, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[134457, 4328, 190, 5, 29, "Text",
 Evaluatable->False],
Cell[134650, 4335, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[135021, 4349, 135, 2, 26, "Text"],
Cell[135159, 4353, 10411, 249, 816, "Input",
 InitializationCell->True],
Cell[145573, 4604, 15935, 359, 1005, "Input",
 InitializationCell->True]
}, Closed]],
Cell[161523, 4966, 596, 20, 35, "Text"],
Cell[CellGroupData[{
Cell[162144, 4990, 101, 2, 29, "Text"],
Cell[162248, 4994, 1715, 60, 202, "Text"],
Cell[163966, 5056, 680, 26, 85, "Text"],
Cell[164649, 5084, 3952, 137, 190, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[168638, 5226, 109, 2, 26, "Text"],
Cell[168750, 5230, 2311, 65, 276, "Input"],
Cell[171064, 5297, 5346, 146, 459, "Input"]
}, Closed]],
Cell[176425, 5446, 136, 3, 26, "Text"],
Cell[176564, 5451, 2939, 102, 143, "Text"],
Cell[179506, 5555, 1448, 54, 101, "Text"],
Cell[CellGroupData[{
Cell[180979, 5613, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[181123, 5619, 170, 4, 29, "Text",
 Evaluatable->False],
Cell[181296, 5625, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[181645, 5637, 7298, 248, 540, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[188968, 5889, 99, 2, 29, "Text"],
Cell[189070, 5893, 2972, 85, 232, "Input"],
Cell[192045, 5980, 2731, 77, 292, "Input"]
}, Closed]],
Cell[194791, 6060, 589, 22, 39, "Text"],
Cell[195383, 6084, 2137, 79, 194, "Text"],
Cell[197523, 6165, 2611, 83, 227, "Text"],
Cell[200137, 6250, 4328, 144, 326, "Text"],
Cell[204468, 6396, 1661, 61, 60, "Text"],
Cell[CellGroupData[{
Cell[206154, 6461, 101, 2, 29, "Text"],
Cell[206258, 6465, 4748, 150, 198, "Text"],
Cell[211009, 6617, 3986, 125, 181, "Text"],
Cell[214998, 6744, 3046, 100, 211, "Text"],
Cell[218047, 6846, 3958, 124, 235, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[222042, 6975, 109, 2, 26, "Text"],
Cell[222154, 6979, 2418, 69, 307, "Input"],
Cell[224575, 7050, 2414, 69, 307, "Input"],
Cell[226992, 7121, 1452, 48, 220, "Text"],
Cell[228447, 7171, 5511, 137, 497, "Input"],
Cell[233961, 7310, 343, 11, 86, "Input"],
Cell[234307, 7323, 344, 11, 86, "Input"],
Cell[234654, 7336, 344, 11, 86, "Input"],
Cell[235001, 7349, 344, 11, 86, "Input"],
Cell[235348, 7362, 343, 11, 86, "Input"],
Cell[235694, 7375, 344, 11, 86, "Input"]
}, Closed]],
Cell[236053, 7389, 1913, 64, 278, "Text"],
Cell[237969, 7455, 5846, 180, 357, "Text"],
Cell[CellGroupData[{
Cell[243840, 7639, 99, 2, 29, "Text"],
Cell[243942, 7643, 610, 23, 101, "Text"],
Cell[244555, 7668, 1910, 53, 272, "Input"],
Cell[246468, 7723, 862, 32, 101, "Text"],
Cell[247333, 7757, 2283, 63, 272, "Input"],
Cell[249619, 7822, 732, 27, 107, "Text"],
Cell[250354, 7851, 2739, 76, 292, "Input"],
Cell[253096, 7929, 1358, 47, 115, "Text"],
Cell[254457, 7978, 54, 0, 29, "Text"],
Cell[254514, 7980, 1300, 40, 220, "Input"],
Cell[255817, 8022, 1256, 44, 137, "Text"],
Cell[257076, 8068, 3368, 120, 352, "Text"],
Cell[260447, 8190, 1435, 44, 146, "Input"],
Cell[261885, 8236, 124, 5, 29, "Text"],
Cell[262012, 8243, 2319, 69, 272, "Input"]
}, Closed]],
Cell[264346, 8315, 722, 24, 98, "Text"],
Cell[265071, 8341, 1454, 45, 177, "Text"],
Cell[266528, 8388, 1675, 62, 209, "Text"],
Cell[268206, 8452, 2175, 78, 140, "Text"],
Cell[270384, 8532, 3947, 142, 367, "Text"],
Cell[274334, 8676, 895, 30, 107, "Text"],
Cell[275232, 8708, 786, 29, 65, "Text"],
Cell[CellGroupData[{
Cell[276043, 8741, 101, 2, 29, "Text"],
Cell[276147, 8745, 527, 20, 71, "Text"],
Cell[276677, 8767, 758, 30, 83, "Text"],
Cell[277438, 8799, 1694, 57, 181, "Text"],
Cell[279135, 8858, 6178, 207, 307, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[285350, 9070, 109, 2, 26, "Text"],
Cell[285462, 9074, 163, 5, 29, "Text"],
Cell[285628, 9081, 2660, 75, 352, "Input"],
Cell[288291, 9158, 2044, 60, 254, "Input"],
Cell[290338, 9220, 51, 0, 29, "Text"],
Cell[290392, 9222, 835, 22, 115, "Input"],
Cell[291230, 9246, 169, 6, 65, "Text"],
Cell[291402, 9254, 1293, 34, 142, "Input"],
Cell[292698, 9290, 133, 3, 29, "Text"],
Cell[292834, 9295, 1580, 45, 161, "Input"],
Cell[294417, 9342, 313, 9, 65, "Text"],
Cell[294733, 9353, 2008, 59, 172, "Input"],
Cell[296744, 9414, 145, 5, 29, "Text"],
Cell[296892, 9421, 3468, 106, 156, "Input"],
Cell[300363, 9529, 288, 12, 65, "Text"],
Cell[300654, 9543, 1664, 49, 252, "Input"]
}, Closed]],
Cell[302333, 9595, 768, 28, 62, "Text"],
Cell[CellGroupData[{
Cell[303126, 9627, 102, 2, 29, "Text"],
Cell[303231, 9631, 562, 21, 74, "Text"],
Cell[303796, 9654, 952, 37, 87, "Text"],
Cell[304751, 9693, 2114, 70, 186, "Text"],
Cell[306868, 9765, 8437, 276, 372, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[315342, 10046, 110, 2, 26, "Text"],
Cell[315455, 10050, 164, 5, 29, "Text"],
Cell[315622, 10057, 2634, 75, 352, "Input"],
Cell[318259, 10134, 2016, 59, 254, "Input"],
Cell[320278, 10195, 51, 0, 29, "Text"],
Cell[320332, 10197, 836, 22, 115, "Input"],
Cell[321171, 10221, 169, 6, 65, "Text"],
Cell[321343, 10229, 1927, 53, 181, "Input"],
Cell[323273, 10284, 133, 3, 29, "Text"],
Cell[323409, 10289, 1938, 57, 179, "Input"],
Cell[325350, 10348, 313, 9, 65, "Text"],
Cell[325666, 10359, 2228, 65, 195, "Input"],
Cell[327897, 10426, 146, 5, 29, "Text"],
Cell[328046, 10433, 4761, 142, 190, "Input"],
Cell[332810, 10577, 288, 12, 65, "Text"],
Cell[333101, 10591, 1637, 49, 252, "Input"]
}, Closed]],
Cell[334753, 10643, 1025, 37, 98, "Text"],
Cell[CellGroupData[{
Cell[335803, 10684, 102, 2, 29, "Text"],
Cell[335908, 10688, 106, 2, 29, "Text"],
Cell[336017, 10692, 1149, 42, 83, "Text"],
Cell[337169, 10736, 3215, 113, 363, "Text"],
Cell[340387, 10851, 106, 2, 29, "Text"],
Cell[340496, 10855, 705, 26, 71, "Text"],
Cell[341204, 10883, 1189, 47, 84, "Text"],
Cell[342396, 10932, 2476, 89, 198, "Text"],
Cell[344875, 11023, 104, 2, 29, "Text"],
Cell[344982, 11027, 8644, 283, 419, "Text"],
Cell[353629, 11312, 106, 2, 29, "Text"],
Cell[353738, 11316, 520, 20, 29, "Text"],
Cell[354261, 11338, 613, 23, 37, "Text"],
Cell[354877, 11363, 326, 14, 35, "Text"],
Cell[355206, 11379, 2668, 90, 258, "Text"],
Cell[357877, 11471, 988, 35, 81, "Text"],
Cell[358868, 11508, 730, 25, 31, "Text"],
Cell[359601, 11535, 1095, 37, 137, "Text"],
Cell[360699, 11574, 1600, 57, 129, "Text"]
}, Closed]],
Cell[362314, 11634, 619, 24, 32, "Text"],
Cell[362936, 11660, 1217, 23, 197, "Text",
 Evaluatable->False],
Cell[364156, 11685, 470, 20, 35, "Text"],
Cell[CellGroupData[{
Cell[364651, 11709, 114, 2, 29, "Text"],
Cell[364768, 11713, 768, 26, 47, "Text"],
Cell[365539, 11741, 2722, 79, 332, "Input"],
Cell[368264, 11822, 449, 16, 31, "Text"],
Cell[368716, 11840, 2331, 66, 312, "Input"],
Cell[371050, 11908, 275, 10, 31, "Text"],
Cell[371328, 11920, 713, 21, 92, "Input"],
Cell[372044, 11943, 184, 7, 29, "Text"],
Cell[372231, 11952, 2878, 82, 312, "Input"],
Cell[375112, 12036, 405, 15, 37, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[375554, 12056, 114, 2, 26, "Text"],
Cell[375671, 12060, 263, 10, 29, "Text"],
Cell[375937, 12072, 786, 23, 132, "Input"],
Cell[376726, 12097, 51, 0, 29, "Text"],
Cell[376780, 12099, 987, 29, 164, "Input"],
Cell[377770, 12130, 596, 24, 42, "Text"],
Cell[378369, 12156, 2886, 88, 322, "Input"],
Cell[381258, 12246, 45, 0, 29, "Text"],
Cell[381306, 12248, 1173, 32, 135, "Input"],
Cell[382482, 12282, 405, 15, 37, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[382924, 12302, 114, 2, 26, "Text"],
Cell[383041, 12306, 761, 27, 42, "Text"],
Cell[383805, 12335, 4899, 136, 293, "Input"],
Cell[388707, 12473, 4941, 148, 236, "Input"],
Cell[393651, 12623, 405, 15, 37, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[394093, 12643, 114, 2, 26, "Text"],
Cell[394210, 12647, 520, 20, 29, "Text"],
Cell[394733, 12669, 2518, 72, 232, "Input"],
Cell[397254, 12743, 631, 24, 37, "Text"],
Cell[397888, 12769, 1005, 29, 150, "Input"],
Cell[398896, 12800, 326, 14, 35, "Text"],
Cell[399225, 12816, 813, 23, 132, "Input"],
Cell[400041, 12841, 405, 14, 31, "Text"],
Cell[400449, 12857, 2348, 65, 241, "Input"],
Cell[CellGroupData[{
Cell[402822, 12926, 95, 2, 29, "Text"],
Cell[402920, 12930, 4502, 121, 322, "Input"]
}, Open  ]],
Cell[407437, 13054, 986, 35, 81, "Text"],
Cell[408426, 13091, 1210, 34, 202, "Input"],
Cell[409639, 13127, 808, 28, 31, "Text"],
Cell[410450, 13157, 1023, 36, 117, "Text"],
Cell[411476, 13195, 971, 29, 132, "Input"],
Cell[412450, 13226, 1593, 56, 129, "Text"],
Cell[414046, 13284, 2038, 62, 212, "Input"],
Cell[416087, 13348, 269, 13, 35, "Text"],
Cell[416359, 13363, 3020, 89, 321, "Input"],
Cell[419382, 13454, 464, 20, 35, "Text"]
}, Closed]],
Cell[419861, 13477, 281, 7, 26, "Text"],
Cell[420145, 13486, 290, 10, 29, "Text"],
Cell[420438, 13498, 310, 10, 29, "Text"],
Cell[420751, 13510, 249, 5, 29, "Text"],
Cell[421003, 13517, 316, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
