(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    406102,      13086]
NotebookOptionsPosition[    395556,      12782]
NotebookOutlinePosition[    396468,      12816]
CellTagsIndexPosition[    396393,      12811]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[{
 StyleBox["9.2  Second Order Homogeneous Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tBefore proceeding with the ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-transform method, we mention a heuristic method based on \
substitution of a trial solution.  Consider the second order homogeneous ",
  FontFamily->"Times New Roman"],
 "linear constant-coefficient difference equation (HLCCDE) ",
 StyleBox["\n\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ",  ",
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"a", "  ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "b"}]]],
 StyleBox[" are constants.  Using the trial solution  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   SuperscriptBox["r", "n"]}]]],
 ",  and direct substitution into ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 " produces the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", 
     RowBox[{"n", "+", "2"}]], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["r", 
      RowBox[{"n", "+", "1"}]]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     SuperscriptBox["r", "n"]}]}], " ", "=", " ", "0"}]]],
 ",  and dividing through by ",
 Cell[BoxData[
  SuperscriptBox["r", "n"]]],
 " produces the characteristic polynomial  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["r", "2"], " ", "-", " ", 
   RowBox[{"2", " ", "a", " ", "r"}], " ", "+", " ", "b"}]]],
 "  and characteristic equation \n\n",
 StyleBox["(9-9)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], " ", "-", " ", 
    RowBox[{"2", " ", "a", " ", "r"}], " ", "+", " ", "b"}], "  ", "=", "  ", 
   "0"}]]],
 ". \n\nThere are three types of solutions to ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 " which are determined by the nature of the roots in ",
 StyleBox["(9-9)",
  FontColor->RGBColor[0, 0, 1]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (i)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", "<", 
   SuperscriptBox["a", "2"]}]]],
 "  then we have real distinct roots   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"a", "-", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", "b"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"a", "+", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "-", "b"}]]}]}]]],
 ",  and  \n\n",
 StyleBox["(9-10)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SubsuperscriptBox["r", "1", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SubsuperscriptBox["r", "2", "n"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", "=", 
   SuperscriptBox["a", "2"]}]]],
 "   then we have a double real root   ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SubscriptBox["r", "1"], "=", 
    RowBox[{
     SubscriptBox["r", "2"], "=", "a"}]}]}]]],
 ",  and  \n\n",
 StyleBox["(9-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], "n", " ", 
     SuperscriptBox["r", "n"]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Case (iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{"b", ">", 
   SuperscriptBox["a", "2"]}]]],
 "   then we have complex roots   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"a", "-", 
    RowBox[{"\[ImaginaryI]", 
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"a", "+", 
    RowBox[{"\[ImaginaryI]", 
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]]}]}]}]]],
 ",  and    \n\n",
 StyleBox["(9-12)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "1"], 
     SubsuperscriptBox["r", "1", "n"]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["k", "2"], 
     SubsuperscriptBox["r", "2", "n"]}]}]}]]],
 ".    \n\t\n\tThe solution for case ",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 " can also be written as the following linear combination \n\t\n",
 StyleBox["(9-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["r", "n"], "sin", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}]}]}]]],
 ",  \n\t\n\t\t\twhere  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   SqrtBox["b"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{"arctan", "[", 
    FractionBox[
     SqrtBox[
      RowBox[{"b", "-", 
       SuperscriptBox["a", "2"]}]], "a"], "]"}]}]]],
 ".  \n\t\n",
 StyleBox["Caution.",
  FontWeight->"Bold",
  FontColor->RGBColor[0.996109, 0.500008, 0.250004]],
 "  Be sure to use the value of arctan that lies in the range  ",
 Cell[BoxData[
  RowBox[{"0", "<", "\[Phi]", "\[LessEqual]", "\[Pi]"}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark About Stability",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tStability depends on the location of the roots of the characteristic \
polynomial.  Without loss if generality, if  ",
 Cell[BoxData[
  RowBox[{"|", 
   SubscriptBox["r", "1"], "|", 
   RowBox[{"\[LessEqual]", 
    RowBox[{"|", 
     SubscriptBox["r", "2"], "|", 
     RowBox[{"<", "1"}]}]}]}]]],
 "  then both roots lie inside the unit circle and the solutions are \
asymptotically stable and tends to zero as  ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ".   If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "\[NotEqual]", 
   SubscriptBox["r", "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    SubscriptBox["r", "1"], "|", 
    RowBox[{"\[LessEqual]", 
     RowBox[{"|", 
      SubscriptBox["r", "2"], "|"}]}]}], "=", "1"}]]],
 "  then a root lies on the unit circle and the solutions are stable.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{
    SubscriptBox["r", "2"], "=", 
    RowBox[{"\[PlusMinus]", "1"}]}]}]]],
 "  then there is an unstable solution.  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "<"}], "|", 
   SubscriptBox["r", "2"], "|"}]]],
 "  then at least one root lies outside the unit circle and there is an \
unstable solution.  "
}], "Text"],

Cell["\<\
\tThe following subroutine uses the characteristic equation to construct \
solutions to a second order homogeneous difference equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica Subroutine (",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox["Solution of a Difference Equation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SolveDE", "[", 
    RowBox[{
    "a0_", ",", "b0_", ",", "x0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{
       "c", ",", "k", ",", "n", ",", "r", ",", "\[Rho]", ",", "\[Theta]", ",",
         "y"}], "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "[", "n_", "]"}], "=", "x0"}], ";", "\[IndentingNewLine]",
       
      RowBox[{"HLCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", "n", "]"}], ",", "n", ",", "z"}], "]"}]}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"CP", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"HLCCDE", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"y", "[", "k_", "]"}], "\[Rule]", 
           SuperscriptBox["r", 
            RowBox[{"k", "-", "n"}]]}], "}"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"p", "[", "r_", "]"}], "=", 
       SubscriptBox["CP", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"CP", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["r", "1"], "=", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       " ", 
      RowBox[{
       SubscriptBox["r", "2"], "=", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "HLCCDE", "]"}], ";", " ", "\[IndentingNewLine]", 
      
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The characteristic polynomial is\>\""}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<p[r] = \>\"", ",", 
        RowBox[{"p", "[", "r", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The difference equation has the form\>\""}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<b y[n] - 2 a y[n+1] + y[n+2] \[Equal] 0\>\"", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<b = \>\"", ",", "b", ",", "\"\<,  a = \>\"", ",", "a", ",", 
        "\"\<,  \!\(\*SuperscriptBox[\(a\), \(2\)]\) = \>\"", ",", 
        SuperscriptBox["a", "2"]}], "  ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<For this example we have  \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "<", 
           SuperscriptBox["a", "2"]}], ",", 
          "\"\<b < \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\"", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             SuperscriptBox["a", "2"]}], ",", 
            "\"\<b = \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\"", ",", 
            "\"\<b > \!\(\*SuperscriptBox[\(a\), \(2\)]\)\>\""}], "]"}]}], 
         "]"}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<p[r] = \>\"", ",", 
        RowBox[{"Factor", "[", 
         RowBox[{"p", "[", "r", "]"}], "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<The roots are \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "<", 
           SuperscriptBox["a", "2"]}], ",", "\"\<real and distinct\>\"", ",", 
          
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"b", "\[Equal]", 
             SuperscriptBox["a", "2"]}], ",", "\"\<real and equal\>\"", ",", 
            "\"\<complex\>\""}], "]"}]}], "]"}], ",", "\"\<.\>\""}], " ", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(1\)]\) = \>\"", ",", 
        SubscriptBox["r", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(r\), \(2\)]\) = \>\"", ",", 
        SubscriptBox["r", "2"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\\n\>\"", ",", "\"\<The general solution is\>\""}], "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["r", "1"], "=!=", 
         SubscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "n_", "]"}], "=", 
         RowBox[{
          RowBox[{
           SubscriptBox["c", "1"], 
           SuperscriptBox[
            SubscriptBox["r", "1"], "n"]}], "+", 
          RowBox[{
           SubscriptBox["c", "2"], 
           SuperscriptBox[
            SubscriptBox["r", "2"], "n"]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["r", "1"], "\[Equal]", 
         SubscriptBox["r", "2"]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "n_", "]"}], "=", 
         RowBox[{
          RowBox[{
           SubscriptBox["c", "1"], 
           SuperscriptBox[
            SubscriptBox["r", "1"], "n"]}], "+", 
          RowBox[{
           SubscriptBox["c", "2"], "n", " ", 
           SuperscriptBox[
            SubscriptBox["r", "2"], "n"]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"b", "=!=", 
           SuperscriptBox["a", "2"]}], ",", 
          "\"\<\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(1\), \(n\)], \
\(\\\ \)]\)\!\(\*SubscriptBox[\(c\), \(1\)]\) + \
\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(2\), \(n\)], \(\\\ \
\)]\)\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\"", ",", 
          "\"\<\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(1\), \(n\)], \
\(\\\ \)]\)\!\(\*SuperscriptBox[SubscriptBox[\(c\), \(1\)], \(\\\ \)]\) + \
\!\(\*SuperscriptBox[SubsuperscriptBox[\(r\), \(2\), \(n\)], \(\\\ \)]\)n \
\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\""}], "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}], ",", "\"\<\\n\>\""}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"IC", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "0", "]"}], "\[Equal]", " ", "\[Alpha]"}], ",", 
         RowBox[{
          RowBox[{"y", "[", "1", "]"}], "\[Equal]", " ", "\[Beta]"}]}], 
        "}"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"psol", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"IC", ",", 
         RowBox[{"{", 
          RowBox[{
           SubscriptBox["c", "1"], ",", 
           SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y", "[", "n_", "]"}], "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{
         RowBox[{"y", "[", "n", "]"}], ",", 
         SubscriptBox["psol", 
          RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
        " ", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Given the initial conditions\>\"", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Solve the linear system\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "IC", " ", "]"}], ";", "\[IndentingNewLine]",
       
      RowBox[{"Print", "[", "\"\<Get\>\"", "]"}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(1\)]\) = \>\"", ",", " ", 
        SubscriptBox["psol", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[\(c\), \(2\)]\) = \>\"", ",", 
        SubscriptBox["psol", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<\\n\>\"", ",", "\"\<The solution with these IC's is\>\""}], "]"}],
       ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}]}], "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", 
        RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", 
        RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "1", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"b", ">", 
         SuperscriptBox["a", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Rho]", "=", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              SqrtBox[
               RowBox[{"b", "-", 
                SuperscriptBox["a", "2"]}]], ")"}], "2"]}]]}], ";", " ", 
         RowBox[{"\[Phi]", " ", "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"a", ">", " ", "0"}], ",", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              SqrtBox[
               RowBox[{"b", "-", 
                SuperscriptBox["a", "2"]}]], "a"], "]"}], ",", 
            RowBox[{"\[Pi]", "+", 
             RowBox[{"ArcTan", "[", 
              FractionBox[
               SqrtBox[
                RowBox[{"b", "-", 
                 SuperscriptBox["a", "2"]}]], "a"], "]"}]}]}], "]"}]}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{
           RowBox[{
            SubscriptBox["c", "1"], 
            SuperscriptBox["\[Rho]", "n"], "  ", 
            RowBox[{"Cos", "[", 
             RowBox[{"n", " ", "\[Phi]"}], "]"}]}], " ", "+", 
           RowBox[{
            SubscriptBox["c", "2"], " ", 
            SuperscriptBox["\[Rho]", "n"], "  ", 
            RowBox[{"Sin", "[", 
             RowBox[{"n", " ", "\[Phi]"}], "]"}]}]}]}], ";", "  ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\\n\>\"", ",", 
           "\"\<Another form of the complex solution is\>\""}], "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<y[n] = \!\(\*SuperscriptBox[\(\[Rho]\), \(n\)]\) Cos[\[Phi] n]\
\!\(\*SubscriptBox[\(c\), \(1\)]\) + \!\(\*SuperscriptBox[\(\[Rho]\), \(\(n\)\
\(\\\ \)\)]\)Sin[\[Phi] n]\!\(\*SubscriptBox[\(c\), \(2\)]\)\>\"", " ", "]"}],
          ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<   \[Rho] = \!\(\*SqrtBox[\(\*SuperscriptBox[\(a\), \(2\)] + \
\*SuperscriptBox[\((\*SqrtBox[\(b - \*SuperscriptBox[\(a\), \(2\)]\)])\), \(2\
\)]\)]\) = \>\"", ",", "\[Rho]"}], "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<   \[Phi] = ArcTan[\!\(\*FractionBox[SqrtBox[\(b - \
\*SuperscriptBox[\(a\), \(2\)]\)], \(a\)]\)] = \>\"", ",", "\[Phi]"}], "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[n] = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}], ",", "\"\<\\n\>\""}], " ", "]"}], 
         ";", " ", "\[IndentingNewLine]", 
         RowBox[{"IC", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"s", "[", "0", "]"}], "\[Equal]", " ", "\[Alpha]"}], ",",
             
            RowBox[{
             RowBox[{"s", "[", "1", "]"}], "\[Equal]", " ", "\[Beta]"}]}], 
           "}"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"psol", "=", 
          RowBox[{"Solve", "[", 
           RowBox[{"IC", ",", 
            RowBox[{"{", 
             RowBox[{
              SubscriptBox["c", "1"], ",", 
              SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{"ReplaceAll", "[", 
           RowBox[{
            RowBox[{"s", "[", "n", "]"}], ",", 
            SubscriptBox["psol", 
             RowBox[{
             "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], " ", 
           "]"}]}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<Given the initial conditions\>\"", "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<\\n\>\"", ",", "\"\<The solution with these IC's is\>\""}], 
          "]"}], ";", "  ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[n] = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "0", "]"}], "===", 
            RowBox[{"Simplify", "[", 
             RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<y[0] = \>\"", ",", 
              RowBox[{"Simplify", "[", 
               RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], 
          " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "[", "1", "]"}], "===", 
            RowBox[{"Simplify", "[", 
             RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<y[1] = \>\"", ",", 
              RowBox[{"Simplify", "[", 
               RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], 
          " ", "]"}], ";"}]}], "  ", "]"}], ";"}]}], " ", "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.40009396715625*^9, 3.400093998984375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWM1OwkAQXtj2oCdPHgQTjrbAa2g08azXhpjAwWiQRBPUm97Ug/oI+gJ6
U97CF9AXqTszZYF2F/vHVpI2tP0y3+zszO7M0HbfG3SPjr1Br+M1dvreabfX
OWtsn/SFiFcYqzwyxp4bDLAvYHDxxc9/ggtI0uMPuNlg0gFkAWoCqgJqA+KA
XCnbpIEjvCGHCE5HIUNjzJqRjS2HVLfUqnX9hK5C1tI5hlGq2A39BM2YE2hc
n6zkn6sWGevOMTllQSWDM1i1T+lBS4HaEjXlTtfTJdI9GRhLOUnvaOH9IBzk
v4i6gtsazIi8I9EI0Hp4vCORKtosslo4AFfh9CspPeiSMDTwRa9+kJvSYRzv
fNriwvhb6eSFXulGhntuQimWT0UvXJ78kFZFHFWSisOSyP5jNFYqs2f5oPWQ
SqRLVRUmVbJFTYOiJY9hzjSXil2Mv59FZ+My8u+UVYLd0yu9UZkJdteEUiyf
il64SBvCAuAp0nao4Pm8moqIrThlpSzFRDMU1XyGiVzNskZl6yn5f8lny04j
BbTQx5zrFBGUTabkSz5HHiucy/RPmL2GSpgakD22M20z2cONuYYQ+uq1gLaM
G5Tm2bTolCt58/wPlYMvP5mqlL6p1gRby1sp+Z9kxGMjtZtTQ4s0nkn8yd4C
EaxM2cj0xhexxqVHoR1BzVXSRBx8OWeVX/nOKJE=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "3"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"r", "-", "3"}], ")"}]}], " ", "=", " ", "0"}]}]]],
 "  has roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", 
     SubscriptBox["r", "2"]}], "=", "3"}]}]]],
 "  hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "1"], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["3", "n"]}]}]}]]],
 ".   Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "1"}]}], " ", "=", " ", 
    "1"}]}], "\[IndentingNewLine]", "and", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "3"}]}], " ", "=", " ", "5"}]}]}]],
 "  \n\nthen solve for the constants and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "1"], "=", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    SubscriptBox["c", "2"], "=", "2"}]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "1"}], " ", "+", " ", 
    RowBox[{"2", "*", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.12.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "3", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.399482116890625*^9, 3.40008653475*^9, {3.400347064078125*^9, 
   3.400347075609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["3", "n"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482118390625*^9, 3.399482169015625*^9}, {
  3.400067155140625*^9, 3.40006715546875*^9}, {3.4000842666875*^9, 
  3.400084330765625*^9}, {3.40008437196875*^9, 3.400084433078125*^9}, {
  3.400093821359375*^9, 3.40009382215625*^9}, {3.400094013828125*^9, 
  3.400094014625*^9}, {3.4000940488125*^9, 3.400094065296875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWU1SwjAUDrTdOrp1AR1b8CawUA/RYZyBheIgAnoCda9u4A7qBXShS+/h
Qs9Q+5KSSvPShkJDZygD6Zvvvbyf5HtNgRNv2D0984a9jme3B95Ft9e5tFv9
QQAZFUIqU0LIg01A9gMxHPzg7c9gACS7/AwXC1w6IJkgNUGqgnQIkgGSy7EG
x2zm4pVeKEIl+DgIRt0ScwGbx4iZHuCmLg7X5Xm4CIYFdPgyNNXTSYjbUIwr
8dzIstq4FxkcecAwWQ1hyS88vxhXYlKUfSTVsxH1jjmYo3sMvWX75ofcoPpv
prqByw5EpHqHS18g7cfnO4gnbMdUVwrDavFSXCT8GzO6l7E5NjHB/EjF6Jj7
fJcb0XFXrr/iTp7kRkOezqMOI6Wc0grTqR+xqoJXlTeQySUrZfaEXqxFfdjd
1J94I6giLjEsrzAU0lTDjLOhn3usKafnOZs6RvYzeWcFFxh5lIyEwjdN823X
0zan3DIUySDMjumNJLoKsJkSYSxl+VIRdDa3uECqqa6yRks1dJEYWET9J+NM
oG3LjT5gpDe8lg4jIafVtl0LM3M9n68zVFB2b6kvlH7CqZ3lMVtTC7AGtuZ+
/vtc7tTV11CxXxRyuK3RDcry0LRpypV6Bf4U+1xdU98L/RmVXsin+LQIRtmS
26kf8d0vbMuuLwh+qkbcL7t2Bf0vy8jn/wxgRj8w0u9rNR1GSjmtc2FI5Q9h
Mu8V\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{412, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "4"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", "2"}], ")"}], "2"], " ", "=", " ", "0"}]}]]],
 "  has equal roots ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SubscriptBox["r", "1"], "=", 
    RowBox[{
     SubscriptBox["r", "2"], "=", "2"}]}]}]]],
 "  hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["2", "n"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["2", "n"], "n"}]}]}]]],
 ".  Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], " ", "+", " ", 
      RowBox[{
       SubscriptBox["c", "2"], "0"}]}], "=", "1"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], "2"}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], "2"}]}], "=", "5"}]}]}]],
 "  \n\nthen solve for the constants and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["c", "1"], "=", "1"}], ",", 
   RowBox[{
    SubscriptBox["c", "2"], "=", 
    FractionBox["3", "2"]}]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["2", "n"], "+", 
     RowBox[{
      FractionBox["3", "2"], "n", " ", 
      SuperscriptBox["2", "n"]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], "+", 
     RowBox[{"3", "n", " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.13.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "4", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399482179390625*^9, 3.40008654803125*^9, 
  3.40034709821875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994821810625*^9, 3.399482199328125*^9}, {
   3.400067161484375*^9, 3.40006716175*^9}, {3.40008446925*^9, 
   3.40008451084375*^9}, 3.400086553828125*^9, {3.4000940910625*^9, 
   3.400094091734375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1OwkAQXmgbjd5sFzhy0COPoEc5+QymISRwIBIKxrsHTdST+kD6GPoK
vsPa3S27bZmpLf2DWALbLzOzOz/77dDClbucjGfucjpy+8OFO59MR17/8mbh
i4wWIa1XQsh7n3DMfBgMzH+zNz5wSf34RVwMIoNj8sNHszz9Nx8NXpAz3OiL
jxY3Oq3CKFVMRRZmJR36rzZHbY5MAFl/rHMrLmZEv140ozjqBJKFHXuyrDrG
2JoZQ9AZs2C/uHwmHW6ZUCbfCakuY/rKHK9UUYxcJKnjlDf6Rh85QCh70/PY
g49RdWeRWFF9jmYAdNuE9mcVl/kWbb7OvlsAbeqmf6P/33pPYpL3a9wD9GLF
qm+AmGocRThOaHvSf6lNt+l9e6f/5KN4WLvAjT4CQhFyXoVRqpjqLtwu6fXz
Y74H4Aruy3b2rrDe9lhv5ZsGub96R7LZf9mKyx21Yz2OxASqZFTJuhKx8IyO
0tpqZX12jvBAOoDMRu02eNtDp2+YOrCYyngZatBFXSQdvKj9QbYCOIAMCkPv
IqQ92TJhvZdOuWnSlGkiG6rZp7nZUclp5iLUKTk5JGiakEvsB860JYssqT+I
J0RcYDVilW8rfureEusZNIpMYK7uLbFvl4TeUmQTfZZBMBWsj36k6klxzo6y
T/dIgYYKzeXEe3455B6D2WvkAIhyJGYPlGwcKgAUhZOIdIxaBnEuj+wYrx5N
GaZddnDQ1g+A/UMDDu8ptNg1sMQDbn6nzB+r4fau6wUu4K9W0voFyiHDBA==
\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["r", "2"], "-", 
    RowBox[{"4", " ", "r"}], "+", "5"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"r", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}], " ", "=", " ", 
    "0"}]}]]],
 "  has complex roots ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{"2", "+", "\[ImaginaryI]"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "2"], "=", 
   RowBox[{"2", "-", "\[ImaginaryI]"}]}]]],
 " hence the general solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"], " "}]}]}]]],
 ".   Use the initial conditions and form the linear system  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "+", " ", 
     SubscriptBox["c", "2"]}], " ", "=", " ", "1"}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["c", "2"], 
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}]}]}], "  ", "=", " ", 
    "5"}]}]]],
 "  \n\nthen solve for the constants and get ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   FractionBox[
    RowBox[{"1", "-", 
     RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "2"], "=", 
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"]}]]],
 ".  Hence the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 ". \n\nWe leave it for the reader to verify that this can be written as  \n\n\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"}], ")"}]}], " ", "+", " ", 
    RowBox[{"3", "*", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox["1", "2"], ")"}], "n"}], ")"}]}]}]}]]],
 ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["SolveDE"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 ".  It will construct the characteristic polynomial and its roots.  The \
format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"SolveDE", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{"SolveDE", "[", 
    RowBox[{"2", ",", "5", ",", 
     RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994822215*^9, 3.39948222246875*^9}, 
   3.400347107453125*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compare  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"y2", "[", "n", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482226703125*^9, 3.399482240375*^9}, {
  3.400067167109375*^9, 3.400067167296875*^9}, {3.40008455159375*^9, 
  3.40008465109375*^9}, {3.400094160671875*^9, 3.400094161484375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Higher Order Difference Equations",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\n\n\tT",
  FontFamily->"Times New Roman"],
 "he general form of a ",
 Cell[BoxData[
  SuperscriptBox["P", "th"]]],
 " ",
 StyleBox["order linear constant coefficient difference equation",
  FontFamily->"Times New Roman"],
 " (LCCDE), is  ",
 StyleBox["\n\t\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P"}], "]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["b", "0"], " ", 
        RowBox[{"x", "[", "n", "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "1"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "2"], " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["b", 
       RowBox[{"M", "-", "1"}]], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q", "+", "1"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["b", "Q"], " ", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "Q"}], "]"}]}]}]}]}]}]],
 StyleBox["\n\nwhere ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["a", "p"], "}"}], 
   RowBox[{"p", "=", "1"}], "P"]]],
 StyleBox[" and ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    SubscriptBox["b", "q"], "}"}], 
   RowBox[{"q", "=", "0"}], "Q"]]],
 StyleBox[". ",
  FontFamily->"Times New Roman"],
 " The sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " is given and the sequence ",
 Cell[BoxData[
  SubsuperscriptBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["x", "n"], "=", 
     RowBox[{"x", "[", "n", "]"}]}], "}"}], 
   RowBox[{"n", "=", "0"}], "\[Infinity]"]]],
 " is output.  The integer  ",
 Cell[BoxData["P"]],
 "  is the order of the difference equation.  ",
 StyleBox["The compact form of writing this difference equation is \n\n",
  FontFamily->"Times New Roman"],
 StyleBox["(9-15)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "n", "]"}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "q"}], "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "This formula can be expressed in a recursive form:\n\n",
 StyleBox["(9-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "q"}], "]"}]}]}], "  ", "-", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "1"], 
      RowBox[{"y", "[", 
       RowBox[{"n", "-", "p"}], "]"}]}]}]}]}]]],
 ".  \n\n\tThis form of the LCCDE explicitly shows that the present output  \
",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  is a function of the past output values  ",
 Cell[BoxData[
  RowBox[{"y", "[", 
   RowBox[{"n", "-", "p"}], "]"}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"p", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "P"}]]],
 "; and the present input  ",
 Cell[BoxData[
  RowBox[{"x", "[", "n", "]"}]]],
 ",  and the previous inputs  ",
 Cell[BoxData[
  RowBox[{"x", "[", 
   RowBox[{"n", "-", "q"}], "]"}]]],
 "  for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"q", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "2", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "Q"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tNow we would like to emphasize the method of",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transforms for solving difference equations.  Applying the linearity and \
time delay shift property of the",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform to equation ",
 StyleBox["(9-15)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain \n\n",
 StyleBox["(9-17)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], "  ", "+", "  ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"p", "=", "1"}], "P"], 
     RowBox[{
      SubscriptBox["a", "p"], "Y", 
      RowBox[{"(", "z", ")"}], 
      SuperscriptBox["z", 
       RowBox[{"-", "p"}]]}]}]}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"q", "=", "0"}], "Q"], 
    RowBox[{
     SubscriptBox["b", "q"], "X", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"-", "q"}]]}]}]}]]],
 ". \n\nThis can be rearranged as  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"p", "=", "1"}], "P"], 
       RowBox[{
        SubscriptBox["a", "p"], 
        SuperscriptBox["z", 
         RowBox[{"-", "p"}]]}]}]}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"X", 
    RowBox[{"(", "z", ")"}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"q", "=", "0"}], "Q"], 
     RowBox[{
      SubscriptBox["b", "q"], 
      SuperscriptBox["z", 
       RowBox[{"-", "q"}]]}]}]}]}]]],
 "  and then solved for the quotient ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 ".  The sequence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"h", "[", "n", "]"}], "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 " can be used to construct a particular solution to ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 ", i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"H", 
      RowBox[{"(", "z", ")"}], "X", 
      RowBox[{"(", "z", ")"}]}], "]"}], "=", 
    RowBox[{
     RowBox[{"h", "[", "n", "]"}], "*", 
     RowBox[{"x", "[", "n", "]"}]}]}]}]]],
 ".  This solution can be expressed using the convolution sum, as follows:\n\n\
",
 StyleBox["(9-18)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "n"], " ", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"n", "-", "i"}], "]"}], 
     RowBox[{"x", "[", "i", "]"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  This particular solution   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 " does not involve initial conditions for ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 ".  We will illustrate how to use convolution at the end of this section.  "
}], "Text"],

Cell[TextData[{
 StyleBox["Difference Equations with Initial Conditions",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tOften times a difference equation involves only one input on the \
right hand side of ",
 StyleBox["(9-14)",
  FontColor->RGBColor[0, 0, 1]],
 " and we write\n\n",
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", "n", "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "-", "P"}], "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 "\n\t\t\nthen we could shift the index and use the form\n\n",
 StyleBox["\t\t\t",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "[", 
       RowBox[{"n", "+", "P"}], "]"}], "+", 
      RowBox[{
       SubscriptBox["a", "1"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "P", "-", "1"}], "]"}]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], " ", 
       RowBox[{"y", "[", 
        RowBox[{"n", "+", "P", "-", "2"}], "]"}]}], "+"}], "..."}], "+", 
    RowBox[{
     SubscriptBox["a", 
      RowBox[{"N", "-", "1"}]], " ", 
     RowBox[{"y", "[", 
      RowBox[{"P", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     SubscriptBox["a", "P"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", 
    RowBox[{"n", "+", "P"}], "]"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Consider the first order linear constant coefficient difference \
equation",
  FontFamily->"Times New Roman"],
 " (LCCDE)  \n\n",
 StyleBox["(9-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{"x", "[", 
    RowBox[{"n", "+", "2"}], "]"}]}]]],
 " \n\nwith the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "0"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", " ", 
    SubscriptBox["y", "1"]}]}]]],
 "  (and implicitly we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "0", "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     RowBox[{"x", "[", "1", "]"}]}], "=", " ", 
    SubscriptBox["x", "1"]}]}]]],
 "). "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Step (i)",
  FontColor->RGBColor[0, 0, 1]],
 "  Using the time forward properties  \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "]"}], " ", "=", "   ", 
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], "-", 
      SubscriptBox["y", "0"]}], ")"}]}]}]]],
 ", \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["y", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["y", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 ",   \n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"x", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["x", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["x", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 " \n\t\tand take the",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform of each term and get the equation  \n\n",
 StyleBox["(9-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"2", "a", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"b", " ", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"X", 
       RowBox[{"(", "z", ")"}]}], " ", "-", " ", 
      SubscriptBox["x", "0"], " ", "-", " ", 
      RowBox[{
       SubscriptBox["x", "1"], 
       SuperscriptBox["z", 
        RowBox[{"-", "1"}]]}]}], ")"}]}]}]]],
 ". \n\t\n\t",
 StyleBox["Step (ii)",
  FontColor->RGBColor[0, 0, 1]],
 "  Solve equation ",
 StyleBox["(9-20)",
  FontColor->RGBColor[0, 0, 1]],
 " for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ". \n\n\t",
 StyleBox["Step (iii)",
  FontColor->RGBColor[0, 0, 1]],
 "  Use partial fractions to expand  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  in a sum of terms, and look up the inverse",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform(s) using Table 1, to get the solution  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Step (iv)",
  FontColor->RGBColor[0, 0, 1]],
 "  Alternate calculation using residues.  Perform steps ",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 " listed above.  Then find  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 "  using residues  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}], "]"}], "  ", "=", "   ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "k"], 
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["z", "i"]}], "]"}]}]}]}]]],
 ".  \n\n\t\twhere  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["z", "k"]}]]],
 "  are the poles of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t",
 StyleBox["Remark",
  FontColor->RGBColor[0, 0, 1]],
 "  The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 "  has real coefficients.  Hence, if , and if ",
 Cell[BoxData[
  SubscriptBox["z", "i"]]],
 " and ",
 Cell[BoxData[
  OverscriptBox[
   SubscriptBox["z", "i"], "_"]]],
 " are poles, then we can use the computational fact: \n\n",
 StyleBox["(9-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     OverscriptBox[
      SubscriptBox["z", "i"], "_"]}], "]"}], "  ", "=", "   ", 
   OverscriptBox[
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      SubscriptBox["z", "i"]}], "]"}], "_"]}]]]
}], "Text"],

Cell[TextData[{
 "\tWe now show how to obtain answers to Examples 9.12-9.14 using",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods. "
}], "Text"],

Cell[TextData[{
 "\tThe following subroutine uses",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transforms to construct solutions to a second order homogeneous difference \
equation."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica Subroutines (",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox["Solution of a Difference Equation",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Zsolution", "[", 
    RowBox[{
    "a0_", ",", "b0_", ",", "x0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{"n", ",", "y", ",", "Y", ",", "z"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "[", "n_", "]"}], "=", "x0"}], ";", "\[IndentingNewLine]",
       
      RowBox[{"LCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "+", "2"}], "]"}]}]}], ";", " ", "\[IndentingNewLine]", 
      
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", 
        RowBox[{"x", "[", 
         RowBox[{"n", "+", "2"}], "]"}]}]}], ";", " ", "\[IndentingNewLine]", 
      
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "LCCDE", " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<Take the z-transforms of each term\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqn1", " ", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
            SubscriptBox["y", "0"], " ", "-", " ", 
            RowBox[{
             SubscriptBox["y", "1"], 
             SuperscriptBox["z", 
              RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
         RowBox[{"2", "a", 
          RowBox[{"(", 
           RowBox[{"z", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
              SubscriptBox["y", "0"]}], ")"}]}], ")"}]}], "+", 
         RowBox[{"b", 
          RowBox[{"(", 
           RowBox[{"Y", "[", "z", "]"}], ")"}]}]}], "\[Equal]", "  ", 
        RowBox[{"ZTransform", "[", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"n", "+", "2"}], "]"}], ",", "n", ",", "z"}], "]"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Use the initial values\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[0] = \!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", 
        "\[Alpha]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[1] = \!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", " ", 
        "\[Beta]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"eqn2", " ", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"eqn1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["y", "0"], "\[Rule]", "\[Alpha]"}], ",", 
           RowBox[{
            SubscriptBox["y", "1"], "\[Rule]", "\[Beta]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Substitute them and obtain\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn2", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"eqn2", ",", 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Y", "[", "z_", "]"}], "=", 
       RowBox[{"Together", "[", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
        "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Solve this equation for Y[z] = \[GothicCapitalZ][y[n]]\>\"", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Y[z] = \>\"", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"y", "[", "n_", "]"}], "=", 
       RowBox[{"InverseZTransform", "[", 
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Take the inverse z-transform and get the solution\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \
\(-1\)]\)[Y[z]] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"",
         ",", 
        RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[n] = \>\"", ",", 
        RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<It has the desired initial conditions\>\"", "]"}], 
      ";", "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[0] = \>\"", ",", 
        RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "0", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[0] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "0", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<y[1] = \>\"", ",", 
        RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", "1", "]"}], "===", 
         RowBox[{"Simplify", "[", 
          RowBox[{"y", "[", "1", "]"}], "]"}]}], ",", "\"\<\>\"", ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<y[1] = \>\"", ",", 
           RowBox[{"Simplify", "[", 
            RowBox[{"y", "[", "1", "]"}], "]"}]}], " ", "]"}], ";"}]}], " ", 
       "]"}], ";"}]}], " ", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400094287109375*^9, 3.400094312078125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ResidueSolution", "[", 
    RowBox[{"a0_", ",", "b0_", ",", "\[Alpha]0_", ",", "\[Beta]0_"}], "]"}], ":=",
    
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", "=", "a0"}], ";", " ", 
      RowBox[{"b", "=", "b0"}], ";", " ", 
      RowBox[{"\[Alpha]", "=", "\[Alpha]0"}], ";", " ", 
      RowBox[{"\[Beta]", "=", "\[Beta]0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Clear", "[", 
       RowBox[{"n", ",", "y", ",", "Y", ",", "z"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"HLCCDE", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "[", 
          RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
         RowBox[{"2", "a", " ", 
          RowBox[{"y", "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
         RowBox[{"b", " ", 
          RowBox[{"y", "[", "n", "]"}]}]}], "\[Equal]", " ", "0"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{"thede", "=", 
       RowBox[{
        RowBox[{"\"\<y[n+2]\>\"", " ", "-", " ", 
         RowBox[{"2", "a", " ", "\"\<y[n+1]\>\""}], " ", "+", " ", 
         RowBox[{"b", " ", "\"\<y[n]\>\""}]}], "\[Equal]", " ", "0"}]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
      ";", " ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", " ", "HLCCDE", " ", "]"}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", "\"\<Take the z-transforms of each term\>\"", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"eqn1", " ", "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["z", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
            SubscriptBox["y", "0"], " ", "-", " ", 
            RowBox[{
             SubscriptBox["y", "1"], 
             SuperscriptBox["z", 
              RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
         RowBox[{"2", "a", 
          RowBox[{"(", 
           RowBox[{"z", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
              SubscriptBox["y", "0"]}], ")"}]}], ")"}]}], "+", 
         RowBox[{"b", 
          RowBox[{"(", 
           RowBox[{"Y", "[", "z", "]"}], ")"}]}]}], "\[Equal]", " ", "0"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Use the initial values\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[0] = \!\(\*SubscriptBox[\(y\), \(0\)]\) = \>\"", ",", " ", 
        "\[Alpha]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<y[1] = \!\(\*SubscriptBox[\(y\), \(1\)]\) = \>\"", ",", " ", 
        "\[Beta]"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "\"\<Substitute them and obtain\>\"", "]"}], ";", 
      "  ", "\[IndentingNewLine]", 
      RowBox[{"eqn2", " ", "=", 
       RowBox[{"ReplaceAll", "[", 
        RowBox[{"eqn1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["y", "0"], "\[Rule]", "\[Alpha]"}], ",", 
           RowBox[{
            SubscriptBox["y", "1"], "\[Rule]", "\[Beta]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "eqn2", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"solset", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{"eqn2", ",", 
         RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Y", "[", "z_", "]"}], "=", 
       RowBox[{"Together", "[", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], 
        "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
      "Print", "[", 
       "\"\<Solve this equation for Y[z] = \[GothicCapitalZ][y[n]]\>\"", 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<   Y[z] = \>\"", ",", 
        RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"zsolve", "=", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Denominator", "[", 
           RowBox[{"Y", "[", "z", "]"}], "]"}], "\[Equal]", "0"}], ",", "z"}],
         "]"}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["z", "1"], "=", 
       SubscriptBox["zsolve", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["z", "2"], "=", 
       SubscriptBox["zsolve", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "=!=", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The poles are\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], "+", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
           SubscriptBox["z", "2"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", "\"\<The solution is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - \
1\)]\),\!\(\*SubscriptBox[\(z\), \(1\)]\)] + Res[Y[z]z\!\(\*SuperscriptBox[\(\
\\\ \), \(n - 1\)]\),\!\(\*SubscriptBox[\(z\), \(2\)]\)] \>\"", "]"}], ";", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \>\"", ",", 
           SubscriptBox["z", "1"], ",", 
           "\"\<] + Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \
\>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<] \>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<, \>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<] + Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<, \>\"", ",", 
           SubscriptBox["z", "2"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = (\>\"", ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "1"]}], "}"}]}], "]"}], ",", "\"\<) + (\>\"",
            ",", 
           RowBox[{"Residue", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Y", "[", "z", "]"}], 
              SuperscriptBox[
               RowBox[{"z", " "}], 
               RowBox[{"n", "-", "1"}]]}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               SubscriptBox["z", "2"]}], "}"}]}], "]"}], ",", "\"\<)\>\""}], 
          " ", "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["z", "1"], "\[Equal]", 
         SubscriptBox["z", "2"]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", "\"\<The pole is\>\"", "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"s", "[", "n_", "]"}], "=", 
          RowBox[{"Residue", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Y", "[", "z", "]"}], 
             SuperscriptBox[
              RowBox[{"z", " "}], 
              RowBox[{"n", "-", "1"}]]}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              SubscriptBox["z", "1"]}], "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
           SubscriptBox["z", "1"]}], " ", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) =  \
\!\(\*FractionBox[\(1\), \(2\\\ \[Pi]\\\ \[ImaginaryI]\)]\)\>\"", ",", 
           UnderscriptBox["\"\<\[ClockwiseContourIntegral]\>\"", "C"], ",", 
           "\"\<(\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], " ", 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", "\"\<) \[DifferentialD]z\>\""}],
           "]"}], ";", " ", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - \
1\)]\),\!\(\*SubscriptBox[\(z\), \(1\)]\)]\>\"", "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \
Res[Y[z]z\!\(\*SuperscriptBox[\(\\\ \), \(n - 1\)]\), \>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = Res[\>\"", ",", 
           RowBox[{
            RowBox[{"Y", "[", "z", "]"}], 
            SuperscriptBox["z", 
             RowBox[{"n", "-", "1"}]]}], ",", " ", "\"\<,{z,\>\"", ",", 
           SubscriptBox["z", "1"], ",", "\"\<]\>\""}], "]"}], ";", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<     \!\(\*SubscriptBox[\(y\), \(n\)]\) = \>\"", ",", 
           RowBox[{"s", "[", "n", "]"}]}], " ", "]"}], ";"}]}], "  ", "]"}], 
      ";"}]}], "\[IndentingNewLine]", " ", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.400094440484375*^9, 3.400094446859375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.15 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.15 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   SuperscriptBox["2", 
    RowBox[{"n", "+", "2"}]]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWj9v00AUvyZxZ2Bo0wHISJw/4jMgoCzMSSohFFVIDQiBkgCfACTYETCV
LvABYICBib1s7LDQ78BgfHf2c2K/dzmfz7VDLbX207v7vX/3/thub4/nB/ce
jueT/XFrdzp+fDDZn7VuPpr6rPoGY7VDxtjrFuO055PBxfN/5OWIXzg7B8Yb
fnO4wjanGpzqcKrGqR6n6pxygTcDhAuIHqz2AdEF3o5U9U7cxBoLjJBKYzyh
njWWeKGO2NYr+NY5stVFeD0c3ifhia1N2jVMYZcKgQMRi61OyQAt80ibHcqj
Ldp0TAFmHBH+KH+eaArC7Gsr0kAvrRJY4hDj7mI8/kunVUJkV8Ve1oTldZBW
b8HXLkJFkehA0c2Q1T5CRYUdqLLRS+5LoeESWCU3bcpNE5mUXnAaYvvfMFEX
MD/l9hG/neOGCkwbqG8QjPOS52NcoL5z6kJcYxso7Hiz8K6BBy7iC5beWBlg
qbAdj62LBPAYVHUQQz5IEQ+o9I2JPaZ8jilQiB0ohY2yi9gDez7SIobg3A9k
1QsUUOgohwsHvgJvnxmgX0K4n9LoFxCrI1MRz+HE3ucjQisMahGrjkAdhjVK
GS3gVngmrMYpMRkaQG2aipUjxVle8OS0E4qSg7GGyKqXQb+IxOL8KtrrgfLM
nIKtG9lRg/HEdRvxWT9jbVpXh8RYVX55x6Ts+ofKMyMzdo36aAVMCfwaVpB3
ywD9Rar1Gbs0+rNU4QXvRCYiPgXuMfQtPKWIO5wShRbNFXXn0gpSTAHarony
TrDJUlQccRTmu8iqsr3g+ks3cNVPT9rOWYy5hUl4+v1hoMx/4ykwyJz1DVPV
w8wJ35DFEyZ82Qf5wEbCZwt39RhxVoE59btim3gxb6o7Bj5XM7NMxfAfAXNq
68XOqmI+NOwZ+Fw9GpSpGOwDm5BCVj/xFj1CZGk5UFQaBZby7bIEk2ph4RRV
NyFOuh8qSpr6FfBsAMWwJVuccfcvepoatLiU3xNKMLQztThStYW/EpENkMyn
YgeGpYGsPx+jGOf/kTlSmOlzWzbVdSojqpFYAdcA+Fsmsb96wwD9K1hn7HqJ
0elfBKOoXJUUgV1V5PnO0txmy0nodDBAbD31RA8h9kwX53AiY+6vNuNHnm4O
CeIi2Jp9iP1BLcs0sARxKbMYfWvJGSdAl5VbsApJpJdgY/+xvVhLbOMfQS/G
JQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.15 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "+", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "1"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{"z", "-", "3"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "*", 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{"-", "1"}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{"z", "-", "1"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"6", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "n"}], "-", "1"}]]}], " ", "=", " ", 
     RowBox[{"2", "*", 
      SuperscriptBox["3", "n"]}]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "1"}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["3",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}]}]}]]],
 ", \n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "1"}], " ", "+", "  ", 
    RowBox[{"2", "*", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "\n\nwhich agrees with the result of example 1. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.15 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{"4", " ", "z"}], 
    RowBox[{"z", "-", "2"}]]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "3"], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"6", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "3"}], ")"}]}]]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"6", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "1"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"6", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"2", "*", 
      SuperscriptBox["1", 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", "2"}]}]}]]],
 "  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "1"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "2"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "3"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"6", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "8"}], "*", 
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], "=", " ", 
     RowBox[{"-", 
      SuperscriptBox["2", 
       RowBox[{"n", "+", "2"}]]}]}]}]}]]],
 "  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "3"], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"6", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}]}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"9", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], " ", "=", " ", 
     SuperscriptBox["3", 
      RowBox[{"n", "+", "1"}]]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "1"}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["2",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox["3",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], "]"}]}]}]]],
 ", \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{"2", " ", "-", " ", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "2"}]], " ", "+", " ", 
    SuperscriptBox["3", 
     RowBox[{"n", "+", "1"}]]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.15 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      RowBox[{"3", "-", 
       RowBox[{"4", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox[
       RowBox[{"z", " "}], 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),1] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482264125*^9, 3.399482265328125*^9}, {
  3.40006731521875*^9, 3.4000673243125*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "3", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<and\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948226853125*^9, 3.399482269625*^9}, 
   3.400347129578125*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "3", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399482272296875*^9, 3.400086590359375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["3", "n"]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "500", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994822743125*^9, 3.399482289375*^9}, {
   3.400067173375*^9, 3.4000671735625*^9}, {3.400084728875*^9, 
   3.400084761875*^9}, 3.400086595328125*^9, {3.40009423471875*^9, 
   3.400094235125*^9}, 3.40009432753125*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.15 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "z"}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "1"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),1] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "2"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948229753125*^9, 3.3994822989375*^9}, {
  3.400067351140625*^9, 3.400067352359375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    SuperscriptBox["2", 
     RowBox[{"n", "+", "2"}]]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "3"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   SuperscriptBox["2", 
    RowBox[{"n", "+", "2"}]]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["2", 
      RowBox[{"n", "+", "2"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "3", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "3"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{3.399482301546875*^9, 3.400347144015625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{"2", "-", 
      SuperscriptBox["2", 
       RowBox[{"2", "+", "n"}]], "+", 
      SuperscriptBox["3", 
       RowBox[{"1", "+", "n"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "620"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "620"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948230265625*^9, 3.399482336109375*^9}, {
  3.400067179609375*^9, 3.4000671798125*^9}, {3.40008478603125*^9, 
  3.400084842359375*^9}, {3.4000945154375*^9, 3.4000945158125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.16 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.16 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   SuperscriptBox["3", "n"]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"2", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztGctuEzHQzSbACXFokdJyiNhNEBc4I1GOcAAuoXCPSqr2gEAl/QvSGzcq
xIUvAPUHypEfAMEXUH7BxK/ZZjPe2I6d3SUrVd7p2PMez9jO08Fof/hqMDrY
HXQeHQ7e7B/svu08fH04QUVrhDQ+EkLedwiD6QSUA538ieETGxg6AOId+7SY
wJhBTQb1GNRg0C0GRQxKANcF3Etr2h7grgvxx/zDMUQqJphlcJyQNKdwSkZm
6U18aYKjh0tToIujN/SOSBAcJjCGOPTM1cEM9yMwtja0ayg3z7OZ3NwLKcYi
jU3TIKsbhtPZoM9h39KxcMu4jqe9k5aADJSGKFNIrGjTCEjxPmrhUDBVU3cR
Y/l4WSyX5Y/K2pIStpRyFNSkoDo9FdQv2Ocq481ZxAB9B5vl7IQmASgG6DOD
rmVViRGlsBw3zS0Md0/I4HopCErCBUuxbDHNqvVsSBLExB+5iqS4sWCG1YQE
EfAzN35dE7aPgdkvZHZkwuIJaPYbmT0CfY71LPh4Z04aY4RHIPurA/UIjP+C
zJ6A5nuuLD6A/4ZBWeS7wYiFNgRGbnAOYEkJ+8plpMEgXtSbALVc2e7wT2t6
noo2xgXNdrwGwhLDLV0+RxVt9Qkk/rg4JeT+UpeUHCWeIcmUn1bmvLFcX4za
3LkV2tlawrbwFcG3/CVXtlt+8i4qg3zuCf7/lRWy2kX+JpJC+cn0jY28zT5w
yPAzlbx0u3hq3jy5f9OscWyeM17pa6OkCegMumkjf6Z4o+3ASnQp+qaR/L6V
cUHcbdUrq9ZxakLPhLJaUPzRcB61rGPqlaJC1OZ2B9pUxVaKYm41zx1sNizM
/CiqbaDzjqJhg9FGJuwasDbLFsvRTa2HrRSrzhm37SPO84Lh8YRbvn5RE64Q
Ie8SEWwFX60vYBswf6SU6meEebqGlOAacGF+iaJ3IDsWvsdWdM+sNGGgDlds
2y7mOfCGg831Ken/vK15apjm/Sv1YrUeCp1FR2Br3bJqwpowNCGvp9H0Vqt8
mfYn3fKmkVavSlfqLbDF5edkxzpe9DnL4TJq+egW7Dj3V3mcbuhVOBeLJrO3
M7N+lDhXTqTreiX+iEVKCe0FFcsxSwH3w7Cw9PW2a06Wr1WQtX8CQNwP\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.16 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], "+", 
    RowBox[{"4", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "+", "z"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "2"}], ")"}], "2"]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the pole\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{
     FractionBox["\[PartialD]", 
      RowBox[{"\[PartialD]", "z"}]], "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], ")"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], "]"}]}]}]]],
 "  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "z"}], "+", "1"}], ")"}], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "-", "1"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SuperscriptBox["z", "2"]}], ")"}], " ", 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "2"}]]}]}], ")"}]}]}]]],
 " \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"5", "*", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}], "+", 
     RowBox[{"3", "  ", 
      RowBox[{"(", 
       RowBox[{"n", "-", "1"}], ")"}], 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], " ", "+", " ", 
     RowBox[{"3", "n", " ", 
      SuperscriptBox["2", 
       RowBox[{"n", "-", "1"}]]}]}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["2", "n"], " ", "+", " ", 
    RowBox[{"3", "n", " ", 
     SuperscriptBox["2", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  \n\nwhich agrees with the result of example 2."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.16 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Y", 
          RowBox[{"(", "z", ")"}]}], "-", "2"}], ")"}]}], ")"}]}], "+", 
    RowBox[{"4", 
     RowBox[{"(", 
      RowBox[{"Y", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], " ", "=", " ", 
   FractionBox["4", 
    RowBox[{"z", "-", "3"}]]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["z", "3"]}], "-", 
     RowBox[{"11", " ", 
      SuperscriptBox["z", "2"]}], "+", 
     RowBox[{"16", " ", "z"}]}], 
    RowBox[{" ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"], 
      RowBox[{"(", 
       RowBox[{"z", "-", "3"}], ")"}]}]}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["z", "3"]}], "-", 
       RowBox[{"11", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"16", " ", "z"}]}], 
      RowBox[{" ", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], "2"], 
        RowBox[{"(", 
         RowBox[{"z", "-", "3"}], ")"}]}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 " at the poles \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{"[", 
     RowBox[{
      FractionBox["\[PartialD]", 
       RowBox[{"\[PartialD]", "z"}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["z", "3"]}], "-", 
          RowBox[{"11", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          RowBox[{"16", " ", "z"}]}], 
         RowBox[{" ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "3"}], ")"}]}]], 
        SuperscriptBox["z", 
         RowBox[{"n", "-", "1"}]]}], ")"}]}], "]"}]}]}]]],
 "  \n\t\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"z", "\[Rule]", "2"}]], " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"2", 
        RowBox[{"(", " ", 
         RowBox[{"n", "+", "1"}], ")"}], " ", 
        SuperscriptBox["z", "3"]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"17", " ", "n"}], "+", "12"}], ")"}], " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"49", " ", "n"}], "+", "17"}], ")"}], " ", "z"}], "-", 
       RowBox[{"48", " ", "n"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "3"}], ")"}], "2"]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]], " "}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "2"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", "n"}]}], ")"}], 
     SuperscriptBox["2", 
      RowBox[{"n", "-", "1"}]]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["2", "n"], "-", 
     RowBox[{
      SuperscriptBox["2", "n"], " ", "n"}]}]}]}]]],
 " \nand\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "3"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "3"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["z", "3"]}], "-", 
        RowBox[{"11", " ", 
         SuperscriptBox["z", "2"]}], "+", 
        RowBox[{"16", " ", "z"}]}], 
       RowBox[{" ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "2"}], ")"}], "2"]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"3", "*", 
      SuperscriptBox["3", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "n"}]]}], " ", "=", " ", 
     SuperscriptBox["3", "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["2", "n"], "-", 
    RowBox[{"n", " ", 
     SuperscriptBox["2", "n"]}], " ", "+", " ", 
    SuperscriptBox["3", "n"]}]}]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.16(a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "2"}], ")"}], "2"]]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482352359375*^9, 3.399482353671875*^9}, {
  3.4000673620625*^9, 3.40006736240625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "4", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948235584375*^9, 3.399482357140625*^9}, 
   3.400347153203125*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "4", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948235946875*^9, 3.400086618890625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "n"}]], " ", "n"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "670"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823614375*^9, 3.3994823789375*^9}, {
  3.400067185765625*^9, 3.40006718596875*^9}, {3.4000848301875*^9, 
  3.400084890515625*^9}, {3.400094549328125*^9, 3.40009455034375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.16 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"16", " ", "z"}], "-", 
       RowBox[{"11", " ", 
        SuperscriptBox["z", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "3"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"4", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),3]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "2"}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "3"}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823875*^9, 3.399482388390625*^9}, {
  3.400067371046875*^9, 3.400067371515625*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    SuperscriptBox["3", "n"]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"2", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "3"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "4"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   SuperscriptBox["3", "n"]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", 
     SuperscriptBox["3", "n"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "4", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "2", ",", "3"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948239084375*^9, 3.400084902421875*^9, 
  3.400347164109375*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", "n"], "+", 
      SuperscriptBox["3", "n"], "-", 
      RowBox[{
       SuperscriptBox["2", "n"], " ", "n"}]}]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"m0", "=", "6"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "430"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "20"}], ",", "430"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "600", ",", "100"}], "]"}]}], "}"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994823924375*^9, 3.39948240396875*^9}, {
  3.4000671909375*^9, 3.40006719115625*^9}, {3.4000849065625*^9, 
  3.400084945578125*^9}, {3.40009459459375*^9, 3.40009459509375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.17 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ".  \n\n",
 StyleBox["9.17 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use",
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 StyleBox["z",
  FontFamily->"Courier New"],
 StyleBox["-",
  FontFamily->"Times New Roman"],
 "transform methods to solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "  ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "0"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztW81u00AQdpNG/AoJNW4bEFJOBYSaXtrwAEBLD4gQHiCEqiKRQKC2AoR4
As4gwQlxgAuIEy8AjwFvAgezO7ZnY3vsXa/X8VaJ1G4ms56Zb2dmd8dr587w
aLT/ZHg03hu2dw6Gz0bjvcP29tMDxqovOE7to+M479oOpz1GBo3H/vzmE284
2yLGW6Drjg/V8/95e9rERb94y1neTf/KcZqmK0THT942OOOGndJ//OGx3l3d
wf/27bDe2xInZ0tvhnidGqdqnFpEqlFIdxe+N6LSHmS3b41ZmuxDdlQhxfuC
Pnqg4ubrBpEA6zOGeSBJknO8WUS3luMOdTjLNoBwiVTLTrpEvO9hKKi8Vchg
avJOpnY/yxn52HLXKSG6G/o3HFXMWE5swkfAuiqxvot5rOOCXKB0nNOL9VeD
6A2m6euJNAUn182lqVDaxSm3gvOhj9RZyTSkdPdoL2xFDSUv6OLILxBaM7aL
VCR9grcpgyFwrqIbzmgYv59mvB7V3ZUB0jGeEoMW2u8SQtII6SARmdZC9VvR
wQMghKZl5THqfq+LUYRFW08vmTreBw09QroVpUD3D4nGy8RoVqLIlPRc4s0p
zg5UJKkWp8DUd06dkGhcI/AIipr11AymeLLVYS06/phvL5ZoWUQDvuok9+Qm
NReU7eCpG6SBig7qJ9vqFli9dOpx9VpTp8ZrmPOVyerXtuiVnrMWzd8mb4ye
FEBb4g3p1O0Da+ZGrWM//wmApbNiLjgXzBSEfQsmk8ETgISBWD+YsuYsxsOV
wgQiUc64ma6VLSKi2NE+mC22RjYLBy41QlXWTG7h6IPqxF5auNaqes9rlur2
+Y5bhmDwLI71PtSQDh4Gst7hMZMuNu5jFOCKBEuajdUuMdXcSqUcdxtc0cWD
N81njVMJyxROksxnsqXHXxVVhBYcFs5PweaCsyAIe1Udp4KBDfglSm/4utl1
8AJXbOeAJ3Ol7lcUuhe0+nUfIKNvAStrbYkqxEd/Od9GoW/uKMivCN61Ynir
KI1EXnS0wa/GeFNEHuN1MLe3c46hhX7QOa1JxQes54TGjoZGS1exETrdRQr6
z0sEH2HGLSElVCwjtYOU7JXdAf84GUSMqw2pJkG5QbT5OhPy9lViQ+FuZlJi
VIJH3fhuaLjaVcSwVMgylR3rRKxS0SjFj7IyIHR/1Z+PrPebdVNotu7EDd0T
q9+ECy+aPcHONkjWRUVM/wtHLX3Vx0X/qO5mf/25xRiyXz+UcWViZMCGRvmH
H87Cf6gLZZQ=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{671, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.17 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1", "-", 
       RowBox[{"5", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "1"}], ")"}]}], "+", 
    RowBox[{"5", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "+", "z"}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"4", " ", "z"}], "+", "5"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "+", "z"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residue for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", "z"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"5", "-", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "z"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", "\[Rule]", 
        RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["z", "2"], "+", "z"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"5", "+", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], ")"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]}]]],
 "  \n"
}], "Text"],

Cell[TextData[{
 "Therefore, the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "+", 
    " \[InvisibleSpace]", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " \[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"3", " ", "\[ImaginaryI]"}]}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 " \n\nwhich agrees with the result of example 3. \n\nRemark.  Observe that \
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"2", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["2",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "+", "\[ImaginaryI]"}]}], "]"}], 
     "_"]}]}]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.17 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1", " ", "-", " ", 
       RowBox[{"0", " ", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"4", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], " ", "-", " ", "1"}], ")"}]}], "+", 
    RowBox[{"5", "Y", 
     RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["z", 
     RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}]], "+", 
    FractionBox["z", 
     RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "4"], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["z", "3"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["z", "2"]}], "-", 
     RowBox[{"10", " ", "z"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "4"], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["z", "3"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"10", " ", "z"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], "5"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"], " "}]}]}]}]]],
 "\t\t\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], "5"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"2", "-", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "+", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], "  ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "+", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "+", 
         RowBox[{"11", " ", "\[ImaginaryI]"}]}], "10"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"2", "-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["z", "4"], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["z", "3"]}], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"10", " ", "z"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "+", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"z", "-", "1", "-", "\[ImaginaryI]"}], ")"}], "  ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "2", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "-", 
         RowBox[{"11", " ", "\[ImaginaryI]"}]}], "10"], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", "10"], 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "Therefore, the solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], "+", "\[InvisibleSpace]", 
    
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}], "]"}], "+", 
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}]}]}]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "10"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", 
         RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}]}], ")"}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Remark.  Observe that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}], "_"]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     RowBox[{"2", "-", "\[ImaginaryI]"}]}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"Res", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      OverscriptBox[
       RowBox[{"2", "+", "\[ImaginaryI]"}], "_"]}], "]"}], " ", "=", " ", 
    OverscriptBox[
     RowBox[{"Res", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{
        StyleBox["2",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "+", "\[ImaginaryI]"}]}], "]"}], 
     "_"]}]}]]],
 ".\n"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.17 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "+", 
       SuperscriptBox["z", "2"]}], 
      RowBox[{"5", "-", 
       RowBox[{"4", " ", "z"}], "+", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<           Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<       Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\) = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox[
       RowBox[{"z", " "}], 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<          y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - \
1\)]\),2-\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\
\[ImaginaryI]}]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482420078125*^9, 3.399482421234375*^9}, {
  3.400067380015625*^9, 3.40006738034375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "5", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482423453125*^9, 3.3994824256875*^9}, 
   3.400347173140625*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "5"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{"2", ",", "5", ",", "1", ",", "5"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482427890625*^9, 3.39948242984375*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compare  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["5", 
      RowBox[{"n", "/", "2"}]], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"n", " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["1", "2"], "]"}]}], "]"}]}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["5", 
        RowBox[{"n", "/", "2"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "2"], "]"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{"y2", "[", "n", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482432796875*^9, 3.399482456484375*^9}, {
  3.4000671961875*^9, 3.400067196390625*^9}, {3.4000849784375*^9, 
  3.400085054734375*^9}, {3.40009463021875*^9, 3.400094630796875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution  9.17 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "10"}], " ", "z"}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["z", "3"]}], "+", 
       SuperscriptBox["z", "4"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], "+", "z"}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}], ")"}], "+", "z"}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"5", "-", 
         RowBox[{"4", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          Y[z]z  = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<          Y[z]z  = \>\"", ",", 
      FractionBox[
       RowBox[{"Numerator", "[", 
        RowBox[{"Y", "[", "z", "]"}], "]"}], 
       RowBox[{"Factor", "[", 
        RowBox[{"Denominator", "[", 
         RowBox[{"Y", "[", "z", "]"}], "]"}], "]"}]], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"1", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1-\
\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),1+\
\[ImaginaryI]]+Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2-\
\[ImaginaryI]] + Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),2+\
\[ImaginaryI]]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"2", "+", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482466734375*^9, 3.399482469796875*^9}, {
  3.400067423671875*^9, 3.4000674243125*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    SubscriptBox["y", "0"], "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      RowBox[{"y", "[", "1", "]"}]}], "=", 
     RowBox[{
      SubscriptBox["y", "1"], "=", "0"}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"x", "[", "n", "]"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "2"}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "5"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{"2", ",", "5", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", "0"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948247375*^9, 3.40008506190625*^9, 3.40034718190625*^9}
  ],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      FractionBox["1", "10"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "-", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "+", "\[ImaginaryI]"}], ")"}], "n"]}]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "9"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "150"}], ",", "530"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "600", ",", "100"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "150"}], ",", "530"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "100"}], ",", "600", ",", "100"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994824754375*^9, 3.399482479546875*^9}, {
  3.4000672020625*^9, 3.400067202578125*^9}, {3.400085064921875*^9, 
  3.400085121328125*^9}, {3.400094663734375*^9, 3.40009466425*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "3"}], "]"}], "+", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "+", 
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "1"}], "]"}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], " ", "=", " ", "2"}], ",", " ", 
   RowBox[{
    RowBox[{"y", "[", "1", "]"}], " ", "=", " ", 
    RowBox[{"-", "2"}]}], ",", " ", 
   RowBox[{
    RowBox[{"and", "  ", 
     RowBox[{"y", "[", "2", "]"}]}], " ", "=", " ", "0"}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1SwjAQDv0ZAWf4p6jjAdCzPy+hJx+iwzgDB0YH0IuPoT5vZZOStGUT
k5LiwXQg2fm+zW52kzZN8xRv5s/LeLOYxePHVfw6X8zW44eX1Rbya4TUPgkh
32MCcrIV0yLZ/pIvKACxL3/QyifMWcL+UEaMX0MVABsgmg0ofejqHSLdK9lG
xkHBbIhgdShDaHiDSLdKts5cbRCzAesPITYcLJXJ8quJap3GkTVb3XDRHHpg
FBuk7Mz5bWY53vGOd7zjHW+LH0JJl8IRSJQccukMJLp29UEKQfI41uVYulLv
Lsp2OOtzey3RIsi1yFkreAi4DdETRTAF7BzBBrTcewGIcJhph/m0pn33EOsd
hT7WQ+y9o23RJ6bfQjAfD78nz3ckG4NQxFptlvMYptdD3O16aJo1U/22tI8m
WR4ZzuDCnTu0kFjsRbxbKhl7A0GV+rJEZe540wgUTwjJnBSqcGFpP8ITouxc
h6trdE+YPi32wjafyhEfUzE/xboz4tiASwGXekos5FInr+fzxGjYU6wtR1mI
6b6xyaVrBLvSxLC2U7l7mnGxSQ65egGbaGLStoS8Q3WZDhrwO2mKYBNNDGt7
AdKJWcxN2dBo6Onaq8Sv/qw6ld2YGnq69mz7VYT412/Qjne84x3veMf/d16c
faXffJIyBydZY9hGtOTpD9v7oWda3uFm32iFfGc4xKjkpMpCcvVPpaiMnIOS
2g9XDLUS\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.18.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", 
       RowBox[{"0", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", 
        RowBox[{"(", "z", ")"}]}], "-", "2"}], ")"}]}], "+", 
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}]}], "=", " ", "0"}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 " and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{
      SuperscriptBox["z", "3"], "+", 
      SuperscriptBox["z", "2"], "+", "z", "+", "1"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]]}]}]]]
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"2", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
     SuperscriptBox["z", 
      RowBox[{"n", "-", "1"}]]}]}]}]]],
 "  at the poles \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"-", "1"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "1"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "+", "1"}], ")"}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", " ", "\[ImaginaryI]"}], " ", "]"}], " ",
    "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", "\[ImaginaryI]"}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "\[ImaginaryI]"}]}]], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        SuperscriptBox["z", "3"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Thus the solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  which can be rewritten as \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "+", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ImaginaryI]", "n"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}], "  ", "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ImaginaryI]", "n"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}]}]}]]],
 "\n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}]], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}], "2"]], "+", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "\[Pi]"}], "2"]]}], 
      ")"}]}], "  ", "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[ImaginaryI]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "n", " ", "\[Pi]"}], "2"]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "\[Pi]"}], "2"]]}], 
      ")"}], " "}]}]}]]],
 "\n\t\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "n"}], ")"}]}], "+", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}], "-", 
    RowBox[{"sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]}]]],
 "   "
}], "Text"],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  In the next section we will see that \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "4"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "[", "n", "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "1"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "2"}], "]"}], "+", 
      RowBox[{"x", "[", 
       RowBox[{"n", "-", "3"}], "]"}]}], ")"}]}]}]]],
 "  \n\nis a moving average filter which filters out the signals ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{"\[Pi]", " ", "n"}], ")"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "2"], "n"}], ")"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{"and", "  ", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "2"], "n"}], ")"}]}]}]}]]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.18.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term and then solve for  ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 ".  Substitute ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "0"], " ", "=", " ", "2"}], ",", "  ", 
   RowBox[{
    SubscriptBox["y", "1"], " ", "=", " ", 
    RowBox[{"-", "2"}]}], ",", "  ", 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["y", "2"]}], " ", "=", " ", "0"}]}]]],
 "  into \n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", " ", 
       RowBox[{
        SubscriptBox["y", "2"], 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"], " ", "-", " ", 
       RowBox[{
        SubscriptBox["y", "1"], 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", 
       SubscriptBox["y", "0"]}], ")"}]}], "+", 
    RowBox[{"Y", "[", "z", "]"}]}], "=", " ", "0"}]]],
 ",  and get\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["z", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}], "-", " ", 
       RowBox[{"0", 
        SuperscriptBox["z", 
         RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
       RowBox[{"2", 
        SuperscriptBox["z", 
         RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2"}], ")"}]}], "+", 
    RowBox[{"Y", "[", "z", "]"}]}], "\[Equal]", " ", "0"}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["z", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
          RowBox[{"2", 
           SuperscriptBox["z", 
            RowBox[{"-", "1"}]]}], "-", " ", 
          RowBox[{"0", 
           SuperscriptBox["z", 
            RowBox[{"-", "2"}]]}]}], ")"}]}], " ", "+", 
       RowBox[{
        SuperscriptBox["z", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2", " ", "+", 
          RowBox[{"2", 
           SuperscriptBox["z", 
            RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "+", 
       RowBox[{"z", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], " ", "-", " ", "2"}], ")"}]}], "+", 
       RowBox[{"Y", "[", "z", "]"}]}], "\[Equal]", " ", "0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", "eqn", " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", 
       RowBox[{"Y", "[", "z", "]"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"InverseZTransform", "[", 
      RowBox[{
       RowBox[{"Y", "[", "z", "]"}], ",", "z", ",", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solve for Y[z] and get\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Take the inverse z-transformation\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<y[n] = \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[Y[z]] \
= \!\(\*SuperscriptBox[\(\[GothicCapitalZ]\), \(-1\)]\)[\>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", "\"\<]\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"ComplexExpand", "[", 
        RowBox[{"y", "[", "n", "]"}], "]"}], ",", 
       RowBox[{"n", "\[Element]", "Integers"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948248953125*^9, 3.39948249078125*^9}}],

Cell[TextData[{
 "Compare this solution with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482493828125*^9, 3.399482498515625*^9}, {
  3.399482816765625*^9, 3.399482819546875*^9}, {3.400067208796875*^9, 
  3.40006720903125*^9}, {3.400085168859375*^9, 3.400085245578125*^9}, {
  3.40009469390625*^9, 3.4000946944375*^9}, {3.400139562125*^9, 
  3.400139584375*^9}}],

Cell[TextData[{
 "Use the fact that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "3"], "+", 
    SuperscriptBox["z", "2"], "+", "z", "+", "1"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "+", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]}]}]]],
 " and write  ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 " in the form"
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{"1", "+", "z", "+", 
       SuperscriptBox["z", "2"], "+", 
       SuperscriptBox["z", "3"]}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", 
       SuperscriptBox["z", "3"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482505390625*^9, 3.39948250646875*^9}, {
  3.400067440703125*^9, 3.40006744134375*^9}}],

Cell[TextData[{
 "The solution y[n]  can be computed using residues\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "+", "1"}], ")"}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "]"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", "\[ImaginaryI]"}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}]}]}]]],
 "  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Y", "[", "z", "]"}], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", 
         SuperscriptBox["z", "3"]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}]], 
       SuperscriptBox["z", 
        RowBox[{"n", "-", "1"}]]}], ",", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{"-", "\[ImaginaryI]"}]}]}], "]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 "  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-1] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "\[ImaginaryI]"}], "}"}]}], "]"}]}], "  ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-\[ImaginaryI]] = \
\>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "\[ImaginaryI]"}]}], "}"}]}], "]"}]}], "  ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-1] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\[ImaginaryI]] + \
Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),-\[ImaginaryI]]\>\"", " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948250984375*^9, 3.39948251171875*^9}, {
  3.400347195375*^9, 3.40034721390625*^9}}],

Cell[TextData[{
 "The solution is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "+", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox["\[ImaginaryI]", "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "2"], "-", 
       FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}]}]]],
 ".  Which can be written as ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox["\[ImaginaryI]", "n"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482513984375*^9, 3.39948252303125*^9}, {
   3.400067215421875*^9, 3.400067215640625*^9}, {3.400085274546875*^9, 
   3.400085364640625*^9}, {3.40009471009375*^9, 3.40009471053125*^9}, 
   3.400094855140625*^9, {3.4001396036875*^9, 3.400139608703125*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can show that the two formulas compute the same values."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"FullSimplify", "[", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], " ", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox["\[ImaginaryI]", "n"]}], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "-", 
         FractionBox["\[ImaginaryI]", "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"]}]}], ",", " ", 
     RowBox[{"n", "\[Element]", "Integers"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"FullSimplify", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"n", " ", "\[Pi]"}], "]"}], "+", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}], "-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "2"], "]"}]}], ",", " ", 
     RowBox[{"n", "\[Element]", "Integers"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482527796875*^9, 3.399482529171875*^9}, {
  3.40013964321875*^9, 3.400139647671875*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 9.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], "=", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"2", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    SqrtBox["2"]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWM1Og0AQXlqI0dSjUuiFm17VuwdN9GIfgjSmkGg0FX2R6tH4BvowxudB
hq2zKc4Qlv4sh03a5ct8M8P8MTQdx1lyex9n6SSOrmfxY5JOnqKrh1kh6jtC
OHMhxFskAOcFXBx58clf4QBJe/xSXvpCOs3lF85Rd/kEThDlX7zSFE4PBJ/b
UGoUk+nCWX41foxNPkNU8xzd4OCcIJqbUteM3XSpLW95y7fnD+GEnSCRC2gI
qAcoBFQa+Cgboiwk/FF66h49ZPf4kIZcmKSeuyRjojqgVX1aHLABaKh6y22Q
6rIAFf0dvVL4hIwNw+OCZCqikbrqr7/ZhCmZRkpqmlXEIy5NpcdNy8bSZMrM
zGjVAyWrn6Cmd6oVr6UaamcEBAqJ/lVmr7K1AmRVT11ENZvH9DI+/Qs8Twm0
zxuqX3ZTAg2k4R1czsFswf9HpdfdFnNbWjedv214Gegl4WOVqc2i9WCt0UtN
x02PquUtb3nLd5VXS/QDkfpD45g3VK+Qd0Tq9XrUJcPWOZpujuWb88/Y0B9E
l5LKcEi+EV2sQtXcy3QZhPMLN3jztw==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.19.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Take the z-transforms of each term and get\n\n",
 Cell[BoxData[
  RowBox[{"\t\t", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["z", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}]}], "-", " ", "2", " ", "-", " ", 
        RowBox[{
         SqrtBox["2"], 
         SuperscriptBox["z", 
          RowBox[{"-", "1"}]]}]}], ")"}]}], " ", "-", 
     RowBox[{
      SqrtBox["2"], "z", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Y", 
         RowBox[{"(", "z", ")"}]}], " ", "-", " ", "2"}], ")"}]}], "+", 
     RowBox[{"Y", 
      RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", "0"}]}]]]
}], "Text"],

Cell[TextData[{
 "Solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 "  and get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}]}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}], "+", "1"}]], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["z", "2"]}], "-", 
      RowBox[{
       SqrtBox["2"], " ", "z"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}]}]]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "Calculate the residues for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}], 
    SuperscriptBox["z", 
     RowBox[{"n", "-", "1"}]]}]}]]],
 "  at the poles  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
   SqrtBox["2"]]]],
 "  and  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{"1", " ", "-", "\[ImaginaryI]"}], 
   SqrtBox["2"]]]],
 "\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     FractionBox[
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
      SqrtBox["2"]]}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", "\[Rule]", 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]], 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{
         SqrtBox["2"], " ", "z"}]}], 
       RowBox[{" ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}]}]], 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}]}], "=", " ", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], 
       SqrtBox["2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "\[ImaginaryI]"}], 
         SqrtBox["2"]], ")"}], 
       RowBox[{"n", "-", "1"}]]}], " ", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "+", "\[ImaginaryI]"}], 
        SqrtBox["2"]], ")"}], "n"]}]}]}]]],
 " \n\nSimilarly,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Res", "[", 
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", "z", ")"}]}], ",", 
     FractionBox[
      RowBox[{"1", " ", "-", "\[ImaginaryI]"}], 
      SqrtBox["2"]]}], "]"}], " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"1", "-", "\[ImaginaryI]"}], 
      SqrtBox["2"]], ")"}], "n"]}]]],
 ".  Therefore, the solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "+", "\[ImaginaryI]"}], 
       SqrtBox["2"]], ")"}], "n"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", "\[ImaginaryI]"}], 
       SqrtBox["2"]], ")"}], "n"]}]}]]],
 ", \nwhich can be written as \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"], " ", "+", 
     SuperscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"\[Pi]", "/", "4"}]}]], ")"}], "n"]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]], " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", 
        RowBox[{"\[Pi]", "/", "4"}]}]]}], " ", "=", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 "  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{"2", "cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Remark.  The solution can also be obtained by applying the z-transform \
identity with ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox["\[Pi]", "4"]}]]],
 "that was proven in example 5 of the first section of this chapter to get  \n\
\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "]"}], "=", " ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"cos", 
      RowBox[{"(", 
       FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
    RowBox[{
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]]}]]],
 ",  \nthen we have\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[GothicCapitalZ]", 
      RowBox[{"-", "1"}]], "[", 
     FractionBox[
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["z", "2"]}], "-", 
       RowBox[{
        SqrtBox["2"], "z"}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], " ", "+", "1"}]], "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[GothicCapitalZ]", 
       RowBox[{"-", "1"}]], "[", 
      FractionBox[
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["z", "2"]}], "-", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
       RowBox[{
        SuperscriptBox["z", "2"], "-", 
        RowBox[{"2", "cos", 
         RowBox[{"(", 
          FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]], 
      "]"}], "=", 
     RowBox[{"2", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]}]]],
 ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.19.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "It is worthwhile to point out how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can do the important step using residues."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        SqrtBox["2"], " ", "z"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["z", "2"]}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], "-", 
       SuperscriptBox["z", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<            Y[z]z  = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}], ",", 
      SuperscriptBox["z", 
       RowBox[{"n", "-", "1"}]]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\
\(1 - \[ImaginaryI]\), SqrtBox[\(2\)]]\)] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          FractionBox[
           RowBox[{"1", "-", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\
\(1 + \[ImaginaryI]\), SqrtBox[\(2\)]]\)] = \>\"", ",", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          FractionBox[
           RowBox[{"1", "+", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], "}"}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<              y[n] = Res[Y[z]\!\(\*SuperscriptBox[\(z\), \(n - 1\)]\
\),\!\(\*FractionBox[\(1 - \[ImaginaryI]\), SqrtBox[\(2\)]]\)] + Res[Y[z]\!\(\
\*SuperscriptBox[\(z\), \(n - 1\)]\),\!\(\*FractionBox[\(1 + \[ImaginaryI]\), \
SqrtBox[\(2\)]]\)}]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<              y[n] = \>\"", ",", 
      RowBox[{
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           FractionBox[
            RowBox[{"1", "-", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}], "}"}]}], "]"}], "+", 
       RowBox[{"Residue", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Y", "[", "z", "]"}], 
          SuperscriptBox["z", 
           RowBox[{"n", "-", "1"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           FractionBox[
            RowBox[{"1", "+", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}], "}"}]}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482548828125*^9, 3.399482550203125*^9}, {
  3.40006745040625*^9, 3.400067450734375*^9}}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], " ", "=", " ", "0"}]}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], "=", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"2", "  ", "and", "  ", 
      SubscriptBox["y", "1"]}], "=", 
     RowBox[{
      RowBox[{"y", "[", "1", "]"}], "=", 
      SqrtBox["2"]}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["Zsolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"x", "[", "n", "]"}], "=", " ", "0"}]}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"Zsolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"x", "[", "n", "]"}], ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    FractionBox[
     SqrtBox["2"], "2"]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "1"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "2"], ",", "1", ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "2", ",", 
      SqrtBox["2"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"2", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39948255265625*^9, 3.400085393484375*^9, 
  3.400347269515625*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{
        RowBox[{"-", "n"}], "/", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "n"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "n"]}], ")"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"n", " ", "\[Pi]"}], "4"], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y1", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", " ", "\[Alpha]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", " ", "\[Beta]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y1", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2"}], ",", "2.2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4500"}], ",", "500", ",", "500"}], "]"}]}], 
         "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y2", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482555328125*^9, 3.3994825640625*^9}, {
   3.400067220640625*^9, 3.400067220859375*^9}, {3.400085396765625*^9, 
   3.400085504859375*^9}, {3.400094732796875*^9, 3.400094753453125*^9}, {
   3.4000947979375*^9, 3.400094803125*^9}, 3.40009483640625*^9}],

Cell[TextData[{
 "\tTo solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{"y", "[", "n", "]"}]}], " ", "=", " ", "0"}]]],
 "   with  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "0"], "=", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], "=", 
    RowBox[{
     RowBox[{"2", "  ", "and", "  ", 
      SubscriptBox["y", "1"]}], "=", 
     RowBox[{
      RowBox[{"y", "[", "1", "]"}], "=", 
      SqrtBox["2"]}]}]}]}]]],
 ",  we will use our ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine  ",
 Cell[BoxData["ResidueSolution"]],
 "  for finding the solution to",
 StyleBox["  ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".   It will take the z-transforms of each term;  solve for  ",
 Cell[BoxData[
  RowBox[{"Y", 
   RowBox[{"(", "z", ")"}]}]]],
 ";  and it's inverse ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"Y", "[", "z", "]"}], "]"}]}]],
  InitializationCell->True],
 ".   The format of the subroutine call is   ",
 Cell[BoxData[
  RowBox[{"ResidueSolution", "[", 
   RowBox[{"a", ",", "b", ",", 
    SubscriptBox["y", "0"], ",", 
    SubscriptBox["y", "1"]}], "]"}]]],
 "  with   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", 
    FractionBox[
     SqrtBox["2"], "2"]}], ",", " ", 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "b"}], "=", "1"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ResidueSolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "2"], ",", "1", ",", "2", ",", 
      SqrtBox["2"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"s", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{"2", 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948257325*^9, 3.399482574578125*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Convolution for Solving a Non-homogeneous Equation",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n",
 StyleBox["(i)",
  FontColor->RGBColor[0, 0, 1]],
 "\tSolve the homogeneous equation   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "2"}], "]"}], " ", "-", " ", 
    RowBox[{"2", "a", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], " ", "+", " ", 
    RowBox[{"b", " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]],
 "   and get  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "h"], "[", "n", "]"}]]],
 ".  \n\n",
 StyleBox["(ii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tUse the transfer function   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   FractionBox["1", 
    RowBox[{"1", " ", "-", " ", 
     RowBox[{"2", "a", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "1"}]]}], " ", "+", " ", 
     RowBox[{"b", " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "2"}]]}]}]]}]]],
 ".    \n\n",
 StyleBox["(iii)",
  FontColor->RGBColor[0, 0, 1]],
 "\tConstruct the particular solution using convolution  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "   ", 
   RowBox[{
    SuperscriptBox["\[GothicCapitalZ]", 
     RowBox[{"-", "1"}]], "[", 
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}], "X", 
     RowBox[{"(", "z", ")"}]}], "]"}]}]]],
 ",   or\n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], "  ", "=", "   ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "n"], " ", 
    RowBox[{
     RowBox[{"h", "[", "i", "]"}], 
     RowBox[{"x", "[", 
      RowBox[{"n", "-", "i"}], "]"}]}]}]}]]],
 ".  \n\n",
 StyleBox["(iv)",
  FontColor->RGBColor[0, 0, 1]],
 "\tThe total solution to the nonhomogeneous difference equation is  \n\n\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["y", "p"], "[", "n", "]"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 9.20 (a).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ". \n\n",
 StyleBox["9.20 (b).",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".   "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWd0uA0EU3na30V1caolGmuCeKyparkiUuBV3jUj0oirdViSeQnDtNXgB
XoMH4BVqfrZn7O6Z2Wm7+kOFneOcb85+c+abMR1HlebFea3SrJ5V8vuNytVF
9czN79UbxGUmDCNxbxjGY96gdpuY3qNNvtsP9EE98dst2pj8fcTKce81a5ib
WeyHPhd53KVNikZNf/8Mj9doY1FvkjksXybyZcle4CVoBuI6fdhQkjrI2zGM
r/BCk+iXHLTM54VEPwcB0uIUZ2Fc0FXUFLtIPNWl6LhyO/peh8F+BEWOkTER
3xoU9f0nS63VEerbBLlj4wrBsdKGhjQMYZdgHEXOubNrMF8B8W1B4U3wOfIX
FPEilzxN+Lh6W00SSbPZJX5DKooQFVtOfhfxbffEHNG1Bk6yfysYi/nciYGn
mPVuRz0VQRH1xUA24CvgBeyxrsxVhJpY/jUhfCbii1onUQs1wxOT6ClYT3L4
HH2yHegELAc63ul0PAS4DT5hlSB6rJOsDFYaSWZDMgexpmVEpDgsyyyneUOb
HCXJvKtgrVDLy93xOeBLKy07FlygeAo1FqEO4qSQRaqUVlYdi+riZnTIiRPK
AoLTfb2tHFgMNIXQ1erLKqMKzSk2FBKdB+tFDher+LlPUNnPMwp+gGwfCp4C
/tonSPB8k4OG/blgVI7HP5EtBImdh8OMevugKD0Fj9LkTOL9xcVNRZSUsNsL
7GgWkp/iRqMfeU7uMf5p3AUpRW1OPcpL1Y31EicXFnR0eImzC/vdxpXMX9xV
b1M2JLwPVl18PMOe5/8e1/8j/Fs6HyibyZnjr8TZFW7gdtETVWeLyXJknTX6
10NiN8uMTwIrGAuV4dJfpiSsvSUeZ7b3ryUj8Q39yHNG\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWc1u00AQdupEkBQOiDb8SgS1lGuRQNCKUOAAEgi4UuASVU2bSmlRnLb8
XOAB4AI3JLgi8QA8AkeQ4Ai8AC+ABJLx7joz/pldjx0nrVCq1Lud+WZ2fr2b
7a1Gd3W53ei2lhq1653Gw9XWklO7ttHxSHbBsgqvLMv6WLPE3PWm/sP1Pu5r
8RCU4c03xWArO7zZcUXdkoMky5n8Fc9jiu+IoSS4dli+qvhtMRQFdUwSiiFN
3k9Rt4CvoBvhc2SkK2Mc5NMRf+j8m71CcT/pQTd6deV2AX6HA4eCdG/nBkeL
x2HW5AjeBdAiCFai/jjQIlS1ogqc3Q8IRuCldCqi3eXKFvUNtC6BqYdhthhV
0TaabxO0OpHbB0GXWC8J1PI14IvseioIMTiVL3T4W/b6/gJKrupBn8GcK8MA
NcGmFY51y6DzQ0KwZLxPAfxgb6Ze95I7R9DmoWhsoFX0S9XpspiGdSf94g/l
SYH8jSes8EJK/HltaceMKuvduEzQpiAf1Uw+EL3LwGk2Y4PtZ8DOCmRsIQeL
sSYuptS2R2/sLBRGWVe4KRY6EUkRFcowbY4Ob/qoRxyRzDpErAizk4CbCHOl
xDwhYeg2XLQDsxanMhwO/D3A1/SgPM8gj8QgA31APMb1UgsEjepZLs6wVL8O
/oAontODvkM+zvYJcmC5JgeOddPk2Inwt32C0M532WP7BpRs60HTRNWjs/v1
glNEd+F+u2+gglQaDYLo40+OZ2lq2nzojSEZp9xfYOJpJWg+2z4nQjGjBDcJ
Qeoc+4xIw0zQaNY51qDFfKJFQdgb3HvRIFB5QNfLROke1Qu+IEw9khv8JZER
A/w3x+I895ERvz8+XjBRzRREUpdO1DEr9powXESl6MgqVNZfBePeQU1C3f4J
uKy9iIrBqQiyQDGLdzrXI/5g+bCRkztDxrrnitG9xbJGuycnydgco3c6KyN+
ej6eXeTfhq+le8WzBEjDt+ZBIGk7zSe0YffhwK3hL5BUCk/C4TykqI/D6aim
p9J6d2Ph/0/8di8Xgeu8pArZkAP/Fi7pAJhJX6yFdoVVBn3rEF+8ykuKtJwn
/PfXKvwDEMZ+NQ==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 183},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\tFigure 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.20 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe homogeneous difference equation has the form  ",
 StyleBox["(9-8)",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" with ",
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      SqrtBox["2"], "3"], "  ", "and", "  ", "b"}], "=", 
    FractionBox["4", "9"]}]}]]],
 " and  ",
 Cell[BoxData[
  RowBox[{"b", ">", 
   SuperscriptBox["a", "2"]}]]],
 " so that the solution are complex and have the form  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox["r", "n"], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox["r", "n"], "sin", 
     RowBox[{"(", 
      RowBox[{"\[Phi]", " ", "n"}], ")"}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"r", "=", 
   RowBox[{
    SqrtBox["b"], "=", 
    RowBox[{
     SqrtBox[
      FractionBox["4", "9"]], "=", 
     FractionBox["2", "3"]}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", "=", 
   RowBox[{
    RowBox[{"arctan", 
     RowBox[{"(", 
      FractionBox[
       SqrtBox[
        RowBox[{"b", "-", 
         SuperscriptBox["a", "2"]}]], "a"], ")"}]}], "=", 
    RowBox[{
     RowBox[{"arctan", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["4", "9"], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              SqrtBox["2"], "3"], ")"}], "2"]}], ")"}]], "/", 
        RowBox[{"(", 
         FractionBox[
          SqrtBox["2"], "3"], ")"}]}], ")"}]}], " ", "=", 
     RowBox[{
      RowBox[{"arctan", 
       RowBox[{"(", "1", ")"}]}], "=", 
      FractionBox["\[Pi]", "4"]}]}]}]}]]],
 ".  Hence, the general homogeneous solution is  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]]],
 ". \n\n",
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  The homogeneous solution is transient and and will decay to ",
 Cell[BoxData["0"]],
 " as ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ", i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{
     SubscriptBox["y", "h"], "[", "n", "]"}]}], "=", "0"}]]],
 ".  An illustration using ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 " is shown in figure 2 below. \n\n",
 StyleBox["Typo.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Please note that there is a typo in the book which mistakenly stated that \
the homogeneous solution involves ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "3"], " ", "n"}]]],
 ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 9.20 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe transfer function is seen to be  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{
       FractionBox["2", "3"], 
       SqrtBox["2"], "z"}], "+", 
      FractionBox["4", "9"]}]], " ", "=", " ", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}]}], ")"}]}]}]}]]],
 " .  Using the z-transform ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[GothicCapitalZ]", "[", 
    RowBox[{"cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], "]"}], "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"cos", 
       RowBox[{"(", 
        FractionBox["\[Pi]", "4"], ")"}], "z"}]}], 
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "cos", 
       RowBox[{"(", 
        FractionBox["\[Pi]", "4"], ")"}], " ", "z"}], " ", "+", "1"}]], " ", 
    "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{
        SqrtBox["2"], " ", "z"}], "+", "1"}]], "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "-", 
        RowBox[{
         FractionBox["1", 
          SqrtBox["2"]], "z"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}], ")"}]}], ")"}]}]}]}]}]]],
 " in example 8 and the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{"Y", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"X", 
     RowBox[{"(", "z", ")"}]}]]}]]],
 " we can write the z-transform ",
 Cell[BoxData[
  RowBox[{"Y", "[", "z", "]"}]]],
 "using convolution   \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Y", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"H", 
     RowBox[{"(", "z", ")"}], "X", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"z", "/", 
       SqrtBox["2"]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{
         FractionBox["2", "3"], 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        FractionBox[
         RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
         SqrtBox["2"]]}], ")"}]}]]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Residue calculus can again be used to find the solution, but the details \
are tedious.  Let us announce that the following computations hold true  \n\n\
\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]}], "]"}], "+", 
    RowBox[{"Residue", "[", 
     RowBox[{
      RowBox[{"f", 
       RowBox[{"(", "z", ")"}]}], ",", 
      RowBox[{
       FractionBox["2", "3"], 
       FractionBox[
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}]}], "]"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["18", "13"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", "cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["63", "26"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}]}]}]]],
 " \n\nwhich is part of the homogeneous solution.  And the steady state or \
particular part of the solution is  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], ",", 
       FractionBox[
        RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}], "]"}], "+", 
     RowBox[{"Residue", "[", 
      RowBox[{
       RowBox[{"f", 
        RowBox[{"(", "z", ")"}]}], ",", 
       FractionBox[
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
        SqrtBox["2"]]}], "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "13"]}], " ", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox["27", "13"], " ", "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 " \n\nTherefore, the general solution to part (b) is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}], "+", 
     RowBox[{
      SubscriptBox["y", "p"], "[", "n", "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["c", "1"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], "+", 
     RowBox[{
      SubscriptBox["c", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["18", "13"], " ", "cos", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["27", "13"], " ", "sin", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tFor applications, it is useful to determine the limiting amplitude of  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 ".  We need to simplify ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["y", "p"], "[", "n", "]"}]]],
 " in a form that displays it's amplitude and to do this we apply to the \
trigonometric identity (also known as the ",
 ButtonBox["harmonic addition theorem",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/HarmonicAdditionTheorem.html"], None}],
 ")  \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"a", "  ", "cos", 
     RowBox[{"(", "\[Theta]", ")"}]}], " ", "+", " ", 
    RowBox[{"b", " ", "sin", 
     RowBox[{"(", "\[Theta]", ")"}]}]}], " ", "=", " ", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]], "cos", 
    RowBox[{"(", 
     RowBox[{"\[Theta]", "+", 
      RowBox[{"arctan", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"-", "b"}], "a"], ")"}]}]}], ")"}]}]}]]],
 ".  \n\nTherefore, the steady state solution is \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "p"], "[", "n", "]"}], " ", "=", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", " ", 
          FractionBox["18", "13"]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["27", "13"], ")"}], "2"]}]], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], "+", 
       RowBox[{"arctan", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{"-", 
           FractionBox["27", "13"]}], 
          RowBox[{"-", " ", 
           FractionBox["18", "13"]}]], ")"}]}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"9", " "}], 
      SqrtBox["13"]], " ", "cos", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "+", 
       RowBox[{"arctan", 
        RowBox[{"(", 
         FractionBox["3", "2"], ")"}]}]}], ")"}]}]}]}]]],
 "\n\t\t\nand the output signal ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 " tends to this limit as ",
 Cell[BoxData[
  RowBox[{"n", "\[Rule]", "\[Infinity]"}]]],
 ",  i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    RowBox[{"y", "[", "n", "]"}]}], "=", 
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}]}]]],
 ".  Loosely speaking, for large values of  ",
 Cell[BoxData["n"]],
 "  the values of the input signal  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "[", "n", "]"}], "=", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "\[Pi]"}], "4"], "n"}], ")"}]}]}]]],
 "  are amplified by the factor  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"9", " "}], 
    SqrtBox["13"]], " ", "=", " ", "2.49615"}]]],
 " to produce the values of the output signal  ",
 Cell[BoxData[
  RowBox[{"y", "[", "n", "]"}]]],
 ".    An illustration using ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 " is shown in figure 3 below. "
}], "Text"],

Cell[TextData[{
 StyleBox["Typo.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Please note that there is a typo in the book which mistakenly stated that \
the homogeneous solution involves ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "3"], " ", "n"}]]],
 ".  We apologize for this inconvenience. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.20 (a).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Use the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    FractionBox[
     SqrtBox["2"], "3"]}]}]]],
 "  and get the solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"], "Cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SolveDE", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{{3.399482584421875*^9, 3.399482585453125*^9}, 
   3.400347294203125*^9}],

Cell[TextData[{
 "Use the initial conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", 
     RowBox[{"y", "[", "1", "]"}]}], "=", 
    FractionBox[
     SqrtBox["2"], "3"]}]}]]],
 "  and get the solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"], "Sin", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SolveDE", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "0", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{{3.399482588546875*^9, 3.3994825899375*^9}, 
   3.40034730184375*^9}],

Cell["\<\
The above derivation can also be accomplished using z-transforms.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "1", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], 
      RowBox[{"Cos", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482593046875*^9, 3.399482598125*^9}, 
   3.400347306125*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "x"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "n_", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Zsolution", "[", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], "3"], ",", 
      FractionBox["4", "9"], ",", 
      RowBox[{"x", "[", "n", "]"}], ",", "0", ",", 
      FractionBox[
       SqrtBox["2"], "3"]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Which agrees with\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["2", "3"], ")"}], "n"], 
      RowBox[{"Sin", "[", 
       RowBox[{
        FractionBox["\[Pi]", "4"], "n"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<{\!\(\*SubscriptBox[\(y\), \(n\)]\)\!\(\*SubsuperscriptBox[\(}\), \
\(n = 0\), \(\[Infinity]\)]\)  = \>\"", ",", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"y", "[", "n", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "0", ",", "9"}], "}"}]}], "]"}], ",", 
        "\"\<...\>\""}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482595296875*^9, 3.399482599359375*^9}, 
   3.40034730996875*^9}],

Cell[TextData[{
 "Form the linear combination  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["y", "h"], "[", "n", "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "Cos", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], " ", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["c", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], "sin", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Pi]", "4"], " ", "n"}], ")"}]}]}]}]]],
 "  and substitute it into the difference equation\n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "h"], "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{
      SubscriptBox["y", "h"], "[", "n", "]"}]}]}], "  ", "=", "  ", "0"}]]]
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["y", "h"], "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "1"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{
       SubscriptBox["c", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "1"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "1"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", 
       RowBox[{"n", "+", "2"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2] = \>\"", ",", 
      RowBox[{"TrigExpand", "[", 
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "2"}], "]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<         \!\(\*SubscriptBox[\(y\), \(h\)]\)[n] = \>\"", ",", 
      RowBox[{
       SubscriptBox["y", "h"], "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<-\!\(\*FractionBox[\(2\), \
\(3\)]\)\!\(\*SqrtBox[\(2\)]\)\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+1] = \>\"",
       ",", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", "3"]}], 
       SqrtBox["2"], 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "1"}], "]"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<     \!\(\*FractionBox[\(4\), \(9\)]\)\!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n+2] = \>\"", ",", 
      RowBox[{
       FractionBox["4", "9"], 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "2"}], "]"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Now add up the three terms\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n]\>\"", " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    =    \>\"", ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["y", "h"], "[", 
        RowBox[{"n", "+", "2"}], "]"}], "-", 
       RowBox[{
        FractionBox["2", "3"], " ", 
        SqrtBox["2"], " ", 
        RowBox[{
         SubscriptBox["y", "h"], "[", 
         RowBox[{"n", "+", "1"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["4", "9"], " ", 
        RowBox[{
         SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"Expand", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "h"], "[", 
          RowBox[{"n", "+", "2"}], "]"}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          SqrtBox["2"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["4", "9"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(y\), \(h\)]\)[n+2]-\!\(\*FractionBox[\(2\), \
\(3\)]\) \!\(\*SqrtBox[\(2\)]\) \!\(\*SubscriptBox[\(y\), \
\(h\)]\)[n+1]+\!\(\*FractionBox[\(4\), \(9\)]\) \!\(\*SubscriptBox[\(y\), \(h\
\)]\)[n] = \>\"", ",", 
      RowBox[{"MapAll", "[", 
       RowBox[{"TrigExpand", ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["y", "h"], "[", 
          RowBox[{"n", "+", "2"}], "]"}], "-", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          SqrtBox["2"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", 
           RowBox[{"n", "+", "1"}], "]"}]}], "+", 
         RowBox[{
          FractionBox["4", "9"], " ", 
          RowBox[{
           SubscriptBox["y", "h"], "[", "n", "]"}]}]}]}], "]"}]}], " ", "]"}],
     ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948260775*^9, 3.399482610359375*^9}, {
  3.400139903203125*^9, 3.400139917578125*^9}}],

Cell[TextData[{
 "The following graph is shows the solution for the choice of constants ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"10", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "3"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{"5", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "3"], " ", "n"}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The initial conditions are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", 
      RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", 
      RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948261396875*^9, 3.39948261996875*^9}, {
  3.400067226234375*^9, 3.400067226453125*^9}, {3.400085580328125*^9, 
  3.400085641171875*^9}, {3.40009493278125*^9, 3.400094933359375*^9}, {
  3.40009501021875*^9, 3.400095010484375*^9}, {3.40009506365625*^9, 
  3.4000951411875*^9}, {3.40034732053125*^9, 3.400347323734375*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 9.20 (b).",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
The important step in the solution is the computation of a particular \
solution residues. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Y", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox["z", 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y[z] = \>\"", ",", 
      RowBox[{"Y", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482628390625*^9, 3.399482629546875*^9}, {
  3.400067479484375*^9, 3.400067479984375*^9}}],

Cell[TextData[{
 "To show that this is equivalent to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"y", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["18", "13"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["63", "26"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["2", "3"], ")"}], "n"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       FractionBox[
        RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}]}]}]]],
 ",  we shall resort to comparing their graphs.  Also note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will expand the fractions in the printout, i.e.  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["18", "13"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"]}], "  ", "=", " ", 
   RowBox[{
    FractionBox["1", "13"], " ", 
    SuperscriptBox["2", 
     RowBox[{"1", "+", "n"}]], " ", 
    SuperscriptBox["3", 
     RowBox[{"2", "-", "n"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", 
     FractionBox["63", "26"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["2", "3"], ")"}], "n"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["7", "13"]}], " ", 
    SuperscriptBox["2", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "n"}]], " ", 
    SuperscriptBox["3", 
     RowBox[{"2", "-", "n"}]]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"z", "/", 
        SqrtBox["2"]}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{
          FractionBox["2", "3"], 
          FractionBox[
           RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
           SqrtBox["2"]]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", 
         FractionBox[
          RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
          SqrtBox["2"]]}], ")"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y1", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox[
          RowBox[{"z", " "}], 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}], "+", 
      RowBox[{"Residue", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Y", "[", "z", "]"}], 
         SuperscriptBox[
          RowBox[{"z", " "}], 
          RowBox[{"n", "-", "1"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{
           FractionBox["2", "3"], 
           FractionBox[
            RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], 
            SqrtBox["2"]]}]}], "}"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{
       FractionBox["18", "13"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}], " ", "-", " ", 
      RowBox[{
       FractionBox["63", "26"], 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox[
          RowBox[{" ", "\[Pi]"}], "4"], "n"}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "21"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Y2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y2", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Y2pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y2"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y1", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The second-order difference equation is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "thede", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y2pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", 
            RowBox[{"m0", "+", "0.15"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.13"}], ",", "1.45"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g2", ",", "g3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y2", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399482632234375*^9, 3.39948264109375*^9}, {
  3.400067231859375*^9, 3.4000672320625*^9}, {3.400085657546875*^9, 
  3.40008572396875*^9}, {3.400095225296875*^9, 3.400095268921875*^9}}],

Cell[TextData[{
 "The following graph is the solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 "  for the choice of constants ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "1"], "=", 
   RowBox[{
    RowBox[{"10", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", 
     SubscriptBox["c", "2"]}], "=", "5"}]}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.400095367265625*^9, 3.400095368359375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"n", ",", "y"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "n_", "]"}], "=", 
     RowBox[{
      RowBox[{"10", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], " ", "]"}]}], " ", "+", 
      RowBox[{"5", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["2", "3"], ")"}], "n"], 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["\[Pi]", "4"], " ", "n"}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"9", " "}], 
        SqrtBox["13"]], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{
          FractionBox["\[Pi]", "4"], "n"}], "+", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"-", "2"}], ",", 
           RowBox[{"-", "3"}]}], "]"}]}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m0", "=", "20"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Y1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"y", "[", "i", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ticval", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "m0"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Y1pts", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"ticval", ",", "Y1"}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g0", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"Y1pts", ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.02", "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", 
            RowBox[{"m0", "+", "0.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "m0", ",", "5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "4"}], ",", "10", ",", "2"}], "]"}]}], "}"}]}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{"g0", ",", "g1"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[n] = \>\"", ",", 
      RowBox[{"y", "[", "n", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[0] = \>\"", ",", 
      RowBox[{"y", "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y[1] = \>\"", ",", 
      RowBox[{"y", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39948264678125*^9, 3.399482651265625*^9}, {
  3.40006723728125*^9, 3.4000672375*^9}, {3.400085739578125*^9, 
  3.400085764328125*^9}, {3.40009537696875*^9, 3.400095397140625*^9}, {
  3.40034733396875*^9, 3.400347337140625*^9}}],

Cell[TextData[{
 StyleBox["Figure 9.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  A typical solution to ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", 
     RowBox[{"n", "+", "2"}], "]"}], "-", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SqrtBox["2"], " ", 
     RowBox[{"y", "[", 
      RowBox[{"n", "+", "1"}], "]"}]}], "+", 
    RowBox[{
     FractionBox["4", "9"], " ", 
     RowBox[{"y", "[", "n", "]"}]}]}], " ", "=", " ", 
   RowBox[{"cos", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["\[Pi]", "4"], "n"}], ")"}]}]}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["The z-Transform",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ZTransformBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399474649328125*^9, 3.3994746494375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False,
"FirstPageHeader"->False,
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {36, 54}}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 396283, 12804}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 2703, 87, 245, "Text"],
Cell[3611, 121, 911, 39, 74, "Text"],
Cell[4525, 162, 718, 30, 65, "Text"],
Cell[5246, 194, 2133, 81, 233, "Text"],
Cell[7382, 277, 1363, 44, 101, "Text"],
Cell[8748, 323, 159, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[8932, 330, 367, 11, 29, "Text"],
Cell[9302, 343, 17761, 433, 1472, "Input",
 InitializationCell->True]
}, Closed]],
Cell[27078, 779, 937, 35, 26, "Text"],
Cell[28018, 816, 879, 17, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[28922, 837, 102, 2, 29, "Text"],
Cell[29027, 841, 1790, 63, 194, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[30854, 909, 110, 2, 26, "Text"],
Cell[30967, 913, 2037, 72, 65, "Text"],
Cell[33007, 987, 551, 16, 112, "Input"],
Cell[33561, 1005, 4684, 132, 412, "Input"]
}, Closed]],
Cell[38260, 1140, 937, 35, 26, "Text"],
Cell[39200, 1177, 904, 18, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[40129, 1199, 102, 2, 29, "Text"],
Cell[40234, 1203, 2010, 72, 206, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[42281, 1280, 110, 2, 26, "Text"],
Cell[42394, 1284, 2038, 72, 65, "Text"],
Cell[44435, 1358, 525, 15, 112, "Input"],
Cell[44963, 1375, 4629, 134, 412, "Input"]
}, Closed]],
Cell[49607, 1512, 937, 35, 26, "Text"],
Cell[50547, 1549, 961, 19, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[51533, 1572, 102, 2, 29, "Text"],
Cell[51638, 1576, 3317, 116, 281, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[54992, 1697, 110, 2, 26, "Text"],
Cell[55105, 1701, 2038, 72, 65, "Text"],
Cell[57146, 1775, 524, 15, 112, "Input"],
Cell[57673, 1792, 1262, 47, 35, "Text"],
Cell[58938, 1841, 9527, 276, 683, "Input"]
}, Closed]],
Cell[68480, 2120, 3692, 129, 235, "Text"],
Cell[72175, 2251, 2598, 95, 122, "Text"],
Cell[74776, 2348, 3308, 121, 188, "Text"],
Cell[78087, 2471, 386, 12, 31, "Text"],
Cell[78476, 2485, 1953, 65, 173, "Text"],
Cell[80432, 2552, 1594, 56, 101, "Text"],
Cell[82029, 2610, 3522, 128, 254, "Text"],
Cell[85554, 2740, 2213, 81, 104, "Text"],
Cell[87770, 2823, 1433, 54, 65, "Text"],
Cell[89206, 2879, 261, 9, 29, "Text"],
Cell[89470, 2890, 296, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[89791, 2904, 368, 11, 29, "Text"],
Cell[90162, 2917, 7371, 185, 682, "Input",
 InitializationCell->True],
Cell[97536, 3104, 12533, 300, 1012, "Input",
 InitializationCell->True]
}, Closed]],
Cell[110084, 3407, 2246, 85, 62, "Text"],
Cell[112333, 3494, 1392, 26, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[113750, 3524, 106, 2, 29, "Text"],
Cell[113859, 3528, 705, 25, 68, "Text"],
Cell[114567, 3555, 425, 19, 41, "Text"],
Cell[114995, 3576, 2367, 88, 133, "Text"],
Cell[117365, 3666, 1367, 47, 137, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[118769, 3718, 106, 2, 26, "Text"],
Cell[118878, 3722, 777, 28, 71, "Text"],
Cell[119658, 3752, 568, 24, 41, "Text"],
Cell[120229, 3778, 3967, 144, 185, "Text"],
Cell[124199, 3924, 1959, 68, 101, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[126195, 3997, 114, 2, 26, "Text"],
Cell[126312, 4001, 161, 5, 29, "Text"],
Cell[126476, 4008, 2814, 82, 244, "Input"],
Cell[129293, 4092, 2473, 88, 65, "Text"],
Cell[131769, 4182, 1141, 33, 152, "Input"],
Cell[132913, 4217, 2332, 83, 65, "Text"],
Cell[135248, 4302, 863, 24, 112, "Input"],
Cell[136114, 4328, 4569, 131, 412, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[140720, 4464, 114, 2, 26, "Text"],
Cell[140837, 4468, 161, 5, 29, "Text"],
Cell[141001, 4475, 4246, 124, 308, "Input"],
Cell[145250, 4601, 2629, 95, 65, "Text"],
Cell[147882, 4698, 1137, 32, 132, "Input"],
Cell[149022, 4732, 4577, 131, 412, "Input"]
}, Closed]],
Cell[153614, 4866, 2221, 84, 62, "Text"],
Cell[155838, 4952, 1322, 24, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[157185, 4980, 106, 2, 29, "Text"],
Cell[157294, 4984, 615, 22, 68, "Text"],
Cell[157912, 5008, 379, 17, 42, "Text"],
Cell[158294, 5027, 3042, 112, 159, "Text"],
Cell[161339, 5141, 339, 11, 101, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[161715, 5157, 106, 2, 26, "Text"],
Cell[161824, 5161, 752, 27, 71, "Text"],
Cell[162579, 5190, 600, 25, 42, "Text"],
Cell[163182, 5217, 4727, 170, 225, "Text"],
Cell[167912, 5389, 284, 10, 29, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[168233, 5404, 113, 2, 26, "Text"],
Cell[168349, 5408, 161, 5, 29, "Text"],
Cell[168513, 5415, 2011, 59, 223, "Input"],
Cell[170527, 5476, 2473, 88, 65, "Text"],
Cell[173003, 5566, 1141, 33, 152, "Input"],
Cell[174147, 5601, 2327, 83, 65, "Text"],
Cell[176477, 5686, 862, 24, 112, "Input"],
Cell[177342, 5712, 4606, 133, 412, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[181985, 5850, 114, 2, 26, "Text"],
Cell[182102, 5854, 161, 5, 29, "Text"],
Cell[182266, 5861, 3528, 103, 286, "Input"],
Cell[185797, 5966, 2578, 93, 65, "Text"],
Cell[188378, 6061, 1161, 33, 152, "Input"],
Cell[189542, 6096, 4579, 132, 412, "Input"]
}, Closed]],
Cell[194136, 6231, 2402, 90, 62, "Text"],
Cell[196541, 6323, 1461, 27, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[198027, 6354, 106, 2, 29, "Text"],
Cell[198136, 6358, 609, 21, 68, "Text"],
Cell[198748, 6381, 672, 25, 42, "Text"],
Cell[199423, 6408, 4587, 151, 158, "Text"],
Cell[204013, 6561, 2956, 100, 182, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[207006, 6666, 106, 2, 26, "Text"],
Cell[207115, 6670, 805, 26, 72, "Text"],
Cell[207923, 6698, 783, 27, 42, "Text"],
Cell[208709, 6727, 7152, 229, 238, "Text"],
Cell[215864, 6958, 2894, 96, 107, "Text"],
Cell[218761, 7056, 2922, 101, 50, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[221720, 7162, 114, 2, 26, "Text"],
Cell[221837, 7166, 161, 5, 29, "Text"],
Cell[222001, 7173, 3054, 88, 244, "Input"],
Cell[225058, 7263, 2473, 88, 65, "Text"],
Cell[227534, 7353, 1140, 33, 152, "Input"],
Cell[228677, 7388, 2327, 83, 65, "Text"],
Cell[231007, 7473, 864, 24, 112, "Input"],
Cell[231874, 7499, 1262, 47, 35, "Text"],
Cell[233139, 7548, 9527, 276, 683, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[242703, 7829, 115, 2, 26, "Text"],
Cell[242821, 7833, 161, 5, 29, "Text"],
Cell[242985, 7840, 5719, 168, 352, "Input"],
Cell[248707, 8010, 2946, 105, 65, "Text"],
Cell[251656, 8117, 1358, 40, 152, "Input"],
Cell[253017, 8159, 5592, 161, 426, "Input"]
}, Closed]],
Cell[258624, 8323, 735, 27, 26, "Text"],
Cell[259362, 8352, 908, 18, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[260295, 8374, 102, 2, 29, "Text"],
Cell[260400, 8378, 930, 33, 68, "Text"],
Cell[261333, 8413, 718, 27, 42, "Text"],
Cell[262054, 8442, 3058, 111, 192, "Text"],
Cell[265115, 8555, 2885, 97, 173, "Text"],
Cell[268003, 8654, 1475, 51, 113, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[269515, 8710, 110, 2, 26, "Text"],
Cell[269628, 8714, 2318, 77, 71, "Text"],
Cell[271949, 8793, 3290, 95, 318, "Input"],
Cell[275242, 8890, 408, 15, 35, "Text"],
Cell[275653, 8907, 7488, 218, 596, "Input"],
Cell[283144, 9127, 689, 25, 32, "Text"],
Cell[283836, 9154, 1899, 57, 256, "Input"],
Cell[285738, 9213, 2842, 99, 179, "Text"],
Cell[288583, 9314, 3208, 95, 224, "Input"],
Cell[291794, 9411, 1022, 37, 35, "Text"],
Cell[292819, 9450, 7723, 225, 601, "Input"],
Cell[300545, 9677, 136, 4, 29, "Text"],
Cell[300684, 9683, 1341, 39, 121, "Input"]
}, Closed]],
Cell[302040, 9725, 587, 24, 28, "Text"],
Cell[302630, 9751, 749, 15, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[303404, 9770, 102, 2, 29, "Text"],
Cell[303509, 9774, 695, 24, 69, "Text"],
Cell[304207, 9800, 997, 39, 69, "Text"],
Cell[305207, 9841, 3816, 137, 336, "Text"],
Cell[309026, 9980, 1924, 66, 151, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[310987, 10051, 110, 2, 26, "Text"],
Cell[311100, 10055, 161, 5, 29, "Text"],
Cell[311264, 10062, 3497, 100, 340, "Input"],
Cell[314764, 10164, 2287, 83, 82, "Text"],
Cell[317054, 10249, 2266, 67, 286, "Input"],
Cell[319323, 10318, 8485, 245, 644, "Input"],
Cell[327811, 10565, 2136, 78, 82, "Text"],
Cell[329950, 10645, 1987, 58, 246, "Input"]
}, Closed]],
Cell[331952, 10706, 2277, 81, 292, "Text"],
Cell[334232, 10789, 1092, 41, 81, "Text"],
Cell[335327, 10832, 1066, 20, 163, "Text",
 Evaluatable->False],
Cell[336396, 10854, 506, 19, 37, "Text"],
Cell[336905, 10875, 1282, 24, 197, "Text",
 Evaluatable->False],
Cell[338190, 10901, 602, 23, 37, "Text"],
Cell[CellGroupData[{
Cell[338817, 10928, 106, 2, 29, "Text"],
Cell[338926, 10932, 3749, 135, 274, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[342712, 11072, 106, 2, 26, "Text"],
Cell[342821, 11076, 3782, 134, 197, "Text"],
Cell[346606, 11212, 3480, 116, 245, "Text"],
Cell[350089, 11330, 3517, 121, 269, "Text"],
Cell[353609, 11453, 332, 10, 35, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[353978, 11468, 114, 2, 26, "Text"],
Cell[354095, 11472, 570, 22, 44, "Text"],
Cell[354668, 11496, 659, 21, 134, "Input"],
Cell[355330, 11519, 570, 22, 44, "Text"],
Cell[355903, 11543, 656, 21, 134, "Input"],
Cell[356562, 11566, 89, 2, 29, "Text"],
Cell[356654, 11570, 2396, 72, 288, "Input"],
Cell[359053, 11644, 2401, 72, 288, "Input"],
Cell[361457, 11718, 1142, 40, 79, "Text"],
Cell[362602, 11760, 6409, 182, 530, "Input"],
Cell[369014, 11944, 494, 17, 29, "Text"],
Cell[369511, 11963, 4822, 137, 426, "Input"],
Cell[374336, 12102, 500, 19, 37, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[374873, 12126, 114, 2, 26, "Text"],
Cell[374990, 12130, 115, 3, 29, "Text"],
Cell[375108, 12135, 2598, 81, 221, "Input"],
Cell[377709, 12218, 1611, 59, 59, "Text"],
Cell[379323, 12279, 8826, 265, 595, "Input"],
Cell[388152, 12546, 1017, 36, 37, "Text"],
Cell[389172, 12584, 4641, 137, 355, "Input"],
Cell[393816, 12723, 595, 23, 37, "Text"]
}, Closed]],
Cell[394426, 12749, 281, 7, 26, "Text"],
Cell[394710, 12758, 269, 6, 29, "Text"],
Cell[394982, 12766, 249, 5, 29, "Text"],
Cell[395234, 12773, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
