(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    179422,       4903]
NotebookOptionsPosition[    175498,       4778]
NotebookOutlinePosition[    176203,       4808]
CellTagsIndexPosition[    176129,       4803]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[{
 StyleBox["Chapter 10  ",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["Conformal Mapping",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe terminology \"",
 StyleBox[ButtonBox["conformal mapping",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ConformalMapping.html"], None}],
  FontVariations->{"Underline"->True}],
 "\" should have a familiar sound.  In 1569 the Flemish cartographer Gerardus \
Mercator (1512--1594) devised a cylindrical map projection that preserves \
angles.  The Mercator projection is still used today for world maps.  Another \
map projection known to the ancient Greeks is the stereographic projection. \
It is also conformal (i.e., angle preserving), and we introduced it in \
Chapter 2 when we defined the Riemann sphere. In complex analysis a function \
preserves angles if and only if it is analytic or anti-analytic (i.e., the \
conjugate of an analytic function).  A significant result, known as Riemann \
mapping theorem, states that any simply connected domain (other than the \
entire complex plane) can be mapped conformally onto the unit disk. "
}], "Text"],

Cell[TextData[StyleBox["10.1  Basic Properties of Conformal Mappings",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tLet ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " be an analytic function in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and let  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  be a point in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ",  then we can express ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " in the form  \n\n",
 StyleBox["(10-1)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "+", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}]}], "+", 
    RowBox[{"\[Eta]", 
     RowBox[{"(", "z", ")"}], 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Eta]", 
    RowBox[{"(", "z", ")"}]}], "\[Rule]", 
   RowBox[{
    RowBox[{"0", "  ", "as", "  ", "z"}], "\[Rule]", 
    SubscriptBox["z", "0"]}]}]]],
 ".  If ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " is near ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", then the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  has the linear approximation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"A", "+", 
    RowBox[{"B", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["z", "0"]}], ")"}]}]}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], "  ", "and", "  ", "B"}], "=", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}]}]}]]],
 ".  Because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Eta]", 
    RowBox[{"(", "z", ")"}]}], "\[Rule]", "0"}]]],
 "  when  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", 
   SubscriptBox["z", "0"]}]]],
 ",  for points near ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  has an effect much like the linear mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  The effect of the linear mapping  S  is a rotation of the plane through \
the angle  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", "=", " ", 
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}]}], ")"}]}]}]]],
 ",  followed by a magnification by the factor  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|"}]]],
 ",  followed by a rigid translation by the vector  ",
 Cell[BoxData[
  RowBox[{"A", "+", 
   SubscriptBox["Bz", "0"]}]]],
 ".  Consequently, the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  preserves angles at the point  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  We now show that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  also preserves angles at  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\n\tFor a smooth curve that passes through the point  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", "0", ")"}]}], "=", 
   SubscriptBox["z", "0"]}]]],
 ",  we use the notation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"z", 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"x", 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "y", 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ",  \n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "1"}], "\[LessEqual]", "t", "\[LessEqual]", "1"}]]],
 ".   \n\t\n\tA vector ",
 Cell[BoxData[
  OverscriptBox["T", "\[RightVector]"]]],
 " tangent to ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   OverscriptBox["T", "\[RightVector]"], " ", "=", " ", 
   RowBox[{
    RowBox[{"z", "'"}], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ",  \n\t\t\t\nwhere the complex number  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", "'"}], 
   RowBox[{"(", "0", ")"}]}]]],
 "  is expressed as a vector."
}], "Text"],

Cell[TextData[{
 "\tThe angle of inclination of  ",
 Cell[BoxData[
  OverscriptBox["T", "\[RightVector]"]]],
 "  with respect to the positive ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Beta]", " ", "=", " ", 
   RowBox[{"Arg", " ", 
    RowBox[{"z", "'"}], 
    RowBox[{"(", "0", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The image of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is the curve ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane given by the formula \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"K", ":", " ", 
    RowBox[{"w", 
     RowBox[{"(", "t", ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", 
        RowBox[{"(", "t", ")"}]}], ",", 
       RowBox[{"y", 
        RowBox[{"(", "t", ")"}]}]}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "v", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", 
        RowBox[{"(", "t", ")"}]}], ",", 
       RowBox[{"y", 
        RowBox[{"(", "t", ")"}]}]}], ")"}]}]}]}]]],
 ".  \n\nWe can use the chain rule to show that a vector  ",
 Cell[BoxData[
  OverscriptBox[
   SuperscriptBox["T", "*"], "\[RightVector]"]]],
 "  tangent to ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "  is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   OverscriptBox[
    SuperscriptBox["T", "*"], "\[RightVector]"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"w", "'"}], 
     RowBox[{"(", "0", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], 
     RowBox[{"z", "'"}], 
     RowBox[{"(", "0", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The angle of inclination of ",
 Cell[BoxData[
  OverscriptBox[
   SuperscriptBox["T", "*"], "\[RightVector]"]]],
 " with respect to the positive u axis is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"\[Gamma]", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"Arg", " ", 
     RowBox[{"w", "'"}], 
     RowBox[{"(", "0", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"Arg", " ", 
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}], "  ", "+", "  ", 
      RowBox[{"Arg", " ", 
       RowBox[{"z", "'"}], 
       RowBox[{"(", "0", ")"}]}]}], "  ", "=", "  ", 
     RowBox[{"\[Alpha]", "  ", "+", "  ", "\[Beta]"}]}]}]}]]],
 ",   \n\nwhere  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", "=", " ", 
   RowBox[{"Arg", " ", 
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  \n\n\tTherefore the effect of the transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is to rotate the angle of inclination of the tangent vector ",
 Cell[BoxData[
  OverscriptBox["T", "\[RightVector]"]]],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " through the angle ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", "=", " ", 
   RowBox[{"Arg", " ", 
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 "  to obtain the angle of inclination of the tangent vector ",
 Cell[BoxData[
  OverscriptBox[
   SuperscriptBox["T", "*"], "\[RightVector]"]]],
 " at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  This situation is illustrated in Figure 10.1."
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{573, 219},
  ImageMargins->0],
 StyleBox[" \n\n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.1",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1001.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The tangents at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], " ", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["w", "0"]}]]],
 ", where ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is an analytic function and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.399496442390625*^9, 3.399496484578125*^9}}],

Cell[TextData[{
 "\tA mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is said to be angle preserving, or ",
 StyleBox[ButtonBox["conformal",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ConformalTransformation.html"], None}],
  FontVariations->{"Underline"->True}],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", if it preserves angles between oriented curves in magnitude as well as in \
orientation.  Theorem 10.1 shows where a mapping by an analytic function is \
conformal. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Theorem 10.1 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Conformal Mapping",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/ConformalMapping.html"], None}],
  FontWeight->"Bold"],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " be an analytic function in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", and let ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " be a point in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ",  then ",
 StyleBox["f(z)",
  FontFamily->"Courier New"],
 " is conformal at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{566, 244},
  ImageMargins->0],
 StyleBox[" \n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.2",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1002.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The analytic mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is conformal at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.399496491078125*^9, 3.39949650571875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 10.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"cos", 
     RowBox[{"(", "z", ")"}]}]}]}]]],
 "  is conformal at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", "\[ImaginaryI]"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", " ", "1"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", " ", 
   RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}]}]]],
 " and , ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", " ", 
   RowBox[{"1", "-", "\[ImaginaryI]"}]}]]],
 " and determine the angle of rotation given by ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{"Arg", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 " at the given points. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{512, 188},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Because ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "sin"}], 
    RowBox[{"(", "z", ")"}]}]}]]],
 ", we conclude that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"cos", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is conformal at all points except ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"n", " ", "\[Pi]"}]}]]],
 ", where n is an integer.  Calculation reveals that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}], "  ", "=", "     ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "\[ImaginaryI]", ")"}]}], "     ", "=", "  ", 
      RowBox[{
       RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "sinh", " ", "1"}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\n", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "2"], ")"}]}], "  ", "=", "     ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", "1", ")"}]}], "     ", "=", "  ", 
      RowBox[{
       RowBox[{"-", " ", "sin"}], " ", "1"}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\n", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "3"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
      RowBox[{"\[ImaginaryI]", " ", "sinh", " ", "1"}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "4"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "cosh"}], " ", "1", " ", "sin", " ", "1"}], "  ", "+",
      "  ", 
     RowBox[{"\[ImaginaryI]", " ", "cos", " ", "1", " ", "sinh", " ", 
      RowBox[{"1", 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]}]],
 "   \n\nTherefore the angle of rotation is given by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Alpha]", "1"], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"Arg", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", 
          SubscriptBox["z", "1"], ")"}]}], ")"}]}], "  ", "=", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "\[ImaginaryI]", ")"}]}], "     ", "=", "  ", 
       RowBox[{
        RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "sinh", " ", "1"}]}]}]}], 
    StyleBox[
     RowBox[{" ", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\n", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["\[Alpha]", "2"], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"Arg", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", 
          SubscriptBox["z", "2"], ")"}]}], ")"}]}], "  ", "=", "     ", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", "1", ")"}]}], "     ", "=", "  ", 
       RowBox[{
        RowBox[{"-", " ", "sin"}], " ", "1"}]}]}]}], 
    StyleBox[
     RowBox[{" ", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "\n", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["\[Alpha]", "3"], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"Arg", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "'"}], 
         RowBox[{"(", 
          SubscriptBox["z", "3"], ")"}]}], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", 
         RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
       RowBox[{"\[ImaginaryI]", " ", "sinh", " ", "1"}]}]}]}], 
    StyleBox[
     RowBox[{"  ", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["  ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Alpha]", "4"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"Arg", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", "'"}], 
        RowBox[{"(", 
         SubscriptBox["z", "4"], ")"}]}], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", "cosh"}], " ", "1", " ", "sin", " ", "1"}], "  ", 
       "+", "  ", 
       RowBox[{
       "\[ImaginaryI]", " ", "cos", " ", "1", " ", "sinh", " ", "1"}]}]}]}]}],
    " "}], "\[IndentingNewLine]", 
  RowBox[{"                                          ", 
   RowBox[{"=", "  ", 
    RowBox[{"\[Pi]", "-", 
     RowBox[{"arctan", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"cot", " ", "1", " ", "tanh", " ", "1"}], ")"}], 
       StyleBox[
        RowBox[{" ", 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]}]],
 "    "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell["Enter the function f(z) = cos(z).", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"z", ",", "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"z", ",", "Z", ",", "f"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39949466271875*^9, {3.39949489259375*^9, 3.399494900078125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["(a)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  w = cos(z)  near ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", "\[ImaginaryI]"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", " ", "=", " ", "\[ImaginaryI]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   At \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", "Z"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39949466646875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The image of a small rectangle about  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", " ", "\[ImaginaryI]"}]]],
 "  is a curvilinear region about ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", " ", 
   RowBox[{"cosh", 
    RowBox[{"(", "1", ")"}]}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", "Z", "]"}], ",", 
           RowBox[{"Im", "[", "Z", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
           RowBox[{"Im", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "Z", "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"Z", "+", "0.3"}], "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["W", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
             RowBox[{"Im", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "+", 
            RowBox[{"0.3", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}], ",", 
               RowBox[{"Im", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}]}], 
              "}"}]}]}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "1.5", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.6"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "0.75"}], ",", "0.75", ",", "0.25"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "1.5", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "2.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.25"}], ",", "1.25"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",",
        
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", 
     SubscriptBox["Z", "1"], ",", "zdot", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "0.75", ",", "0.25"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1.5", ",", "0.5"}], "]"}]}], "}"}]}], ",",
      
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A small square about \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", 
      ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", 
     SubscriptBox["W", "1"], ",", "wdot", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.1", "2.4"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The curvilinear image about \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\
\"", ",", " ", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<where \!\(\*SubscriptBox[\(w\), \(1\)]\) = f(\>\"", ",", "Z", ",", 
      "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(1\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(1\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39949467075*^9, 3.39949468596875*^9}, {
   3.4001439564375*^9, 3.40014395696875*^9}, {3.400158219203125*^9, 
   3.400158367703125*^9}, {3.400158423796875*^9, 3.400158441046875*^9}, 
   3.400158474421875*^9, {3.400172862*^9, 3.400172942671875*^9}, {
   3.40017297484375*^9, 3.400172992125*^9}, {3.400173125921875*^9, 
   3.40017320203125*^9}, 3.400173558546875*^9, {3.40017368728125*^9, 
   3.400173688*^9}, 3.400173927609375*^9, {3.400174021890625*^9, 
   3.4001740238125*^9}, 3.40017410384375*^9, {3.40017413790625*^9, 
   3.400174139046875*^9}, {3.400400719801*^9, 3.4004007348635*^9}}],

Cell[TextData[{
 StyleBox["(b)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  w = cos(z)  near ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", " ", "1"}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<   At \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", "Z"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399494708453125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The image of a small rectangle about  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", " ", "1"}]]],
 " is a curvilinear region about ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"cos", 
    RowBox[{"(", "1", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", "Z", "]"}], ",", 
           RowBox[{"Im", "[", "Z", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
           RowBox[{"Im", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "Z", "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"Z", "+", "0.2"}], "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["W", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
             RowBox[{"Im", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "+", 
            RowBox[{"0.2", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}], ",", 
               RowBox[{"Im", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}]}], 
              "}"}]}]}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{"0.6", ",", "1.4", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", "0.4", ",", "0.1"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.75"}], ",", "0.75"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2.0", ",", "0.25"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1.0"}], ",", "1.0", ",", "0.25"}], "]"}]}], "}"}]}],
        ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0.6", ",", "1.4", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4"}], ",", "0.4", ",", "0.1"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.88"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0", ",", "1.88"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", 
     SubscriptBox["Z", "1"], ",", "zdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.75"}], ",", "0.75"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2.0", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1.0"}], ",", "1.0", ",", "0.25"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A small square about \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", 
      ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", 
     SubscriptBox["W", "1"], ",", "wdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.25"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The curvilinear image about \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\
\"", ",", " ", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<where \!\(\*SubscriptBox[\(w\), \(2\)]\) = f(\>\"", ",", "Z", ",", 
      "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(2\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(2\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399494697875*^9, 3.399494722140625*^9}, {
   3.400143963640625*^9, 3.400143963890625*^9}, {3.400173731203125*^9, 
   3.40017373240625*^9}, {3.400173764359375*^9, 3.400173774296875*^9}, {
   3.400173808625*^9, 3.4001738614375*^9}, {3.400173896328125*^9, 
   3.40017391128125*^9}, 3.400174116765625*^9, {3.400174150328125*^9, 
   3.400174151296875*^9}, {3.400400744379125*^9, 3.40040077270725*^9}}],

Cell[TextData[{
 StyleBox["(c)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  w = cos(z)  near ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", " ", 
   RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", " ", "=", " ", 
     RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}]}], ";"}], "    ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    At  \!\(\*SubscriptBox[\(z\), \(3\)]\)  = \>\"", ",", "Z"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(3\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(3\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39949472834375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The image of a small rectangle about  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", " ", 
   RowBox[{"\[Pi]", "+", "\[ImaginaryI]"}]}]],
  AspectRatioFixed->True],
 "  is a curvilinear region about  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], "=", " ", 
   RowBox[{
    RowBox[{"-", "cosh"}], 
    RowBox[{"(", "1", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", "Z", "]"}], ",", 
           RowBox[{"Im", "[", "Z", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
           RowBox[{"Im", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "Z", "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"Z", "+", "0.4"}], "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["W", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
             RowBox[{"Im", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "+", 
            RowBox[{"0.4", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}], ",", 
               RowBox[{"Im", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}]}], 
              "}"}]}]}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Pi]", "-", "0.5"}], ",", 
         RowBox[{"\[Pi]", "+", "0.5"}], ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "1.5", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Pi]", "-", "0.5"}], ",", 
         RowBox[{"\[Pi]", "+", "0.5"}], ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "1.5", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.2"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",",
        
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", 
     SubscriptBox["Z", "1"], ",", "zdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "3.65"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.55"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.55", "3.65"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A small square about \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", 
      ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", 
     SubscriptBox["W", "1"], ",", "wdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.4"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.1", "2.4"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The curvilinear image about \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\
\"", ",", " ", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<where \!\(\*SubscriptBox[\(w\), \(3\)]\) = f(\>\"", ",", "Z", ",", 
      "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(3\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(3\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(3\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3994947328125*^9, 3.399494737640625*^9}, {
   3.400143968703125*^9, 3.400143968953125*^9}, {3.40017373834375*^9, 
   3.400173740265625*^9}, {3.4001739469375*^9, 3.40017399665625*^9}, 
   3.4001741239375*^9, {3.400174162671875*^9, 3.4001741638125*^9}, {
   3.40040077976975*^9, 3.4004008326135*^9}, 3.400400943535375*^9}],

Cell[TextData[{
 StyleBox["(d)",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 " Consider the mapping  w = cos(z)  near ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], "=", " ", 
   RowBox[{"1", "-", "\[ImaginaryI]"}]}]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Z", "=", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<     f(z) = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f'(z) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    At  \!\(\*SubscriptBox[\(z\), \(4\)]\)  = \>\"", ",", "Z"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    f(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   f'(\>\"", ",", "Z", ",", "\"\<) = \>\"", ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(4\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(4\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399494742125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The image of a small rectangle about  z = 1- i  is a curvilinear region \
about ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"cos", 
     RowBox[{"(", "1", ")"}], " ", "cosh", 
     RowBox[{"(", "1", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "sin", 
     RowBox[{"(", "1", ")"}], " ", "sinh", 
     RowBox[{"(", "1", ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], "=", 
     RowBox[{"Cos", "[", "z", "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", "Z", "]"}], ",", 
           RowBox[{"Im", "[", "Z", "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdot", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Re", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
           RowBox[{"Im", "[", 
            RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", "Z", "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"Z", "+", "0.4"}], "]"}], ",", 
             RowBox[{"Im", "[", "Z", "]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["W", "1"], " ", "=", " ", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Purple", ",", 
        RowBox[{"Arrowheads", "[", 
         RowBox[{"{", 
          RowBox[{"0.0", ",", "0.06"}], "}"}], "]"}], ",", 
        RowBox[{"Thickness", "[", "0.01", "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Re", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
             RowBox[{"Im", "[", 
              RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Re", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}], ",", 
              RowBox[{"Im", "[", 
               RowBox[{"f", "[", "Z", "]"}], "]"}]}], "}"}], "+", 
            RowBox[{"0.4", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}], ",", 
               RowBox[{"Im", "[", 
                FractionBox[
                 RowBox[{
                  RowBox[{"f", "'"}], "[", "Z", "]"}], 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]], "]"}]}], 
              "}"}]}]}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{"0.6", ",", "1.4", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.4"}], ",", 
         RowBox[{"-", "0.6"}], ",", "0.1"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.5"}], ",", "0.0"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2.0", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2.0"}], ",", "0.0", ",", "0.5"}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"0.6", ",", "1.4", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1.4"}], ",", 
         RowBox[{"-", "0.6"}], ",", "0.1"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1.88"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0", ",", "1.88"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", 
     SubscriptBox["Z", "1"], ",", "zdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "0.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2.0", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2.0"}], ",", "0.0", ",", "0.5"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<A small square about \!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", 
      ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", 
     SubscriptBox["W", "1"], ",", "wdot", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1.88"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "1.88"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The curvilinear image about \!\(\*SubscriptBox[\(w\), \(4\)]\) = \>\
\"", ",", " ", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<where \!\(\*SubscriptBox[\(w\), \(4\)]\) = f(\>\"", ",", "Z", ",", 
      "\"\<) = \>\"", ",", 
      RowBox[{"f", "[", "Z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"f", "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(4\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))) = \>\"", ",", 
      RowBox[{"Arg", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Rotate \!\(\*SubscriptBox[\(\[Alpha]\), \(4\)]\) = \
Arg(f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))) = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Arg", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{
        RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< Magnify  =   |f'(\!\(\*SubscriptBox[\(z\), \(4\)]\))|  = |\>\"", 
      ",", 
      RowBox[{
       RowBox[{"f", "'"}], "[", "Z", "]"}], ",", "\"\<| = \>\"", ",", 
      RowBox[{"N", "[", 
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"f", "'"}], "[", "Z", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399494752875*^9, 3.399494759328125*^9}, {
  3.400143974359375*^9, 3.400143974578125*^9}, {3.400174191578125*^9, 
  3.400174228875*^9}, {3.400400841676*^9, 3.400400864972875*^9}}]
}, Closed]],

Cell[TextData[{
 "\tLet ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 " be a nonconstant analytic function.  If ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", "0"}]]],
 ", then ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " is called a critical point of ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 ", and the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is ",
 ButtonBox["not conformal",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/NonconformalMap.html"], None}],
 " at ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  The next result shows what happens at a critical point."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 10.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 StyleBox["f(z)",
  FontFamily->"Courier"],
 " be analytic at the point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     RowBox[{"f", "''"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"(", 
       RowBox[{"k", "-", "1"}], ")"}]], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 " ",
 Cell[BoxData[
  SuperscriptBox["", 
   TagBox["",
    Derivative],
   MultilineFunction->None]]],
 "and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "k", ")"}]], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ",  then the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " magnifies angles at the vertex ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " by the factor ",
 StyleBox["k",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{554, 255},
  ImageMargins->0],
 StyleBox[" \n\n\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.3",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1003.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The analytic mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " at point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "...", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", 
      RowBox[{"(", 
       RowBox[{"k", "-", "1"}], ")"}]], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "0"}]}]]],
 " ",
 Cell[BoxData[
  SuperscriptBox["", 
   TagBox["",
    Derivative],
   MultilineFunction->None]]],
 "and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["f", 
     RowBox[{"(", "k", ")"}]], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 "."
}], "Text",
 CellChangeTimes->{{3.3994965159375*^9, 3.399496526578125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.2 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 10.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]],
  AspectRatioFixed->True],
 " maps the unit square ",
 Cell[BoxData[
  RowBox[{"S", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"y", ":", " ", 
        RowBox[{"0", "<", "x", "<", "1"}]}]}]}], ",", 
     RowBox[{"0", "<", "y", "<", "1"}]}], "}"}]}]]],
 " onto the region in the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ", which lies under the parabolas  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"u", " ", "=", " ", 
   RowBox[{"1", "-", 
    RowBox[{
     FractionBox["1", "4"], 
     SuperscriptBox["v", "2"]}]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{"u", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "1"}], "+", 
    RowBox[{
     FractionBox["1", "4"], 
     SuperscriptBox["v", "2"]}]}]}]]],
 "\n\nas shown in Figure 10.4. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{501, 190},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.4",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/conformalmapping/\
ConformalMappingFigures/mat1004.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 "."
}], "Text"],

Cell[TextData[{
 "Solution.  The derivative is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"2", "z"}]}]],
  AspectRatioFixed->True],
 ",  and we conclude that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 "  is conformal for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]],
  AspectRatioFixed->True],
 ".   Note that the right angles at the vertices  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", "1"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", "\[ImaginaryI]"}]]],
 "  are mapped onto right angles at the vertices  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "=", "1"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", 
   RowBox[{"2", "\[ImaginaryI]"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], "=", 
   RowBox[{"-", "1"}]}]]],
 ",  respectively.  At the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 ",  we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "0", ")"}]}], "=", "0"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "''"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "''"}], 
     RowBox[{"(", "0", ")"}]}], "=", 
    RowBox[{"2", "\[NotEqual]", "0"}]}]}]]],
 ".  Hence angles at the vertex  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 "  are magnified by the factor ",
 Cell[BoxData[
  RowBox[{"k", "=", "2"}]]],
 ".  In particular, the right angle at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", "0"}]]],
 " is mapped onto the straight angle at ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", "0"}]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "=", 
   SuperscriptBox["z", "2"]}]],
  AspectRatioFixed->True],
 "  and graph the mapping."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", 
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     SuperscriptBox["z", "2"]}], ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Vertical lines x = a, and horizontal lines y = b,\>\"",
      "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<forming a unit square in the z-plane.\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{"CartesianMap", "[", " ", 
    RowBox[{"f", "  ", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The image parabolas \>\"", ",", " ", 
      RowBox[{"u", "\[Equal]", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        FractionBox[
         SuperscriptBox["v", "2"], 
         RowBox[{"4", 
          SuperscriptBox["a", "2"]}]]}]}], ",", "\"\< and \>\"", ",", 
      RowBox[{"u", "\[Equal]", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        FractionBox[
         SuperscriptBox["v", "2"], 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"]}]]}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39949481453125*^9, 3.399494836875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tAnother property of a conformal mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is obtained by considering the modulus of  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", 
    SubscriptBox["z", "0"], ")"}]}]]],
 ".  If  ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 "  is near  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ",  we can use the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[Eta]", 
     RowBox[{"(", 
      SubscriptBox["z", "1"], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ")"}]}]}]}]]],
 " \n\nand neglect the term  ",
 Cell[BoxData[
  RowBox[{"\[Eta]", 
   RowBox[{"(", 
    SubscriptBox["z", "1"], ")"}], 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["z", "1"], "-", 
     SubscriptBox["z", "0"]}], ")"}]}]]],
 ".  We then have the approximation\n\n",
 StyleBox["(10-9)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "-", 
    SubscriptBox["w", "0"]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}], "-", 
     RowBox[{"f", 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}]}]}], "  ", 
    StyleBox["\[TildeTilde]",
     FontSize->14], "  ", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "1"], "-", 
       SubscriptBox["z", "0"]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tFrom Equation ",
 StyleBox["(10-9)",
  FontColor->RGBColor[0, 0, 1]],
 ", the distance  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    SubscriptBox["w", "1"], "-", 
    SubscriptBox["w", "0"]}], "|"}]]],
 "  between the images of the points  ",
 Cell[BoxData[
  SubscriptBox["z", "1"]]],
 "  and  ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 "  given approximately by  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "||", 
    RowBox[{
     SubscriptBox["z", "1"], "-", 
     SubscriptBox["z", "0"]}]}], "|"}]]],
 ".  Therefore we say that the transformation   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  changes small distances near ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " by the scale factor ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "|"}]]],
 ".   For example, the scale factor of the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox["z", "2"]}]}]],
  AspectRatioFixed->True],
 "  near the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"1", "+", "\[ImaginaryI]"}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "|"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{"2", 
      SubscriptBox["z", "0"]}], "|"}], " ", "=", 
    RowBox[{
     RowBox[{"|", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "|"}], " ", "=", " ", 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{"2", " "}]]}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tWe also need to say a few things about the inverse transformation   ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"g", 
    RowBox[{"(", "w", ")"}]}]}]]],
 "  of a conformal mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  near a point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 ", where ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}], "\[NotEqual]", "0"}]]],
 ".  \nA complete justification of the following assertions relies on \
theorems studied in advanced calculus. (See, for instance, R. Creighton Buck, \
Advanced Calculus, 3rd ed. (New York, McGraw-Hill), pp. 358-361, 1978.)  "
}], "Text"],

Cell[TextData[{
 "\tWe express the mapping   ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  in the coordinate form  \n\n",
 StyleBox["(10-10)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}], "   ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "v"}], "=", 
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe mapping in Equations ",
 StyleBox["(10-10)",
  FontColor->RGBColor[0, 0, 1]],
 " represents a transformation from the xy plane into the uv plane, and the \
Jacobian determinant, ",
 Cell[BoxData[
  RowBox[{"J", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ", is defined by  \n\n",
 StyleBox["(10-11)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"|", GridBox[{
      {
       RowBox[{
        SubscriptBox["u", "x"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}], 
       RowBox[{
        SubscriptBox["u", "y"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}]},
      {
       RowBox[{
        SubscriptBox["v", "x"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}], 
       RowBox[{
        SubscriptBox["v", "y"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}]}
     }], "|"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe transformation in Equations ",
 StyleBox["(10-10)",
  FontColor->RGBColor[0, 0, 1]],
 " has a local inverse, provided  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "\[NotEqual]", "0"}]]],
 ".  Expanding Equation ",
 StyleBox["(10-11)",
  FontColor->RGBColor[0, 0, 1]],
 " and using the Cauchy--Riemann equations, we obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "0"], ",", 
       SubscriptBox["y", "0"]}], ")"}]}], "   ", "=", "   ", 
    RowBox[{"|", GridBox[{
       {
        RowBox[{
         SubscriptBox["u", "x"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], ",", 
           SubscriptBox["y", "0"]}], ")"}]}], 
        RowBox[{
         SubscriptBox["u", "y"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], ",", 
           SubscriptBox["y", "0"]}], ")"}]}]},
       {
        RowBox[{
         SubscriptBox["v", "x"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], ",", 
           SubscriptBox["y", "0"]}], ")"}]}], 
        RowBox[{
         SubscriptBox["v", "y"], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["x", "0"], ",", 
           SubscriptBox["y", "0"]}], ")"}]}]}
      }], "|"}]}], "    ", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                  ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}], 
      SubscriptBox["v", "y"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}]}], "  ", "-", "  ", 
     RowBox[{
      SubscriptBox["v", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}], 
      SubscriptBox["u", "y"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}], 
      SubscriptBox["u", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}]}], "  ", "-", "  ", 
     RowBox[{
      SubscriptBox["v", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["v", "x"]}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["x", "0"], ",", 
          SubscriptBox["y", "0"]}], ")"}]}], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", "   ", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["u", "x", "2"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}]}], "  ", "+", "  ", 
     RowBox[{
      SubsuperscriptBox["v", "x", "2"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], ",", 
        SubscriptBox["y", "0"]}], ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                       ", 
   RowBox[{"=", " ", 
    RowBox[{"|", " ", 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       SubscriptBox["z", "0"], ")"}]}], "|", "  ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", "                  ", 
     RowBox[{"\[NotEqual]", " ", "0"}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tConsequently, Equations ",
 StyleBox["(10-11)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(10-11)",
  FontColor->RGBColor[0, 0, 1]],
 " imply that a local inverse ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"g", 
    RowBox[{"(", "w", ")"}]}]}]]],
 " exists in a neighborhood of the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], "=", 
   RowBox[{"f", 
    RowBox[{"(", 
     SubscriptBox["z", "0"], ")"}]}]}]]],
 ".  The derivative of ",
 StyleBox["g(w)",
  FontFamily->"Courier New"],
 " at ",
 Cell[BoxData[
  SubscriptBox["w", "0"]]],
 " is given by the familiar expression  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", 
      SubscriptBox["w", "0"], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      UnderscriptBox[
       RowBox[{"lim", " "}], 
       RowBox[{"w", "\[Rule]", 
        SubscriptBox["w", "0"]}]], " ", 
      FractionBox[
       RowBox[{
        RowBox[{"g", 
         RowBox[{"(", "w", ")"}]}], "-", 
        RowBox[{"g", 
         RowBox[{"(", 
          SubscriptBox["w", "0"], ")"}]}]}], 
       RowBox[{"w", "-", 
        SubscriptBox["w", "0"]}]]}], "  ", "=", "   ", 
     RowBox[{
      RowBox[{
       UnderscriptBox[
        RowBox[{"lim", " "}], 
        RowBox[{"w", "\[Rule]", 
         SubscriptBox["w", "0"]}]], " ", 
       FractionBox[
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], 
        RowBox[{"w", "-", 
         SubscriptBox["w", "0"]}]]}], "  ", "=", "   ", 
      RowBox[{
       UnderscriptBox[
        RowBox[{"lim", " "}], 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], 
        RowBox[{"w", "-", 
         SubscriptBox["w", "0"]}]]}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{
       UnderscriptBox[
        RowBox[{"lim", " "}], 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["z", "0"]}]], " ", 
       FractionBox[
        RowBox[{"z", "-", 
         SubscriptBox["z", "0"]}], 
        RowBox[{
         RowBox[{"f", 
          RowBox[{"(", "z", ")"}]}], "-", 
         RowBox[{"f", 
          RowBox[{"(", 
           SubscriptBox["z", "0"], ")"}]}]}]]}], "  ", "=", "   ", 
      RowBox[{
       UnderscriptBox[
        RowBox[{"lim", " "}], 
        RowBox[{"z", "\[Rule]", 
         SubscriptBox["z", "0"]}]], " ", 
       RowBox[{"1", "/", 
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           RowBox[{"f", 
            RowBox[{"(", "z", ")"}]}], "-", 
           RowBox[{"f", 
            RowBox[{"(", 
             SubscriptBox["z", "0"], ")"}]}]}], 
          RowBox[{"z", "-", 
           SubscriptBox["z", "0"]}]], ")"}]}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        UnderscriptBox[
         RowBox[{"lim", " "}], 
         RowBox[{"z", "\[Rule]", 
          SubscriptBox["z", "0"]}]], " ", 
        FractionBox[
         RowBox[{
          RowBox[{"f", 
           RowBox[{"(", "z", ")"}]}], "-", 
          RowBox[{"f", 
           RowBox[{"(", 
            SubscriptBox["z", "0"], ")"}]}]}], 
         RowBox[{"z", "-", 
          SubscriptBox["z", "0"]}]]}], ")"}]}]}], "\[IndentingNewLine]", 
    " "}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"f", "'"}], 
       RowBox[{"(", 
        SubscriptBox["z", "0"], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"f", "'"}], 
      RowBox[{"(", 
       RowBox[{"g", 
        RowBox[{"(", 
         SubscriptBox["w", "0"], ")"}]}], ")"}]}]]}]}]}]],
 "   "
}], "Text"],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.html"],
    None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399493381203125*^9, 3.39949338134375*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{968, 641},
WindowMargins->{{7, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[44708, 1054, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[144221, 3770, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 175838, 4790}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 193, 7, 29, "Text"],
Cell[1101, 41, 1093, 20, 137, "Text"],
Cell[2197, 63, 132, 2, 29, "Text"],
Cell[2332, 67, 3689, 149, 227, "Text",
 Evaluatable->False],
Cell[6024, 218, 1175, 44, 231, "Text"],
Cell[7202, 264, 369, 14, 67, "Text"],
Cell[7574, 280, 1679, 66, 143, "Text"],
Cell[9256, 348, 1730, 59, 163, "Text"],
Cell[10989, 409, 13123, 238, 272, "Text"],
Cell[24115, 649, 638, 20, 47, "Text",
 Evaluatable->False],
Cell[24756, 671, 961, 40, 29, "Text",
 Evaluatable->False],
Cell[25720, 713, 18645, 325, 279, "Text"],
Cell[CellGroupData[{
Cell[44390, 1042, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[44534, 1048, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[44708, 1054, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[45057, 1066, 1027, 41, 44, "Text",
 Evaluatable->False],
Cell[46087, 1109, 3815, 65, 202, "Text",
 Evaluatable->False],
Cell[49905, 1176, 10071, 337, 386, "Text"],
Cell[CellGroupData[{
Cell[60001, 1517, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[60161, 1523, 49, 0, 29, "Text"],
Cell[60213, 1525, 739, 21, 132, "Input"],
Cell[60955, 1548, 233, 9, 29, "Text"],
Cell[61191, 1559, 3141, 89, 332, "Input"],
Cell[64335, 1650, 315, 12, 29, "Text"],
Cell[64653, 1664, 11588, 315, 704, "Input"],
Cell[76244, 1981, 221, 9, 29, "Text"],
Cell[76468, 1992, 3357, 95, 352, "Input"],
Cell[79828, 2089, 298, 12, 29, "Text"],
Cell[80129, 2103, 11222, 306, 656, "Input"],
Cell[91354, 2411, 287, 11, 29, "Text"],
Cell[91644, 2424, 3157, 89, 332, "Input"],
Cell[94804, 2515, 392, 15, 29, "Text"],
Cell[95199, 2532, 11300, 309, 705, "Input"],
Cell[106502, 2843, 257, 10, 29, "Text"],
Cell[106762, 2855, 3396, 96, 352, "Input"],
Cell[110161, 2953, 393, 13, 29, "Text"],
Cell[110557, 2968, 11055, 304, 656, "Input"]
}, Closed]],
Cell[121627, 3275, 770, 31, 44, "Text"],
Cell[122400, 3308, 1973, 82, 47, "Text",
 Evaluatable->False],
Cell[124376, 3392, 19502, 362, 308, "Text"],
Cell[CellGroupData[{
Cell[143903, 3758, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[144047, 3764, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[144221, 3770, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[144570, 3782, 1197, 45, 122, "Text",
 Evaluatable->False],
Cell[145770, 3829, 6207, 105, 204, "Text",
 Evaluatable->False],
Cell[151980, 3936, 486, 17, 29, "Text"],
Cell[152469, 3955, 2138, 88, 83, "Text"],
Cell[CellGroupData[{
Cell[154632, 4047, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[154792, 4053, 219, 9, 29, "Text"],
Cell[155014, 4064, 3506, 101, 333, "Input"]
}, Closed]],
Cell[158535, 4168, 2099, 82, 134, "Text",
 Evaluatable->False],
Cell[160637, 4252, 1882, 76, 67, "Text"],
Cell[162522, 4330, 756, 24, 65, "Text"],
Cell[163281, 4356, 723, 28, 65, "Text"],
Cell[164007, 4386, 1039, 40, 81, "Text"],
Cell[165049, 4428, 3910, 131, 274, "Text"],
Cell[168962, 4561, 4071, 144, 305, "Text"],
Cell[173036, 4707, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[173496, 4719, 407, 7, 29, "Text"],
Cell[173906, 4728, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[174053, 4735, 281, 7, 26, "Text"],
Cell[174337, 4744, 281, 7, 29, "Text"],
Cell[174621, 4753, 299, 7, 29, "Text"],
Cell[174923, 4762, 249, 5, 29, "Text"],
Cell[175175, 4769, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
