(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    316384,       8058]
NotebookOptionsPosition[    309898,       7858]
NotebookOutlinePosition[    310603,       7888]
CellTagsIndexPosition[    310529,       7883]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["10.2  Bilinear Transformations - Mobius \
Transformations",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tAnother important class of elementary mappings was studied by ",
 StyleBox[ButtonBox["August Ferdinand M\[ODoubleDot]bius",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mobius.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " (1790-1868).  These mappings are conveniently expressed as the quotient of \
two linear expressions and are commonly known as linear fractional or \
bilinear transformations.  They arise naturally in mapping problems involving \
the function  arctan(z).  In this section, we show how they are used to map a \
disk one-to-one and onto a half-plane.  \n\n\tLet  ",
 Cell[BoxData[
  RowBox[{"a", ",", "b", ",", "c", ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "d"}]}]]],
 "  denote four complex constants with the restriction that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", " ", "d"}], "\[NotEqual]", 
   RowBox[{"b", " ", "c"}]}]]],
 ".  Then the function\n\n",
 StyleBox["(10-13)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"a", " ", "z"}], " ", "+", " ", "b"}], 
     RowBox[{
      RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}]]}]}]]],
 "\n\nis called  a bilinear transformation, a ",
 StyleBox[ButtonBox["M\[ODoubleDot]bius transformation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/MoebiusTransformation.html"], None}],
  FontVariations->{"Underline"->True}],
 ", or a ",
 StyleBox[ButtonBox["linear fractional transformation",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/LinearFractionalTransformation.html"], 
    None}],
  FontVariations->{"Underline"->True}],
 ".   \nIf the expression for ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " in Equation ",
 StyleBox["(10-13)",
  FontColor->RGBColor[0, 0, 1]],
 " is multiplied through by the quantity  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}]]],
 ",  then the resulting expression has the bilinear form  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"c", " ", "w", " ", "z"}], " ", "-", " ", 
    RowBox[{"a", " ", "z"}], " ", "+", " ", 
    RowBox[{"d", " ", "w"}], " ", "-", " ", "b"}], " ", "=", " ", "0"}]]],
 ".  \nWe collect terms involving ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " and write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"z", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", " ", "w"}], " ", "-", "a"}], " ", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "d"}], " ", "w"}], " ", "+", " ", "b"}]}]]],
 ".  Then, for values of  ",
 Cell[BoxData[
  RowBox[{"w", "\[NotEqual]", 
   FractionBox["a", "c"]}]]],
 "  the inverse transformation is given by\n\n",
 StyleBox["(10-14)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "d"}], " ", "w"}], " ", "+", " ", "b"}], 
     RowBox[{
      RowBox[{"c", " ", "w"}], " ", "-", " ", "a"}]]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tWe can extend  ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", "z", ")"}], "  ", "and", "  ", 
   SuperscriptBox["S", 
    RowBox[{"-", "1"}]], 
   RowBox[{"(", "w", ")"}]}]]],
 "  to mappings in the extended complex plane.  The value  ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", "\[Infinity]", ")"}]}]]],
 "  should be chosen to equal the limit of ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", "z", ")"}]}]]],
 "  as  ",
 Cell[BoxData[
  RowBox[{"z", "\[Rule]", "\[Infinity]"}]]],
 ".  Therefore we define\n\n\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "\[Infinity]", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"z", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
     RowBox[{"S", 
      RowBox[{"(", "z", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"z", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
      FractionBox[
       RowBox[{"a", "  ", "+", " ", 
        FractionBox["b", "z"]}], 
       RowBox[{"c", "  ", "+", " ", 
        FractionBox["d", "z"]}]]}], " ", "=", "  ", 
     FractionBox["a", "c"]}]}]}]]],
 ",  \n\nand the inverse is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["S", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", 
     FractionBox["a", "c"], ")"}]}], " ", "=", " ", "\[Infinity]"}]]],
 ".  Similarly, the value  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["S", 
    RowBox[{"-", "1"}]], 
   RowBox[{"(", "\[Infinity]", ")"}]}]]],
 "  is obtained by \n\n\t\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["S", 
     RowBox[{"-", "1"}]], 
    RowBox[{"(", "\[Infinity]", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"w", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
     RowBox[{
      SuperscriptBox["S", 
       RowBox[{"-", "1"}]], 
      RowBox[{"(", "w", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"w", " ", "\[Rule]", " ", "\[Infinity]"}]], "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "d"}], " ", "+", 
        FractionBox["b", "w"]}], 
       RowBox[{"c", " ", "-", 
        FractionBox["a", "w"]}]]}], " ", "\[Equal]", "  ", 
     FractionBox[
      RowBox[{"-", " ", "d"}], "c"]}]}]}]]],
 ",\n\nand the inverse is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"-", " ", "d"}], "c"], ")"}]}], " ", "=", " ", 
   "\[Infinity]"}]]],
 ".  With these extensions we conclude that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  is a one-to-one mapping of the extended complex z-plane onto the extended \
complex ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane.  "
}], "Text"],

Cell[TextData[{
 "\tWe now show that a bilinear transformation carries the class of circles \
and lines onto itself.  If ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " is an arbitrary bilinear transformation given by Equation ",
 StyleBox["(10-13)",
  FontColor->RGBColor[0, 0, 1]],
 " and  ",
 Cell[BoxData[
  RowBox[{"c", "=", "0"}]]],
 ",  then ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 "  reduces to a linear transformation, which carries lines onto lines and \
circles onto circles.  If  ",
 Cell[BoxData[
  RowBox[{"c", "\[NotEqual]", "0"}]]],
 ",  then we can write ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " in the form  \n\n",
 StyleBox["(10-15)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"a", " ", "z"}], " ", "+", " ", "b"}], 
     RowBox[{
      RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", " ", "z"}], " ", "+", " ", "b"}], ")"}]}], 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "z"}], "+", "d"}], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "c", " ", "z"}], " ", "+", " ", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "z"}], "+", "d"}], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "c", " ", "z"}], "  ", "+", " ", 
       RowBox[{"a", " ", "d"}], " ", "-", " ", 
       RowBox[{"a", " ", "d"}], " ", "+", " ", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "z"}], "+", "d"}], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", " ", "z"}], "+", "d"}], ")"}]}], " ", "-", " ", 
       RowBox[{"a", " ", "d"}], " ", "+", " ", 
       RowBox[{"b", " ", "c"}]}], 
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"c", " ", "z"}], "+", "d"}], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["a", "c"], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"b", " ", "c"}], " ", "-", " ", 
        RowBox[{"a", " ", "d"}]}], "c"], 
      FractionBox["1", 
       RowBox[{
        RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}]]}]}]}]}]}]],
 "   "
}], "Text"],

Cell[TextData[{
 "\tThe condition  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", " ", "d"}], " ", "\[NotEqual]", " ", 
   RowBox[{"b", " ", "c"}]}]]],
 "  precludes the possibility that ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " reduces to a constant.  Equation ",
 StyleBox["(10-15)",
  FontColor->RGBColor[0, 0, 1]],
 " indicates that ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " can be considered as a composition of functions.  \nIt is a linear mapping \
 ",
 Cell[BoxData[
  RowBox[{"\[Xi]", " ", "=", " ", 
   RowBox[{
    RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}]}]]],
 ",  followed by the reciprocal transformation  ",
 Cell[BoxData[
  RowBox[{"Z", " ", "=", " ", 
   FractionBox["1", "\[Xi]"]}]]],
 ",  followed by  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    FractionBox["a", "c"], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"b", " ", "c"}], " ", "-", " ", 
       RowBox[{"a", " ", "d"}]}], "c"], "Z"}]}]}]]],
 ".  In Chapter 2 we showed that each function in this composition maps the \
class of circles and lines onto itself; it follows that the bilinear \
transformation ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " has this property.  A half-plane can be considered to be a family of \
parallel lines and a disk as a family of circles.  Therefore we conclude that \
a bilinear transformation maps the class of half-planes and disks onto \
itself.  Example 10.3 illustrates this idea."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 10.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}]}], 
     RowBox[{"1", " ", "+", " ", "z"}]]}]}]],
  AspectRatioFixed->True],
 "  maps the unit disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 "  one-to-one and onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{596, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We first consider the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", "z", "|"}]}], "=", "1"}]]],
 ",  which forms the boundary of the disk and find its image in the w plane.  \
\nIf we write  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "z"}], " ", "+", " ", 
     "\[ImaginaryI]"}], 
    RowBox[{"z", " ", "+", " ", "1"}]]}]],
  AspectRatioFixed->True],
 ",  then we see that  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"b", "=", "\[ImaginaryI]"}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{"c", "=", "1"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{"d", "=", "1"}]]],
 ".  \nUsing Equation ",
 StyleBox["(10-14)",
  FontColor->RGBColor[0, 0, 1]],
 ", we find that the inverse is given by\n\n\t\t\t\n",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{"z", "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"-", "d"}], " ", "w"}], " ", "+", " ", "b"}], 
      RowBox[{
       RowBox[{"c", " ", "w"}], " ", "-", " ", "a"}]], "  ", "=", "  ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", "1", ")"}]}], " ", "w"}], " ", "+", " ", 
        RowBox[{"(", "\[ImaginaryI]", ")"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", "1", ")"}], " ", "w"}], " ", "-", "  ", 
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}]}]], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"-", " ", "w"}], " ", "+", " ", "\[ImaginaryI]"}], 
       RowBox[{"w", " ", "+", " ", "\[ImaginaryI]"}]]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ",  then Equation ",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 " implies that the images of points on the unit circle satisfy ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    FractionBox[
     RowBox[{
      RowBox[{"-", " ", "w"}], " ", "+", " ", "\[ImaginaryI]"}], 
     RowBox[{"w", " ", "+", " ", "\[ImaginaryI]"}]], "|"}], "=", "1"}]]],
 " which yields the equation  \n\n",
 StyleBox["(10-17)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"w", " ", "+", " ", "\[ImaginaryI]"}], "|"}], " ", "=", " ", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"-", " ", "w"}], " ", "+", " ", "\[ImaginaryI]"}], "|"}]}]]],
 ".  \n"
}], "Text"],

Cell[TextData[{
 "Squaring both sides of Equation ",
 StyleBox["(10-17)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain\n\n\t\t\t   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}], " ", "+", " ", "\[ImaginaryI]"}], 
    "|"}], "  ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"-", " ", "u"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "v"}], " ", "+", " ", "\[ImaginaryI]"}], 
    "|"}]}]]],
 "   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "v"}], ")"}]}]}], 
    SuperscriptBox["|", "2"]}], " ", "=", "  ", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"-", " ", "u"}], "+", " ", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"1", "-", "v"}], ")"}]}]}], 
    SuperscriptBox["|", "2"]}]}]]],
 "   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "v"}], ")"}], "2"]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", " ", "u"}], ")"}], "2"], "+", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "v"}], ")"}], "2"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["u", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "v"}], ")"}], "2"]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["u", "2"], "+", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "v"}], ")"}], "2"]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"        ", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "v"}], ")"}], "2"], "  ", "=", "  ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "v"}], ")"}], "2"]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "v"}], "+", 
      SuperscriptBox["v", "2"]}], " ", "=", "  ", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "v"}], "+", 
      SuperscriptBox["v", "2"]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", "v"}], "  ", "=", "  ", "0"}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"v", "  ", "=", "  ", "0"}]}]}]],
 "     \n\nwhich is the equation of the ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane.  "
}], "Text"],

Cell[TextData[{
 "\tThe circle ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " divides the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane into two portions, and its image is the u axis, which divides the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane into two portions.  The image of the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", "0"}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "0", ")"}]}], "=", "\[ImaginaryI]"}]}]]],
 ",  so we expect that the interior of the circle ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is mapped onto the portion of the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane that lies above the ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis.  To show that this outcome is true, we let  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 ".  Then Equation ",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 " implies that the image values must satisfy the inequality  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    RowBox[{"-", " ", "w"}], " ", "+", " ", "\[ImaginaryI]"}], "|", " ", 
   RowBox[{"<", " ", 
    RowBox[{"|", 
     RowBox[{"w", " ", "+", " ", "\[ImaginaryI]"}], "|"}]}]}]]],
 ",  which we write as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["d", "1"], " ", "=", " ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{"w", " ", "-", " ", "\[ImaginaryI]"}], "|", " ", 
     RowBox[{"<", " ", 
      RowBox[{"|", 
       RowBox[{"w", " ", "-", 
        RowBox[{"(", 
         RowBox[{"-", " ", "\[ImaginaryI]"}], ")"}]}], "|"}]}]}], " ", "=", 
    " ", 
    SubscriptBox["d", "2"]}]}]]],
 " .  "
}], "Text"],

Cell[TextData[{
 "\tIf we interpret ",
 Cell[BoxData[
  SubscriptBox["d", "1"]]],
 " as the distance from  ",
 Cell[BoxData[
  RowBox[{"w", "  ", 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", "\[ImaginaryI]"}]]],
 "  and ",
 Cell[BoxData[
  SubscriptBox["d", "2"]]],
 " as the distance from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "  ", 
    StyleBox["to",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], " ", "-", "\[ImaginaryI]"}]]],
 ",  then a geometric argument shows that the image point w must lie in the \
upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ",  as shown in Figure 10.5.  As ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " is one-to-one and onto in the extended complex plane, it follows that ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " maps the disk onto the half-plane. "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{640, 272},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 10.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1005.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The image  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 "  under  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}]}], 
    RowBox[{"1", " ", "+", " ", "z"}]]}]],
  AspectRatioFixed->True],
 ",  the points \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "\[ImaginaryI]"}]}]]],
 "  are mapped onto the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "1"}]}]]],
 ",  respectively."
}], "Text",
 CellChangeTimes->{{3.3994965984375*^9, 3.39949662178125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", " ", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "z"}], ")"}]}], 
    RowBox[{"1", " ", "+", " ", "z"}]]}]],
  AspectRatioFixed->True],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "=", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "z", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "eqn", ",", "Iden", ",", "solset", ",", "S", ",", "w", ",", "z"}], "]"}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}]}], 
      RowBox[{"1", "+", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399495960609375*^9},
 AspectRatioFixed->True],

Cell["To show  S(z)  is one-to-one, find the inverse function.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn", "=", 
     RowBox[{"w", "\[Equal]", 
      RowBox[{"S", "[", "z", "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqn", ",", "z"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"S1", "[", "w_", "]"}], "=", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eqn", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \!\(\*SuperscriptBox[\(S\), \(-1\)]\)[w] = \>\"", ",", 
      RowBox[{"S1", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399495965140625*^9},
 AspectRatioFixed->True],

Cell["Check out the inverse function.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \!\(\*SuperscriptBox[\(S\), \(-1\)]\)[w] = \>\"", ",", 
      RowBox[{"S1", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SuperscriptBox[\(S\), \(-1\)]\)[S[z]] = \>\"", ",", 
      RowBox[{"S1", "[", 
       RowBox[{"S", "[", "z", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{"S1", "[", 
        RowBox[{"S", "[", "z", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SuperscriptBox[\(S\), \(-1\)]\)[w]] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"S1", "[", "w", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{"S", "[", 
        RowBox[{"S1", "[", "w", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399495969109375*^9}],

Cell[TextData[{
 "Consider the unit circle C: |z| = 1.  Since  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], "=", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", "-", " ", "w"}], 
     RowBox[{"\[ImaginaryI]", " ", "+", " ", "w"}]]}]}]]],
 ",  the image of these points will satisfy  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"|", 
     RowBox[{"w", "+", "\[ImaginaryI]"}], "|"}], "=", 
    RowBox[{"|", 
     RowBox[{"w", "+", "\[ImaginaryI]"}], "|"}]}]}]]],
 ".  \nSquare both sides of the above equation and obtain ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}], "+", "\[ImaginaryI]"}], 
    SuperscriptBox["|", "2"]}], "=", 
   RowBox[{"|", 
    RowBox[{
     RowBox[{"-", "u"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "v"}], "+", "\[ImaginaryI]"}], 
    SuperscriptBox["|", "2"]}]}]]],
 "  which can be simplified."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqn", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"v", "+", "1"}], ")"}], "2"]}], "==", 
      RowBox[{
       SuperscriptBox["u", "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "v"}], "+", "1"}], ")"}], "2"]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "eqn", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Simplify", "[", "eqn", "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399495972578125*^9}],

Cell["\<\
The circle  C  divides the z-plane into two portions, and its image, v = 0, \
is the u-axis which divides the w-plane into two portions. The image of a \
point interior to  C  will determine which half plane is the image of the \
unit disk.  For example\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[0] = \>\"", ",", 
      RowBox[{"S", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39949597659375*^9}],

Cell[TextData[{
 "Therefore, the image of the unit disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 " is the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 ".  \n\nTo visualize that  S(z)  is onto we will consider a graph. The graph \
is not conclusive, but it appears to confirm our suspicion."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", "z"}], ")"}]}]}], 
      RowBox[{"1", "+", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"graph1", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"Iden", ",", 
      RowBox[{"{", 
       RowBox[{"0.000005", ",", "0.999995", ",", "0.11111"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The disk |z| < 1.\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{"graph2", "=", 
    RowBox[{"PolarMap", "[", 
     RowBox[{"S", "   ", ",", 
      RowBox[{"{", 
       RowBox[{"0.000005", ",", "0.999995", ",", "0.11111"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "\[Pi]"}], ",", 
        FractionBox["\[Pi]", "12"]}], "}"}], ",", 
      RowBox[{"Ticks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       FractionBox["1", "2"]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image half-plane Im[w] > 0,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399495980359375*^9, 3.399495985640625*^9}, {
  3.400146680671875*^9, 3.400146681*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}]}], 
     RowBox[{"1", " ", "+", " ", "z"}]]}]}]],
  AspectRatioFixed->True],
 "  maps the unit disk ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", "1"}]}]]],
 " one-to-one and onto the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.023", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.023", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "zdots"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph2", ",", "wdots"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = S[\>\"", ",", "z", ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   S[\>\"", ",", 
      RowBox[{"-", "\[ImaginaryI]"}], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"-", "\[ImaginaryI]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<    S[\>\"", ",", "1", ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<    S[\>\"", ",", "\[ImaginaryI]", ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", "\[ImaginaryI]", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39949599153125*^9, 3.399496045828125*^9}, {
  3.40040119108225*^9, 3.400401195285375*^9}}]
}, Closed]],

Cell[TextData[{
 "\tThe general formula for a bilinear transformation (Equation ",
 StyleBox["(10-13)",
  FontColor->RGBColor[0, 0, 1]],
 ") appears to involve four independent coefficients:  ",
 Cell[BoxData[
  RowBox[{"a", ",", "b", ",", "c", ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", "d"}]}]]],
 ".  But as ",
 StyleBox["S(z)",
  FontFamily->"Courier New"],
 " is not identically constant, either  ",
 Cell[BoxData[
  RowBox[{"a", "\[NotEqual]", "0"}]]],
 "  or  ",
 Cell[BoxData[
  RowBox[{"c", "\[NotEqual]", "0"}]]],
 ",  we can express the transformation with three unknown coefficients and \
write either \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   FractionBox[
    RowBox[{"z", " ", "+", " ", 
     FractionBox["b", "a"]}], 
    RowBox[{
     RowBox[{
      FractionBox["c", "a"], " ", "z"}], " ", "+", " ", 
     FractionBox["d", "a"]}]]}]]],
 "     or     ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{
      FractionBox["a", "c"], " ", "z"}], " ", "+", " ", 
     FractionBox["b", "c"]}], 
    RowBox[{"z", " ", "+", " ", 
     FractionBox["d", "c"]}]]}]]],
 ",  \n\nrespectively.  Doing so permits us to determine a unique a bilinear \
transformation if three distinct image values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["z", "1"], ")"}]}], "=", 
   SubscriptBox["w", "1"]}]]],
 ",   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["z", "2"], ")"}]}], "=", 
   SubscriptBox["w", "2"]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     SubscriptBox["z", "3"], ")"}]}], "=", 
   SubscriptBox["w", "3"]}]]],
 "  are specified.  To determine such a mapping, we can conveniently use an \
implicit formula involving ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 10.3 (The Implicit Formula).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 " There exists a unique bilinear transformation that maps three distinct \
points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", 
   SubscriptBox["z", "2"], ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["z", "3"]}]}]]],
 "  onto three distinct points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], ",", 
   SubscriptBox["w", "2"], ",", 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    SubscriptBox["w", "3"]}]}]]],
 ", respectively.  An implicit formula for the mapping is given by the \
equation    \n\n",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " "}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.3 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 10.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Construct the bilinear transformation  ",
 StyleBox["w = S(z)",
  FontFamily->"Courier New"],
 "  that maps the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "\[ImaginaryI]"}]}]]],
 "  onto the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "1"}]}]]],
 ",  respectively."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{556, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We use the implicit formula, Equation ",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 ", and write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
    RowBox[{" ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"(", 
         RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], ")"}]}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"0", " ", "-", " ", "1"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"0", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ")"}], " "}]]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "+", " ", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}]}]], " ", "=", " ", 
   
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "+", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"0", " ", "-", " ", "1"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"0", " ", "+", " ", "1"}], ")"}]}]]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "+", " ", "\[ImaginaryI]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}]}]], " ", "=", " ", 
   
   FractionBox[
    RowBox[{"  ", 
     RowBox[{"w", " ", "+", " ", "1"}]}], 
    RowBox[{
     RowBox[{"-", " ", "w"}], " ", "+", " ", "1"}]]}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 "Expanding this equation, collecting terms involving w and zw on the left \
and then simplify.\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"1", " ", "+", " ", "\[ImaginaryI]"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"w", " ", "+", " ", "1"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"z", " ", "+", " ", "\[ImaginaryI]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", " ", "w"}], " ", "+", " ", "1"}], ")"}], " "}]}]]],
 "  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", " ", "\[ImaginaryI]"}], ")"}], "z", " ", "w"}], " ", 
   "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", " ", "\[ImaginaryI]"}], ")"}], "w"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", " ", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", "  ", 
   RowBox[{"(", 
    RowBox[{"1", "-", " ", "\[ImaginaryI]"}], ")"}]}], "\[IndentingNewLine]", 
 
  RowBox[{"=", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", " ", "\[ImaginaryI]"}], ")"}], "z", " ", 
     "w"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", " ", "\[ImaginaryI]"}], ")"}], "w"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", " ", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", "  ", 
    
    RowBox[{"(", 
     RowBox[{"1", "+", " ", "\[ImaginaryI]"}], ")"}]}]}]}]],
 "   \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"z", " ", "w"}], "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "z", " ", "w"}], " ", "+", " ", "w", "-", 
    " ", 
    RowBox[{"\[ImaginaryI]", " ", "w"}], "+", "z", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "z"}], " ", "+", "1", "-", " ", 
    "\[ImaginaryI]"}], "  "}], "\[IndentingNewLine]", 
  RowBox[{"=", "\[IndentingNewLine]", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "z"}], " ", "w"}], "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "z", " ", "w"}], " ", "-", "w", "-", " ", 
    RowBox[{"\[ImaginaryI]", " ", "w"}], "+", "z", "-", " ", 
    RowBox[{"\[ImaginaryI]", " ", "z"}], " ", "+", " ", "1", "+", " ", 
    "\[ImaginaryI]"}]}]}]],
 "  \n\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "z", " ", "w"}], " ", "+", " ", 
     RowBox[{"2", " ", "w"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "z"}], " ", "+", " ", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"      ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"z", " ", "w"}], " ", "+", " ", "w"}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "\[ImaginaryI]"}], " ", "z"}], " ", "+", " ", 
      "\[ImaginaryI]"}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{
    RowBox[{"w", 
     RowBox[{"(", 
      RowBox[{"1", "+", "z"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "Therefore the desired bilinear transformation is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"1", " ", "-", " ", "z"}], ")"}]}], 
     RowBox[{"1", " ", "+", " ", "z"}]]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"formula", ",", "solset", ",", "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"formula", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "3"]}], ")"}]}], 
       RowBox[{" ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "3"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "2"], "-", 
           SubscriptBox["z", "1"]}], ")"}]}]}]], "\[Equal]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"w", "-", 
          SubscriptBox["w", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["w", "2"], "-", 
          SubscriptBox["w", "3"]}], ")"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"w", "-", 
           SubscriptBox["w", "3"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["w", "2"], "-", 
           SubscriptBox["w", "1"]}], ")"}]}], " "}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"-", "\[ImaginaryI]"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", "1"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", "\[ImaginaryI]"}], ";"}], "   ", 
   "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"-", "1"}]}], ";"}], "   ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", "0"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute the values\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "w"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496058578125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Check our work and by looking at the images of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", " ", 
   SubscriptBox["z", "2"], ",", " ", 
   SubscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39949606315625*^9},
 AspectRatioFixed->True],

Cell["\<\
To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}]}], 
       RowBox[{"1", "+", "z"}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.04", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.04", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.04", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.025", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "2"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The points \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<,\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<in the z-plane.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The images \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = S[z] = \>\"", " ", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399496066828125*^9, 3.39949612640625*^9}, {
  3.400146687484375*^9, 3.40014668771875*^9}, {3.40040122058225*^9, 
  3.400401248316625*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"Iden", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], " ", "=", " ", "z"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{"0.000005", ",", "0.999995", ",", "0.11111"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "   ", "\n",
    
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"S", "   ", ",", 
       RowBox[{"{", 
        RowBox[{"0.000005", ",", "0.999995", ",", "0.11111"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The points \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<in the z-plane.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "1.0"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The images \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = S[z] = \>\"", " ", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399496131703125*^9, 3.39949614028125*^9}, {
  3.400146693734375*^9, 3.400146693953125*^9}, {3.40040125395725*^9, 
  3.400401271301*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 10.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the bilinear transformation  ",
 StyleBox["w = S(z)",
  FontFamily->"Courier New"],
 "  that maps the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "2"}]}], ",", "  ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}], ",", "  ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 "  onto the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], ",", "  ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "1"}]}]]],
 ",  respectively."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{462, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Again, we use the implicit formula, Equation ",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 ", and write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], " ", "-", " ", 
       "0"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "0"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}], " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"0", " ", "-", "1"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", "1"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"0", " ", "-", " ", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}]}], ")"}], " "}]]}]]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "+", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", "z", " ", ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", "\[ImaginaryI]", " ", "+", "2"}], ")"}]}]], 
   " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "+", " ", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "1"}], ")"}], 
     RowBox[{"(", "1", ")"}], " "}]]}]]],
 "  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", "+", " ", "2", " "}], 
     RowBox[{"z", " "}]], 
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], " ", "-", " ", "\[ImaginaryI]"}], 
     RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}]]}], "  ", "=", " ", 
   FractionBox[
    RowBox[{"1", " ", "+", " ", "w", " "}], 
    RowBox[{"1", " ", "-", " ", "w", "  "}]]}]]],
 "    "
}], "Text"],

Cell[TextData[{
 "Using the fact that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], " ", "-", " ", "\[ImaginaryI]"}], 
    RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}]], "  ", "=", " ", 
   FractionBox["1", "\[ImaginaryI]"]}]]],
 ",  we rewrite this equation as  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"z", " ", "+", " ", "2", " "}], 
    RowBox[{"\[ImaginaryI]", " ", "z", " "}]], " ", "=", " ", 
   FractionBox[
    RowBox[{"1", " ", "+", " ", "w", " "}], 
    RowBox[{"1", " ", "-", " ", "w", "  "}]]}]]],
 ".    "
}], "Text"],

Cell[TextData[{
 "We now expand the equation and obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"z", " ", "+", " ", "2"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "w"}], ")"}]}], "   ", "=", "   ", 
      RowBox[{"\[ImaginaryI]", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", "w"}], " ", ")"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"z", " ", "+", " ", "2", " ", "-", " ", 
       RowBox[{"z", " ", "w"}], " ", "-", " ", 
       RowBox[{"2", " ", "w"}]}], "   ", "=", "   ", 
      RowBox[{
       RowBox[{"\[ImaginaryI]", " ", "z"}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "z", " ", "w"}]}]}], 
     "\[IndentingNewLine]"}], "\[IndentingNewLine]", "           ", 
    RowBox[{
     RowBox[{
      RowBox[{"z", " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", "z"}], " ", "+", " ", "2"}], "    ", "=",
       "   ", 
      RowBox[{
       RowBox[{"z", " ", "w"}], "  ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "z", " ", "w"}], " ", "+", " ", 
       RowBox[{"2", " ", "w"}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", "         ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
       "2"}], "   ", "=", "   ", 
      RowBox[{"w", 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", " ", "z"}], " ", "+", " ", "2"}], " ", 
        ")"}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    "         ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], " ", "z"}], " ", "+", " ",
       "2"}], "   ", "=", "   ", 
     RowBox[{"w", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", 
        " ", "2"}], ")"}], " "}]}]}]}]]],
 "  \n\nwhich can be solved for w in terms of z, giving the desired solution  \
\n \n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
      "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
      "2"}]]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"w", "=", 
     RowBox[{"z", "=", "0"}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"formula", ",", "solset", ",", "S"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"formula", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "3"]}], ")"}]}], 
       RowBox[{" ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"z", "-", 
           SubscriptBox["z", "3"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["z", "2"], "-", 
           SubscriptBox["z", "1"]}], ")"}]}]}]], "\[Equal]", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"w", "-", 
          SubscriptBox["w", "1"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["w", "2"], "-", 
          SubscriptBox["w", "3"]}], ")"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"w", "-", 
           SubscriptBox["w", "3"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["w", "2"], "-", 
           SubscriptBox["w", "1"]}], ")"}]}], " "}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"-", "2"}]}], ";"}], "   ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"-", "1"}]}], ";"}], "   ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", "0"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute the values\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "w"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496194078125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "This is equivalent to the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
     "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
     "2"}]]}]]],
 ",  and can be verified by a computation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< = \>\"", ",", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
        "2"}], 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
        "2"}]]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"S", "[", "z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
         "2"}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
         "2"}]], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Are they equal ?  \>\"", ",", 
      RowBox[{
       RowBox[{"S", "[", "z", "]"}], " ", "\[Equal]", " ", 
       RowBox[{"Simplify", "[", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
          "2"}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
          "2"}]], "]"}]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496198421875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Check our work and look at the images of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", " ", 
   SubscriptBox["z", "2"], ",", " ", 
   SubscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,  \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      "\"\<, S[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496201515625*^9},
 AspectRatioFixed->True],

Cell["\<\
To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "Iden", ",", "wplane", ",", "z", ",", "zplane"}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "z_", "]"}], "=", "z"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], "=", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "+", "z"}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "+", "z"}]]}]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "0", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1"}], ",", "0.1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "0", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"S", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "0", ",", "0.125"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", "2.0"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.1"}], ",", "0.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "0", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The points \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<in the z-plane.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.2"}], ",", "1.2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.4"}], ",", "2.0"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The image points \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<, \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"], ",", "\"\<,\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping w = S[z] = \>\"", " ", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39949620503125*^9, 3.39949623228125*^9}, {
  3.400146699734375*^9, 3.4001467*^9}, {3.400401279316625*^9, 
  3.4004012996135*^9}, {3.400401377222875*^9, 3.40040138045725*^9}}]
}, Closed]],

Cell[TextData[{
 "\tWe let ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " be a region in the z plane that is bounded by either a circle or a \
straight line ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ".  We further let ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   SubscriptBox["z", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["z", "3"]}]}]]],
 " be three distinct points that lie on ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " and have the property that an observer moving along ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " from ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["z", "3"]}]]],
 " through ",
 Cell[BoxData[
  SubscriptBox["z", "2"]]],
 " finds the region ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " to be on the left.  If ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is a circle and ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is the interior of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 ", then we say that ",
 StyleBox["C",
  FontFamily->"Courier New"],
 " is positively oriented.  Conversely, the ordered triple ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["z", "1"], 
    StyleBox[",",
     FontFamily->"Times New Roman"], 
    SubscriptBox["z", "2"], 
    StyleBox[",",
     FontFamily->"Times New Roman"], 
    SubscriptBox["z", "3"]}], ")"}]]],
 " uniquely determines a region that lies to the left of ",
 StyleBox["C",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 "\tWe let ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " be a region in the w plane that is bounded by either a circle of a \
straight line ",
 StyleBox["K",
  FontFamily->"Courier New"],
 ".  We further let ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   SubscriptBox["w", "2"], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["w", "3"]}]}]]],
 " be three distinct points that lie on ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " such that an observer moving along ",
 StyleBox["K",
  FontFamily->"Courier New"],
 " from ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], 
   StyleBox["to",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   SubscriptBox["w", "3"]}]]],
 " through ",
 Cell[BoxData[
  SubscriptBox["w", "2"]]],
 " finds the region ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " to be on the left.  Because a bilinear transformation is a conformal \
mapping that maps the class of circles and straight lines onto itself, we can \
use the implicit formula to construct a bilinear transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]],
  AspectRatioFixed->True],
 " that is a one-to-one mapping of ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto ",
 StyleBox["G",
  FontFamily->"Courier New"],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 10.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}]]}]}]],
  AspectRatioFixed->True],
 "  maps the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", " ", 
   RowBox[{"|", 
    RowBox[{"z", "+", "1"}], "|", 
    RowBox[{"<", " ", "1"}]}]}]]],
 "  one-to-one and onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{590, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For convenience, we choose the ordered triple  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "2"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], "  ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 ", which gives the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", " ", 
    RowBox[{"|", 
     RowBox[{"z", "+", "1"}], "|"}]}], "=", " ", "1"}]]],
 "  a positive orientation and the disk ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " a left orientation.  From Example 10.5, the corresponding image points are \
  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "1"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}]}], "  ", "=", "  ", 
      RowBox[{"-", "1"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "2"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "2"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ",
       "0"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     StyleBox["  ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  "}]], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "3"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "3"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", "0", ")"}]}], "  ", "=", "  ", 
      RowBox[{"1", 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["  ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "  \n\n\nBecause the ordered triple of points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "1"}]}]]],
 ",  lie on the ",
 StyleBox["u",
  FontFamily->"Courier"],
 " axis, it follows that the image of circle ",
 StyleBox["C",
  FontFamily->"Courier"],
 " is the ",
 StyleBox["u",
  FontFamily->"Courier"],
 " axis.  The points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "1"}]}]]],
 " give the upper half-plane  ",
 Cell[BoxData[
  RowBox[{"G", ":", 
   RowBox[{
    RowBox[{"Im", 
     RowBox[{"(", "w", ")"}]}], ">", "0"}]}]]],
 "  a left orientation.  Therefore ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}]]}]}]],
  AspectRatioFixed->True],
 " maps the disk ",
 StyleBox["D",
  FontFamily->"Courier"],
 " onto the upper half-plane ",
 StyleBox["G",
  FontFamily->"Courier"],
 ".  To check our work, we choose a point ",
 Cell[BoxData[
  SubscriptBox["z", "0"]]],
 " that lies in ",
 StyleBox["D",
  FontFamily->"Courier"],
 " and find the half-plane in which its image, ",
 Cell[BoxData[
  SubscriptBox["w", "0"]]],
 " lies.  The choice  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "0"], "=", 
   RowBox[{"-", "1"}]}]]],
 "  yields  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "0"], " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", 
      SubscriptBox["z", "0"], ")"}]}], "=", "\[ImaginaryI]"}]}]]],
 ".  Hence the upper half-plane is the correct image.  This situation is \
illustrated in Figure 10.6. "
}], "Text"],

Cell[TextData[{
 "\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{573, 240},
  ImageMargins->0],
 StyleBox[" \n\n\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.6",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1006.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The bilinear mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}]]}]}]],
  AspectRatioFixed->True],
 "."
}], "Text",
 CellChangeTimes->{{3.39949663634375*^9, 3.399496650484375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}], "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
     "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
     "2"}]]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{"w", "=", 
      RowBox[{"W", "=", 
       RowBox[{"z", "=", 
        RowBox[{"Z", "=", "0"}]}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"S", ",", "w", ",", "W", ",", "z", ",", "Z"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "d", ",", "g", ",", "solset", ",", "w1", ",", "w2", ",", "w3", ",", "z1",
       ",", "z2", ",", "z3"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
       "2"}], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
       "2"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496244625*^9},
 AspectRatioFixed->True],

Cell["To show  S(z)  is one-to-one, find the inverse function.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", "\[Equal]", 
        RowBox[{"S", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \!\(\*SuperscriptBox[\(S\), \(-1\)]\)[w] = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3994962495625*^9},
 AspectRatioFixed->True],

Cell["\<\
To show  S(z)  is onto, use the method of oriented points on the boundary \
curve.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", 
     RowBox[{"-", "2"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "1"}], "-", "\[ImaginaryI]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", 
     RowBox[{"-", "1"}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", "0"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", "1"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,          \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", 
      "\"\<,       S[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496251828125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore, the image of the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "+", "1"}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  is the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 ".  In order to graph the image of the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "+", "1"}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  under  w = S(z)  we use the change of variable and find the image of  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  under  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"g", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"S", 
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"S", "[", 
      RowBox[{"z", "-", "1"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<         S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g(z) = S(z-1) = \>\"", ",", 
      RowBox[{"g", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39949625409375*^9},
 AspectRatioFixed->True],

Cell["\<\
To plot the graph we use the shifted disk and the functions d[z] = z-1  and  \
g[z] = S[z-1].\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"S", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"z", "-", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
       "2"}], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], " ", "+", " ", 
       "2"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"S", "[", 
      RowBox[{"z", "-", "1"}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"d", "   ", ",", 
       RowBox[{"{", 
        RowBox[{"0.00005", ",", "0.99995", ",", "0.1111"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.05"}], ",", "0.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "1", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"1", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"PolarMap", "[", 
      RowBox[{"g", "   ", ",", 
       RowBox[{"{", 
        RowBox[{"0.00005", ",", "0.99995", ",", "0.1111"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"2", "\[Pi]"}], ",", 
         FractionBox["\[Pi]", "12"]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "0.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The disk |z+1| < 1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image half-plane Im[w] > 0,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399496256625*^9, 3.399496282953125*^9}, {
  3.4001467059375*^9, 3.400146706171875*^9}, {3.400401308926*^9, 
  3.40040132958225*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that the transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}], 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}], "z"}], "  ", "+", "  ", 
      "2"}]]}]}]],
  AspectRatioFixed->True],
 "  maps the disk  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "+", "1"}], "|", 
   RowBox[{"<", " ", "1"}]}]]],
 "  one-to-one and onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Corollary 10.1 (The Implicit Formula with a point at Infinity).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  In equation ",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 " the point at infinity can be introduced as one of the prescribed points in \
either the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane or the  ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 10.1 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Case 1.",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "3"], "=", "\[Infinity]"}]]],
 ",  then we can write  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["z", "2"], " ", "-", " ", 
      SubscriptBox["z", "3"]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"z", " ", "-", " ", 
      SubscriptBox["z", "3"]}], ")"}]], " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", "\[Infinity]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[Infinity]"}], ")"}]], " ", "=", " ", 
    "1"}]}]]],
 "  and substitute this expression into Equation ",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", "\[Infinity]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[Infinity]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " "}]]}]]],
 "  which can be rewritten as ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", "\[Infinity]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "\[Infinity]"}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " "}]]}]]],
 "  and simplifies to obtain  \n\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"z", " ", "-", " ", 
     SubscriptBox["z", "1"], " "}], 
    RowBox[{
     SubscriptBox["z", "2"], " ", "-", " ", 
     SubscriptBox["z", "1"]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " "}]]}]]],
 ".  \n\n",
 StyleBox["Case 2.",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], "=", "\[Infinity]"}]]],
 ",  then we can write  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{" ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "3"]}], ")"}]}], 
    RowBox[{"(", 
     RowBox[{"w", " ", "-", " ", 
      SubscriptBox["w", "3"]}], ")"}]], " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{" ", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["w", "2"], " ", "-", " ", "\[Infinity]"}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "\[Infinity]"}], ")"}]], " ", "=", " ", 
    "1"}]}]]],
 " and substitute this expression into Equation ",
 StyleBox["(10-18)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", "\[Infinity]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "\[Infinity]"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " "}]]}]]],
 " which can be rewritten as   ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", "\[Infinity]"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["w", "2"], " ", "-", " ", 
       SubscriptBox["w", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"w", " ", "-", " ", "\[Infinity]"}], ")"}]}]]}]]],
 " and simplifies to obtain\n\n",
 StyleBox["(10-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", 
       SubscriptBox["z", "3"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["z", "2"], " ", "-", " ", 
       SubscriptBox["z", "1"]}], ")"}]}]], " ", "=", " ", 
   FractionBox[
    RowBox[{"w", " ", "-", " ", 
     SubscriptBox["w", "1"]}], 
    RowBox[{
     SubscriptBox["w", "2"], " ", "-", " ", 
     SubscriptBox["w", "1"]}]]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "      Equation ",
 StyleBox["(10-21)",
  FontColor->RGBColor[0, 0, 1]],
 " is sometimes used to map the crescent-shaped region that lies between the \
tangent circles onto an infinite strip."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 10.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the bilinear transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " that maps the crescent-shaped region that lies inside the disk ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  onto a horizontal strip."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{695, 175},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  For convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "4"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 "  and the image values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]]],
 ",  respectively.  The ordered triple  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "4"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]]],
 "  gives the circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"C", ":", 
    RowBox[{"|", 
     RowBox[{"z", "-", "2"}], "|"}]}], "=", " ", "2"}]]],
 "  a positive orientation and the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  has a left orientation.  The image points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]]],
 "  all lie on the extended ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis, and they determine a left orientation for the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  Therefore we can use the second implicit formula (Equation ",
 StyleBox["(10-21)",
  FontColor->RGBColor[0, 0, 1]],
 ") to write  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "4"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}], " ", "-", " ", "0"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "0"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}], " ", "-", " ", "4"}], ")"}]}]], " ", 
   "=", " ", 
   FractionBox[
    RowBox[{"w", " ", "-", " ", "0"}], 
    RowBox[{"1", " ", "-", " ", "0"}]]}]]],
 ",  \n\nwhich determines a mapping of the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", 
    RowBox[{"z", "-", "2"}], "|", 
    RowBox[{"<", " ", "2"}]}]}]]],
 "  onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 ".  Use the fact that ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{" ", 
     RowBox[{"2", " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], 
    RowBox[{
     RowBox[{"-", "2"}], " ", "+", " ", 
     RowBox[{"2", "\[ImaginaryI]"}]}]], " ", "=", 
   RowBox[{"-", "\[ImaginaryI]"}]}]]],
 "  to simplify the preceding equation and get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"z", " ", "-", " ", "4"}], 
     RowBox[{"z", " "}]], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"2", " ", "+", " ", 
       RowBox[{"2", "\[ImaginaryI]"}]}]}], 
     RowBox[{
      RowBox[{"-", "2"}], " ", "+", " ", 
      RowBox[{"2", "\[ImaginaryI]"}]}]]}], " ", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"z", " ", "-", " ", "4"}], 
      RowBox[{"z", " "}]], 
     RowBox[{"(", 
      RowBox[{"-", "\[ImaginaryI]"}], ")"}]}], " ", "=", "  ", 
    FractionBox["w", "1"]}]}]]],
 " \n\nwhich can be written in the form  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]z"}], " ", "+", " ", "\[ImaginaryI]4"}], 
     RowBox[{"z", " "}]]}]}]],
  AspectRatioFixed->True],
 ". "
}], "Text"],

Cell[TextData[{
 "A straightforward calculation shows that the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "4"], "=", 
    RowBox[{"1", "-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "5"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["z", "6"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]]],
 "  are mapped onto the points  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "4"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "5"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "5"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", "2", ")"}]}], "  ", "=", "  ", "\[ImaginaryI]"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     StyleBox["  ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  "}]], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["w", "6"], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       SubscriptBox["z", "6"], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", 
        RowBox[{"1", "+", "\[ImaginaryI]"}], ")"}]}], "  ", "=", "  ", 
      RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]]],
 "  \n\nrespectively.  The points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "5"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], " ", 
   RowBox[{
    SubscriptBox["w", "6"], "=", 
    RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]]],
 "  lie on the horizontal line  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "1"}]]],
 "  in the upper half-plane.  Therefore the crescent-shaped region is mapped \
onto the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"0", "<", 
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], "<", "1"}]]],
 ",  as shown in Figure 10.7. "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{702, 243},
  ImageMargins->0],
 StyleBox["\n\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.7",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1007.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]z"}], " ", "+", " ", "\[ImaginaryI]4"}], 
     RowBox[{"z", " "}]]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.39949666084375*^9, 3.39949667153125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.7.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter three points and their images and solve for  w = S(z).  For \
convenience we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", "4"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "2"], "=", 
    RowBox[{"2", "+", 
     RowBox[{"2", "\[ImaginaryI]"}]}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "3"], "=", "0"}]}]],
  AspectRatioFixed->True],
 "  which are mapped onto the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "2"], "=", "1"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "3"], "=", "\[Infinity]"}]}]],
  AspectRatioFixed->True],
 ",  respectively.  In this case we remove the terms involving  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "3"], " ", "=", " ", "\[Infinity]"}]],
  AspectRatioFixed->True],
 ",  in the implicit formula, because this implies that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["w", "2"], " ", "-", " ", 
     SubscriptBox["w", "3"]}], 
    RowBox[{"w", " ", "-", " ", 
     SubscriptBox["w", "3"]}]], "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["w", "2"], " ", "-", " ", "\[Infinity]"}], 
     RowBox[{"w", " ", "-", " ", "\[Infinity]"}]], "=", "1"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{"T", "=", 
      RowBox[{"w", "=", 
       RowBox[{"W", "=", 
        RowBox[{"z", "=", 
         RowBox[{"Z", "=", "0"}]}]}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{"S", ",", "T", ",", "w", ",", "W", ",", "z", ",", "Z"}], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"formula", ",", "Iden", ",", "solset"}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"formula", " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "1"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "3"]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["z", "3"]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["z", "2"], "-", 
          SubscriptBox["z", "1"]}], ")"}]}]], " ", "\[Equal]", " ", 
      FractionBox[
       RowBox[{"w", "-", 
        SubscriptBox["w", "1"]}], 
       RowBox[{
        SubscriptBox["w", "2"], "-", 
        SubscriptBox["w", "1"]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "1"], " ", "=", " ", "4"}], ";"}], "   ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["z", "2"], " ", "=", " ", 
     RowBox[{"2", "+", 
      RowBox[{"2", "\[ImaginaryI]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
     SubscriptBox["z", "3"], " ", "=", " ", "0"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "1"], " ", "=", " ", "0"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "2"], " ", "=", " ", "1"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "3"], " ", "=", " ", "\[Infinity]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Substitute the values\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,   \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "formula", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "w"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "z_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S(z) = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496295609375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Check our work and look at the images of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], ",", " ", 
   SubscriptBox["z", "2"], ",", " ", 
   SubscriptBox["z", "3"]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["z", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(z\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["z", "2"], ",", 
      "\"\<,    \!\(\*SubscriptBox[\(z\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["z", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(1\)]\) = \>\"", ",", 
      SubscriptBox["w", "1"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(2\)]\) = \>\"", ",", 
      SubscriptBox["w", "2"], ",", 
      "\"\<,        \!\(\*SubscriptBox[\(w\), \(3\)]\) = \>\"", ",", 
      SubscriptBox["w", "3"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(2\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", 
      "\"\<,     S[\!\(\*SubscriptBox[\(z\), \(3\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496300015625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "And we need to look at the images of three more points;   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "4"], "=", 
    RowBox[{"1", "-", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "5"], "=", "2"}], ",", " ", 
   RowBox[{
    SubscriptBox["z", "6"], "=", 
    RowBox[{"1", "+", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "4"], "=", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "5"], "=", "\[ImaginaryI]"}], ",", " ", 
   RowBox[{
    SubscriptBox["w", "6"], "=", 
    RowBox[{"2", "+", "\[ImaginaryI]"}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["z", "4"], " ", "=", "  ", 
     RowBox[{"1", "-", "\[ImaginaryI]"}]}], ";", "     ", 
    RowBox[{
     SubscriptBox["z", "5"], " ", "=", " ", "2"}], ";", "    ", 
    RowBox[{
     SubscriptBox["z", "6"], " ", "=", " ", 
     RowBox[{"1", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["w", "4"], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "\[ImaginaryI]"}]}], ";", "   ", 
    RowBox[{
     SubscriptBox["w", "5"], " ", "=", " ", "\[ImaginaryI]"}], ";", "   ", 
    RowBox[{
     SubscriptBox["w", "6"], " ", "=", " ", 
     RowBox[{"2", "+", "\[ImaginaryI]"}]}], ";"}], " ", "\[IndentingNewLine]",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(z\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["z", "4"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(z\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["z", "5"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(z\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["z", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(w\), \(4\)]\) = \>\"", ",", 
      SubscriptBox["w", "4"], ",", 
      "\"\<,      \!\(\*SubscriptBox[\(w\), \(5\)]\) = \>\"", ",", 
      SubscriptBox["w", "5"], ",", 
      "\"\<,       \!\(\*SubscriptBox[\(w\), \(6\)]\) = \>\"", ",", 
      SubscriptBox["w", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\!\(\*SubscriptBox[\(z\), \(4\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "4"], "]"}], ",", 
      "\"\<,   S[\!\(\*SubscriptBox[\(z\), \(5\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "5"], "]"}], ",", 
      "\"\<,    S[\!\(\*SubscriptBox[\(z\), \(6\)]\)] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "6"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496301984375*^9},
 AspectRatioFixed->True],

Cell["\<\
To illustrate the mapping, consider the inverse image of the horizontal \
strip.  We will need to use the inverse function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{"formula", ",", "z"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", "w_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = S[z] = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = T[w] = \>\"", ",", 
      RowBox[{"T", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[S[z]] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"S", "[", "z", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"T", "[", 
        RowBox[{"S", "[", "z", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[T[w]] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"T", "[", "w", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{"S", "[", 
        RowBox[{"T", "[", "w", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399496304640625*^9},
 AspectRatioFixed->True],

Cell["Now plot the graphs using T[w] then the identity map.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"set", " ", "=", "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"wdots", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Magenta", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Cyan", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Green", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
          RowBox[{"Point", "[", 
           SubscriptBox["set", 
            RowBox[{"\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]], 
           "]"}]}], "}"}]}], "}"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"T", "   ", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9"}], ",", "9", ",", "0.3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005", ",", "0.995", ",", "0.09"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.05"}], ",", "4.05"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"2", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"wplane", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"Iden", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "9"}], ",", "9", ",", "0.9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005", ",", "0.995", ",", "0.09"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        FractionBox["1", "3"]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Range", "[", 
           RowBox[{
            RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"zplane", ",", "zdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "4.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The the crescent-shaped region that lies inside\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<the disk |z-2| < 2 and outside the circle |z-1| = 1.\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"wplane", ",", "wdots", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "3"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "9"}], ",", "9", ",", "3"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image is the horizontal strip 0 < v < 1,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping  w = \>\"", ",", 
      RowBox[{"S", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "1"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "1"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,      S[\>\"", ",", 
      SubscriptBox["z", "2"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "2"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "3"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "3"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[\>\"", ",", 
      SubscriptBox["z", "4"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "4"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "5"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "5"], "]"}], ",", "\[IndentingNewLine]", 
      "\"\<,   S[\>\"", ",", 
      SubscriptBox["z", "6"], ",", "\"\<] = \>\"", ",", 
      RowBox[{"S", "[", 
       SubscriptBox["z", "6"], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399496306859375*^9, 3.39949635546875*^9}, {
  3.400146711921875*^9, 3.400146712140625*^9}, {3.40040133864475*^9, 
  3.400401370879125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We have constructed the transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", "[", "z", "]"}], "=", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "+", " ", "z"}], ")"}]}], "z"]}]}]}]]],
 "  and see that the image of the crescent-shaped region that lies inside the \
disk ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{"z", "-", "2"}], "|", 
   RowBox[{"<", " ", "2"}]}]]],
 "  and outside the circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"z", "-", "1"}], "|"}], "=", " ", "1"}]]],
 "  is the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"0", "<", "v", "<", "1"}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Lines of Flux",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tIn electronics, images of certain lines represent lines of electric \
flux, which comprise the trajectory of an electron placed in an electrical \
field. Consider the bilinear transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox["z", 
     RowBox[{"z", " ", "-", " ", "a"}]]}]}]]],
 "    and    ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"a", " ", "w"}], 
     RowBox[{"w", " ", "-", " ", "1"}]]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.40014703696875*^9, 3.40014704184375*^9}}],

Cell[TextData[{
 "\tThe half rays  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Arg", 
     RowBox[{"(", "w", ")"}]}], "=", "c"}], "}"}]]],
 ",  where c is a constant, that meet at the origin ",
 Cell[BoxData[
  RowBox[{"w", "=", "0"}]]],
 " represent the lines of electric flux produced by a source located at ",
 Cell[BoxData[
  RowBox[{"w", "=", "0"}]]],
 "  (and a sink at ",
 Cell[BoxData[
  RowBox[{"w", "=", "\[Infinity]"}]]],
 " ).  The preimage of this family of lines is a family of circles that pass \
through the points ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"0", " ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "z"}], "=", "a"}]}]]],
 ".  We visualize these circles as the lines of electric flux from one point \
charge to another.  The limiting case as a is called a dipole and is \
discussed in Exercise 6, Section 10.11.  The graphs for ",
 Cell[BoxData[
  RowBox[{"a", "=", "1"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{"a", "=", "0.5"}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{"a", "=", "0.1"}]]],
 " are shown in Figure 10.8."
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{716, 425},
  ImageMargins->0],
 StyleBox[" \n\n\t\t\t",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Figure 10.8",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1008.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Images of ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Arg", 
    RowBox[{"(", "w", ")"}]}], "=", "c"}]]],
 " under the mapping ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["S", 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"a", " ", "w"}], 
     RowBox[{"w", " ", "-", " ", "1"}]]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399496678859375*^9, 3.39949668903125*^9}, {
  3.40014698075*^9, 3.400146982359375*^9}, {3.400147057203125*^9, 
  3.400147057203125*^9}}],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.html"],
    None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Smith Chart",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SmithChartBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399493393515625*^9, 3.3994933940625*^9}}]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{973, 642},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[69765, 1881, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[194077, 5211, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 310238, 7870}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 145, 3, 29, "Text"],
Cell[1053, 37, 3484, 108, 265, "Text"],
Cell[4540, 147, 2845, 99, 264, "Text"],
Cell[7388, 248, 3125, 104, 319, "Text"],
Cell[10516, 354, 1498, 44, 108, "Text"],
Cell[12017, 400, 740, 29, 38, "Text",
 Evaluatable->False],
Cell[12760, 431, 13071, 217, 189, "Text",
 Evaluatable->False],
Cell[25834, 650, 1976, 70, 139, "Text"],
Cell[27813, 722, 792, 28, 92, "Text"],
Cell[28608, 752, 2770, 96, 364, "Text"],
Cell[31381, 850, 1685, 58, 101, "Text"],
Cell[33069, 910, 1234, 43, 47, "Text"],
Cell[34306, 955, 15471, 280, 352, "Text"],
Cell[CellGroupData[{
Cell[49802, 1239, 110, 2, 29, "Text"],
Cell[49915, 1243, 333, 13, 38, "Text"],
Cell[50251, 1258, 940, 29, 168, "Input"],
Cell[51194, 1289, 118, 2, 29, "Text",
 Evaluatable->False],
Cell[51315, 1293, 1130, 31, 195, "Input"],
Cell[52448, 1326, 93, 2, 29, "Text",
 Evaluatable->False],
Cell[52544, 1330, 1335, 33, 181, "Input"],
Cell[53882, 1365, 1068, 35, 54, "Text",
 Evaluatable->False],
Cell[54953, 1402, 754, 24, 112, "Input"],
Cell[55710, 1428, 323, 7, 47, "Text",
 Evaluatable->False],
Cell[56036, 1437, 273, 8, 72, "Input"],
Cell[56312, 1447, 429, 13, 65, "Text",
 Evaluatable->False],
Cell[56744, 1462, 3640, 104, 360, "Input"],
Cell[60387, 1568, 588, 22, 38, "Text"],
Cell[60978, 1592, 3980, 109, 292, "Input"]
}, Closed]],
Cell[64973, 1704, 2215, 80, 156, "Text"],
Cell[67191, 1786, 2231, 79, 94, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[69447, 1869, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[69591, 1875, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[69765, 1881, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[70114, 1893, 808, 30, 26, "Text",
 Evaluatable->False],
Cell[70925, 1925, 7723, 129, 189, "Text",
 Evaluatable->False],
Cell[78651, 2056, 2487, 85, 176, "Text"],
Cell[81141, 2143, 3322, 101, 382, "Text"],
Cell[84466, 2246, 399, 13, 74, "Text"],
Cell[CellGroupData[{
Cell[84890, 2263, 110, 2, 29, "Text"],
Cell[85003, 2267, 90, 2, 29, "Text"],
Cell[85096, 2271, 4295, 125, 490, "Input"],
Cell[89394, 2398, 266, 10, 29, "Text",
 Evaluatable->False],
Cell[89663, 2410, 1384, 32, 112, "Input"],
Cell[91050, 2444, 132, 4, 29, "Text",
 Evaluatable->False],
Cell[91185, 2450, 9739, 266, 684, "Input"],
Cell[100927, 2718, 6603, 179, 532, "Input"]
}, Closed]],
Cell[107545, 2900, 839, 32, 26, "Text",
 Evaluatable->False],
Cell[108387, 2934, 7008, 118, 189, "Text",
 Evaluatable->False],
Cell[115398, 3054, 2383, 85, 170, "Text"],
Cell[117784, 3141, 596, 19, 79, "Text"],
Cell[118383, 3162, 2629, 80, 303, "Text"],
Cell[CellGroupData[{
Cell[121037, 3246, 110, 2, 29, "Text"],
Cell[121150, 3250, 90, 2, 29, "Text"],
Cell[121243, 3254, 4326, 126, 490, "Input"],
Cell[125572, 3382, 529, 20, 42, "Text",
 Evaluatable->False],
Cell[126104, 3404, 1793, 55, 188, "Input"],
Cell[127900, 3461, 260, 10, 29, "Text",
 Evaluatable->False],
Cell[128163, 3473, 1375, 32, 112, "Input"],
Cell[129541, 3507, 132, 4, 29, "Text",
 Evaluatable->False],
Cell[129676, 3513, 10135, 280, 691, "Input"]
}, Closed]],
Cell[139826, 3796, 2056, 79, 62, "Text"],
Cell[141885, 3877, 1814, 67, 65, "Text"],
Cell[143702, 3946, 916, 36, 42, "Text",
 Evaluatable->False],
Cell[144621, 3984, 13335, 221, 189, "Text",
 Evaluatable->False],
Cell[157959, 4207, 6348, 229, 281, "Text"],
Cell[164310, 4438, 12060, 218, 306, "Text"],
Cell[CellGroupData[{
Cell[176395, 4660, 110, 2, 29, "Text"],
Cell[176508, 4664, 457, 19, 42, "Text"],
Cell[176968, 4685, 1186, 37, 151, "Input"],
Cell[178157, 4724, 118, 2, 29, "Text",
 Evaluatable->False],
Cell[178278, 4728, 825, 23, 135, "Input"],
Cell[179106, 4753, 152, 5, 29, "Text",
 Evaluatable->False],
Cell[179261, 4760, 2166, 57, 232, "Input"],
Cell[181430, 4819, 819, 31, 47, "Text",
 Evaluatable->False],
Cell[182252, 4852, 617, 18, 112, "Input"],
Cell[182872, 4872, 163, 5, 29, "Text",
 Evaluatable->False],
Cell[183038, 4879, 9389, 263, 744, "Input"],
Cell[192430, 5144, 794, 31, 42, "Text",
 Evaluatable->False]
}, Closed]],
Cell[193239, 5178, 493, 17, 44, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[193757, 5199, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[193901, 5205, 173, 4, 29, "Text",
 Evaluatable->False],
Cell[194077, 5211, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[194426, 5223, 7265, 256, 236, "Text"],
Cell[201694, 5481, 221, 6, 29, "Text"],
Cell[201918, 5489, 633, 23, 47, "Text",
 Evaluatable->False],
Cell[202554, 5514, 7565, 127, 189, "Text",
 Evaluatable->False],
Cell[210122, 5643, 4426, 157, 297, "Text"],
Cell[214551, 5802, 4474, 154, 196, "Text"],
Cell[219028, 5958, 17116, 295, 300, "Text"],
Cell[CellGroupData[{
Cell[236169, 6257, 110, 2, 29, "Text"],
Cell[236282, 6261, 1369, 46, 56, "Text",
 Evaluatable->False],
Cell[237654, 6309, 4079, 119, 490, "Input"],
Cell[241736, 6430, 260, 10, 29, "Text",
 Evaluatable->False],
Cell[241999, 6442, 1387, 32, 112, "Input"],
Cell[243389, 6476, 804, 29, 29, "Text",
 Evaluatable->False],
Cell[244196, 6507, 2098, 52, 152, "Input"],
Cell[246297, 6561, 193, 5, 29, "Text",
 Evaluatable->False],
Cell[246493, 6568, 1724, 49, 232, "Input"],
Cell[248220, 6619, 115, 2, 29, "Text",
 Evaluatable->False],
Cell[248338, 6623, 10574, 288, 701, "Input"],
Cell[258915, 6913, 750, 27, 55, "Text"]
}, Closed]],
Cell[259680, 6943, 870, 27, 123, "Text"],
Cell[260553, 6972, 1289, 42, 65, "Text"],
Cell[261845, 7016, 45321, 761, 485, "Text"],
Cell[307169, 7779, 435, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[307629, 7791, 407, 7, 29, "Text"],
Cell[308039, 7800, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[308186, 7807, 281, 7, 26, "Text"],
Cell[308470, 7816, 281, 7, 29, "Text"],
Cell[308754, 7825, 299, 7, 29, "Text"],
Cell[309056, 7834, 265, 6, 29, "Text"],
Cell[309324, 7842, 249, 5, 29, "Text"],
Cell[309576, 7849, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
