(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     35503,       1102]
NotebookOptionsPosition[     33181,       1020]
NotebookOutlinePosition[     33895,       1050]
CellTagsIndexPosition[     33822,       1045]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 11  Applications of Harmonic Functions",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["11.1  Preliminaries",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 StyleBox["Overview",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tA wide variety of problems in engineering and physics involve \
harmonic functions, which are the real or imaginary part of an analytic \
function.  The standard applications are two dimensional steady state \
temperatures, electrostatics, fluid flow and complex potentials.  The \
techniques of conformal mapping and integral representation can be used to \
construct a harmonic function with prescribed boundary values.  Noteworthy \
methods include Poisson's integral formulae; the Joukowski transformation; \
and Schwarz-Christoffel transformation.  Modern computer software is capable \
of implemeting these complex analysis methods."
}], "Text"],

Cell[TextData[{
 "\tIn most applications involving harmonic functions, a ",
 StyleBox[ButtonBox["harmonic function",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/HarmonicFunction.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " that takes on prescribed values along certain contours must be found.  In \
presenting the material in this chapter, we assume that you are familiar with \
the material covered in Sections 2.5, 3.3, 5.1, and 5.2.  If you aren't, \
please review it before proceeding. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 11.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the function ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " that is harmonic in the vertical strip ",
 Cell[BoxData[
  RowBox[{"a", "<", 
   RowBox[{"Re", 
    RowBox[{"(", "z", ")"}]}], "<", "b"}]]],
 " and takes on the boundary values\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"a", ",", "y"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["U", "1"]}]]],
 "    for all  ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ",  and\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"b", ",", "y"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["U", "2"]}]]],
 "    for all  ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", \n\nalong the vertical lines  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"a", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "x"}], "=", "b"}]}]]],
 ",  respectively."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzt3E1O20AUwPFJ7JSQSOVDfHRhqhyBSj0DXXXVE0QICRYIBNl0lbCh7R2q
LjhHV71GD2P8xqNJ4rxBiXDiQfpH2PP0ZmJ+npk40sTy1+Ho8uJ6OLo6Hw6+
3A1vL6/O7wdnN3dFKmkZ0zo1xvwbGInzInS7vPjLP8lOMnHFP6ToCPPAR22J
2hIlEqUS7Si1HYkSid6H3mtrd5Xa1EdH/n/0StIvW9h32ki2IyW3peT2lVxP
ye0Ej5fO5YrX3vJND5Wm/dVOqqvkgoKO793aT0WzrTg+20quDqxNaQPd9XPq
Q5Cz4uxaSlUds2XbvTi2odm1kHaj8tOf/LGPej7a81HfR7vz7RIlVzmem8ur
XmMepXiSA3RnEotn8k7pi07NuTTy4zVrXhgSN2BjKaZX8Mp7/yi5cizNg1JV
1yHslCy/ZnzlidI4e3Vu2i3u5brluxS2UuvStt6lH4vPxm/X9FsRy5bZfZkz
f3O7ZXbvcvlnu2V2X+b+5+WW2X1o5MID0DBs4ocwjYETuCSBAAECBAgQIECA
AAECBAgQIEBsDDGSovLLSSVqmnivI7p6OomY3FfSubLgWEhP1ux1L+e9lsJW
Btbwtt/ElNB+GYpiPkw/ZdOfRKKARXENAgECBAgQIECAAAECBAgQIECAaBox
kSKexa+xjohiPeklW/PLnG+155q2RfYBiOKiAAIECBAgQIAAAQIECBAgQIAA
0TSCGzs3SI72xs6Al9s5X+Xldk4QIECAAAECBAgQIECAAAECBIiYEWMpZh46
2TAn2icpLv+AzI0va67z8Z9qty80rfPhn/PdPvFdbNdmZ59va5uu8aHdpvUM
LZSsJA==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{304, 194},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.1",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1101.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Level curves of the harmonic function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["U", "1"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["U", "2"], "-", 
       SubscriptBox["U", "1"]}], 
      RowBox[{"b", "-", "a"}]], 
     RowBox[{"(", 
      RowBox[{"x", "-", "a"}], ")"}]}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Solution.  Intuition suggests that we should seek a solution that takes on \
constant values along the vertical lines of the form ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   SubscriptBox["x", "0"]}]]],
 " and that ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " be a function of ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " alone; that is,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{"P", 
    RowBox[{"(", "x", ")"}]}]}]]],
 ",    for  ",
 Cell[BoxData[
  RowBox[{"a", "\[LessEqual]", "x", "\[LessEqual]", "b"}]]],
 "  and for all ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ".\n\nLaplace's equation,  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["u", "xx"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["u", "yy"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}], " ", "=", " ", "0"}]]],
 ",  implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"P", "''"}], 
    RowBox[{"(", "x", ")"}]}], "=", "0"}]]],
 ",  which implies  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"P", 
    RowBox[{"(", "x", ")"}]}], "=", 
   RowBox[{
    RowBox[{"m", " ", "x"}], " ", "+", " ", "c"}]}]]],
 ",  where ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["c",
  FontFamily->"Courier New"],
 " are constants.  The stated boundary conditions  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"a", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"P", 
     RowBox[{"(", "a", ")"}]}], " ", "=", " ", 
    SubscriptBox["U", "1"]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"b", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"P", 
     RowBox[{"(", "b", ")"}]}], " ", "=", " ", 
    SubscriptBox["U", "2"]}]}]]],
 "  lead to the solution  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["U", "1"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["U", "2"], "-", 
       SubscriptBox["U", "1"]}], 
      RowBox[{"b", "-", "a"}]], 
     RowBox[{"(", 
      RowBox[{"x", "-", "a"}], ")"}]}]}]}]]],
 ".  \n\nThe level curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "constant"}]]],
 "  are vertical lines as indicated in Figure 11.1. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "A specific example of the general case.  Find the function ",
 StyleBox["u(x,y)",
  FontFamily->"Courier New"],
 " that is harmonic in the vertical strip ",
 Cell[BoxData[
  RowBox[{"1", "<", "x", "<", "2"}]]],
 " and takes on the boundary values \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"1", ",", "y"}], ")"}]}], " ", "=", " ", "6"}]]],
 "    for all  ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ",  and\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"2", ",", "y"}], ")"}]}], " ", "=", " ", "1"}]]],
 "    for all  ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", \n\nalong the vertical lines  ",
 Cell[BoxData[
  RowBox[{"x", "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "x"}], "=", "2"}]}]]],
 ",  respectively. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Applications involving similar formulas are found in Example 11.14 and \
Example 11.18.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "   ", "=", " ", "1"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"b", "   ", "=", " ", "2"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "1"], " ", "=", " ", "6"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "2"], " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["U", "1"], " ", "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["U", "2"], " ", "-", " ", 
         SubscriptBox["U", "1"]}], 
        RowBox[{"b", "-", "a"}]], 
       RowBox[{"(", 
        RowBox[{"x", "-", "a"}], ")"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
      "}"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "10"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Contour plot for  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = c\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399538792890625*^9, 3.399538800875*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the function ",
 Cell[BoxData[
  RowBox[{"\[CapitalPsi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " that is harmonic in the sector  ",
 Cell[BoxData[
  RowBox[{"0", "<", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}], "<", "\[Alpha]"}]]],
 " and takes on the boundary values \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "0"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["C", "1"]}]]],
 "   for  x > 0,\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["C", "2"]}]]],
 "   for all points on the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Alpha]"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{399, 194},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.2",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1102.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Level curves of the harmonic function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["C", "2"], "-", 
       SubscriptBox["C", "1"]}], "\[Alpha]"], "Arg", " ", "z"}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution.  Recalling that the function  ",
 Cell[BoxData[
  RowBox[{"Arg", " ", "z"}]]],
 "  is harmonic and takes on constant values along rays emanating from the \
origin, we see that a solution has the form  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{"a", " ", "+", " ", 
    RowBox[{"b", " ", "Arg", " ", "z"}]}]}]]],
 ",  \n\nwhere ",
 StyleBox["a",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["b",
  FontFamily->"Courier New"],
 " are constants.  The boundary conditions lead to  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["C", "1"], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["C", "2"], "-", 
       SubscriptBox["C", "1"]}], "\[Alpha]"], "Arg", " ", "z"}]}]}]]],
 ".  \n\nThe level curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "constant"}]]],
 "  are rays emanating from the origin as indicated in Figure 11.2. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "A specific example of the general case. Find the function ",
 Cell[BoxData[
  RowBox[{"\[CapitalPsi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " that is harmonic in the sector ",
 Cell[BoxData[
  RowBox[{"0", "<", 
   RowBox[{"Arg", 
    RowBox[{"(", "z", ")"}]}], "<", 
   FractionBox[
    RowBox[{"2", "\[Pi]"}], "3"]}]]],
 " and takes on the boundary values \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "0"}], ")"}]}], " ", "=", " ", "1"}]]],
 "   for  x > 0,\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "9"}]]],
 "   for all points on the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "0"}], ",", 
   RowBox[{"\[Theta]", "=", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "3"]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "   ", "=", " ", 
     FractionBox[
      RowBox[{"2", "\[Pi]"}], "3"]}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "1"], " ", "=", " ", "1"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "2"], " ", "=", " ", "9"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["c", "1"], " ", "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["c", "2"], " ", "-", " ", 
         SubscriptBox["c", "1"]}], "a"], " ", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", 
       "9"}], "}"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.0001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2", "3"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Contour plot for  u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<for  0 < Arg(z) <\!\(\*FractionBox[\(\(\\\ \)\(2  \[Pi]\)\), \(3\)]\
\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = c\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399538810359375*^9, 3.399538813515625*^9}, {
  3.400152019234375*^9, 3.4001520195625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the function ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " that is harmonic in the annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "<"}], "|", "z", "|", 
   RowBox[{"<", " ", "R"}]}]]],
 "  and takes on the boundary values  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["K", "1"]}]]],
 "   when  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"|", "z", "|"}], " ", "=", "1"}]}]]],
 ",  and  \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   SubscriptBox["K", "2"]}]]],
 "   when  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"|", "z", "|"}], " ", "=", "R"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{304, 194},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.3",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1103.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Level curves of the harmonic function\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["K", "1"], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["K", "2"], "-", 
        SubscriptBox["K", "1"]}], 
       RowBox[{"ln", " ", "R"}]], "ln"}]}], "|", "z", "|"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Solution.  This problem is a companion to the one in Example 11.2.  Here we \
use the fact that  ",
 Cell[BoxData[
  RowBox[{"ln", "|", "z", "|"}]]],
 "  is a harmonic function, for all  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  The solution is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["K", "1"], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["K", "2"], "-", 
        SubscriptBox["K", "1"]}], 
       RowBox[{"ln", " ", "R"}]], "ln"}]}], "|", "z", "|"}]}]]],
 ",   \n\nand the level curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", "constant"}]]],
 "  are concentric circles, as illustrated in Figure 11.3. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[{
 "A specific example of the general case.  Find the function ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " that is harmonic in the annulus  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "<"}], "|", "z", "|", 
   RowBox[{"<", " ", "4"}]}]]],
 "  and takes on the boundary values \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "1"}]]],
 "   when  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"|", "z", "|"}], " ", "=", "1"}]}]]],
 ",  and  \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "6"}]]],
 "   when  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"|", "z", "|"}], " ", "=", "4"}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Applications involving similar formulas will be found in Example 11.19.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"R", "   ", "=", " ", "4"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "1"], " ", "=", " ", "1"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "2"], " ", "=", " ", "6"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x_", ",", " ", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["k", "1"], " ", "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["k", "2"], " ", "-", " ", 
         SubscriptBox["k", "1"]}], ")"}], 
       FractionBox[
        RowBox[{"Log", "[", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]], "]"}], 
        RowBox[{"Log", "[", "R", "]"}]]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
      "}"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4.2"}], ",", "4.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "4.2"}], ",", "4.2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Contour plot for u[x,y] = \>\"", ",", 
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\< = c\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399538823546875*^9, 3.399538825515625*^9}, {
  3.400152026078125*^9, 3.400152026359375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399538780828125*^9, 3.3995387809375*^9}}]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{962, 632},
WindowMargins->{{1, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 33712, 1038}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 134, 2, 29, "Text"],
Cell[1042, 36, 107, 2, 29, "Text"],
Cell[1152, 40, 752, 13, 119, "Text"],
Cell[1907, 55, 632, 14, 47, "Text",
 Evaluatable->False],
Cell[2542, 71, 1256, 48, 119, "Text",
 Evaluatable->False],
Cell[3801, 121, 1030, 20, 208, "Text",
 Evaluatable->False],
Cell[4834, 143, 733, 26, 37, "Text"],
Cell[5570, 171, 2601, 100, 219, "Text"],
Cell[CellGroupData[{
Cell[8196, 275, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[8356, 281, 1124, 41, 119, "Text",
 Evaluatable->False],
Cell[9483, 324, 111, 3, 29, "Text"],
Cell[9597, 329, 2263, 66, 286, "Input"]
}, Closed]],
Cell[11875, 398, 967, 36, 80, "Text",
 Evaluatable->False],
Cell[12845, 436, 3628, 62, 208, "Text",
 Evaluatable->False],
Cell[16476, 500, 685, 23, 37, "Text"],
Cell[17164, 525, 1214, 39, 181, "Text"],
Cell[CellGroupData[{
Cell[18403, 568, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[18563, 574, 956, 35, 95, "Text",
 Evaluatable->False],
Cell[19522, 611, 2492, 73, 326, "Input"]
}, Closed]],
Cell[22029, 687, 1027, 41, 80, "Text",
 Evaluatable->False],
Cell[23059, 730, 3112, 54, 208, "Text",
 Evaluatable->False],
Cell[26174, 786, 742, 25, 38, "Text"],
Cell[26919, 813, 921, 30, 110, "Text"],
Cell[CellGroupData[{
Cell[27865, 847, 157, 4, 29, "Text",
 Evaluatable->False],
Cell[28025, 853, 937, 36, 83, "Text",
 Evaluatable->False],
Cell[28965, 891, 95, 2, 29, "Text"],
Cell[29063, 895, 2395, 70, 285, "Input"]
}, Closed]],
Cell[31473, 968, 281, 7, 26, "Text"],
Cell[31757, 977, 281, 7, 29, "Text"],
Cell[32041, 986, 276, 7, 29, "Text"],
Cell[32320, 995, 284, 7, 29, "Text"],
Cell[32607, 1004, 249, 5, 29, "Text"],
Cell[32859, 1011, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
