(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    318699,       9001]
NotebookOptionsPosition[    310711,       8765]
NotebookOutlinePosition[    311515,       8798]
CellTagsIndexPosition[    311441,       8793]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.4  Two-Dimensional Mathematical Models",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tWe now consider problems involving steady state heat flow, \
electrostatics, and ideal fluid flow that can be solved with conformal \
mapping techniques.  Conformal mapping transforms a region in which the \
problem is posed to one in which the solution is easy to obtain.  As our \
solutions involve only two independent variables, ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", we first mention a basic assumption needed for the validity of the \
model."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tThe physical problems we just mentioned are real-world applications and \
involve solutions in three-dimensional Cartesian space.  Such problems \
generally would involve the Laplacian in three variables and the divergence \
and curl of three-dimensional vector functions.  Since complex analysis \
involves only ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ", we consider the special case in which the solution does not vary with the \
coordinate along the axis perpendicular to the ",
 StyleBox["xy",
  FontFamily->"Courier New"],
 " plane.  For steady state heat flow and electrostatics, this assumption \
means that the temperature, ",
 StyleBox["T",
  FontFamily->"Courier New"],
 ", or the potential, ",
 StyleBox["V",
  FontFamily->"Courier New"],
 ", varies only with ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 ".  Thus for the flow of ideal fluids, the fluid motion is the same in any \
plane that is parallel to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane.  Curves drawn in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane are to be interpreted as cross sections that correspond to infinite \
cylinders perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane.  An infinite cylinder is the limiting case of a \"long\" physical \
cylinder, so the mathematical model that we present is valid provided the \
three-dimensional problem involves a physical cylinder long enough that the \
effects at the ends can be reasonably neglected."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIn Section 11.1 and Section 11.2 we learned how to obtain solutions  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  for harmonic functions.  For applications it is important to consider the \
family of level curves  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SubscriptBox["K", "1"],
      FontSize->14], ":", "  ", 
     RowBox[{
      StyleBox[
       SubscriptBox["K", "1"],
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["a",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["real",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["constant",
       FontFamily->"Times New Roman"]}]}]}], "}"}]]],
 "  and the conjugate harmonic function  ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and its family of level curves  ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SubscriptBox["K", "2"],
      FontSize->14], ":", "  ", 
     RowBox[{
      StyleBox[
       SubscriptBox["K", "2"],
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["a",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["real",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["constant",
       FontFamily->"Times New Roman"]}]}]}], "}"}]]],
 ".  It is convenient to introduce the terminology complex potential for the \
analytic function   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[CurlyPhi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ".  The following result regarding the orthogonality of the above mentioned \
families of level curves will be use in developing the ideas concerning the \
physical applications."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIn Sections 11.1 and 11.2, we showed how to obtain solutions ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " for harmonic functions.  For applications, we need to consider the family \
of level curves  \n\n",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SubscriptBox["K", "1"],
      FontSize->14], ":", "  ", 
     RowBox[{
      StyleBox[
       SubscriptBox["K", "1"],
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["a",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["real",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["constant",
       FontFamily->"Times New Roman"]}]}]}], "}"}]]],
 " \n\nand the conjugate harmonic function  ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and its family of level curves  \n\n",
 StyleBox["(10-17)\t\t",
  FontColor->RGBColor[0, 0, 1]],
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
    RowBox[{
     StyleBox[
      SubscriptBox["K", "2"],
      FontSize->14], ":", "  ", 
     RowBox[{
      StyleBox[
       SubscriptBox["K", "2"],
       FontSize->14], "  ", 
      StyleBox["is",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["a",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["real",
       FontFamily->"Times New Roman"], 
      StyleBox[" ",
       FontFamily->"Times New Roman"], 
      StyleBox["constant",
       FontFamily->"Times New Roman"]}]}]}], "}"}]]],
 " \n\nFor convenience, we introduce the term complex potential for the \
analytic function  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ".\n\nWe use Theorem 11.4, regarding the orthogonality of the families of \
level curves ",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(10-17)",
  FontColor->RGBColor[0, 0, 1]],
 ", to develop ideas concerning the physical applications that we will \
consider.\n"
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 11.4 (Orthogonal Families of Level Curves).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " be harmonic in a domain D.  Let ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " be the harmonic conjugate and let   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  be the complex potential.  Then the two families of level curves given in \
Equations  ",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(10-17)",
  FontColor->RGBColor[0, 0, 1]],
 ", respectively, are orthogonal in the sense that if ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"a", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "b"}], ")"}]]],
 " is a point in common to the two curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   StyleBox[
    SubscriptBox["K", "1"],
    FontSize->14]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   StyleBox[
    SubscriptBox["K", "2"],
    FontSize->14]}]]],
 ",  and  if   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}]}], " ", "\[NotEqual]", " ",
    "0", " "}]]],
 " ,  then these two curves intersect orthogonally."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.4 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Theorem 11.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 FontColor->RGBColor[0, 1, 1]],

Cell[TextData[{
 "Use the Cauchy Riemann equations  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "x"], " ", "u"}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "v"}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 "  and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "u"}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "v"}]}], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}]}]]],
 ",  which are implemented by using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  substitutions:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "u", ",", "v", ",", "CR"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"CR", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], " ", 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "\[Rule]", " ", 
        RowBox[{"-", 
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], " ", 
          RowBox[{"v", "[", 
           RowBox[{"x", ",", "y"}], "]"}]}]}]}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Using Mathematica's notation\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(u\), \(x\)]\)(x,y) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(u\), \(y\)]\)(x,y) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"u", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(v\), \(x\)]\)(x,y) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<   \!\(\*SubscriptBox[\(y\), \(y\)]\)(x,y) = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"v", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The Cauchy Riemann equations are\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) u[x,y] =  \
\!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) v[x,y]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\< \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) u[x,y] = \
-\!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) v[x,y]\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<We will use the replacements\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"TableForm", "[", "CR", "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399540961984375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The normal vectors to the curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["K", "1"], "  ", "and", "  ", "v", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "=", 
    SubscriptBox["K", "2"]}]}]]],
 "  are "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     OverscriptBox[
      SubscriptBox["N", "1"], "\[RightVector]"], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"u", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     OverscriptBox[
      SubscriptBox["N", "2"], "\[RightVector]"], " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ",", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"v", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}], "}"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\)  =  {\!\(\*SubscriptBox[\(u\), \(x\)]\)(x,y), \!\(\*SubscriptBox[\(u\), \
\(y\)]\)(x,y)}  =  \>\"", ",", 
      OverscriptBox[
       SubscriptBox["N", "1"], "\[RightVector]"]}], " ", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\
\)  =  {\!\(\*SubscriptBox[\(v\), \(x\)]\)(x,y), \!\(\*SubscriptBox[\(v\), \
\(y\)]\)(x,y)}  =  \>\"", ",", 
      OverscriptBox[
       SubscriptBox["N", "2"], "\[RightVector]"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399540967625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "We will show that  ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    SubscriptBox["N", "1"], "\[RightVector]"],
   FontSize->14]]],
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " is orthogonal to  ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    SubscriptBox["N", "2"], "\[RightVector]"],
   FontSize->14]]],
 "  by forming the dot product: "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\).\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\) = \>\
\"", ",", 
      OverscriptBox[
       SubscriptBox["N", "1"], "\[RightVector]"], ",", "\"\<.\>\"", ",", 
      OverscriptBox[
       SubscriptBox["N", "2"], "\[RightVector]"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\).\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\) = \>\
\"", ",", 
      RowBox[{
       OverscriptBox[
        SubscriptBox["N", "1"], "\[RightVector]"], ".", 
       OverscriptBox[
        SubscriptBox["N", "2"], "\[RightVector]"]}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399540971125*^9},
 AspectRatioFixed->True],

Cell["\<\
Using the Cauchy Riemann equations, this is simplified and we obtain: \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\).\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\) = \>\
\"", ",", 
      RowBox[{
       OverscriptBox[
        SubscriptBox["N", "1"], "\[RightVector]"], ".", 
       OverscriptBox[
        SubscriptBox["N", "2"], "\[RightVector]"]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Use the replacements\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       \>\"", ",", 
      RowBox[{"TableForm", "[", "CR", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"replace", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], " ", 
         RowBox[{"v", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "\[Rule]", 
        "\"\<\!\(\*SuperscriptBox[\"u\", TagBox[
RowBox[{\"(\", 
RowBox[{\"1\", \",\", \"0\"}], \")\"}],
Derivative],
MultilineFunction->None]\)[x,y]\>\""}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], " ", 
         RowBox[{"u", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], "\[Rule]", " ", 
        "\"\<(-\!\(\*SuperscriptBox[\"v\", TagBox[
RowBox[{\"(\", 
RowBox[{\"1\", \",\", \"0\"}], \")\"}],
Derivative],
MultilineFunction->None]\)[x,y])\>\""}]}], "}"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\).\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\) = \>\
\"", ",", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{
         OverscriptBox[
          SubscriptBox["N", "1"], "\[RightVector]"], ".", 
         OverscriptBox[
          SubscriptBox["N", "2"], "\[RightVector]"]}], ",", "replace"}], 
       "]"}]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Therefore\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*OverscriptBox[SubscriptBox[\(N\), \(1\)], \(\[RightVector]\)]\
\).\!\(\*OverscriptBox[SubscriptBox[\(N\), \(2\)], \(\[RightVector]\)]\) = \>\
\"", ",", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{
         OverscriptBox[
          SubscriptBox["N", "1"], "\[RightVector]"], ".", 
         OverscriptBox[
          SubscriptBox["N", "2"], "\[RightVector]"]}], ",", "CR"}], "]"}]}], 
     "]"}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{3.3995409746875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore  ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    SubscriptBox["N", "1"], "\[RightVector]"],
   FontSize->14]]],
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " is orthogonal to  ",
 Cell[BoxData[
  StyleBox[
   OverscriptBox[
    SubscriptBox["N", "2"], "\[RightVector]"],
   FontSize->14]]],
 " ."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 "\tThe complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  has many physical interpretations.  Suppose, for example, that we have \
solved a problem in steady state temperatures. Then we can obtain the \
solution to a similar problem with the same boundary conditions in \
electrostatics by interpreting the isothermals as equipotential curves and \
the heat flow lines as flux lines. This implies that heat flow and \
electrostatics correspond directly."
}], "Text"],

Cell[TextData[{
 "\tOr suppose that we have solved a fluid flow problem.  Then we can obtain \
a solution to an analogous problem in heat flow by interpreting the \
equipotentials as isothermals and streamlines as heat flow lines.  Various \
interpretations of the families of level curves given in Equations  ",
 StyleBox["(10-16)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(10-17)",
  FontColor->RGBColor[0, 0, 1]],
 " and correspondences between families are summarized in Table 11.1. "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[BoxData[GridBox[{
    {GridBox[{
       {
        RowBox[{
         StyleBox["   ",
          FontWeight->"Bold"], 
         RowBox[{
          StyleBox["Physical",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[" ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Bold",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["Phenomenon",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "   "}]}]},
       {" "}
      },
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, {True}, False}, "RowsIndexed" -> {}}], GridBox[{
       {
        RowBox[{"      ", 
         RowBox[{
          RowBox[{"\[Phi]", 
           RowBox[{"(", 
            RowBox[{"x", 
             StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontSlant->"Plain",
              FontVariations->{"StrikeThrough"->False,
              "Underline"->False},
              FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
          StyleBox["constant",
           FontSize->14], 
          StyleBox["   ",
           FontSize->14]}]}]},
       {" "}
      },
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, {True}, False}, "RowsIndexed" -> {}}], GridBox[{
       {
        RowBox[{"     ", 
         RowBox[{
          RowBox[{"\[Psi]", 
           RowBox[{"(", 
            RowBox[{
             StyleBox["x",
              FontWeight->"Plain"], 
             StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontSlant->"Plain",
              FontVariations->{"StrikeThrough"->False,
              "Underline"->False},
              FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
          StyleBox["constant",
           FontSize->14], 
          StyleBox["   ",
           FontSize->14]}]}]},
       {" "}
      },
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, {True}, False}, "RowsIndexed" -> {}}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"Heat", " ", "flow"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox["Isothermals",
       FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Heat", " ", "flow", " ", "lines"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox["Electrostatics",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Equipotential", " ", "curves"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Flux", " ", "lines"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"Fluid", " ", "flow"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox["Equipotentials",
       FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox["Streamlines",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"Gravitational", " ", "field"}],
       FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Gravitational", " ", "potential"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Lines", " ", "of", " ", "force"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox["Magnetism",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox["Potential",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Lines", " ", "of", " ", "force"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox["Diffusion",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox["Concentration",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Lines", " ", "of", " ", "flow"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     RowBox[{
      StyleBox["Elasticity",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Strain", " ", "function"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}], 
     RowBox[{
      StyleBox[
       RowBox[{"Stress", " ", "lines"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]},
    {
     StyleBox[
      RowBox[{"Current", " ", "flow"}],
      FontFamily->"Times New Roman"], 
     StyleBox["Potential",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"Lines", " ", "of", " ", "flow"}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}
   },
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}}]]]
}], "Text"],

Cell[TextData[{
 StyleBox["\t\t\t\tTable 11.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Interpretations for the level curves of ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 StyleBox["Preview of Applications",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe following is a sample of applications taken from Section 11-5  to \
Section11-11."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " at each point in the upper half-disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", ":", 
    RowBox[{"y", ">", "0"}]}], ",", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  if the temperature at points on the boundary satisfies \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "100"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{
     RowBox[{"0", "<", "\[Theta]", "<", 
      RowBox[{
       RowBox[{"\[Pi]", "   ", 
        StyleBox["on",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["the",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["upper",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["semi",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], 
       StyleBox["-",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["circle",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "1"}], "<", "x", "<", 
    RowBox[{"1", "  ", 
     StyleBox["on",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["the",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"diameter", "."}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "    "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  As discussed in Example 11.9, the transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}]}], 
      RowBox[{"1", "+", "z"}]], "  ", "=", "  ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      RowBox[{"1", "+", "x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}]}]}]]],
 " \n\nis a one-to-one conformal mapping of the half-disk ",
 StyleBox["H",
  FontFamily->"Courier New"],
 " onto the first quadrant ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", ":", " ", 
    RowBox[{"u", ">", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", ">", "0"}]}]]],
 ", and can be written as \n\n",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "y"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
       SuperscriptBox["y", "2"]}]], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "The conformal map given by Equation ",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 " gives rise to a new problem of finding the temperature ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " that satisfies the boundary conditions  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["T", "*"], 
      RowBox[{"(", 
       RowBox[{"u", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "100"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "u"}], ">", "0"}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "*"], 
     RowBox[{"(", 
      RowBox[{"0", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", "  ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "v"}], ">", 
    RowBox[{"0", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "\n\n If we use Example 11.2, the harmonic function ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " is given by  \n \n",
 StyleBox["(11-25)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["T", "*"], 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"100", " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"50", "-", "100"}], 
       RowBox[{"\[Pi]", "/", "2"}]], "Arg", 
      RowBox[{"(", 
       RowBox[{"u", "+", 
        RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{"100", " ", "-", " ", 
     RowBox[{
      FractionBox["100", "\[Pi]"], "Arctan", 
      RowBox[{"(", 
       FractionBox["v", "u"], ")"}]}]}]}]}]]],
 ".  \n\nSubstituting the expressions for u and v from Equation ",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 " into Equation ",
 StyleBox["(11-25)",
  FontColor->RGBColor[0, 0, 1]],
 " yields the desired solution:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"100", " ", "-", " ", 
    RowBox[{
     FractionBox["100", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", "y"}]], ")"}]}]}]}]]],
 ".\nThe isothermals  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "constant"}]],
  
  AspectRatioFixed->True],
 "  are circles that pass through the points \[PlusMinus]1, as shown in \
Figure 11.19. "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{364, 211},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.19",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1119.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The temperature ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"100", "-", 
    RowBox[{
     FractionBox["100", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", "y"}]], ")"}]}]}]}]]],
 " in a half-disk."
}], "Text",
 CellChangeTimes->{{3.399541011515625*^9, 3.399541040375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.16.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution via a known conformal mapping. This is similar to \
Example 11.9.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "T", ",", "U", ",", "V", ",", "x", ",", "y", ",", "w", ",", "W"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "cont"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "z"}], ")"}]}]}], 
      RowBox[{"1", " ", "+", " ", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"100", " ", "-", " ", 
      RowBox[{
       FractionBox["100", "\[Pi]"], " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["V", "U"], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u = \>\"", ",", "U"}], " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v = \>\"", ",", " ", "V"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<T[x,y] = 100 - \!\(\*FractionBox[\(100\), \(\[Pi]\)]\) \
ArcTan[\!\(\*FractionBox[\(v\), \(u\)]\)]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39954462928125*^9},
 AspectRatioFixed->True],

Cell["\<\
We can check out some of the boundary values by taking limits.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) \
T[\!\(\*FractionBox[\(-1\), \(2\)]\),y] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], "2"], ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) T[0,y] = \>\"", 
      ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) \
T[\!\(\*FractionBox[\(1\), \(2\)]\),y] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< T[\!\(\*FractionBox[SqrtBox[\(2\)], \
\(2\)]\),\!\(\*FractionBox[SqrtBox[\(2\)], \(2\)]\)] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        FractionBox[
         SqrtBox["2"], "2"], ",", 
        FractionBox[
         SqrtBox["2"], "2"]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       T[0,1] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<T[\!\(\*FractionBox[\(-\*SqrtBox[\(2\)]\), \
\(2\)]\),\!\(\*FractionBox[SqrtBox[\(2\)], \(2\)]\)] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"-", 
          SqrtBox["2"]}], "2"], ",", 
        FractionBox[
         SqrtBox["2"], "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995446328125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"50", "+", 
        RowBox[{"10", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.01", ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544636765625*^9, 3.39954463896875*^9}, {
  3.400181768546875*^9, 3.400181768921875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nHence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"100", "-", 
    FractionBox[
     RowBox[{"100", " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{"1", "-", " ", 
         SuperscriptBox["x", "2"], "-", " ", 
         SuperscriptBox["y", "2"]}], 
        RowBox[{"2", " ", "y"}]], "]"}]}], "\[Pi]"]}]}]]],
 "  is harmonic in the upper half-disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", ":", 
    RowBox[{"y", ">", "0"}]}], ",", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the electrical potential  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the disk  ",
 Cell[BoxData[
  RowBox[{"D", ":", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 "  that satisfies the boundary values\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "80"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
     RowBox[{
      RowBox[{"z", "  ", 
       StyleBox["on",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "  ", 
       SubscriptBox["C", "1"]}], "=", 
      RowBox[{"{", 
       RowBox[{"z", "=", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", ":", " ", 
         RowBox[{"0", "<", "\[Theta]", "<", 
          FractionBox["\[Pi]", "2"]}]}]}], "}"}]}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->14,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "  ", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "x"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
    RowBox[{
     RowBox[{"z", "  ", 
      StyleBox["on",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", 
      SubscriptBox["C", "2"]}], "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"z", "=", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]], " ", ":", " ", 
         RowBox[{
          FractionBox["\[Pi]", "2"], "<", "\[Theta]", "<", 
          RowBox[{"2", "\[Pi]"}]}]}]}], "}"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{350, 240},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}]]}]}]]],
 "  is a one-to-one conformal mapping of ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  with the property that ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is mapped onto the negative ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis and ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " is mapped onto the positive ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis.  The potential ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " in the upper half-plane that satisfies the new boundary values \n\n\t\t\t\
",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "80"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], "<", "0"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{"for", "   ", "u"}], ">", "0"}], ","}]]],
 "  \n\n is given by  \n \n",
 StyleBox[" (11-29)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["80", "\[Pi]"], "Arg", 
     RowBox[{"(", "w", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["80", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox["v", "u"], ")"}]}]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text"],

Cell[TextData[{
 "A straightforward calculation shows that  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", "+", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     RowBox[{
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "\[ImaginaryI]"}], 
         ")"}]}], 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "1"}], ")"}]]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "-", "1"}], ")"}]}]}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"x", "-", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"y", "-", "1"}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "-", "1", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "1", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{"x", "-", "1", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "y"}], "+", 
       SuperscriptBox["y", "2"], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1", "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"   ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox["y", "2"]}]], " ", "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "\n\nWe substitute the real and imaginary parts,  ",
 Cell[BoxData[
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{"u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"v", "=", 
   RowBox[{
    RowBox[{"v", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->14,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
      SuperscriptBox["y", "2"]}]]}]}]]],
 "  from this equation, into Equation ",
 StyleBox[" (11-29)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain the desired solution:   \n\n \t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["80", "\[Pi]"], "Arctan", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"y", "-", "1"}], ")"}], "2"], "-", "1"}]], ")"}]}]}]],
  AspectRatioFixed->True],
 ".  \n\nThe level curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPhi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", "\[Alpha]"}]],
  AspectRatioFixed->True],
 "  in the upper half-plane is a ray emanating from the origin, and the \
preimage  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->14,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "\[Alpha]"}]],
  AspectRatioFixed->True],
 "  in the unit disk is an arc of a circle that passes through the points  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "z"}], "=", "\[ImaginaryI]"}]}]]],
 ".  Several level curves are illustrated in Figure 11.38."
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{683, 296},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.38",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1138.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The potentials  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{"\[CapitalPhi]", 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->14,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399541054625*^9, 3.399541054796875*^9}, {
  3.39954108540625*^9, 3.399541113203125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.21.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution with a conformal mapping.  This example is similar to \
Example 11.8.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{"U", "=", 
      RowBox[{"v", "=", 
       RowBox[{"V", "=", 
        RowBox[{"w", "=", 
         RowBox[{"W", "=", 
          RowBox[{"x", "=", 
           RowBox[{"X", "=", 
            RowBox[{"y", "=", 
             RowBox[{"Y", "=", 
              RowBox[{"z", "=", 
               RowBox[{"Z", "=", "0"}]}]}]}]}]}]}]}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "u", ",", "U", ",", "v", ",", "V", ",", "w", ",", "W", ",", "x", ",", 
      "X", ",", "y", ",", "Y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "\[Phi]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{"z", " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", "  ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["80", "\[Pi]"], " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox["V", "U"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = u + \[ImaginaryI] v = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\[Phi][x,y] = \!\(\*FractionBox[\(80\), \(\[Pi]\)]\) \
ArcTan[\!\(\*FractionBox[\(v\), \(u\)]\)]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39954465334375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature.  For computational purposes we \
use the following formula   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FractionBox["80", "\[Pi]"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"1", " ", "-", " ", 
       SuperscriptBox["x", "2"], " ", "-", " ", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"2", " ", "x"}], " ", "+", " ", 
       SuperscriptBox["x", "2"], " ", "-", " ", 
       RowBox[{"2", " ", "y"}], " ", "+", " ", 
       SuperscriptBox["y", "2"]}]], "]"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "80"}], "\[Pi]"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "\[Pi]"}], "2"], "+", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"], "-", 
         SuperscriptBox["y", "2"]}], ",", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "x"}], "+", 
         SuperscriptBox["x", "2"], "-", 
         RowBox[{"2", " ", "y"}], "+", 
         SuperscriptBox["y", "2"]}]}], "]"}]}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      FractionBox[
       RowBox[{"-", "80"}], "\[Pi]"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "\[Pi]"}], "2"], "+", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"1", "-", 
           SuperscriptBox["x", "2"], "-", 
           SuperscriptBox["y", "2"]}], ",", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "x"}], "+", 
           SuperscriptBox["x", "2"], "-", 
           RowBox[{"2", " ", "y"}], "+", 
           SuperscriptBox["y", "2"]}]}], "]"}]}], ")"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"10", "k"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "8"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "60"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544657421875*^9, 3.39954465875*^9}, {
  3.400181774609375*^9, 3.40018177478125*^9}},
 AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "=", 
     RowBox[{"v", "=", 
      RowBox[{"w", "=", 
       RowBox[{"X", "=", 
        RowBox[{"Y", "=", 
         RowBox[{"z", "=", 
          RowBox[{"Z", "=", "0"}]}]}]}]}]}]}], ";", " ", 
    RowBox[{"Remove", "[", 
     RowBox[{
     "u", ",", "v", ",", "w", ",", "X", ",", "Y", ",", "z", ",", "Z"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "F", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", "\[ImaginaryI]"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"z", " ", "-", " ", "\[ImaginaryI]"}], ")"}]}], 
      RowBox[{"z", " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", " ", "\[Equal]", " ", 
        RowBox[{"F", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"Z", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"w", "\[Rule]", 
        RowBox[{"u", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "v"}]}]}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", 
         RowBox[{"Z", "[", 
          RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", " ", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Y", "[", 
      RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"Z", "[", 
          RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", " ", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", " ", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<z = \>\"", ",", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Z = \>\"", ",", 
      RowBox[{"Z", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<X = \>\"", ",", 
      RowBox[{"X", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Y = \>\"", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"u", ",", "v"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544663359375*^9, 3.399544676984375*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "8"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "r_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"X", "[", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}], ",", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "r_", "]"}], " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Y", "[", 
       RowBox[{
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}], ",", 
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"k", " ", "\[Pi]"}], "n"], "]"}]}]}], "]"}], "]"}]}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "r", "]"}], ",", 
          RowBox[{"y", "[", "r", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", "n", ",", "2"}], "}"}]}], "]"}], "]"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.05", ",", "40"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "r", "]"}], ",", 
          RowBox[{"y", "[", "r", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"n", "-", "1"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "0.05", ",", "40"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39954468009375*^9, 3.399544685015625*^9}, {
  3.400402703722875*^9, 3.400402712660375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the electrical potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    FractionBox["80", "\[Pi]"], " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox[
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "y"}], "+", 
       SuperscriptBox["y", "2"]}]], "]"}]}]}]]],
 "  is harmonic in the disk |z| < 1 and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We use the fact that the conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"z", "+", 
     FractionBox["1", "z"]}]}]}]]],
 "  maps the domain  ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 "  one-to-one and onto the w plane slit along the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], "\[LessEqual]", "u", "\[LessEqual]", "2"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ".  The complex potential for a uniform horizontal flow parallel to this \
slit in the w plane is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", "w"}]}]]],
 ",  \n\nwhere ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a positive real number.  The stream function for the flow in the w \
plane is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", "v"}]}]]],
 "  so that the slit lies along the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "0"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe composite function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", 
     RowBox[{"S", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 "  determines the fluid flow in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", where the complex potential is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       FractionBox["1", "z"]}], ")"}]}]}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  RowBox[{"A", ">", "0"}]]],
 ".  We can use polar coordinates to express ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 " as \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["F", "2"], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["F", "2"], 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], "  ", "=", 
     "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "+", 
        FractionBox["1", 
         RowBox[{"r", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
          RowBox[{
          "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}]]}], 
       ")"}]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox[
         RowBox[{
          RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "-", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", "cos\[Theta]"}], " ", "+", " ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "Sin", " ", "\[Theta]"}]}], ")"}],
           
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "-", " ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
           ")"}]}]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox[
         RowBox[{"r", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{"cos", " ", "\[Theta]"}], " ", "-", "  ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
           ")"}]}], 
         SuperscriptBox["r", "2"]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        FractionBox["1", "r"]}], ")"}], " ", "cos", " ", "\[Theta]"}], "   ", 
     "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "A", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]", 
      " "}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "The streamline   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"r", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[Theta]"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"r", "-", 
       FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]"}], "  ", "=", 
    "  ", "0"}]}]]],
 "  consists of the rays \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "1"}], ",", 
   RowBox[{"\[Theta]", "=", "0"}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "1"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Pi]"}]}]]],
 " \n\nalong the x axis and the curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", "-", 
    FractionBox["1", "r"]}], " ", "=", " ", "0"}]]],
 ",  which is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], " ", "=", " ", 
   RowBox[{"r", " ", "=", " ", "1"}]}]]],
 ".  Thus the unit circle can be considered as a boundary curve for the fluid \
flow."
}], "Text"],

Cell[TextData[{
 "\tThe approximation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       FractionBox["1", "z"]}], ")"}]}], "  ", "\[TildeTilde]", "  ", 
    RowBox[{"A", " ", "z"}]}]}]]],
 "  is valid for large values of z, so we can approximate the flow with a \
uniform horizontal flow having speed  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}], " ", "=", " ", 
   "A"}]]],
 "  at points that are distant from the origin.  The streamlines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  and their images  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"z", "+", 
     FractionBox["1", "z"]}]}]}]]],
 " are illustrated in Figure 11.51."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{333, 214},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.51",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1151.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Fluid flow around a circle.  "
}], "Text",
 CellChangeTimes->{{3.399540889796875*^9, 3.39954092278125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.24.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Consider the complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "z", "]"}], "=", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"z", "+", 
      FractionBox["1", "z"]}], ")"}]}]}]],
  AspectRatioFixed->True],
 " where  A  is a positive real number.  The velocity potential and stream \
function are given by  \n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       FractionBox["x", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", "\n", 
   RowBox[{
    RowBox[{"v", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"y", "-", 
        FractionBox["y", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}]]}], ")"}], "."}]}]}]}]]],
 "  \n",
 "Enter the complex potential and determine the velocity potential and stream \
function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"x", "=", 
      RowBox[{"y", "=", 
       RowBox[{"u", "=", 
        RowBox[{"v", "=", 
         RowBox[{"w", "=", 
          RowBox[{"z", "=", 
           RowBox[{"Z", "=", "0"}]}]}]}]}]}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "A", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", "z", ",", 
      "Z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "cont", ",", "f", ",", "F", ",", "g", ",", "g1", ",", "g2", ",", 
      "solset"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{"z", " ", "+", " ", 
        FractionBox["1", "z"]}], ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The  complex potential is   F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z]  =  (\>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995447056875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"0", "+", 
        RowBox[{"0.2", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "7"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39954471075*^9, 3.3995447148125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"z", "+", 
      RowBox[{
       FractionBox["1", "z"], "  ", "is", "  ", "z"}]}], "=", 
     RowBox[{
      RowBox[{"g", 
       RowBox[{"(", "w", ")"}]}], "=", " ", 
      FractionBox[
       RowBox[{"w", " ", "+", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"z", " ", "+", " ", 
      FractionBox["1", "z"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"w", "\[Equal]", 
        RowBox[{"f", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "w_", "]"}], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "0"], " ", "=", " ", 
     RowBox[{"PowerExpand", "[", 
      RowBox[{"ExpandAll", "[", 
       RowBox[{"g", "[", 
        RowBox[{"f", "[", "z", "]"}], "]"}], "]"}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "1"], " ", "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["Z", "0"], " ", ",", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["z", "2"]}], "+", 
          SuperscriptBox["z", "4"]}]], " ", "\[Rule]", " ", 
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["z", "2"]}], ")"}]}]}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "2"], " ", "=", " ", 
     RowBox[{"Together", "[", 
      SubscriptBox["Z", "1"], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "3"], "=", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Factor", ",", 
       SubscriptBox["Z", "2"]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "4"], "=", 
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["z", "2"], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "z"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "z"}], ")"}], "2"]}]]}], 
      RowBox[{"2", " ", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "5"], "=", 
     RowBox[{"PowerExpand", "[", 
      SubscriptBox["Z", "4"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["Z", "6"], "=", 
     RowBox[{"Simplify", "[", 
      SubscriptBox["Z", "5"], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[w] = \>\"", ",", 
      RowBox[{"g", "[", "w", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "0"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "1"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "2"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "3"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "4"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "5"]}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<g[f[z]] = \>\"", ",", 
      SubscriptBox["Z", "6"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[g[w]] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"g", "[", "w", "]"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[g[w]] = \>\"", ",", 
      RowBox[{"Together", "[", 
       RowBox[{"f", "[", 
        RowBox[{"g", "[", "w", "]"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995447906875*^9}],

Cell["\<\
Use conformal mapping  z = g(w)  to make an image of the flow.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "w_", "]"}], " ", "=", "  ", 
     FractionBox[
      RowBox[{"w", " ", "+", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "w_", "]"}], " ", "=", "  ", 
     FractionBox[
      RowBox[{"w", " ", "-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.2"}], ",", "3.2", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.2", ",", "0.2"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The horizontal flow in the z-plane.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"gr1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g1", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"gr2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.20001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", " ", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image flow across the complex plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<and around the unit circle |z| = 1,\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping z = g(w) = \>\"", ",", 
      RowBox[{"g1", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544892625*^9, 3.399544910765625*^9}, {
  3.400402724879125*^9, 3.4004027379885*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Use the Schwarz Christoffel formula to verify that  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
     FractionBox["1", "2"]]}]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 ".  ",
 " (Use the principal square root throughout.)"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Solution.  If we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "3"], "=", "1"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "d"}]}]]],
 ",  then the formula\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "3"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "0"}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}]}]}]],
 "\n\nwill determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"g", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the portion of the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  that lies outside the triangle with vertices  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", 
    RowBox[{"-", "d"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "d"}]}]]],
 "  as indicated in Figure 11.73(a).  If we let ",
 Cell[BoxData[
  RowBox[{"d", "\[Rule]", "0"}]]],
 ",  then  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "1"], "\[Rule]", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", 
     SubscriptBox["w", "3"]}], "\[Rule]", "0"}]}]]],
 ", and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "\[Rule]", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ".  "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{508, 123},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.73",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1173.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "   The region with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "\[Rule]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "\[Rule]", "0"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "\[Rule]", 
    RowBox[{"-", "\[Pi]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "3"], "\[Rule]", 
    FractionBox["\[Pi]", "2"]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe limiting formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"g", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " becomes    \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", "z", ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "3"]}], "/", "\[Pi]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]], 
      SuperscriptBox[
       RowBox[{"(", "z", ")"}], 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"-", "\[Pi]"}], ")"}]}], "/", "\[Pi]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], "/", "\[Pi]"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       RowBox[{"-", 
        FractionBox["1", "2"]}]], 
      SuperscriptBox[
       RowBox[{"(", "z", ")"}], "1"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"-", 
        FractionBox["1", "2"]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", "z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       RowBox[{"-", 
        FractionBox["1", "2"]}]]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", " ", 
     FractionBox["z", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]],
 "\n\nwhich will determine a mapping ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " from the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "w", ")"}]}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 " as indicated in Figure 11.73(b).  An easy integration reveals that ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 " is given by  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox["z", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}], "  ", "+", "  ", "B"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]]}], "  ", "+", "  ", "B"}]}]}]}],
  AspectRatioFixed->True],
 "  \n\nand the boundary values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", 
     RowBox[{"\[PlusMinus]", "1"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", "f", 
     RowBox[{"(", "0", ")"}]}], "=", "\[ImaginaryI]"}]}]]],
 "  lead to system of equations \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[PlusMinus]", "1"}], ")"}], "2"], "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", "+", " ", "B"}], " ", "=", " ", "0"}]],
  AspectRatioFixed->True],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"0", "-", "1"}], ")"}], 
      FractionBox["1", "2"]]}], " ", "+", " ", "B"}], " ", "=", " ", 
   "\[ImaginaryI]"}]],
  AspectRatioFixed->True],
 "\n\nthe solution is easily found to be ",
 Cell[BoxData[
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"1", "  ", "and", "  ", "B"}], "=", "0"}]}]]],
 " and the desired function  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
    FractionBox["1", "2"]]}]],
  AspectRatioFixed->True],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.27.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the formula ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{"A", " ", "z"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"z", " ", "+", " ", "1"}]], " ", 
     SqrtBox[
      RowBox[{"z", " ", "-", " ", "1"}]]}]]}]],
  AspectRatioFixed->True],
 " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "A", ",", "B", ",", "z", ",", "F"}], "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"A", " ", "z"}]}], 
      RowBox[{
       SqrtBox[
        RowBox[{"z", " ", "+", " ", "1"}]], " ", 
       SqrtBox[
        RowBox[{"z", " ", "-", " ", "1"}]]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{" ", 
          RowBox[{"A", " ", "z"}]}], 
         RowBox[{
          SqrtBox[
           RowBox[{"z", " ", "+", " ", "1"}]], " ", 
          SqrtBox[
           RowBox[{"z", " ", "-", " ", "1"}]]}]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39954493015625*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "F"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", " ", "z"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"A", " ", "z"}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544933484375*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], "\[Equal]", "0"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", "0", "]"}], "\[Equal]", "\[ImaginaryI]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{"solset", " ", "=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = B + A \!\(\*SqrtBox[\(\*SuperscriptBox[\(z\), \(2\)] - \
1\)]\)\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544936671875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z).  We will need to use two branches of \
f(z) to form the graph."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f1", ",", "f2", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", "   ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       RowBox[{"1", " ", "-", " ", 
        SuperscriptBox["z", "2"]}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "3", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "0", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<is upper half plane Im[w] > 0 slit\>\"", "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<along the line segment from w = 0 to \!\(\*SubscriptBox[\(w\), \
\(2\)]\) = \[ImaginaryI],\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544940796875*^9, 3.39954494571875*^9}, {
  3.400402746129125*^9, 3.400402755660375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We see that  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox["z", "2"], "-", "1"}]]}]]],
 "  maps the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "w", "]"}], ">", "0"}]]],
 "  slit along the line segment from  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{
     RowBox[{"0", "  ", "to", "  ", 
      SubscriptBox["w", "2"]}], "=", "\[ImaginaryI]"}]}], " "}]]],
 ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.29.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
       FractionBox["1", "2"]], "+", 
      RowBox[{"Log", 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
          FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "u"}], "\[GreaterEqual]", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 "   (see Figure 11.87)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{575, 178},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.87",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1187.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  (a) Flow over a step.\n\t\t\t\t\t(b) Flow around a blunt object."
}], "Text"],

Cell[TextData[{
 "Hint:  Set  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "1"}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 ".  In the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 "-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "0"}]}]]],
 ", and the exterior angles are  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "1"], "=", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox[
     StyleBox["\[Alpha]",
      FontSize->14], "2"], "=", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  and the formula for the derivative ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "'"}], 
   RowBox[{"(", "z", ")"}]}]]],
 " is  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "1"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "1"]}], "/", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", 
        SubscriptBox["x", "2"]}], ")"}], 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["\[Alpha]", "2"]}], "/", "\[Pi]"}]]}]}], " ", 
   "\[IndentingNewLine]"}], "\n", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", 
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}]}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox["\[Pi]", "2"]}], ")"}]}], "/", "\[Pi]"}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          FractionBox["\[Pi]", "2"], ")"}]}], "/", "\[Pi]"}]]}]}], 
    "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"               ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       RowBox[{"-", 
        FractionBox["1", "2"]}]]}]}], "\[IndentingNewLine]"}]}], "\n", 
  RowBox[{"               ", 
   RowBox[{"=", "  ", 
    RowBox[{"A", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}]}]}]}]],
 "\n"
}], "Text"],

Cell[TextData[{
 "Integrate and get  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{"B", "  ", "+", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], 
          FractionBox["1", "2"]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], 
          FractionBox["1", "2"]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"             ", 
   RowBox[{"=", "  ", 
    RowBox[{"B", "  ", "+", " ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
         FractionBox["1", "2"]], "+", 
        RowBox[{"Log", 
         RowBox[{"(", 
          RowBox[{"z", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
            FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]}]}]],
 " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", " ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
        FractionBox["1", "2"]], "+", 
       RowBox[{"Log", 
        RowBox[{"(", 
         RowBox[{"z", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["z", "2"], "-", "1"}], ")"}], 
           FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]]]
}], "Text"],

Cell[TextData[{
 "It maps the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  onto the domain in the w plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "  ", "u"}], "\[GreaterEqual]", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".  Furthermore, the image of horizontal streamlines in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane are curves in the w plane given by the parametric equation \n\n\t\t\
",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"w", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
     RowBox[{"f", 
      RowBox[{"(", 
       RowBox[{"t", "+", 
        RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}]}]}]}], "  ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t", "+", 
              RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "2"], "-", "1"}], 
          ")"}], 
         FractionBox["1", "2"]], "+", 
        RowBox[{"Log", 
         RowBox[{"(", 
          RowBox[{"t", "+", 
           RowBox[{"\[ImaginaryI]", " ", "c"}], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"t", "+", 
                 RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "2"], "-", 
              "1"}], ")"}], 
            FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", " ", 
         RowBox[{
          SuperscriptBox["t", "2"], "-", 
          SuperscriptBox["c", "2"], "-", "1", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "c", " ", "t"}]}], ")"}], 
        FractionBox["1", "2"]], "+", 
       RowBox[{"Log", 
        RowBox[{"(", 
         RowBox[{"t", "+", 
          RowBox[{"\[ImaginaryI]", " ", "c"}], "+", 
          SuperscriptBox[
           RowBox[{"(", " ", 
            RowBox[{
             SuperscriptBox["t", "2"], "-", 
             SuperscriptBox["c", "2"], "-", "1", "+", " ", 
             RowBox[{"\[ImaginaryI]", " ", "2", "c", " ", "t"}]}], ")"}], 
           FractionBox["1", "2"]]}], ")"}]}]}], ")"}]}]}]}]}]],
 "\n\nfor  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], "<", "t", "<", "\[Infinity]"}]]],
 ".  The new flow is that of a step in the bed of a deep stream and is \
illustrated in Figure 11.87(a).  The function ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is also defined for values of ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " in the lower half-plane, and the images of horizontal streamlines that lie \
above or below the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis are mapped onto streamlines that flow past a long rectangular \
obstacle, which is illustrated in Figure 11.87(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.29.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Use the Schwarz Christoffel formula, enter the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", "'"}], "[", "z", "]"}], "=", 
   FractionBox[
    RowBox[{"A", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], 
      FractionBox["1", "2"]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"z", "-", "1"}], ")"}], 
     FractionBox["1", "2"]]]}]],
  AspectRatioFixed->True],
 "  and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"A", ",", "B", ",", "z", ",", "f", ",", "f1", ",", "F"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"z", "+", "1"}], ")"}], 
        FractionBox["1", "2"]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], 
       FractionBox["1", "2"]]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"A", 
       RowBox[{"\[Integral]", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "+", "1"}], ")"}], 
           FractionBox["1", "2"]], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"z", "-", "1"}], ")"}], 
           FractionBox["1", "2"]]], 
         RowBox[{"\[DifferentialD]", "z"}]}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544971953125*^9},
 AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"A", " ", 
       RowBox[{"(", 
        RowBox[{"z", " ", "+", " ", "1"}], ")"}]}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"B", " ", "+", " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"A", " ", 
          RowBox[{"(", 
           RowBox[{"z", " ", "+", " ", "1"}], ")"}]}], 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "1"}]]], 
        RowBox[{"\[DifferentialD]", "z"}]}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f'[z] = \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = B + \[Integral] \>\"", ",", 
      RowBox[{"f1", "[", "z", "]"}], ",", "\"\< \[DifferentialD]z\>\""}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< f[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.3995449754375*^9},
 AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eq1", " ", "=", " ", 
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"-", "1"}], "]"}], " ", "\[Equal]", "  ", "0"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"eq2", " ", "=", "  ", 
     RowBox[{
      RowBox[{"F", "[", "1", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"-", "\[ImaginaryI]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eq1", ",", "eq2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq1", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "eq2", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<f[z] = B + A \!\(\*SqrtBox[\(\(-1\) + \*SuperscriptBox[\(z\), \
\(2\)]\)]\)+ A Log[z+\!\(\*SqrtBox[\(\(-1\) + \*SuperscriptBox[\(z\), \
\(2\)]\)]\)]\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.39954497834375*^9},
 AspectRatioFixed->True],

Cell["\<\
Unfortunately, the branch cuts don't work out right and we will have to do \
this one by hand.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"F", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"A", "\[Rule]", 
          FractionBox["1", "\[Pi]"]}], ",", 
         RowBox[{"B", "\[Rule]", "0"}]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399544981421875*^9},
 AspectRatioFixed->True],

Cell["\<\
Using this formula in the book we form the two branches of the function.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"f1", ",", "f2"}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f1", "[", "z_", "]"}], " ", "=", " ", 
    FractionBox[
     RowBox[{" ", 
      RowBox[{
       SqrtBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}]], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}]}], "\[Pi]"]}], 
   ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f2", "[", "z_", "]"}], " ", "=", " ", 
    FractionBox[
     RowBox[{
      RowBox[{"-", 
       SqrtBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}], ")"}]]}], "+", 
      RowBox[{"Log", "[", 
       RowBox[{"z", "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}], "\[Pi]"]}], ";"}],
   " ", "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(1\)]\)[z] = \>\"", ",", 
     RowBox[{"f1", "[", "z", "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<\!\(\*SubscriptBox[\(f\), \(2\)]\)[z] = \>\"", ",", 
     RowBox[{"f2", "[", "z", "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{3.399544985078125*^9},
 AspectRatioFixed->False],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f1", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2", ",", "0.25"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"g2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"f2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "6.00001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.25"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", " ", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"g1", ",", "g2", ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "0.5"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the domain that lies above the boundary curve consisting\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and the \
segment u=0,-1\[LessEqual]v\[LessEqual]0,\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
  3.39954555025*^9, 3.399545577421875*^9}, {3.400181779765625*^9, 
  3.400181780125*^9}, {3.400402762566625*^9, 3.400402769566625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Another version of the graph can be made with the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], " ", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[ImaginaryI]", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "+", 
     RowBox[{"Log", "[", 
      RowBox[{"z", "+", 
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}]],
  CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
   3.39954555025*^9, 3.399545577421875*^9}, {3.399545711203125*^9, 
   3.39954576765625*^9}, {3.39954589696875*^9, 3.399545938703125*^9}},
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399546018015625*^9, 3.399546038171875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", 
          SqrtBox[
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"f0", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6.0"}], ",", "2", ",", "0.25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<is the domain that lies above the boundary curve consisting\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and the \
segment u=0,-1\[LessEqual]v\[LessEqual]0,\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544987796875*^9, 3.39954499015625*^9}, {
  3.39954555025*^9, 3.399545577421875*^9}, {3.399545711203125*^9, 
  3.39954576765625*^9}, {3.39954589696875*^9, 3.399545938703125*^9}, {
  3.400181811296875*^9, 3.4001818115*^9}, {3.400402775785375*^9, 
  3.4004027779885*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f0", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}]]}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         RowBox[{"\[ImaginaryI]", 
          SqrtBox[
           RowBox[{"1", "-", 
            SuperscriptBox["z", "2"]}]]}]}], "]"}]}], "\[Pi]"]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f0", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.2"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.8", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f0", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399544998421875*^9, 3.3995450020625*^9}, {
  3.3995455884375*^9, 3.3995456408125*^9}, {3.399546136984375*^9, 
  3.399546201140625*^9}, {3.400181817015625*^9, 3.40018181753125*^9}, {
  3.400402784316625*^9, 3.400402796129125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "We have shown that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["z", "2"], "-", "1"}]], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], "-", "1"}]]}], "]"}]}], ")"}]}], "-", 
    "\[ImaginaryI]"}]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], ",", 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "u"}], "\[GreaterEqual]", "0"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".    "
}], "Text"],

Cell[TextData[{
 "We are done.\n\n",
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 "  Here is another function that produces the desired result.  The graph is \
drawn parametrically in this case."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", " ", "-", " ", 
          SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "boundary", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1.8", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image of the upper half plane Im[z] > 0,\>\"", 
     "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399546929078125*^9, 3.399546934234375*^9}, {
  3.39954700840625*^9, 3.39954700853125*^9}, {3.400181821484375*^9, 
  3.400181821734375*^9}, {3.400402803910375*^9, 3.400402822379125*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       RowBox[{"\[ImaginaryI]", 
        SqrtBox[
         RowBox[{"1", " ", "-", " ", 
          SuperscriptBox["z", "2"]}]]}], " ", "+", " ", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], " ", "-", " ", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"f", "[", 
           RowBox[{"x", "+", 
            RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}], ",", 
         RowBox[{"-", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "0.2", "k"}]}], "]"}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "2", ",", "11", ",", "2"}], "}"}]}], "]"}]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "9"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"boundary", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Red", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1.1"}], ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{
    "graph1", ",", "graph2", ",", "graph3", ",", "graph4", ",", "boundary", 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.6"}], ",", "1.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["3.2", "3"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image of the z-plane,\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under w = f[z] = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39954694025*^9, {3.39954698471875*^9, 3.399547002171875*^9}, {
   3.40018182646875*^9, 3.4001818266875*^9}, {3.40040282933225*^9, 
   3.4004028443635*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Also, we have shown that the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]"}], "2"], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["z", "2"]}]]}], "-", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"ArcSin", "[", "z", "]"}]}]}], "\[Pi]"]}]]],
 "  maps the upper half plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "\[LessEqual]", "0"}], ",", 
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"1", "  ", "and", "  ", "u"}], "\[GreaterEqual]", "0"}]}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 " and the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "v", "\[LessEqual]", "0"}]}]]],
 ".    "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.30.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 StyleBox["(Source and sink of equal strength)",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let a source and sink of unit strength be located at the points ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"+", "1"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 ", respectively.  The complex potential for a fluid flowing from the source \
at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", 
   RowBox[{"+", "1"}]}]]],
 "  to the sink at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 "  is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}], " ", "-", " ", 
     RowBox[{"log", 
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{"log", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"z", "-", "1"}], 
       RowBox[{"z", "+", "1"}]], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["CompressedBitmap", "\<\
eJztnflvFscZx4f38H1gDnMYsLENAcodoAgIJEBJD5KqSdtUvRRCWiVS06QE
Va1aVWlImqSJql5JD/WHKGnVH/pv9f9wvc+sn/GuP7Oe8e6++5pGgpfh2Znv
88x37vupO/df+sErd+6/fPfO3JP37rz20st3X5+79eq9ZVF7izFbnjHG/HfO
JO6lZWf6s7T8Z+nZ5CeRxLnfk3/aJpXK349BtmC9vwufPgHZ/Ia8vwOfPo3z
fjv5HU6I+Sp8PWgD/gY+3Up+B5OAwwpxKw7ievLbSQLuSVztxHUjDuKqQsyp
61ocxJXkt5UEPKJWPAb+5izE2/DpskKcUNflOIiLqvuMQlwCf7N+iAsa0Lku
xkGcy+p2YAzxFnx6VANeVdd58HfAD+EYuK6uR+MgTqeyJSnvVnYTZKfjYE8B
xC21sQDsAXw6qQG/ArAnIcR+P9gJgLgNshNxsMcB4mmQHY+DPaZRf0ZdBRBv
+iByVnwdZEfjYI8CxDdBdiQO9ghAPFcP7LcCYff5YR8BiG+D7JE42MMA8V2Q
HY6DPQQQ3wfZob6AXQSI50G2GAe7ABAvgGyhPOxdkM3Hwc4DxIvlYQ8CxA9B
drAvYOcAQqqfHYngc/B1rrwCKVvibUfi6iQuqkVm41TNAsSCKphRpVSoIlUd
8DEv3ubVRVn3QHlVYm1LaRMXZZBIVft9EKLguLooTfeXV0UQ/h5IKfX7AGKf
xu+suoj8feVVzYC/cyCbKa+eIEg99bBDw0aq36P0XlJXBar2+lTl/F0B2e44
9dSd3AMQu8Hf1UD1e8ur3wX+HgfZLghLzBV0pikG05q6N9VVk6qd4I8mAnbU
o34H+PtioHrKIwXqiUBS/2WQba9H/Xbwdxtk2wKzaMFwNVS9FJSpxNtsIA/T
fkNoED4NENvAn2QumRGaUhfV4MRNBSZN+TKwjHbdjBdVNlOAR+VsNs6krT5/
4u2AuihjkkmU+VOTaHaJiiCxtENZWlSTKPY1mUQsbVeTjqqLVG2NM4nmI6mE
TPqyrZt0DCgQk70zjpLmJMgo+clMqmjm4syc8CWXcHhWXcTcRJxJNNFOtQyZ
NKGGXIAQxHVNxo0Hqvq8GkwFZxxCEMMHyxtHqi6VCFuBmWOBqq4EmjkG/qgI
FSwnUckkM0mVtAtjiYA6/KEoFRg8GqhKisFAIhhT184SeJTD7TwDLgxSa0Cq
RsGfRFu87VYXVWuheBWYPhLIklRSbgwvLiodhEemU6Vnp0fNb+ETtR+hqibU
4Hl1habiSO9MJ1XUmCxqJKpGthN55n34RI0EqRoGf+Nq8FF1Ed5w/5k+qgaf
UBfV9WQ64RWY/gF8KqOKcvMpkBHDoTqoObMLPeZH4J0mFctEcVjThFaSKWJD
5SP2SomIkfohn7+WthMDZmX8JrLQiBEyRWwW/HVtZH8Mn2i4HRrZwUB/0lAO
Jd7EENmSQt1fiuJgoD+iguanBywVrwZSQY1nKBVkulTy4i1d3PF0ykPxiArq
5e23+W0p3QtkzGuBBFATTAQMBBrsBk8zSgXVo0TAAPgLJYAWGlIqfgKfaHqb
qKAohqbdqBIwFxiJUJLJAmpBiBRbH5l7gaRQ9UUmhZo+ovljUV1UtgmP8gdR
Qf2FmZw28zoEpIlAyhVkSKjBw2rIEXVRXuhWTACNF1Mq7qshoTmADAk1eEi1
HVcXGRyKR8QT3h7VZitk81MVULpTRyM02l3wN6jaTquLuk6heBRtwnMT3nYA
aH4GAWkhomoCullDJpOPNJymWqMToyMgL9BKSkrPz9VMmoMnUkIN6QT6k1LZ
TQSTWdcGEyNUL+WeaWXDTtqYX0BAWqqhdpuIopQNNThtYJcF6UKTSWeZAogq
o5f6R7TYk1L2S+WQihnV36FEtWNSVrzNqYuq9TIJRP6IqJ258mV+lcti6+ej
UPVEj9dMGawdVldoQW+XsI/occtctlEyb0BAGlxRPiJDyOBQogaVnmPqcs05
FTPS1ipLD/bazK/VEFpRC6WnBf6IHorYgJJyMkvPBvFCiaIW061Nrt7PIALK
PdSbCKWHzPTSk/MnXbEJ1ztZ3yoir4xVRN6UcjVryXtbBb0wk/x1NUdJCydz
LBPqGtOvlM9DdZROSGEot0C3OiDNhFB75Sevm/EnikwBhpuBc3tPxDWiX/36
uxn98ndZEloqvCTl/KV0vav8EUmUw/ypyiRRzdHKkpQbl1PP2V9PlaOL2tbJ
rE3pgo0IaFVnYN3IdzLfll1eTqgXkhu0U3fZz04ny84KMUxa8cRaOrX9gQpo
fq0bT0ZoEyQ8i7fj6iKL2wUm+KsfZoRK03g2UYz5nQpoRqmIkXYRIxzEjefd
xhWysqhIFn0L7ViOqXZ7Hsv8HgLS5GBnXeVr+CiydyCbHfcmQpdnqXi34pWE
dl5pFJjS8we1iWbdAotGAUdumkNIl+y815YTky5HtrT8t3zg6+ea9UkYVV12
e5r5U9a0lqsBwxQ5GVekAj2ksZb1+8HENZSN9drKcE01Y4yv3qSc5Bovu2Zq
PszGdGMZb60xgc2YeMsNAcQYm0pD+SjltRW2GL7Z5DMW5S8qGEkNouq0FWPI
mlibVdGUtVwx1VUAKwsvxeCY6BRHx59dODZ/s9pXMlvLJd5wPk3XKvfnrI5G
6pK6bG4bR/vX+7/rgQ6pwfYctvmHZU2bjIl1yfIoctnKbdSYT2RbcyV8LAbV
l/YdNduearf3LrgcIfrSIpcnfeVfP0uSYWX1PK05MhWVLTuj/mhAdFwHX2y0
e/zsdQ6rWqURP1YW0/WWhYghrXCGsxV6vn5JoSw7nTw7zj57OMb8U3PLmlrd
rKC0Mza2lSCRP54FaEOI1SgrJuYAjPm3JvdgWsDTCyYGVCZfb1jvsonkCSXg
OXXdSFy2h2j+o7HNZDD5XX0Wnb4+iWZJhS3nTbpo1r+y5SSAzlaWzutZOr0h
iE7R+4SVfaqCTpqXA/OdM7utuU3y3Ugujbue6g7znWuyr60qzO1sVu63wtxR
G69wTTqZqbAi67xVEe91Tfp3TY2K2jRbZlyELms2qbBNE4PtLnnzVxXY5r+C
ngd3/kTq+h35Ga8kSFRXznC3ww3w7OFU85EKaGJkw53KTp6nlq3GltZ0JF1n
rxyLxZ2ssxblz9nYVj5YoGlYsXTR1hyZ+LY5IiWHDQ7f3htj/qgC/4C5zNiw
k8WXEjKjER/PRrfWsaEbMdkzQXbWYJ1hcWVzBenwYSmdqJnRCte1Pr2bK3DD
ZHv/zWfTSBK2D6YX3VVefTG92Aezz+7oIy2O9nL2+T3QRRml1pULb33uTq3G
zdLXtIaR87dgY/aOmkvnsepaF3ODWLc/1Z07bmZdzC30pNQ0v97qOs5uvVXM
HNLmu7/WWx+ooKn1fTcFJPl5slfJR7YErep/tmNktb81O0begICN7jzK+TtW
sS2h5EXuS2p+f5vbtuUuzIrftlXprrbm90Smc/ImvTtMekihm/5q3xPZT7ts
R5Qet4zZh7ts+2TfdkfbP+km0XHWRvZtN7/rX0iZSj7SSfSGd/03cBYk5++U
WtDIqZDengFysx5ujN/IGaCmToG5FeG+OQVGJwJDqajmRCBdTUoTsbWcDcz5
s4nR7NlRN7zzzkZWfWLUHZNMCaBzxERA6EHqUIPHtYD0zTliOlNOVJQ5Xt93
Z8oxHv93Nw244/UpAXSvBBFA/b9Nd6/EQ3s7SOgFNJvkFpdNfJ9OmauYGr7F
6KG4RarMBWQN3+K1ie9OK3PZXvGNde6W8ZpurKvvnsBxddHVsBXcE1jLnYzj
yvoGUQruZNwkd10+ZDeH9vXtq957a3P+zoOsghtsy9z46xZ73UNlFdz4W+au
ZLeYSq+W9fCG5EZume7DW7mrubv8kLoquLv8LfgUdcO7W3mWETxNvtdkErG0
S01yUz49vAefsu1u5Ua+dtW4gPqw4LWAB77YBxRfUb9NEy6gBNdkSA9flOjh
exoNvybSh2+p1PRqTMPv4/TwdaA34VMP30Yi9T18Barh964afu2rh++aNfyC
Ww/fquvhC3w9fFdwFiAWVME+ddGS5GycKkqDQ6pgWl0VvAFJqgR2OhHQe71z
cQo21/Oe8wDxIsjm42Ap+92tB/YFXzYNh10EiOdBthgHSwWjgrd56YHi75WH
peeUvwOyyHePa3qluaY3pWt6WJuqlW+Uh6XXd58FWcHr4tQVJdivgYw2F2/k
lfbMxE0gmNsT9RTARoKdAogvgazgtXsa1BPsLbX7NIQoeLyPZt1ugiwS9oza
c11dtLpcAOGmKK+q67wfguatzmnAS+qi/vesH+JCNqC4LsZBXNSAZ7P2hEM4
80+q6zL4s30KnPO8rAGl2ErqPhYHId5llmheIa6Bv4N+CLmPQaaX3AOV1/0Q
NCf/heRXtp/IMqBsSaFpggIImdKRGxye9gektapPQDa/Ie+0dPqxTSKTHsRe
dmz5HysCHlw=\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{338, 228},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.95 (a)",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1195.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Source and sink of unit strength."
}], "Text"],

Cell[TextData[{
 "The velocity potential and stream function are  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"ln", "|", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]], "|"}]}]]],
 ",   and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"arg", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", "+", "1"}]], ")"}]}]}]]],
 ",  \n\nrespectively.  Solving for the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", "c"}]]],
 ",  we start with   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"c", "  ", "=", "  ", 
    RowBox[{
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"z", "-", "1"}], 
        RowBox[{"z", "+", "1"}]], ")"}]}], "  ", "=", "  ", 
     RowBox[{"arg", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "-", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"x", "-", 
           RowBox[{"\[ImaginaryI]", " ", "y"}], "+", "1"}], ")"}]}]], 
       ")"}]}]}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      RowBox[{"arg", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "-", "1", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "y"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          RowBox[{"2", " ", "x"}], "+", "1", "+", 
          SuperscriptBox["y", "2"], " "}]], ")"}]}], "  ", "=", "  ", 
      RowBox[{"arg", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "-", "1", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "2", "y"}]}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
          SuperscriptBox["y", "2"], " "}]], ")"}]}]}]}], " ", 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"     ", 
   RowBox[{"=", "  ", 
    RowBox[{"arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "y"}], 
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "-", "1", " "}]], ")"}]}]}]}]}]],
 "  \n\nand obtain the equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"tan", " ", "c"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "-", "1"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"2", "y"}]}]]],
 ". \n\nA straightforward calculation shows that points on the streamline \
must satisfy the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], " ", "+", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"y", "-", 
       RowBox[{"cot", " ", "c"}]}], ")"}], "2"]}], "  ", "=", "  ", 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{
     SuperscriptBox["cot", "2"], "c"}]}]}]]],
 ",  \n\nwhich is the equation of a circle with center at  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"0", ",", 
    RowBox[{"cot", " ", "c"}]}], ")"}]]],
 "  that passes through the points  ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[PlusMinus]", "1"}], ",", "0"}], ")"}]]],
 ".  Several streamlines are indicated in Figure 11.95(a)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.30.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f", ",", "F", ",", "\[Phi]", ",", "\[Psi]", ",", "W", ",", "x", ",", 
      "y", ",", "z", ",", "Z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "Z_", "]"}], " ", "=", " ", 
     RowBox[{"Log", "[", 
      FractionBox[
       RowBox[{"Z", " ", "-", " ", "1"}], 
       RowBox[{"Z", " ", "+", " ", "1"}]], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Im", "[", 
         RowBox[{"F", "[", 
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}], ",", 
       RowBox[{"2", " ", "y"}]}], "]"}]}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399547031109375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399547034640625*^9, 3.3995470364375*^9}, 
   3.400181830765625*^9}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1.5"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.50001"}], ",", 
         RowBox[{"-", "0.00001"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Contours", "\[Rule]", "11"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The stream function for the\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39954704746875*^9, 3.39954708315625*^9}, 
   3.40018183584375*^9, {3.40040285133225*^9, 3.40040286051975*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "11"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", "z", "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"Re", "[", 
       RowBox[{"F", "[", 
        RowBox[{"x", " ", "+", " ", "\[ImaginaryI]y"}], "]"}], "]"}]}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399547089390625*^9, 3.39954709103125*^9}, 
   3.400181840078125*^9}],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", "Z", "]"}], " ", "\[Equal]", " ", "W"}], ",", "Z"}],
       "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", "  ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"W", "\[Rule]", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W = F[Z] = \>\"", ",", 
      RowBox[{"F", "[", "Z", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The inverse function is:\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.399547098515625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns1", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"k", " ", "\[Pi]"}]}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns1", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns2", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"k", " ", "\[Pi]"}]}], "n"]}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"x", ",", 
             FractionBox[
              RowBox[{"k", " ", "\[Pi]"}], "n"]}], "]"}], "]"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"k", ",", "0", ",", 
          RowBox[{"2", "n"}], ",", "2"}], "}"}]}], "]"}], "]"}]}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns2", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The streamlines for the\>\"", "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399547102078125*^9, 3.3995471395*^9}, {
  3.40018184503125*^9, 3.40018184528125*^9}, {3.400402866004125*^9, 
  3.40040287483225*^9}},
 AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", " ", "=", " ", "12"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "k", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns3", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr3", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqns4", " ", "=", " ", 
     RowBox[{"N", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}], ",", 
          RowBox[{"Im", "[", 
           RowBox[{"f", "[", 
            RowBox[{"k", ",", "y"}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           FractionBox["1", "2"]}], ",", 
          RowBox[{"4", "-", 
           FractionBox["1", "2"]}], ",", "1"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr4", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", "eqns4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], "]"}]}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr3", ",", "gr4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential for the\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39954714415625*^9, 3.3995471461875*^9}, {
  3.40018185025*^9, 3.40018185046875*^9}, {3.400402881051*^9, 
  3.40040289001975*^9}},
 AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The streamlines and velocity potential for the\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<source at \!\(\*SubscriptBox[\(z\), \(1\)]\)=+1 and sink at \
\!\(\*SubscriptBox[\(z\), \(2\)]\)=-1.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = f[x,y] = \>\"", ",", 
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399547151171875*^9, 3.399547153484375*^9}, {
  3.400402895785375*^9, 3.400402897441625*^9}},
 AspectRatioFixed->True],

Cell["\<\
The streamlines and velocity potential for a fluid flowing from the source at \
 z = +1  to the sink at  z = -1.  \
\>", "Text"]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Neumann Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/NeumannProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Poisson Integral",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/PoissonIntegralBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Schwarz-Christoffel Transformation",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/SchwarzChristoffelBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Green's Function",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/GreensFunctionBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.39954094284375*^9, 3.399540943703125*^9}}]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{964, 654},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[15535, 524, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 311242, 8783}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 129, 2, 29, "Text"],
Cell[1037, 36, 594, 15, 65, "Text",
 Evaluatable->False],
Cell[1634, 53, 1691, 45, 137, "Text",
 Evaluatable->False],
Cell[3328, 100, 4107, 136, 83, "Text",
 Evaluatable->False],
Cell[7438, 238, 4296, 145, 263, "Text"],
Cell[11737, 385, 3455, 123, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[15217, 512, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[15361, 518, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[15535, 524, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[CellGroupData[{
Cell[15906, 538, 148, 3, 26, "Text"],
Cell[16057, 543, 865, 34, 31, "Text",
 Evaluatable->False],
Cell[16925, 579, 3156, 89, 292, "Input"],
Cell[20084, 670, 406, 16, 29, "Text",
 Evaluatable->False],
Cell[20493, 688, 1740, 50, 150, "Input"],
Cell[22236, 740, 449, 18, 37, "Text",
 Evaluatable->False],
Cell[22688, 760, 990, 26, 106, "Input"],
Cell[23681, 788, 140, 4, 29, "Text",
 Evaluatable->False],
Cell[23824, 794, 2780, 80, 194, "Input"],
Cell[26607, 876, 413, 18, 37, "Text",
 Evaluatable->False]
}, Closed]],
Cell[27035, 897, 1262, 35, 62, "Text"],
Cell[28300, 934, 514, 11, 65, "Text"],
Cell[28817, 947, 9417, 297, 341, "Text"],
Cell[38237, 1246, 363, 15, 29, "Text"],
Cell[38603, 1263, 214, 6, 65, "Text"],
Cell[38820, 1271, 6972, 231, 104, "Text",
 Evaluatable->False],
Cell[45795, 1504, 3616, 62, 163, "Text",
 Evaluatable->False],
Cell[49414, 1568, 3061, 99, 270, "Text"],
Cell[52478, 1669, 6208, 213, 286, "Text"],
Cell[58689, 1884, 16108, 285, 277, "Text"],
Cell[CellGroupData[{
Cell[74822, 2173, 111, 2, 29, "Text"],
Cell[74936, 2177, 112, 3, 29, "Text"],
Cell[75051, 2182, 2950, 87, 378, "Input"],
Cell[78004, 2271, 86, 2, 29, "Text"],
Cell[78093, 2275, 2509, 74, 297, "Input"],
Cell[80605, 2351, 132, 5, 29, "Text"],
Cell[80740, 2358, 1744, 51, 233, "Input"],
Cell[82487, 2411, 678, 23, 69, "Text"]
}, Closed]],
Cell[83180, 2437, 4869, 164, 93, "Text",
 Evaluatable->False],
Cell[88052, 2603, 5060, 86, 254, "Text",
 Evaluatable->False],
Cell[93115, 2691, 3455, 123, 193, "Text"],
Cell[96573, 2816, 4106, 130, 344, "Text"],
Cell[100682, 2948, 3865, 131, 201, "Text"],
Cell[104550, 3081, 26253, 453, 349, "Text"],
Cell[CellGroupData[{
Cell[130828, 3538, 111, 2, 29, "Text"],
Cell[130942, 3542, 116, 3, 29, "Text"],
Cell[131061, 3547, 3226, 95, 358, "Input"],
Cell[134290, 3644, 1206, 38, 61, "Text"],
Cell[135499, 3684, 2383, 71, 226, "Input"],
Cell[137885, 3757, 138, 4, 29, "Text",
 Evaluatable->False],
Cell[138026, 3763, 3571, 106, 330, "Input"],
Cell[141600, 3871, 3175, 95, 260, "Input"],
Cell[144778, 3968, 620, 19, 43, "Text"]
}, Closed]],
Cell[145413, 3990, 366, 12, 26, "Text",
 Evaluatable->False],
Cell[145782, 4004, 3344, 58, 163, "Text",
 Evaluatable->False],
Cell[149129, 4064, 1887, 64, 125, "Text"],
Cell[151019, 4130, 4475, 140, 351, "Text"],
Cell[155497, 4272, 1220, 43, 113, "Text"],
Cell[156720, 4317, 1998, 71, 77, "Text"],
Cell[158721, 4390, 16589, 280, 267, "Text"],
Cell[CellGroupData[{
Cell[175335, 4674, 111, 2, 29, "Text"],
Cell[175449, 4678, 1136, 40, 118, "Text",
 Evaluatable->False],
Cell[176588, 4720, 2982, 85, 286, "Input"],
Cell[179573, 4807, 223, 8, 65, "Text",
 Evaluatable->False],
Cell[179799, 4817, 1897, 54, 300, "Input"],
Cell[181699, 4873, 566, 22, 44, "Text",
 Evaluatable->False],
Cell[182268, 4897, 4486, 136, 564, "Input"],
Cell[186757, 5035, 132, 4, 29, "Text",
 Evaluatable->False],
Cell[186892, 5041, 4770, 136, 438, "Input"]
}, Closed]],
Cell[191677, 5180, 989, 36, 54, "Text",
 Evaluatable->False],
Cell[192669, 5218, 5824, 214, 202, "Text"],
Cell[198496, 5434, 6263, 105, 137, "Text",
 Evaluatable->False],
Cell[204762, 5541, 1841, 69, 35, "Text"],
Cell[206606, 5612, 5576, 196, 598, "Text"],
Cell[CellGroupData[{
Cell[212207, 5812, 111, 2, 29, "Text"],
Cell[212321, 5816, 407, 16, 42, "Text"],
Cell[212731, 5834, 1763, 54, 260, "Input"],
Cell[214497, 5890, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[214698, 5897, 1574, 48, 260, "Input"],
Cell[216275, 5947, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[216382, 5951, 1777, 52, 286, "Input"],
Cell[218162, 6005, 190, 6, 29, "Text"],
Cell[218355, 6013, 3538, 100, 288, "Input"],
Cell[221896, 6115, 583, 23, 38, "Text"]
}, Closed]],
Cell[222494, 6141, 2231, 79, 60, "Text",
 Evaluatable->False],
Cell[224728, 6222, 6760, 114, 192, "Text",
 Evaluatable->False],
Cell[231491, 6338, 359, 10, 47, "Text"],
Cell[231853, 6350, 3895, 149, 247, "Text"],
Cell[235751, 6501, 1936, 64, 237, "Text"],
Cell[237690, 6567, 4521, 142, 264, "Text"],
Cell[CellGroupData[{
Cell[242236, 6713, 111, 2, 29, "Text"],
Cell[242350, 6717, 501, 18, 57, "Text"],
Cell[242854, 6737, 1909, 58, 293, "Input"],
Cell[244766, 6797, 198, 5, 29, "Text",
 Evaluatable->False],
Cell[244967, 6804, 1616, 49, 240, "Input"],
Cell[246586, 6855, 104, 2, 29, "Text",
 Evaluatable->False],
Cell[246693, 6859, 1952, 56, 286, "Input"],
Cell[248648, 6917, 165, 5, 29, "Text",
 Evaluatable->False],
Cell[248816, 6924, 667, 21, 106, "Input"],
Cell[249486, 6947, 145, 4, 29, "Text",
 Evaluatable->False],
Cell[249634, 6953, 1493, 51, 214, "Input"],
Cell[251130, 7006, 127, 5, 29, "Text"],
Cell[251260, 7013, 2457, 67, 252, "Input"],
Cell[253720, 7082, 808, 23, 48, "Text"],
Cell[254531, 7107, 2062, 57, 242, "Input"],
Cell[256596, 7166, 4365, 128, 303, "Input"],
Cell[260964, 7296, 1072, 38, 63, "Text"],
Cell[262039, 7336, 285, 9, 65, "Text",
 Evaluatable->False],
Cell[262327, 7347, 4307, 124, 303, "Input"],
Cell[266637, 7473, 6718, 198, 383, "Input"],
Cell[273358, 7673, 1027, 34, 67, "Text"]
}, Closed]],
Cell[274400, 7710, 1285, 50, 89, "Text",
 Evaluatable->False],
Cell[275688, 7762, 4718, 80, 242, "Text"],
Cell[280409, 7844, 324, 10, 29, "Text"],
Cell[280736, 7856, 4012, 128, 494, "Text"],
Cell[CellGroupData[{
Cell[284773, 7988, 111, 2, 29, "Text"],
Cell[284887, 7992, 65, 0, 29, "Text"],
Cell[284955, 7994, 4026, 119, 451, "Input"],
Cell[288984, 8115, 139, 5, 29, "Text"],
Cell[289126, 8122, 1664, 46, 172, "Input"],
Cell[290793, 8170, 136, 5, 29, "Text"],
Cell[290932, 8177, 2857, 78, 252, "Input"],
Cell[293792, 8257, 139, 5, 29, "Text"],
Cell[293934, 8264, 1717, 47, 172, "Input"],
Cell[295654, 8313, 54, 0, 29, "Text"],
Cell[295711, 8315, 1355, 40, 172, "Input"],
Cell[297069, 8357, 134, 5, 29, "Text"],
Cell[297206, 8364, 3650, 105, 280, "Input"],
Cell[300859, 8471, 119, 3, 29, "Text"],
Cell[300981, 8476, 3419, 97, 266, "Input"],
Cell[304403, 8575, 122, 3, 29, "Text"],
Cell[304528, 8580, 1297, 35, 132, "Input"],
Cell[305828, 8617, 138, 3, 29, "Text"]
}, Closed]],
Cell[305981, 8623, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[306441, 8635, 407, 7, 29, "Text"],
Cell[306851, 8644, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[306998, 8651, 281, 7, 26, "Text"],
Cell[307282, 8660, 281, 7, 29, "Text"],
Cell[307566, 8669, 277, 7, 29, "Text"],
Cell[307846, 8678, 279, 7, 29, "Text"],
Cell[308128, 8687, 276, 7, 29, "Text"],
Cell[308407, 8696, 269, 6, 29, "Text"],
Cell[308679, 8704, 284, 7, 29, "Text"],
Cell[308966, 8713, 299, 7, 29, "Text"],
Cell[309268, 8722, 300, 7, 29, "Text"],
Cell[309571, 8731, 281, 7, 29, "Text"],
Cell[309855, 8740, 278, 7, 29, "Text"],
Cell[310136, 8749, 249, 5, 29, "Text"],
Cell[310388, 8756, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
