(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    303047,       8092]
NotebookOptionsPosition[    296827,       7911]
NotebookOutlinePosition[    297532,       7941]
CellTagsIndexPosition[    297458,       7936]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.5  Steady State Temperatures",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn the theory of heat conduction, an assumption is made that heat flows \
in the direction of decreasing temperature.  Another assumption is that the \
time rate at which heat flows across a surface area is proportional to the \
component of the temperature gradient in the direction perpendicular to the \
surface area.  If the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " does not depend on time, then the heat flow at the point ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is given by the vector  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox[
     OverscriptBox[
      StyleBox["V",
       FontWeight->"Bold"], "\[RightVector]"],
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "K"}], "  ", "grad", " ", "T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", "K"}], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", "  ", 
        SubscriptBox["T", "y"], 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}]}]}]}]]],
 ",  \n\nwhere K is the thermal conductivity of the medium and is assumed to \
be constant.  If ",
 Cell[BoxData["\[CapitalDelta]z"]],
 " denotes a straight-line segment of length ",
 Cell[BoxData["\[CapitalDelta]s"]],
 ", then the amount of heat flowing across the segment per unit of time is\n\n\
",
 StyleBox["(11-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["V",
      FontWeight->"Bold"], "\[RightVector]"],
    FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
   StyleBox[
    OverscriptBox[
     StyleBox["N",
      FontWeight->"Bold"], "\[RightVector]"],
    FontWeight->"Bold"], "\[CapitalDelta]s"}]]],
 "  \n\nwhere ",
 Cell[BoxData[
  RowBox[{" ", 
   StyleBox[
    OverscriptBox[
     StyleBox["N",
      FontWeight->"Bold"], "\[RightVector]"],
    FontWeight->"Bold"]}]]],
 " is a unit vector perpendicular to the segment. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIf we assume that no thermal energy is created or destroyed within the \
region, then the net amount of heat flowing through any small rectangle with \
sides of length ",
 Cell[BoxData["\[CapitalDelta]x"]],
 " and ",
 Cell[BoxData["\[CapitalDelta]y"]],
 " is identically zero (see Figure 11.16(a)).  This leads to the conclusion \
that ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is a harmonic function.  The following heuristic argument is often used to \
suggest that ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " satisfies Laplace's equation.  Using Expression ",
 StyleBox["(11-19)",
  FontColor->RGBColor[0, 0, 1]],
 " we find that the amount of heat flowing out of the right edge of the \
rectangle in Figure 11.16(a) is approximately  \n\n",
 StyleBox["(11-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      OverscriptBox[
       StyleBox[
        SubscriptBox["V", "1"],
        FontWeight->"Bold"], "\[RightVector]"],
      FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
     StyleBox[
      OverscriptBox[
       StyleBox[
        SubscriptBox["N", "1"],
        FontWeight->"Bold"], "\[RightVector]"],
      FontWeight->"Bold"], "\[CapitalDelta]s"}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "K"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "+", "\[CapitalDelta]x"}], 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "+", "\[CapitalDelta]x"}], 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}], 
     "\[FilledSmallCircle]", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"0", "\[ImaginaryI]"}]}], ")"}], "\[CapitalDelta]y"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{"-", " ", "K"}], " ", 
     SubscriptBox["T", "x"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", "+", "\[CapitalDelta]x"}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}], "\[CapitalDelta]y"}]}]}]}]],
 "  \n\nand the amount of heat flowing out of the left edge is  \n\n",
 StyleBox["(11-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox[
      OverscriptBox[
       StyleBox[
        SubscriptBox["V", "2"],
        FontWeight->"Bold"], "\[RightVector]"],
      FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
     StyleBox[
      OverscriptBox[
       StyleBox[
        SubscriptBox["N", "2"],
        FontWeight->"Bold"], "\[RightVector]"],
      FontWeight->"Bold"], "\[CapitalDelta]s"}], "   ", "=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "K"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}], 
     "\[FilledSmallCircle]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"0", "\[ImaginaryI]"}]}], ")"}], "\[CapitalDelta]y"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                      ", 
   RowBox[{"=", "  ", 
    RowBox[{"K", " ", 
     SubscriptBox["T", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}], "\[CapitalDelta]y"}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tIf we add the contributions in Equations ",
 StyleBox["(11-20)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(11-21)",
  FontColor->RGBColor[0, 0, 1]],
 ", the result is  \n\n",
 StyleBox["(11-22)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", "K"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "+", "\[CapitalDelta]x"}], ",", "y"}], ")"}]}], " ", 
       "-", " ", 
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}]}], "\[CapitalDelta]x"], ")"}], 
    "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}], "  ", "\[TildeTilde]", 
   "  ", 
   RowBox[{
    RowBox[{"-", "  ", "K"}], " ", 
    SubscriptBox["T", "xx"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}], "\[CapitalDelta]x", " ", 
    "\[CapitalDelta]y"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{665, 308},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.16",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1116.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Steady state temperatures."
}], "Text",
 CellChangeTimes->{{3.39954726321875*^9, 3.3995472714375*^9}}],

Cell[TextData[{
 "\tSimilarly, the contribution for the amount of heat flowing out of the top \
and bottom edges is  \n\n",
 StyleBox["(11-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", "K"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{
        SubscriptBox["T", "y"], 
        RowBox[{"(", 
         RowBox[{"x", ",", 
          RowBox[{"y", "+", "\[CapitalDelta]y"}]}], ")"}]}], " ", "-", " ", 
       RowBox[{
        SubscriptBox["T", "x"], 
        RowBox[{"(", 
         RowBox[{"x", ",", "y"}], ")"}]}]}], "\[CapitalDelta]y"], ")"}], 
    "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}], "  ", "\[TildeTilde]", 
   "  ", 
   RowBox[{
    RowBox[{"-", "  ", "K"}], " ", 
    SubscriptBox["T", "yy"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}], "\[CapitalDelta]x", " ", 
    "\[CapitalDelta]y"}]}]]],
 ". \n\nAdding the quantities in Equations ",
 StyleBox["(11-22)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(11-23)",
  FontColor->RGBColor[0, 0, 1]],
 ", we find that the net heat flowing out of the rectangle is approximated by \
the equation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "  ", "K"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["T", "xx"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["T", "yy"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}], 
    "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}], "  ", "=", "  ", "0"}]]],
 ",  \n\nwhich implies that  \n\n    \t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["T", "xx"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", "  ", 
     RowBox[{
      SubscriptBox["T", "yy"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "=", "0"}]}]]],
 ".  \n\nHence  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  satisfies Laplace's equation and is a harmonic function."
}], "Text"],

Cell[TextData[{
 "\tIf the domain in which  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  is defined is simply connected, then a conjugate harmonic function  ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  exists, and    \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", "  ", "S", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  \n\nis an analytic function.  The curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "1"]}]]],
 "  are ca",
 "lled isothermals and",
 " are lines connecting points of the same temperature.  The curves  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 "  are cal",
 "led the heat flow lines, and ",
 "one can visualize the heat flowing along these curves from points of higher \
temperature to points of lower temperature.  The situation is illustrated in \
Figure 11.16(b)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tBoundary value problems for steady state temperatures are realizations of \
the Dirichlet problem where the value of the harmonic function ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is interpreted as the temperature at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "y"}], ")"}]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Suppose that two parallel planes are perpendicular to the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane and pass through the horizontal lines ",
 Cell[BoxData[
  RowBox[{"y", "=", "a"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 " and that the temperature is held constant at the values  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "a"}], ")"}]}], "=", 
   SubscriptBox["T", "1"]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "b"}], ")"}]}], "=", 
   SubscriptBox["T", "2"]}]]],
 ",  respectively, on these planes.  Then ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["T", "1"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["T", "2"], " ", "-", " ", 
       SubscriptBox["T", "1"]}], 
      RowBox[{"b", " ", "-", " ", "a"}]], 
     RowBox[{"(", 
      RowBox[{"y", " ", "-", " ", "a"}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztWsFOwkAQXWxRQKKQeNUQheIH8A168uIfNMQEDkYtXEUvnNST+jf+CF+i
J2t3SraFTrezSyEIm5h2MrPzdt7s7DJZe+UOeze37rDfdRuXnnvf63cHjYs7
L1BZBcYK74yxzwbjsh+I04cf/Pkf/ME1+vIrf+1wSIdLNpdaXCpy6WzWCrqm
GOcIaz0Ee4EX2EAC5RSPWTPqc0R3iru3kaFNROfg7rVQeEM8sMCw2RQCo0Ie
hiBjkcwiMuhYWG3EeiK1KsTsEGM+IKwyaULlhaZOVpsv6jYitaTWSKovvrvi
8kgAw1JDvMC1GtofcUrY2u4gOqx+MN3uAr4Gb/vwsFqrZFcsFPqvkDRr/Jv/
2mFRESLQwZvbozoQYwFhieFRRqqxQdroq3fcND4mEcvm4wkkG5G0d9cDvBIb
voSrtc+BlGn20/Cy0piCV15aQsqIh3Y2orUEhbVQas02Mnw2hw80IEWBrgPx
hJjyB4sy8COkeAYUo7hmfn6U5GCknkwOIVlegmO8eILhKsWzzLAMH8NHDR16
BTisoqaF1JPJYQeIaQ+eKg2Z+hyVNLCssw4DK1HywL5UYywhOkkS5BMo9mFy
sESpBcNVSo2AvnpHw2e9+axfIqCBS71Ep0PMmbQPkRFiitjm18Axv5NJSeX4
luORejg5RLIM/I5SGWSjr97R8NlSPtCK2bMbmdSKEWDnTOFVUH572UNMhIux
nFuxCX7G5norJp9DsRuTgyWqbeIr3VIQ0P+R46YlwvAhopP6BDmEeusix0vt
q7KOtue0GQk67IsM6lcaVF9Mp/nPXj9MQMQ9WkcYeBRqQZ5+DcEKf6sxiHs=
\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The two-dimensional solution is constructed at points in the \
horizontal strip  ",
 Cell[BoxData[
  RowBox[{"a", "<", 
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], "<", "b"}]]],
 "  in the complex plane.  A reasonable assumption is that the temperature at \
all points on the plane passing through the line ",
 Cell[BoxData[
  RowBox[{"y", "=", 
   SubscriptBox["y", "0"]}]]],
 " is constant.  Hence  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"t", 
    RowBox[{"(", "y", ")"}]}]}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"t", 
   RowBox[{"(", "y", ")"}]}]]],
 " is a function of ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " alone.  Laplace's equation implies that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"t", "''"}], 
    RowBox[{"(", "y", ")"}]}], "=", "0"}]]],
 ",  and an argument similar to that in Example 11.1 will show that the \
solution ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " has the form given in the preceding equation."
}], "Text"],

Cell[TextData[{
 "\tThe isothermals  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "\[Alpha]"}]]],
 "  are easily seen to be horizontal lines.  The conjugate harmonic function \
is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["T", "1"], " ", "-", " ", 
      SubscriptBox["T", "2"]}], 
     RowBox[{"b", " ", "-", " ", "a"}]], "x"}]}]]],
 ",  \n\nand the heat flow lines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "\[Beta]"}]]],
 "  are vertical segments between the horizontal lines.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "1"], " ", ">", " ", 
   SubscriptBox["T", "2"]}]]],
 ",  then the heat flows along these segments from the plane through ",
 Cell[BoxData[
  RowBox[{"y", "=", "a"}]]],
 " to the plane through ",
 Cell[BoxData[
  RowBox[{"y", "=", "b"}]]],
 ", as illustrated in Figure 11.17.  "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{508, 213},
  ImageMargins->0],
 "  \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.17",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1117.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The temperature between parallel planes where  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "1"], " ", ">", " ", 
   SubscriptBox["T", "2"]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39954721684375*^9, 3.399547249125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.14.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Show that ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 " is the harmonic conjugate of ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 "."
}], "Text"],

Cell["\<\
Enter the formula for the temperature function.  This is similar to Example \
11.1, and Example 11.18.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "-", "0"}], ";", " ", 
    RowBox[{"Remove", "[", "T", "]"}], ";", " ", 
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "x", ",", "y", ",", "T"}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "cont"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["T", "1"], " ", "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["T", "2"], " ", "-", " ", 
         SubscriptBox["T", "1"]}], 
        RowBox[{"b", " ", "-", " ", "a"}]], " ", 
       RowBox[{"(", 
        RowBox[{"y", " ", "-", " ", "a"}], ")"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["T", "1"], " ", "-", " ", 
        SubscriptBox["T", "2"]}], 
       RowBox[{"b", " ", "-", " ", "a"}]], "x"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<S[x,y] = \>\"", ",", 
      RowBox[{"S", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"S", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(T\), \(x\)]\)[x,y] = \
\!\(\*SubscriptBox[\(S\), \(y\)]\)[x,y] ?\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"S", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< \!\(\*SubscriptBox[\(T\), \(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<-\!\(\*SubscriptBox[\(S\), \(x\)]\)[x,y] = \>\"", ",", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"S", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}]}]}], " ", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does \!\(\*SubscriptBox[\(T\), \(y\)]\)[x,y] = -\!\(\*SubscriptBox[\
\(S\), \(x\)]\)[x,y] ?\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"T", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"S", "[", 
          RowBox[{"x", ",", "y"}], "]"}]}]}]}], "]"}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.4001821529375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{"\[Alpha]", " ", "=", " ", 
    RowBox[{
     SubscriptBox["T", "1"], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{
        SubscriptBox["T", "2"], " ", "-", " ", 
        SubscriptBox["T", "1"]}], 
       RowBox[{"b", " ", "-", " ", "a"}]], " ", 
      RowBox[{"(", 
       RowBox[{"y", " ", "-", " ", "a"}], ")"}]}]}]}]}]]],
 " to get the isothermals."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"\[Alpha]", " ", "\[Equal]", " ", 
        RowBox[{
         SubscriptBox["T", "1"], " ", "+", " ", 
         RowBox[{
          FractionBox[
           RowBox[{
            SubscriptBox["T", "2"], " ", "-", " ", 
            SubscriptBox["T", "1"]}], 
           RowBox[{"b", " ", "-", " ", "a"}]], " ", 
          RowBox[{"(", 
           RowBox[{"y", " ", "-", " ", "a"}], ")"}]}]}]}], ",", "y"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The isothermals are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<T(x,y) = \[Alpha]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Simplify", "[", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<They are horizontal lines.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.40018215771875*^9, 3.400182159296875*^9}}],

Cell[TextData[{
 "Solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   RowBox[{"\[Beta]", " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["T", "1"], " ", "-", " ", 
       SubscriptBox["T", "2"]}], 
      RowBox[{"b", " ", "-", " ", "a"}]], "x"}]}]}]]],
 " to get the heat flow lines."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"\[Beta]", " ", "\[Equal]", " ", 
        RowBox[{
         FractionBox[
          RowBox[{
           SubscriptBox["T", "1"], " ", "-", " ", 
           SubscriptBox["T", "2"]}], 
          RowBox[{"b", " ", "-", " ", "a"}]], "x"}]}], ",", "x"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The heat flow lines are\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<S(x,y) = \[Beta]\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Simplify", "[", 
      SubscriptBox["solset", 
       RowBox[{"\[LeftDoubleBracket]", 
        RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], "]"}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<They are vertical lines.\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182161078125*^9, 3.40018216228125*^9}}],

Cell[TextData[{
 "For illustration we choose  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "1"}], ",", "  ", 
   RowBox[{"b", "=", "3"}], ",", "  ", 
   RowBox[{
    SubscriptBox["T", "1"], "=", 
    RowBox[{
     RowBox[{"50", "  ", "and", "  ", 
      SubscriptBox["T", "2"]}], "=", "10"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"b", " ", "=", " ", "3"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["T", "1"], " ", "=", " ", "50"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["T", "2"], " ", "=", " ", "10"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,1] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,2] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "2"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,3] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "3"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.4001821641875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"10", ",", "20", ",", "30", ",", "40", ",", "50"}], "}"}]}], 
    ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "10"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182047234375*^9, 3.400182050375*^9}, {
  3.400182283421875*^9, 3.400182283765625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 " Hence the temperature function  T[x,y] = 50 - 20 (-1+y)  is harmonic in \
the horizontal strip  ",
 Cell[BoxData[
  RowBox[{"1", "<", 
   RowBox[{"Im", "[", "z", "]"}], "<", "3"}]]],
 "  and has the desired boundary values.  \n"
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " at each point in the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  ,  if the temperature at points on the x-axis on the boundary satisfy \n\n\
\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
     SubscriptBox["T", "1"]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], ">", "0"}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
    SubscriptBox["T", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "x"}], "<", " ", 
    RowBox[{"0", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  Since ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is a harmonic function, this problem is an example of a Dirichlet problem. \
 From Example 11.2, it follows that the solution is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["T", "1"], " ", "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["T", "2"], " ", "-", 
       SubscriptBox["T", "1"]}], "\[Pi]"], "Arg", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}]}]],
  AspectRatioFixed->True],
 "\n\nThe isotherms  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "\[Alpha]"}]],
  
  AspectRatioFixed->True],
 "  are rays emanating from the origin.  The conjugate harmonic function is  \
\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   FractionBox[
    RowBox[{
     SubscriptBox["T", "1"], " ", "-", 
     SubscriptBox["T", "2"]}], "\[Pi]"]}]]],
 Cell[BoxData[
  RowBox[{"ln", "|", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}], "|"}]]],
 ",\n\nand the heat flow lines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "\[Beta]"}]],
  AspectRatioFixed->True],
 "  are semicircles centered at the origin.  If  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "1"], " ", ">", 
   SubscriptBox["T", "2"]}]],
  AspectRatioFixed->True],
 ",  then the heat flows counterclockwise along the semicircles, as shown in \
Figure 11.18. "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{505, 247},
  ImageMargins->0],
 "\n  \n\t\t\t",
 StyleBox[ButtonBox["Figure 11.18",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1118.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " in the upper half-plane where ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "1"], " ", ">", 
   SubscriptBox["T", "2"]}]],
  AspectRatioFixed->True],
 "."
}], "Text",
 CellChangeTimes->{{3.399548250109375*^9, 3.399548250296875*^9}, {
  3.399549387078125*^9, 3.39954939384375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.15.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Verify that  ",
 Cell[BoxData[
  RowBox[{"S", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]],
  AspectRatioFixed->True],
 "  is the harmonic conjugate of  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]],
  AspectRatioFixed->True],
 "  ."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does  \!\(\*SubscriptBox[\(\[PartialD]\), \(x\)]\) \
(\!\(\*FractionBox[\(\*SubscriptBox[\(T\), \(2\)]\\\  - \*SubscriptBox[\(T\), \
\(1\)]\), \(\[Pi]\)]\)ArcTan[\!\(\*FractionBox[\(y\), \
\(x\)]\)])\[Equal]\!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) \
(\!\(\*FractionBox[\(\*SubscriptBox[\(T\), \(1\)]\\\  - \*SubscriptBox[\(T\), \
\(2\)]\), \(2  \[Pi]\)]\)Log[\!\(\*SuperscriptBox[\(x\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(y\), \(2\)]\)])  ?\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "x"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SubscriptBox["T", "2"], " ", "-", 
            SubscriptBox["T", "1"]}], "\[Pi]"], 
          RowBox[{"ArcTan", "[", 
           FractionBox["y", "x"], "]"}]}], ")"}]}], "\[Equal]", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SubscriptBox["T", "1"], " ", "-", 
            SubscriptBox["T", "2"]}], 
           RowBox[{"2", "\[Pi]"}]], 
          RowBox[{"Log", "[", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}], "]"}]}], ")"}]}]}], " ", "]"}], " ", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<Does  \!\(\*SubscriptBox[\(\[PartialD]\), \(y\)]\) \
(\!\(\*FractionBox[\(\*SubscriptBox[\(T\), \(2\)]\\\  - \*SubscriptBox[\(T\), \
\(1\)]\), \(\[Pi]\)]\)ArcTan[\!\(\*FractionBox[\(y\), \(x\)]\)])\[Equal]-\!\(\
\*SubscriptBox[\(\[PartialD]\), \(x\)]\) (\!\(\*FractionBox[\(\*SubscriptBox[\
\(T\), \(1\)]\\\  - \*SubscriptBox[\(T\), \(2\)]\), \(2  \
\[Pi]\)]\)Log[\!\(\*SuperscriptBox[\(x\), \
\(2\)]\)+\!\(\*SuperscriptBox[\(y\), \(2\)]\)])  ?\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{
            SubscriptBox["T", "2"], " ", "-", 
            SubscriptBox["T", "1"]}], "\[Pi]"], 
          RowBox[{"ArcTan", "[", 
           FractionBox["y", "x"], "]"}]}], ")"}]}], "\[Equal]", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "x"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             SubscriptBox["T", "1"], " ", "-", 
             SubscriptBox["T", "2"]}], 
            RowBox[{"2", "\[Pi]"}]], 
           RowBox[{"Log", "[", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], "]"}]}], ")"}]}]}]}], " ", "]"}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182169796875*^9, 3.4001821713125*^9}}],

Cell["\<\
Enter the formula for the temperature function.  This is similar to Example \
11.2.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "x", ",", "y", ",", "T"}], "]"}], ";"}], " ",
    "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["T", "1"], " ", "+", " ", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["T", "2"], " ", "-", 
         SubscriptBox["T", "1"]}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400182173375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "For illustration we choose  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["T", "1"], "=", 
   RowBox[{
    RowBox[{"50", "  ", "and", "  ", 
     SubscriptBox["T", "2"]}], "=", "10"}]}]]],
 ".  \nThen we can check out the temperature at points whose argument is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"Arg", "[", "z", "]"}], "=", "0"}], ",", 
   FractionBox["\[Pi]", "4"], ",", 
   FractionBox["\[Pi]", "2"], ",", 
   FractionBox[
    RowBox[{"3", " ", "\[Pi]"}], "4"], ",", "\[Pi]"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["T", "1"], " ", "=", " ", "50"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["T", "2"], " ", "=", " ", "10"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "4"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"X", "=", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{"\[Pi]", " ", "k"}], "4"], "]"}]}], ";", " ", 
       RowBox[{"Y", "=", 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"\[Pi]", " ", "k"}], "4"], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\< T[\>\"", ",", "X", ",", "\"\<,\>\"", ",", "Y", ",", 
         "\"\<] = \>\"", ",", 
         RowBox[{"T", "[", 
          RowBox[{"X", ",", "Y"}], "]"}]}], "]"}], ";"}]}], "  ", "]"}], 
    ";"}], " ", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.40018217709375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"10", "+", 
        RowBox[{"5", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "8"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "3"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.40018205621875*^9, 3.400182056453125*^9}, 
   3.400182180109375*^9, {3.400182295109375*^9, 3.400182295421875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"50", "-", 
    FractionBox[
     RowBox[{"40", " ", 
      RowBox[{"Arg", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "\[Pi]"]}]}]]],
 "  is harmonic in the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  and has the desired boundary values.  "
}], "Text"],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Phi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "50", ",", "25"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", 
        RowBox[{"-", "3"}], ",", "2"}], "}"}]}], ",", 
     RowBox[{"AxesEdge", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.400182061703125*^9, {3.400182302328125*^9, 3.400182302625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"50", "-", 
    FractionBox[
     RowBox[{"40", " ", 
      RowBox[{"Arg", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "\[Pi]"]}]}]]],
 "  is harmonic in the upper half plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " at each point in the upper half-disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", ":", 
    RowBox[{"y", ">", "0"}]}], ",", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  if the temperature at points on the boundary satisfies \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "100"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    RowBox[{
     RowBox[{"0", "<", "\[Theta]", "<", 
      RowBox[{
       RowBox[{"\[Pi]", "   ", 
        StyleBox["on",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["the",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["upper",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox[" ",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        StyleBox["semi",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]]}], 
       StyleBox["-",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox["circle",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "1"}], "<", "x", "<", 
    RowBox[{"1", "  ", 
     StyleBox["on",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox["the",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"diameter", "."}],
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "    "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  As discussed in Example 11.9, the transformation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}]}], 
      RowBox[{"1", "+", "z"}]], "  ", "=", "  ", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x", "-", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
      RowBox[{"1", "+", "x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}]]}]}]}]]],
 " \n\nis a one-to-one conformal mapping of the half-disk ",
 StyleBox["H",
  FontFamily->"Courier New"],
 " onto the first quadrant ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Q", ":", " ", 
    RowBox[{"u", ">", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"v", ">", "0"}]}]]],
 ", and can be written as \n\n",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"u", "+", 
     RowBox[{"\[ImaginaryI]", " ", "v"}]}], "  ", "=", "  ", 
    FractionBox[
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "y"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["x", "2"], "-", 
          SuperscriptBox["y", "2"]}], ")"}]}]}], 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "x"}], "+", 
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "y"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
       SuperscriptBox["y", "2"]}]], "  ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}]]}]}]}]}]}]],
 "    "
}], "Text"],

Cell[TextData[{
 "The conformal map given by Equation ",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 " gives rise to a new problem of finding the temperature ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " that satisfies the boundary conditions  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["T", "*"], 
      RowBox[{"(", 
       RowBox[{"u", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "100"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "u"}], ">", "0"}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "*"], 
     RowBox[{"(", 
      RowBox[{"0", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", "  ", "50"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "v"}], ">", 
    RowBox[{"0", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "\n\n If we use Example 11.2, the harmonic function ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " is given by  \n \n",
 StyleBox["(11-25)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["T", "*"], 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"100", " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"50", "-", "100"}], 
       RowBox[{"\[Pi]", "/", "2"}]], "Arg", 
      RowBox[{"(", 
       RowBox[{"u", "+", 
        RowBox[{"\[ImaginaryI]", " ", "v"}]}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{"100", " ", "-", " ", 
     RowBox[{
      FractionBox["100", "\[Pi]"], "Arctan", 
      RowBox[{"(", 
       FractionBox["v", "u"], ")"}]}]}]}]}]]],
 ".  \n\nSubstituting the expressions for u and v from Equation ",
 StyleBox["(11-24)",
  FontColor->RGBColor[0, 0, 1]],
 " into Equation ",
 StyleBox["(11-25)",
  FontColor->RGBColor[0, 0, 1]],
 " yields the desired solution:  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{"100", " ", "-", " ", 
    RowBox[{
     FractionBox["100", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", "y"}]], ")"}]}]}]}]]],
 ".\nThe isothermals  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "constant"}]],
  
  AspectRatioFixed->True],
 "  are circles that pass through the points \[PlusMinus]1, as shown in \
Figure 11.19. "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{364, 211},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.19",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1119.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The temperature ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"100", "-", 
    RowBox[{
     FractionBox["100", "\[Pi]"], "Arctan", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"], "-", 
        SuperscriptBox["y", "2"]}], 
       RowBox[{"2", " ", "y"}]], ")"}]}]}]}]]],
 " in a half-disk."
}], "Text",
 CellChangeTimes->{{3.39954940234375*^9, 3.39954941671875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.16.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution via a known conformal mapping. This is similar to \
Example 11.9.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "T", ",", "U", ",", "V", ",", "x", ",", "y", ",", "w", ",", "W"}], "]"}],
     ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "cont"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "z_", "]"}], " ", "=", 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[ImaginaryI]", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", "z"}], ")"}]}]}], 
      RowBox[{"1", " ", "+", " ", "z"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"W", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"f", "[", 
       RowBox[{"x", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"U", " ", "=", " ", 
     RowBox[{"Together", "[", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{
        RowBox[{"Re", "[", "W", "]"}], ",", 
        RowBox[{"TargetFunctions", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"V", " ", "=", " ", 
      RowBox[{"Together", "[", 
       RowBox[{"ComplexExpand", "[", 
        RowBox[{
         RowBox[{"Im", "[", "W", "]"}], ",", 
         RowBox[{"TargetFunctions", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}], "]"}]}], ";"}], " ", 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"100", " ", "-", " ", 
      RowBox[{
       FractionBox["100", "\[Pi]"], " ", 
       RowBox[{"ArcTan", "[", 
        FractionBox["V", "U"], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<w = \>\"", ",", 
      RowBox[{"f", "[", "z", "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"U", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "V"}]}]}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u = \>\"", ",", "U"}], " ", "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<v = \>\"", ",", " ", "V"}], "]"}], ";"}], "  ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<T[x,y] = 100 - \!\(\*FractionBox[\(100\), \(\[Pi]\)]\) \
ArcTan[\!\(\*FractionBox[\(v\), \(u\)]\)]\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400182185390625*^9},
 AspectRatioFixed->True],

Cell["\<\
We can check out some of the boundary values by taking limits.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) \
T[\!\(\*FractionBox[\(-1\), \(2\)]\),y] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          FractionBox[
           RowBox[{"-", "1"}], "2"], ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) T[0,y] = \>\"", 
      ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{"0", ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*UnderscriptBox[\(lim\), \(y \[Rule] 0\)]\) \
T[\!\(\*FractionBox[\(1\), \(2\)]\),y] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{"T", "[", 
         RowBox[{
          FractionBox["1", "2"], ",", "y"}], "]"}], ",", " ", 
        RowBox[{"y", "\[Rule]", "0"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< T[\!\(\*FractionBox[SqrtBox[\(2\)], \
\(2\)]\),\!\(\*FractionBox[SqrtBox[\(2\)], \(2\)]\)] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        FractionBox[
         SqrtBox["2"], "2"], ",", 
        FractionBox[
         SqrtBox["2"], "2"]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<       T[0,1] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<T[\!\(\*FractionBox[\(-\*SqrtBox[\(2\)]\), \
\(2\)]\),\!\(\*FractionBox[SqrtBox[\(2\)], \(2\)]\)] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"-", 
          SqrtBox["2"]}], "2"], ",", 
        FractionBox[
         SqrtBox["2"], "2"]}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.40018218946875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"50", "+", 
        RowBox[{"10", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.01", ",", "1"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182066421875*^9, 3.400182067953125*^9}, {
  3.40018232684375*^9, 3.4001823271875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nHence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"100", "-", 
    FractionBox[
     RowBox[{"100", " ", 
      RowBox[{"ArcTan", "[", 
       FractionBox[
        RowBox[{"1", "-", " ", 
         SuperscriptBox["x", "2"], "-", " ", 
         SuperscriptBox["y", "2"]}], 
        RowBox[{"2", " ", "y"}]], "]"}]}], "\[Pi]"]}]}]]],
 "  is harmonic in the upper half-disk  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"H", ":", 
    RowBox[{"y", ">", "0"}]}], ",", 
   RowBox[{"|", "z", "|", 
    RowBox[{"<", "1"}]}]}]]],
 ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["11.5.1  An Insulated Segment on the Boundary",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tWe now turn to the problem of finding the steady state temperature \
function ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " inside the simply connected domain D whose boundary consists of three \
adjacent curves ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ", and ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 ", where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["T", "1"]}]]],
 "  along  ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ";  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["T", "2"]}]]],
 "  along  ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 ",  and the region is insulated along ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 ".  Zero heat flowing across ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 " implies that  \n\t\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox[
     OverscriptBox[
      StyleBox["V",
       FontWeight->"Bold"], "\[RightVector]"],
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}], "\[FilledSmallCircle]", " ", 
    StyleBox[
     OverscriptBox[
      StyleBox["N",
       FontWeight->"Bold"], "\[RightVector]"],
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "K"}], "  ", 
     StyleBox[
      OverscriptBox[
       StyleBox["N",
        FontWeight->"Bold"], "\[RightVector]"],
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}], "\[FilledSmallCircle]", " ", 
     "grad", " ", "T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", "0"}]}]]],
 ",  \n\nwhere  ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox[
     StyleBox["N",
      FontWeight->"Bold"], "\[RightVector]"],
    FontWeight->"Bold"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is perpendicular to ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 ". Thus the direction of heat flow must be parallel to this portion of the \
boundary.  In other words, ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 " must be part of a heat flow line  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"S", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "constant"}]]],
 "  and the isothermals  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "constant"}]]],
 "  intersect ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 " orthogonally."
}], "Text"],

Cell[TextData[{
 " \tWe can solve this problem by finding a conformal mapping  \n\n",
 StyleBox["(11-26)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]]],
 "\n\nfrom D onto the semi-infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"G", ":", " ", 
    RowBox[{"0", "<", "u", "<", "1"}]}], ",", 
   RowBox[{"v", ">", "0"}]}]]],
 "  so that the image of the curve ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is the ray  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "0"}], ",", 
   RowBox[{"v", ">", "0"}]}]]],
 ";  the image of the curve ",
 Cell[BoxData[
  SubscriptBox["C", "2"]]],
 " is the ray given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"u", "=", "1"}], ",", 
   RowBox[{"v", ">", "0"}]}]]],
 ";  and the thermally insulated curve ",
 Cell[BoxData[
  SubscriptBox["C", "3"]]],
 " is mapped onto the thermally insulated segment  ",
 Cell[BoxData[
  RowBox[{"0", "<", "u", "<", "1"}]]],
 "  of the ",
 StyleBox["u",
  FontFamily->"Courier New"],
 " axis, as shown in Figure 11.20."
}], "Text"],

Cell[TextData[{
 "\tThe new problem in G is to find the steady state temperature function ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " so that along the rays, we have the boundary values  \n\n",
 StyleBox["(11-27)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["T", "*"], 
      RowBox[{"(", 
       RowBox[{"0", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", 
     SubscriptBox["T", "1"]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "v"}], ">", "0"}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "*"], 
     RowBox[{"(", 
      RowBox[{"1", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", 
    SubscriptBox["T", "2"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "v"}], ">", 
    RowBox[{"0", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tThe condition that a segment of the boundary is insulated can be \
expressed mathematically by saying that the normal derivative of  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " is zero. That is,  \n\n",
 StyleBox["(11-28)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"\[PartialD]", 
     SuperscriptBox["T", "*"]}], 
    RowBox[{"\[PartialD]", "n"}]], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["T", "v", "*"], 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "  ", "=", "  ", "0"}]}]]],
 "\n\nwhere ",
 StyleBox["n",
  FontFamily->"Courier New"],
 " is a coordinate measured perpendicular to the segment.  We can easily \
verify that the function  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["T", "*"], 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["T", "1"], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["T", "2"], "-", 
       SubscriptBox["T", "1"]}], ")"}], "u"}]}]}]]],
 " \n\nsatisfies the conditions stated in Equations ",
 StyleBox["(11-27)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(11-28)",
  FontColor->RGBColor[0, 0, 1]],
 " for region G.  Therefore, using Equation ",
 StyleBox["(11-26)",
  FontColor->RGBColor[0, 0, 1]],
 ", we find that the solution in D is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["T", "1"], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["T", "2"], "-", 
       SubscriptBox["T", "1"]}], ")"}], "u", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The isothermals  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "constant"}]]],
 "  and their images under  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}]}]]],
 "  are also illustrated in Figure 11.20."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{584, 335},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.20",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1120.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Steady state temperatures with one boundary portion insulated."
}], "Text",
 CellChangeTimes->{{3.39954942240625*^9, 3.399549432703125*^9}}],

Cell[TextData[{
 StyleBox["Example 11.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " for the domain D consisting of the the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "   where the temperature at points on the boundary satisfies  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "  ", "1"}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], " ", ">", " ", "1"}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
     RowBox[{"-", "1"}]}], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "   ", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "x"}], "<", " ", 
      RowBox[{"-", "1"}]}], 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[";",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "T"}], 
     RowBox[{"\[PartialD]", "N"}]], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["T", "y"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "0"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", "-", "1"}], "<", "x", "<", 
    RowBox[{"1", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  The mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"Arcsin", " ", "z"}]}]]],
 "  conformally maps D onto the semi-infinite strip  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", ">", "0"}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[Pi]", "2"]}], "<", "u", "<", 
    FractionBox["\[Pi]", "2"]}]}]]],
 ",  where the new problem is to find the steady state temperature  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["T", "*"], 
   RowBox[{"(", 
    RowBox[{"u", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "v"}], ")"}]}]]],
 " that has the boundary conditions  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["T", "*"], 
       RowBox[{"(", 
        RowBox[{
         FractionBox["\[Pi]", "2"], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", "  ", "1"}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["for",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "   ", "v"}], " ", ">", " ", "0"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[";",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}], "\n", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["T", "*"], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"-", "\[Pi]"}], "2"], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", 
      RowBox[{"-", "1"}]}], 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", 
     RowBox[{
      RowBox[{
       RowBox[{
        StyleBox["for",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "   ", "v"}], ">", " ", "0"}], 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[";",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"\[PartialD]", 
        SuperscriptBox["T", "*"]}], 
       RowBox[{"\[PartialD]", "n"}]], "  ", "=", "  ", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["T", "v", "*"], 
        RowBox[{"(", 
         RowBox[{"u", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "0"}], ")"}]}], "  ", "=", "  ", "0"}]}],
      
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "   ", 
     RowBox[{
      RowBox[{
       StyleBox["for",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "   ", "-", 
       FractionBox["\[Pi]", "2"]}], "<", "u", "<", 
      RowBox[{
       FractionBox["\[Pi]", "2"], 
       StyleBox[" ",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       StyleBox[".",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]]}]}]}]}]}]]],
 "  \n\nUsing the result of Example 11.1, we can easily obtain the solution:  \
\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["T", "*"], 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", " ", 
   RowBox[{
    FractionBox["2", "\[Pi]"], " ", "u"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "Therefore the solution in D is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", " ", 
   RowBox[{
    FractionBox["2", "\[Pi]"], " ", "Re", 
    RowBox[{"(", 
     RowBox[{"Arcsin", " ", "z"}], ")"}]}]}]]],
 ".  \n\nIf an explicit solution is required, then we can use Formula ",
 StyleBox["(10-26)",
  FontColor->RGBColor[0, 0, 1]],
 " to obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["2", "\[Pi]"], "Arcsin", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
         SuperscriptBox["y", "2"]}]], " ", "-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"x", "-", "1"}], ")"}], "2"], "+", 
         SuperscriptBox["y", "2"]}]]}], "2"], ")"}]}]}]]],
 "\n\nwhere the function  ",
 Cell[BoxData[
  RowBox[{"Arcsin", " ", "t"}]]],
 "  has range values satisfying  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], "<", 
   RowBox[{"Arcsin", " ", "t"}], "<", 
   FractionBox["\[Pi]", "2"]}]]],
 ";  see Figure 11.21."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{422, 290},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.21",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1121.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " with ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["T", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"0", "  ", 
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}], " ", "-", "1"}], "<", "x", "<", "1"}]}]]],
 ", \n\t\t\tand boundary values ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "  ", 
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "x"}], "<", 
    RowBox[{"-", "1"}]}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
   RowBox[{
    RowBox[{"1", "  ", 
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "x"}], ">", "1"}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399549438390625*^9, 3.399549450453125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.17.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
This is similar to Example 11.13, but the method of solution is different.

Construct the solution via a known conformal mapping. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"T", ",", "Ty", ",", "x", ",", "y"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "2"}], "\[Pi]"], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"ComplexExpand", "[", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], " ", 
      RowBox[{"ArcSin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "+", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]], " ", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]]}], "2"], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400182198859375*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "For computational purposes we use the formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{"ArcSin", "[", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], "=", 
   RowBox[{"ArcSin", "[", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "+", "1"}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox["y", "2"]}]], " ", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "1"}], ")"}], "2"], " ", "+", " ", 
        SuperscriptBox["y", "2"]}]]}], "2"], "]"}]}]]],
 "  \nThen we can check out the temperature and the normal derivative at \
several boundary points."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], " ", 
      RowBox[{"ArcSin", "[", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "+", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]], " ", "-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "1"}], ")"}], "2"], " ", "+", " ", 
           SuperscriptBox["y", "2"]}]]}], "2"], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Ty", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Some boundary values are\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< T[-3,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< T[-2,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< T[-1,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  T[1,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  T[2,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"2", ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  T[3,0] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"3", ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(T\), \(y\)]\)[x,y] = \>\"", ",", 
      RowBox[{"Ty", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Some values of the normal derivative are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(T\), \(y\)]\)[\!\(\*FractionBox[\(-1\), \(2\)]\
\),0] = \>\"", ",", 
      RowBox[{"Ty", "[", 
       RowBox[{
        FractionBox[
         RowBox[{"-", "1"}], "2"], ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  \!\(\*SubscriptBox[\(T\), \(y\)]\)[0,0] = \>\"", ",", 
      RowBox[{"Ty", "[", 
       RowBox[{"0", ",", "0"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\< \!\(\*SubscriptBox[\(T\), \(y\)]\)[\!\(\*FractionBox[\(1\), \(2\)]\
\),0] = \>\"", ",", 
      RowBox[{"Ty", "[", 
       RowBox[{
        FractionBox["1", "2"], ",", "0"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.40018220215625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "2"}], "\[Pi]"], " ", 
      RowBox[{"Re", "[", 
       RowBox[{"ArcSin", "[", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{"0.2", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.000001", ",", "4"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", " ", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182073390625*^9, 3.400182075484375*^9}, {
  3.40018234075*^9, 3.40018234109375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{" ", "2"}], "\[Pi]"], " ", 
    RowBox[{"Re", "[", 
     RowBox[{"ArcSin", "[", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}]]],
 "  is harmonic in the upper half plane  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"Im", "[", "z", "]"}], ">", "0"}], " "}]]],
 ",  and has the desired boundary values.  "
}], "Text"],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Phi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", 
        RowBox[{"-", "3"}], ",", "2"}], "}"}]}], ",", 
     RowBox[{"AxesEdge", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.40018208021875*^9, {3.4001823456875*^9, 3.40018234603125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Hence the temperature function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    FractionBox[
     RowBox[{" ", "2"}], "\[Pi]"], " ", 
    RowBox[{"Re", "[", 
     RowBox[{"ArcSin", "[", 
      RowBox[{"x", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}]}]}]]],
 "  is harmonic in the upper half plane  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"Im", "[", "z", "]"}], ">", "0"}], " "}]]],
 ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Using Previous Techniques",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe techniques of the N-value Dirichlet problem in Sections 11.2 and \
Poisson's integral formula in 11.3 can be used to find steady state \
temperatures.  We recast two previous examples in the context of steady state \
temperatures. "
}], "Text"],

Cell[TextData[{
 StyleBox["Revisited Example 11.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 "  where the temperature at points on the boundary satisfies Figure 11.5.  \
That is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "4"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "      ", "x"}], "<", 
    RowBox[{"-", "1"}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "1"}], "<", "x", "<", "0"}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "3"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "      ", "0"}], "<", "x", "<", "1"}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "      ", "1"}], "<", 
    RowBox[{"x", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{400, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution. This is a four-value Dirichlet problem in the upper half-plane \
defined by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ".  For the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane, the solution in Equation ",
 StyleBox["(11-5)",
  FontColor->RGBColor[0, 0, 1]],
 " becomes  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["a", "3"], "  ", "+", "  ", 
     RowBox[{
      FractionBox["1", "\[Pi]"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"k", "=", "1"}], "3"], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["a", 
           RowBox[{"k", "-", "1"}]], "-", 
          SubscriptBox["a", "k"]}], ")"}], " ", "Arg", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", 
          SubscriptBox["x", "k"]}], ")"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    SubscriptBox["a", "3"], "  ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "0"], "-", 
       SubscriptBox["a", "1"]}], "\[Pi]"], " ", "Arg", " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["x", "1"]}], ")"}]}], " ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "1"], "-", 
       SubscriptBox["a", "2"]}], "\[Pi]"], " ", "Arg", " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["x", "2"]}], ")"}]}], " ", "+", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SubscriptBox["a", "2"], "-", 
       SubscriptBox["a", "3"]}], "\[Pi]"], " ", "Arg", " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", 
       SubscriptBox["x", "3"]}], ")"}]}]}]}]}]],
 "\n\nHere we have  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["a", "0"], "=", "4"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "1"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["a", "2"], "=", "3"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["a", "3"]}], "=", "2"}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["x", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"and", "  ", 
     SubscriptBox["x", "3"]}], "=", "1"}]}]]],
 ",  which we substitute into equation for  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  to obtain  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"2", " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"4", "-", "1"}], "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"z", "-", 
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}]}], ")"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "-", "3"}], "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"z", "-", "0"}], ")"}]}], " ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"3", "-", "2"}], "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "  ", "+", "  ", 
     RowBox[{
      FractionBox["3", "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}]}], "  ", "-", "  ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "Arg", 
      RowBox[{"(", "z", ")"}]}], "  ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", " ", "+", " ", 
     RowBox[{
      FractionBox["3", "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"x", "+", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "+", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], "\[Pi]"], "Arg", 
      RowBox[{"(", 
       RowBox[{"x", "-", "1", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                 ", 
   RowBox[{"=", "  ", 
    RowBox[{"2", "  ", "+", "  ", 
     RowBox[{
      FractionBox["3", "\[Pi]"], "Arctan", 
      RowBox[{"(", 
       FractionBox["y", 
        RowBox[{"x", "+", "1"}]], ")"}]}], "  ", "-", "  ", 
     RowBox[{
      FractionBox["2", "\[Pi]"], "Arctan", 
      RowBox[{"(", 
       FractionBox["y", "x"], ")"}]}], "  ", "+", " ", 
     RowBox[{
      FractionBox[
       RowBox[{" ", "1"}], "\[Pi]"], "Arctan", 
      RowBox[{"(", 
       FractionBox["y", 
        RowBox[{"x", "-", "1"}]], ")"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 StyleBox[ButtonBox["Figure 11.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/dirichletproblemplane/\
DirichletProblemFigures/mat1105.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The  Dirichlet solution for the steady state temperatures. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Revisited Solution 11.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the boundary values and construct the  Dirichlet sum.", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "t", ",", "x", ",", "y", ",", "z", ",", "T"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "1"], " ", "=", " ", 
     RowBox[{"-", "1"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "2"], " ", "=", "  ", "0"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "3"], " ", "=", "  ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "0"], " ", "=", "  ", "4"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "1"], " ", "=", "  ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "2"], " ", "=", "  ", "3"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "3"], " ", "=", "  ", "2"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"z", " ", "=", " ", 
     RowBox[{"x", " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{
      SubscriptBox["a", "3"], "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["a", "0"], "-", 
         SubscriptBox["a", "1"]}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"z", "-", 
         SubscriptBox["x", "1"]}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["a", "1"], "-", 
         SubscriptBox["a", "2"]}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"z", "-", 
         SubscriptBox["x", "2"]}], "]"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{
         SubscriptBox["a", "2"], "-", 
         SubscriptBox["a", "3"]}], "\[Pi]"], 
       RowBox[{"Arg", "[", 
        RowBox[{"z", "-", 
         SubscriptBox["x", "3"]}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400182209625*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nFirst use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "4", ",", 
         FractionBox["1", "4"]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.40018208509375*^9, 3.4001820874375*^9}, {
  3.400182353578125*^9, 3.400182353796875*^9}}],

Cell[TextData[{
 "\nThen use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "11"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Phi][x,y] \>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182093046875*^9, 3.40018210803125*^9}, {
  3.400182361703125*^9, 3.400182361890625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nThe function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{"2", "+", 
    FractionBox[
     RowBox[{"Arg", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "\[Pi]"], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"Arg", "[", 
       RowBox[{"x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "\[Pi]"], "+", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"Arg", "[", 
       RowBox[{"1", "+", "x", "+", 
        RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}]}], "\[Pi]"]}]}]]],
 "  is harmonic in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Revisited Example 11.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " in the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ", where the temperature at points on the boundary satisfies  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "    ", "-", "1"}], " ", "\[LessEqual]", " ",
      "x", " ", "\[LessEqual]", " ", "1"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "    ", "|", "x", "|", 
    RowBox[{">", 
     RowBox[{"1", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution. Using Equation ",
 StyleBox["(11-12)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["y", "\[Pi]"], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", "-", "t"}], ")"}], "2"], "+", 
        SuperscriptBox["y", "2"]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 "\n\nUsing techniques from calculus we have the integration formula  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Integral]", 
    RowBox[{
     FractionBox["y", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "t"}], ")"}], "2"], "+", 
       SuperscriptBox["y", "2"]}]], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], "  ", "=", "  ", 
   RowBox[{"Arctan", 
    RowBox[{"(", 
     FractionBox["y", 
      RowBox[{"x", "-", "t"}]], ")"}]}]}]]],
 ".  We obtain the solution as follows \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"(", 
      RowBox[{"Arctan", 
       FractionBox["y", 
        RowBox[{"x", "-", "t"}]]}], ")"}]}], 
    UnderoverscriptBox["|", 
     RowBox[{"t", "=", 
      RowBox[{"-", "1"}], " "}], 
     RowBox[{"t", "-", "1"}]], "  ", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "              ", 
    RowBox[{"=", "   ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "\[Pi]"], "Arctan", 
       RowBox[{"(", 
        FractionBox["y", 
         RowBox[{"x", "-", "1"}]], ")"}]}], "  ", "-", "  ", 
      RowBox[{
       FractionBox["1", "\[Pi]"], "Arctan", 
       RowBox[{"(", 
        FractionBox["y", 
         RowBox[{"x", "+", "1"}]], ")"}]}]}]}]}]}]]],
 "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Revisited Solution 11.11.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "The solution is similar to Example 11.7, but the method of solution is \
different.\n\nEnter the function U[t] and use the Poisson integral to \
construct  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "a", ",", "t", ",", "v", ",", "x", ",", "y", ",", "z", ",", "T", ",", 
      "U"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", "1"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "t_", "]"}], "=", 
     RowBox[{
      FractionBox["y", "\[Pi]"], " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"U", "[", "t", "]"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "t"}], ")"}], "2"], "+", 
          SuperscriptBox["y", "2"]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Apart", "[", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"G", "[", "1", "]"}], "-", 
        RowBox[{"G", "[", 
         RowBox[{"-", "1"}], "]"}]}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{
        RowBox[{"ArcTan", "[", "z_", "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "z"], "]"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  U[t]  =  \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], "   ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<T[x,y]  =  \!\(\*FractionBox[\(y\), \(\[Pi]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(1\)]\)\!\(\*FractionBox[\(U[t]\), \(\*SuperscriptBox[\((x - t)\), \(2\)] + \
\*SuperscriptBox[\(y\), \(2\)]\)]\)\[DifferentialD]t\>\"", "]"}], ";"}], "  ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y]  =  \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y]  =  \>\"", ",", 
      RowBox[{"v", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.400182215453125*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "1", ",", 
         FractionBox["1", "10"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.000001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182114453125*^9, 3.400182116515625*^9}, {
  3.40018236971875*^9, 3.400182370109375*^9}}],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Phi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", 
        RowBox[{"-", "3"}], ",", "2"}], "}"}]}], ",", 
     RowBox[{"AxesEdge", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.4001821214375*^9, {3.400182376734375*^9, 3.400182377046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore, the function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{"1", "-", "x"}], "y"], "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "\[Pi]"], 
     RowBox[{"ArcTan", "[", 
      FractionBox[
       RowBox[{"1", "+", "x"}], "y"], "]"}]}]}]}]]],
 "  is harmonic in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the temperature ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " in the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ", where the temperature at points on the boundary satisfies  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", 
    RowBox[{"1", "-", 
     SuperscriptBox["x", "2"]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["for",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "    ", "-", "1"}], " ", "\[LessEqual]", " ",
      "x", " ", "\[LessEqual]", " ", "1"}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "0"}], ")"}]}], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "           ", 
   RowBox[{
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "    ", "|", "x", "|", 
    RowBox[{">", 
     RowBox[{"1", 
      StyleBox[" ",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      StyleBox[".",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]]}]}]}]}]}]],
 "  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\
eJzdnNlyG8cVhkfAYN8JcAM3cBVFUSRFShR3yzJF2bKkyI5iO4njCq24LDub
QyupVCqWU6nyVXKX5CHyAHk4X9GcBnBAkN8AZ3ogU7FKaE31DM75/69P98wA
Izw8fP7sk98ePv/s6WHt3tHhF88+e/pl7eD3Rydd0UuOc+lfjuP8p+Z428cn
m43m+OTv8b+9xuux3/6H94/rhdzytmLe1i1vK9LetynHFU+90Yk6dTUmpLML
feumddv6Tv5sw6Gb0Feqv+GfsGsnXLYt6Gt4+0bMunDQWse9ARRQX+E03XNR
Qlre5EOLpxhHJE1Ehj0i8c7sLYWvv9PbLyRwzNsy2oyBbH3/VyyfRiECfSno
SyuPu6j3/pD10Rilu4+0KZB90xVrO6BxUCMu74t22BcDPbehr1MMl4V3krQv
pizL/ETjC6cR/L/HrVfdr3O81NjnfHvcetX3TTVF/e9kIjZf3p/4yb9HzWSN
155pm31HjSNaxzXfHzFtvc/L4L0ipnXbdXhcPHnRNukR0zbSvKi/dr2WxkdR
L4TsNROV8jZQnaiSV930t01UTUvmZZK07BKWJr5dwOealofAPTU8MHQqbjtd
uJ1ZcQnVni+qaBuqSIdKcwNW2k7oStNjiwK27S7YvvGDtQuwolaw/I221047
uC3fGgsHzlWC27IFtwPg3B6Aiyon56YSXLQH4FwAt6kBF6nX8MnWdiBc0TZp
0WZ7zoIdug3lZPVH10Ef+OiEccNrW1cJ2S5VZ6ibIxM9hud7UjDZ1h2ziDpm
2T0Hyu0xqJjXmmwbttNzA+otDsiiPUYWg3pbVU5VwhhVYqQTRRzq7aYt0HWp
vFQIjNEgGE22Fam8xPeALCGVZw3qJlReEpC5PUaWgMpbhMqLKzG6Sox0wkhC
5a3aAr0BQKkGtUDprKsFugBAtXUZBmgKgF63BbqmBBoLATSmBDofAmgsBNA0
AF0JdkmzChjTITDGlHWZlLVxTtbGFCCLKWvQBWQxJbLlYJcvK3ISyQKoOIBy
Q9RbSkBNCahMiNqKKWsrIyeRZdspugy1FQYZ1ZZBdg5Kc2KOw8RsAU2EQEa1
lYXaWrSFd02qLA/IEiGQJfyqzHRVnWYyqrI4IIsrkcX9kBmX1qCuCqiisrbi
QUA1lwTnyHzO1eeYe6BmX2Pd0tVRXAklL1AWbKEswNQrKOuI8MQBTxLqKOe1
Sa/Hu+3ywnt5z9dRUllHhCwByAow9S4HOxNeAWRUUWGQpQBZRaZevxJUIgSo
IoCaC3b+uywTrg/wJAFPIgSeBYBCE46qJwFQkn5QmhcjdhNuDqqn13jSgGde
iYdqRounD2pm2hbULIAqhwCV8ANlumZkcmVDQEkpoUzZQplRQkkpoSQBSlbO
ZjU5c+UBSjIElDJAmbSFMg1QKiGgpABKTqCMCpSCEkpSCaUCUGrBzk1TShRp
QJFUosgLiiFBUQQUKSWKtBLFRLCzzySg6A+BIg0oCrJ+lAVFCVCkQ6DoBxTj
tlOlBlAGlFBSSigGQNnr6VOiSClRDACKMVsUE0oUGSWKjNc2Pkw9bzujtJ3x
s20idzN7JLPDhS3f75DHAcWgEkUaUGShKq4roaSVUIagFqpd8PzB/HPuMYQk
d/s+nTAGuIZC4MoBriVZZHMAKfP9Q8r40WidfEaVXLLAJePHpXHP36RRUJZM
FmgMA41hPKn4MEh1n0ojwGAYGOSUtVGA2piHqZRXVklOyWXIrkroOTLfeVQF
VlUlK6oXYjUHrKiGtKyqwGpQvSqbDnOML5RhgDKihJL1g2KSz8gkKgGArBLA
CAAYsD0HDynN5pVmS2K2JmbLytHOvypmC0qzfWJ2VMxWlCNbUJrtD3b7MQgW
R5UWc2DRjJ3pGpAr7X6wmFNaHAWLlWC3FQNgcUxpMQ8WjR3z8af5BM9sDYLF
vNLimFwsVmwLtV9psaS0OOK15rPeMTBWAGNFP2Nnxq7P1mIFLI4rLRbA4h4Y
KyqNjYOxkq2xMhibUBorgrEdpbESGJsAY0VbY31KY31KY9tgrPQqGysrjW0p
R6ysNFYIdgoogZ2a0o7h33gSrnluKyul10B6PtjSXgTpk0rpZRiJGzASWjuT
YCdnW2IFMDalNFaRMVmVMekHExUwMQUmsrYm8mBiGkxUwEQ/jM4SjI7W2DQY
y1yEsQEwtgjGBi7CWA6MzYCxfj9jpmtergGHwEQ/mJgBE+lgq1gY6cMyY2Zk
xoyEla5fxbIgfRakD4D0qkivnbq5OC99AKTPgvSUbelkwMSc0sSolE5VSmcM
TAyCiTkwkbQ1kQYTl8HEIJgY99rGgyQnJtzGmPx/mZjy2j6vYxqkD4H0yyA9
YSs9BdLnQfoQSH9PKXgeBMeDrTVJkHkFZA6DzCcgcxhkXgGZsWDrilZmFWS+
CzKrQWTaDH8CBC+A4BEQ/BgEj4DgBRDsvmzBoyD4EQge7ZFg8783Y1KvJD0O
0q8qpT8E6WMg/SpIj3aR/jXsCm1iDEw8uAgTrTUkBtIXQfo4SL8P0sdB+iJI
j+AaEoi6C9KvgfQJkP4mSJ8IIr1XpaM1UQMTB0oTS6Z120x0tqD478NREL6s
pH8XhNd6Itx3idTKJc77SrnLUCwvU+uk15pRuiOX39Oga+WsrmP+bo2vMiKg
5jqomRI1e6JmVqmmtSh1u5jQqpmBcdyCcSSFp+N1msDdxrG+PkvoNZA5CzI3
QObcxcqck7Fdl7GdB0mrvZN0OixJmhdJqyJpASStgaQOP1ASRtKCSFoSSYs9
ktSajwohiyJkQYQs+Qpp/y5eOxFvQd5rkndO8i5D3htea7MyUtJlSTolSa/3
MukGJF3xWgOuKvfbay876Q1J2idJ1yHpTdukm5D0lteaW/Gtl53q75BgXZOg
NTkChdXfwm5B2L9B2Fu2OH6YCb6GBBu2CbYhwQvbBKd/ceN82K8g7GawitmB
sH/1C2uDYxcS/AUSbF10AvPAl/kQoPXUn+LR0j1I/2dIv90l/ZewK2HaIL8q
dV7Ln0DLjoUW+qG1M49HUvo/QvpdLFFKmuzO/zYkfe6XNKDnJPT5wn8dhByB
kL0uQgI9TNerpL6z6w4k+AISvPZKJGjV4hsQ9ncQ9naw5XIfwv4Gwr5ui+Mu
JPgcEtyxTXAACZ5BgjdsE9zz3mhgfgph923DvgW6n0KCu8HqhMJ+DGEPgtXJ
fQj7Swh7zxbH25DgI0jwpm2CBzKMHzrNG5e3bYM9ArUfgFrrBD+CBO9Bgge2
CR5DgieQ4GGw8ntHKL8rlB8HK7Ufg7JHoOyxrfUnkOABJHjHNsFPBMJ9gfDE
Ntj7oPYA1Fon+EDU7ova94ON+s8kxG0J8dNgo/6hhNiRED+3tfRRPbfjnLp1
/4VtsI+9N5p+A99sHXYJZr6A8/1FaxP2Ewk7L2F/pQl7ZpfvheQzSTAlCT7t
kuAF7GqNoRnrX8tAjctAfY5jHej7mDN92l/3pt8cp+Msfxr5uG675an1BY05
sFLvNduN39x2Ln0HfcItQA==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Enter the function U[t] and use the Poisson integral to construct  ",
 Cell[BoxData[
  RowBox[{"T", 
   RowBox[{"(", 
    RowBox[{"x", ",", "y"}], ")"}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"t", ",", "\[Phi]"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"1", "-", 
      SuperscriptBox["t", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", "t_", "]"}], "=", 
     RowBox[{
      FractionBox["y", "\[Pi]"], " ", 
      RowBox[{"\[Integral]", 
       RowBox[{
        FractionBox[
         RowBox[{"U", "[", "t", "]"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "-", "t"}], ")"}], "2"], "+", 
          SuperscriptBox["y", "2"]}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"Apart", "[", 
      RowBox[{"Together", "[", 
       RowBox[{
        RowBox[{"G", "[", "1", "]"}], "-", 
        RowBox[{"G", "[", 
         RowBox[{"-", "1"}], "]"}]}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{
        RowBox[{"ArcTan", "[", "z_", "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"ArcTan", "[", 
          FractionBox["1", "z"], "]"}]}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<  U[t]  =  \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], "   ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<T[x,y]  =  \!\(\*FractionBox[\(y\), \(\[Pi]\)]\) \
\!\(\*SubsuperscriptBox[\(\[Integral]\), \(-1\), \
\(1\)]\)\!\(\*FractionBox[\(U[t]\), \(\*SuperscriptBox[\((x - t)\), \(2\)] + \
\*SuperscriptBox[\(y\), \(2\)]\)]\)\[DifferentialD]t\>\"", "]"}], ";"}], "  ",
    "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y]  =  \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y]  =  \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{3.40018222021875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"cont", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"k", ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "1", ",", 
         FractionBox["1", "10"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.000001", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "35"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182125921875*^9, 3.400182128140625*^9}, {
  3.400182384078125*^9, 3.400182384375*^9}}],

Cell[TextData[{
 "Then use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot3D", "[", 
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.00001", ",", "1.5"}], "}"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"41", ",", "16"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<\[Phi]\>\""}], 
       "}"}]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "1.5", ",", "0.5"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "3", ",", "0.5"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5"}], ",", 
        RowBox[{"-", "3"}], ",", "2"}], "}"}]}], ",", 
     RowBox[{"AxesEdge", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "}"}]}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[x,y] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.4001821318125*^9, {3.400182389453125*^9, 3.400182389671875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Therefore, the function ",
 Cell[BoxData[
  RowBox[{"T", "[", 
   RowBox[{"x", ",", "y"}], "]"}]]],
 " is harmonic in the upper half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", "[", "z", "]"}], ">", "0"}]]],
 ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.400182479453125*^9, 3.400182479765625*^9}}]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{982, 627},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 297348, 7929}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 119, 2, 29, "Text"],
Cell[1027, 36, 3868, 124, 235, "Text",
 Evaluatable->False],
Cell[4898, 162, 5674, 179, 255, "Text"],
Cell[10575, 343, 1250, 45, 71, "Text"],
Cell[11828, 390, 22123, 370, 361, "Text"],
Cell[33954, 762, 3641, 120, 260, "Text"],
Cell[37598, 884, 2784, 94, 119, "Text",
 Evaluatable->False],
Cell[40385, 980, 841, 28, 47, "Text"],
Cell[41229, 1010, 2325, 84, 92, "Text",
 Evaluatable->False],
Cell[43557, 1096, 1022, 20, 163, "Text",
 Evaluatable->False],
Cell[44582, 1118, 1602, 56, 65, "Text"],
Cell[46187, 1176, 1812, 62, 128, "Text"],
Cell[48002, 1240, 12008, 208, 266, "Text"],
Cell[CellGroupData[{
Cell[60035, 1452, 111, 2, 29, "Text"],
Cell[60149, 1456, 258, 12, 29, "Text"],
Cell[60410, 1470, 126, 3, 29, "Text"],
Cell[60539, 1475, 4262, 125, 404, "Input"],
Cell[64804, 1602, 530, 19, 38, "Text"],
Cell[65337, 1623, 1270, 35, 168, "Input"],
Cell[66610, 1660, 397, 15, 38, "Text"],
Cell[67010, 1677, 1116, 31, 168, "Input"],
Cell[68129, 1710, 368, 14, 29, "Text",
 Evaluatable->False],
Cell[68500, 1726, 1172, 35, 212, "Input"],
Cell[69675, 1763, 132, 5, 29, "Text"],
Cell[69810, 1770, 1660, 47, 233, "Input"],
Cell[71473, 1819, 259, 7, 47, "Text"]
}, Closed]],
Cell[71747, 1829, 3617, 127, 101, "Text",
 Evaluatable->False],
Cell[75367, 1958, 3344, 58, 163, "Text",
 Evaluatable->False],
Cell[78714, 2018, 2988, 102, 189, "Text"],
Cell[81705, 2122, 21879, 378, 300, "Text"],
Cell[CellGroupData[{
Cell[103609, 2504, 111, 2, 29, "Text"],
Cell[103723, 2508, 779, 30, 29, "Text"],
Cell[104505, 2540, 3099, 82, 196, "Input"],
Cell[107607, 2624, 107, 3, 29, "Text"],
Cell[107717, 2629, 911, 29, 126, "Input"],
Cell[108631, 2660, 584, 20, 53, "Text",
 Evaluatable->False],
Cell[109218, 2682, 1405, 41, 220, "Input"],
Cell[110626, 2725, 132, 5, 29, "Text"],
Cell[110761, 2732, 1757, 50, 233, "Input"],
Cell[112521, 2784, 516, 17, 39, "Text"],
Cell[113040, 2803, 129, 5, 29, "Text"],
Cell[113172, 2810, 1949, 57, 132, "Input"],
Cell[115124, 2869, 516, 17, 39, "Text"]
}, Closed]],
Cell[115655, 2889, 6972, 231, 101, "Text",
 Evaluatable->False],
Cell[122630, 3122, 3616, 62, 163, "Text",
 Evaluatable->False],
Cell[126249, 3186, 3061, 99, 270, "Text"],
Cell[129313, 3287, 6208, 213, 286, "Text"],
Cell[135524, 3502, 16109, 285, 277, "Text"],
Cell[CellGroupData[{
Cell[151658, 3791, 111, 2, 29, "Text"],
Cell[151772, 3795, 112, 3, 29, "Text"],
Cell[151887, 3800, 2951, 87, 378, "Input"],
Cell[154841, 3889, 86, 2, 29, "Text"],
Cell[154930, 3893, 2510, 74, 297, "Input"],
Cell[157443, 3969, 132, 5, 29, "Text"],
Cell[157578, 3976, 1742, 51, 233, "Input"],
Cell[159323, 4029, 678, 23, 69, "Text"]
}, Closed]],
Cell[160016, 4055, 5224, 190, 174, "Text"],
Cell[165243, 4247, 1867, 65, 119, "Text"],
Cell[167113, 4314, 3536, 123, 104, "Text"],
Cell[170652, 4439, 3093, 106, 217, "Text"],
Cell[173748, 4547, 571, 21, 29, "Text"],
Cell[174322, 4570, 19165, 322, 388, "Text"],
Cell[193490, 4894, 5264, 181, 148, "Text",
 Evaluatable->False],
Cell[198757, 5077, 3380, 58, 163, "Text",
 Evaluatable->False],
Cell[202140, 5137, 6363, 210, 261, "Text"],
Cell[208506, 5349, 1847, 64, 209, "Text"],
Cell[210356, 5415, 14379, 293, 363, "Text"],
Cell[CellGroupData[{
Cell[224760, 5712, 111, 2, 29, "Text"],
Cell[224874, 5716, 154, 4, 65, "Text"],
Cell[225031, 5722, 1923, 60, 209, "Input"],
Cell[226957, 5784, 848, 27, 63, "Text",
 Evaluatable->False],
Cell[227808, 5813, 3933, 119, 463, "Input"],
Cell[231744, 5934, 132, 5, 29, "Text"],
Cell[231879, 5941, 2149, 63, 267, "Input"],
Cell[234031, 6006, 566, 19, 35, "Text"],
Cell[234600, 6027, 129, 5, 29, "Text"],
Cell[234732, 6034, 1972, 58, 132, "Input"],
Cell[236707, 6094, 566, 19, 35, "Text"]
}, Closed]],
Cell[237288, 6116, 366, 8, 80, "Text"],
Cell[237657, 6126, 5990, 207, 180, "Text",
 Evaluatable->False],
Cell[243650, 6335, 4393, 75, 163, "Text",
 Evaluatable->False],
Cell[248046, 6412, 7250, 248, 327, "Text"],
Cell[255299, 6662, 362, 10, 29, "Text"],
Cell[CellGroupData[{
Cell[255686, 6676, 120, 2, 29, "Text"],
Cell[255809, 6680, 75, 0, 29, "Text"],
Cell[255887, 6682, 2191, 70, 284, "Input"],
Cell[258081, 6754, 137, 5, 47, "Text"],
Cell[258221, 6761, 1693, 49, 220, "Input"],
Cell[259917, 6812, 131, 5, 47, "Text"],
Cell[260051, 6819, 1016, 28, 92, "Input"],
Cell[261070, 6849, 838, 27, 57, "Text"]
}, Closed]],
Cell[261923, 6879, 3562, 124, 82, "Text",
 Evaluatable->False],
Cell[265488, 7005, 4446, 76, 163, "Text",
 Evaluatable->False],
Cell[269937, 7083, 2508, 86, 224, "Text"],
Cell[CellGroupData[{
Cell[272470, 7173, 121, 2, 29, "Text"],
Cell[272594, 7177, 283, 9, 65, "Text"],
Cell[272880, 7188, 2706, 80, 344, "Input"],
Cell[275589, 7270, 129, 5, 29, "Text"],
Cell[275721, 7277, 1676, 48, 220, "Input"],
Cell[277400, 7327, 129, 5, 29, "Text"],
Cell[277532, 7334, 1976, 58, 132, "Input"],
Cell[279511, 7394, 619, 22, 39, "Text"]
}, Closed]],
Cell[280145, 7419, 3614, 126, 82, "Text",
 Evaluatable->False],
Cell[283762, 7547, 3730, 64, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[287517, 7615, 113, 2, 29, "Text"],
Cell[287633, 7619, 194, 7, 29, "Text"],
Cell[287830, 7628, 3055, 92, 384, "Input"],
Cell[290888, 7722, 129, 5, 29, "Text"],
Cell[291020, 7729, 1674, 48, 220, "Input"],
Cell[292697, 7779, 129, 5, 29, "Text"],
Cell[292829, 7786, 1976, 58, 132, "Input"],
Cell[294808, 7846, 294, 10, 29, "Text"]
}, Closed]],
Cell[295117, 7859, 281, 7, 26, "Text"],
Cell[295401, 7868, 281, 7, 29, "Text"],
Cell[295685, 7877, 276, 7, 29, "Text"],
Cell[295964, 7886, 284, 7, 29, "Text"],
Cell[296251, 7895, 249, 5, 29, "Text"],
Cell[296503, 7902, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
