(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    275954,       7074]
NotebookOptionsPosition[    270699,       6909]
NotebookOutlinePosition[    271522,       6943]
CellTagsIndexPosition[    271448,       6938]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.7  Two-Dimensional Fluid Flow",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tSuppose that a fluid flows over the complex plane and that the velocity \
at the point  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"x", "+", 
    RowBox[{"\[ImaginaryI]", " ", "y"}]}]}]]],
 "  is given by the velocity vector  \n\n",
 StyleBox["(11-30)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"p", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "q", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ".  \n\nWe also require that the velocity does not depend on time and that \
the components ",
 Cell[BoxData[
  RowBox[{"p", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"q", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " have continuous partial derivatives.  The divergence of the vector field \
is given by\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"div", " ", 
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["q", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  \n\nand is a measure of the extent to which the velocity field diverges \
near the point.  We ill consider only fluid flows for which the divergence is \
zero.  This is more precisely characterized by requiring that the net flow \
through any simple closed contour be identically zero.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIf we consider the flow out of the small rectangle shown in Figure 11.47, \
then the rate of outward flow equals the line integral of the exterior normal \
component of ",
 Cell[BoxData[
  RowBox[{
   StyleBox["V",
    FontWeight->"Bold"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " taken over the sides of the rectangle.  The exterior normal component is \
given by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "q"}], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the bottom edge, ",
 Cell[BoxData[
  RowBox[{"p", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the right edge,  ",
 Cell[BoxData[
  RowBox[{"q", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the top edge, and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "p"}], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the left edge.  Integrating and setting the resulting net flow to zero \
yield  \n\n",
 StyleBox["(11-31)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "y", 
      RowBox[{"y", "+", "\[CapitalDelta]y"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "+", "\[CapitalDelta]x"}], 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "t"}], ")"}]}], "-", 
        RowBox[{"p", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "t"}], ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "+", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "x", 
      RowBox[{"x", "+", "\[CapitalDelta]x"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", 
         RowBox[{"(", 
          RowBox[{"t", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], 
           RowBox[{"y", "+", "\[CapitalDelta]y"}]}], ")"}]}], "-", 
        RowBox[{"q", 
         RowBox[{"(", 
          RowBox[{"t", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\
eJzVfQvUnlV15sd/T0hIUm6BEP7cIAkxCdcRRWGsqIxtZXWoLGexLNiOl7bL
xgIKDpAAchcNl4Uo1KYWLRYHM6DiDBRBRy10SML9VmgIISTcQVrTOsz65jzn
7Oe8z3u+/b7/F3Gt1m+t//K973nPOfs5++yzzz577/d3PnLqJz76yY+c+kd/
+JE57zv5I5/6xB/94Slz3rvi5HBpcKdOZ6cbOp3OG3M6Q+H/bvhXfh3SDZ/O
YHf7G/+vu3bTS91X/vX/dnCp++l4ozPT7m98/V+69snXvv/MK91VG57urn7o
2doze8Y/Q91HXv0576P+mXZ5w0v/FC/jB//jc2r9ya0//0UucsfWV/eyy2v+
4bl46cL7n4kdxucU7edQ9/p/fCE/GWiZbF1ds2ZNd/ny5d1XXnmls7MVBUnS
yAIrGv7Fk/HbcrlmDSZK9663ivLoFKoKnWSrRx11FEDu3nHHHZ0pPg3zHFBC
bcuKy1Z6vlVs/YvfXk9dIUboqqA7qaUrqIVFw9jP84lZ1lZ6MDINSofB7vxT
6sre9gTGXTo/5nRlqhVFLaw8DP48n5hlTunQrbk+tMusPWAIVg2XOj9KPRxA
Ixw85YNQrq2b4AGBZr5dvvrRrdrwUgfIwJdznfbCZXaTaIV6q26Gx4vh3sPB
INQ46vR6FwfFMEwEVydZ7ke9dKiYveZkt0qW+nX/kB0P30Nv/u75n/V0XDEM
wHkdn1ZAAgEzv70fqJXFQ62p18O1yzY6HT4iteP6nanroVkOZ4A4Tyudn4Hm
kcZeV2LPis7roytae8CsgVOWOpcDHFXHVSBzEuqkCHw07HR8ul90nt+LZU7p
QIvHJ4GUpc7lUOEd1uc6WqFR4q3SJrTU1u2CjydgFC0tQk+ncCjylpZB+0Hu
O+6KeCLkhdQacvo+w4elH14pHpkrdMm08ngl4Fj1HR8SHVCb5YuywZa+60QO
nZ3vtJiZtk6SzbgO+w4xIQztyZbw/+21vvNm6MEsv2Wv77/hT+cJeEZ5NBQh
z6iuIaX1cmjnb63bkYVr7Iclc5bTcqBjwOn7rm3TtJ1ntEuhB03SMdzqKOcX
k6JzWyKFneOjkJOJjkneMEe6PUIaJq5eDrSqhBcGJ9laGv0F2W+Re3zE0Orc
WqeBuGOh3SdeGyuHu+z/bg57hkfmO5dFADbwkDJiwJGzRVmZVN0U741077nn
nq5+nnzyye7LL788oIQNlYyWaButcQIa0XHZrWWqeqpOaMJjsCzH6kpKxmK4
RjSp+6o9snr16qipQ2MP2vouNk5f+cpXuvPmzetedNFFeexmzJjRPfroowFI
Z6dEPee8SLYOSS8YqEb67v4oKUv2CNfhUgKKTKvPH072iekf7o6Pj8deTZs2
rXviiSd2N2zYYIpcGvkbbrgh/kWZMOr4XqO9Lk1DzfvYw0ra719wOUmnWlaI
iPlOZSKatbK8ig7XNF4KDRKtEo5E/7kNV+hHlzvSgfh7MDMBAJgiXHDaaad1
DznkECM3U61rceg0FbTAQt1Vq1bhJ/A3fg93V33/p7nonguXdE866aSgneLe
UHfVxZd2z7r7iXhv5Z33L+BleWTVlVcvtctnfeuW6vKX/2IeG/jiFfnyyp88
0l113vmdpbx38x3VvTvvj/f+PN4b7B544IEZhqH4ezjyATgVRAAm7GC5RQkw
RDjwzaY/lQ3OPKiCxGLt2rW5+t2skWl779M97cePxLIfv+G2mXb5rSf819zL
oz5xynzrzOjUXXJp/A3fg7Ct7oUa8r1Qc2eeVbf8A8fn6kKZZfbIsZ9brZdj
dX8tw48OJ+ZNBJgA6KW3vvaH//lEYJ6IWhJv+D3Uve7vNuSiF6z9XzPt8hf+
/rGK03/04/l2ee3/vitfvuLvH1tql7/zo4ohLrnnSZa+5q4H8uUv3f3Qsnh5
uNbkOes24enONfHeYHfBggV5VAYNLwiBY489NgrDUGqSEQlJj6IY80riUzem
yIbM29eeWHHj3+qs9uwrYYldYJcbdPdCBlA0qHAP/y9zhBtkQBiNzJWQD2gb
394vc/q225JqcbSJatBtmGRhuGLFiu7GjRtNFoxEMPAsVgF8wBgf+9jHdoJE
JCj1vofWZ9vl9/3ucZmRgzCiKaBYu4mLyvGGRS/vq3slfwCko+BQQPIe1yyw
MJ7Dtz3sGiS8fToHONcILEAAV4D2IafcOyiggzgEmAAVUiUI2LzbJqCoI7LW
TsB0J1yv8NQlLwz6bKsXdanMCEBm45iqDGEI5jtrBRdPruxqbVwosKqyCmVO
oQO0WGT3aRkGlkfbGGt8W2TldY036nJ/yBeBJ0xVqPPtErsGHsQC3RWhhcWa
5VgfhsYmsQ1NMlGSxxN0VsWQKqnVil5tDoLkyhYXm12xBJWaYrbv4RBAm6iu
64G9VdPnvF3k1BpwHpSiF92/JXIAuUOHmroQq8YExTP4tjj+nhzL69Dhfw6Z
4LCrVS+EUBnOIy3Ksu1RBlmmNiJajtdsqamNJtoqn8X3IHliu8fXR07NGKH3
1MU4cmGdUb3SE0MBq2Fpp+zPLyMMUn2jpbjPayiGLgmbSeX+JFbAcmeu08Vm
Us92i7zIoYQ2eID1nucNulJc+9hzZGM2hcLTjUMxxB/84Ad5PWoDUP8xnPhg
uEA6tghRQxrAv9SVUBL6UvgbQMHvafE719OW2jJj4TvKQyLSbole4bn0rbpm
Pe2k31a8WjSNhbn9l70IhoIwmIyKhThtiSYmERtE59BRcOCYXANXKrdMJItG
rLROvq8/8QL5M4m5sdrAgUH4/cz1sdi4cVnJD4+9tj3LKe6ru3lhq9bqM4OG
FHhr0BFpXKuAOAXtoHXaAIjIgyAAEAge7WEFIEA1kvMDSHFoB4yfGyqMPcG1
zGgmK8BCoe5cp32P336vzgaFXJhliCkb4IOzAE+y72EkyzoZPzaWA3a7wVJA
rkFp4tCvfKMsokgPQ97hQNHW05VVG+Vu3fJKWBKeifJCy4NdWJ4KK1cV3Dt7
/WYSbytELLRYugA2uviBLdhXxXKwjbEcTQeyW87bBZKOGR34aFLmEZ6XiaCp
4YAHwr287SwqmiqP43KAM7MDeJYT8iC7hgFEnyEa5yQWIUdRu4RlKvHHWA9/
6MIaJh6XFzOKxCJiOEl0jKrdJBYBb6PW0LkWsTbcI4ChgQ3E1SIBf+XDWzF3
8/jycBdP7y+DBql21SPbwrNnrt8Uuov5nnfRNv8DMNTVgRHGGU2cc+/mYWc+
LLTacc1kV6CkV9JweDA0oLibV8PBKE7IJgU/DABFzhoAinK6uuqzPCsEypxN
4f6gNE1gD7SiukkJw15jhPrWNp8y1E3DA05FAWUWxcBhrasGc3KTLSnihL8Y
aEpPV76NqHyLH7QeuHHEWcM5QLL/yXM2MAFZpUPVFqIEbALmH3EGcrERDHbC
s5gsoSyr1HWTtiNvzDmWeg0UcT8+gt+U2TZq/AyAfq+iKVYdkRWNojPodGaZ
wempRIGhjRtoAyiO3fZyuGGwKGq6F4tyOevK8qeGtX5lGMWi9BuWsjgA5967
OQ/AopZyWBJsXG0JqI89y50X6qMDxlIrh3nx7VDfyvWVyLkpfGe5nVsGHjSA
FtBWTfbJ6b9McOaFcM97kqYIQy6zBh4Lc0j3EWalsM6PqKTSLc7c+mAXLipt
g10sBSwqKmwmXs2G9AXpQ1qRB2inSIin33c//3oe78Ut5c7dUC3541YOPSdf
6Diy3HKD7IaNL3bPWlctERcn4xKHWadg6v5onno0HGJKgnKs4JVeuLOhY4yd
dcFqH9leEwU1ykB0GubUwgC3bCXjYwFTckJpElqbWDhZkzqTre5i2tMFSzmB
uk1xhsGixsc1TlCDKlHoV2yNWHlIfUz3vIKv35y5/IfbXsP0rFb28H+2lI3E
kb/8oWoSnBVG9anX/4XKEW5/6dFtUWccMM0RONA7S3c61N25NlHH574XVAUO
KQd9iBKOCtBw+/NUD+V2h+OsxfHBvAnXlthtiCUsU9BsOZLZxpjHudgYeONM
U1xx5ranM85kicJwvLN1aQfk1qiNNuQWzDts+GtPPJ9PeMLQxSHkvWse29ZZ
YPe+8WTV2bM3bI5W4YOtHQgK1AndUfeHFOTUQUzsxm/T00CGHnMgAT34GXSG
y9QkqLSDOWh8+MlzP8PmIg6F7VlB2H5pKFhhsVUnvr1D4R8Eqq3RPmbKqM87
lTCOPTvqmVRBdkzCTJLeXWC9M2WrPmbGkWeFe+g5x+ynASaOJ587xHprC3RN
WTEvybyXRG9pBuHijm5SFeUQgWqikRTFschnNz/9UlD4K4GPoTK+2L8+VDpr
QglvqGiRK6SjKjE0vs9IvBXAHxJKaqZxo8RkZG3X1KdYmCyDc/59CUiIUT0y
xapKcfH5B7bUBgcDt9IGxnYG2ZlXV1ROKB0g3fIQ+NkyXzjJ1GBKhYGyG/3G
xIX45+4ssL7u7W2BNgUwqxqF9ybtWjpYo4aqFsXA4WPGUXPlSZhjPuHb3kIE
Jz3XNXDUOQYY56iecOE6foJY3U8eSXJiE/mlc6g1gXu2KLsYk3W4z8K3twme
xH2uXRNpnreuAPHmp1+O9S2ug6gSJzzaDOJYz8HJq//6Rn40DA9xxADTWkXt
UWcmW8Y4cMcu7sEYKl4O/yuEqufiVOUwq53GjyYI/0DmZrkZPDesIU8l65eJ
9bzxLhxYd3eg8bbWlz+8lZ1Qt9UZ9jgEGQ1jlC86L/JB9MaN8SgHR5gbNmwY
cTqVD0vrW7TQ6n4yuRQ1FAvXFtpTONVG/WgntEd38yY86ddPPMEAVzxcV8wv
uK/aYC2p46n8E6r38KTdGFSiB/i5JFoHYcnd5Bl9yXZgMYpRVq3zg/MIR2Ol
iwiOyHGiqfgX3nfqqlOeBira+pjtxRgQgBaM2KReWW9ICXVCwG/VZFgBhAmu
zoelK7p8wghGhLAS8KAtebFlL+4ibGK3xmGo77Q9y+iBDqZDginLDUqPizPw
jgJL7rAZZ8a+Yc+a0Zlf9Fvbho8L2yZTe7tDtGdhGp3/0lgu6PYPbFHI0qTL
ftqkyBaDXRvlRN1sFU0SFJAYK04bci/4pWZACtcOP/zwWHH4SU0EdA4/4h3d
uYce3p190GHx7zuPPDKg6t8L3wOq6d4hR7wzXudP+B5WkVTzoYcemtsetrZx
3k9UaQwjD8I9iDYW8C7tcL/XyNPDFCdZdkGkL69DW9gtPGgnCYKllcA7xFb7
RrhPsNVz7MtGMK3jKMFDAEzCcnJSNuIk7VgBxo6ke8ole3cqB+KpLxrx9Ecv
9BsKOiWeOomewOLnWxtftMXF31Ps5lA94lDteb+Ii47qwHQVTnM2GaZ0PtvS
Q/1dfcjYMpYjtswdDu38ymCKN71/0JWm6a1qFMauHpWV8S7ilTy8aZL98XMV
HivXR/fIHHNWnHSTwegtozMKazwJ5gKvox4673lD0euRUGOEVQEwLwtq4mil
bBmOYWyZzIARsyisLO05l8GynPP4TllFLZbwq60Vz3LNOjxBTZf/wjGBupEX
KvW9zRVrf/2JF+jaUBwdkwZoMuVqoGssFbZiCW9DmSeQ5RyDDw8h9hZAczqM
JajoESZw87CtAmgHdeOeRLcxHg7N8HwHqPOcPNwbEj7HDMUgHZGAZnxC4X49
IP1g32j39CK+rjCjGszr4RkVKaUL1W7GjBiBsbGxmstdWI93bngUSznR9zx7
F1q16LFj3eRJJVZ8mWHd6dOnYwA4PmBt1B5qNc2/wt3Ye8g6UcYBQA+hYwE6
j45YVcOCPy6BliMV/9FyAYuI4xoYYGoj8Akm7OKxEyLCntNl6AUFDCBANZdd
dlmuxgtc8IIfQzWLDEnvQEGESag9tgJHY4bd8PDM2DIBPBIbhFgC3UDNaqZ0
XitHLBrzA07GvVCUmzT0AbUA4HclgHc1gIs43SwHwTtTHICnCYi2q8AzFCuF
i+puBbZVDfXFj9zqYRv+906uvD0izQ5clgHyftJhlAXBgXvy1n5dlki5SjDO
9f/4YoRrlg0rzSwYJ0CJamLUZJoMYGH0zGT70QpyfWW86pG8vVXvSi9UmQsr
2qPpI9uie9xeqdwp1qyhONhe7sO82GgtT0LQUCCK1irtNhd5RXyxDTCoxiBz
M4q1bSDDns3TWZDDinZ5wPHax7ehN4Pm0YAq0CQEySTzYgY9qBY/0XgIB51B
1ZfCSpVqRcsipo5JI0PGTAan+t5POcobFi7CxbFum3AnTDo2rKYYhAnGphQv
FvKt4QZ0qPXGhkHO6OSdW1+LFE/mmKzfRCtnZ6aNDAihDAKCmBK/kyCcIU3W
h7JuYGiG0Pc9ppguQq88CLlK60iEXjZAyFOHUhExU7buKMpx8yCUtcFYZziL
bByb3vjUSzhtCfdufOrFAcx7qRzFd8HveMnWboIMytH6cQlodqJn81tYEzyg
iVARJ+Q5uIYezGjE2DfcEOjCsHiAdccW6ppeTeEhQRIeyDy45OaL8hVzMwBv
CS4o8sRPOSHjrVwUxoXmSyiUhwJa0x0o6OfsRVcta4AJm3IGDIh9K3NMyYyQ
bzOaABlAFZ9NtFNtkQqyBHtKJLSXeGJXp7N1LckXY9McUBis2Kwq+aAsEc40
B0asCrr3JAlsVvH4ZkJhD2sBtejh9xUPb3UVc8aMFjrgTP+yR+/u0qKvvrQz
ASYAPChUXKqb1C7NxHJoYi/XJ2LNR8+d/DTZFEpZg67Gc1JaXvBtzAGAkHt7
vTYAqMSZd1oknVqYGpqmNgMw06rXA+4L70vncR6fezGVYdw8BSpQo0EmJldd
ALhA6dQNBB5onVP5YppTph10onrsozj48Mt47LXtE9HOhAzcz2O1Dj1oJrtu
uaJ5aU8jy9lHavlJDt2e6aCBbvKDSj7wy9eeeK6jJ5M8VJvSTDeTOUQHFBvz
wPBedhhPc8h7k7qEQgdvfvqlLDHVOWDEoZ3oK1MHRm6jPR0bjMaqvxyu6Qk+
DRM7T0R3GsRzNmyOGxWqSF6uFm9JD/9HXqBzMJw/ovP3usrIp6aMZsr99b+N
/KVGPg65rkoOyXkTY4pAnrMO+QzIKNwEPMrLrFTGIVwgVd54AtcjWsEvA6aa
iK4WvMHuo6HXX3zwWfOYqlQ1HimNNBO+jyOcJJC2l3B/npN6NeurYbGNekZB
OHFEmXplM95jli7MdJMtmXoeViTiJqDeT6Lh5Z6hdCimPI/h1WBAhr/0wS2t
1O/TB/VlbK1Sr6fkgw71A83Uz3aoCYPlEc75UUx3GkrRQdOH3MCVYYfw2Q3E
AfsmwqsJkQi3NdEIH1HClWCjl8EmRboXL1EPp0UxyVUlgjtb1v8e2pqlpNK4
r0MHJZbSWMYGqytkebqJ79+57XaXtvZw2V4C2xbtUvFLPfNYeLwPKsswWyxH
BztUkns+fM3fxPpPO3Ml2XXcxqSIa/Wo8zhbluboRLWe62M62PZYdI5Vo7I3
VHNQA01QOzXkndyfluYxpTPT986ProjXQk//OpHJRougdC810L5O0WyxG+4+
8PI/RzWAKoAerCmZcx0yw/8Hmcwql2LTMtkhqzl+06SB537zJlKoaxKPmi90
gEorjPVnrPQ9iGWEfPJDsZWmZgJvT5pbQ00e4V6+mkz4pB7Cjaez2yH8wnjW
Q2lz4imnAxHvTPNcYRseF1Ga712nvPDqj632UN47eTHZST5sQnQijObNXvLL
5D5W9GCrXVEBHfe8+LqrwNJ4IgI3a+DhOaoBxuWx8JnWGxbDBkWP3am4GEOk
cRqtCRgIcZ0LnDaFHY/aWsPmqxeOXtUTyuzBVo0uHUFNVsauw1FfcIk+1Eu6
aimLQGkEi5xu5fRst3RHqI4JrMcjNeKO++QppIjzujC7zWxgb04xxWRBAyZY
Cii+MSo0arOzarR/iwOIxpMC06aD6JOlHP0zWA79sQMQE/gZEF0FP/uTR2O6
m9C8l8Et2+TGPJuSgrFfCxZUStSvQc9727BQb6OSOXTQTxIsWB/tMLSiYCKV
fhcSZDooTXGOUXPQiXPiV/+7CEj/GHimTcoyZ9kZZ52V2Wd/eb7UcZZK10k2
DTRwASeJTLKhkKmXGNhH2UKPdz9sfeQSwfMFnluk5CDYGw53/88Lr8cd6+Vx
9/h0LaRVfaQsQsdLuBa6M+7MuTV33U/Z4qWtm2lMqway41d8hiAulEdLDPVw
gIYensLC6YUYHuBgSOMPxq/0BSGG0LdPsHJ68DJm+raF7OdoCpNj+9Uh0tEP
6FNSa5Ki0AmuRirkA+7cdbJ5KExkr6YcLjojJVQ0DyeUorCaNUJDa3yvm8xQ
bEfcbD7koDNsv4nOlY9szQ4fi3Qi9jgtjxtB7z7mP+U8RdTcvPxLoVY1FRGb
a266ZXEDNFUAzkg2FfEe+vvDba95iOzqIELrhnjEMIYitPIfZX6AeEy7wCaE
EW1hpiFULPRjSR2WgmMIC9b7he96n+rijas2CJ0p9979x6dGaj665sYoGjyA
KNoOsXsQCWdv2JyjUKDgL3bQ4f6fIevqt8LjTNwL/SiTcJtbxdvtMkrxvD+r
kSNZkePPFx58trvt578wz1b6QKsACYNB3z1qSdfc9UDW39QixdSF5TlTJZuG
u6eckYQ6ti28NzGC6fwY7G9mQMq8hQ6ImgJYYrvV/4cuD6FWLy460H9oUYmF
qIzajPzKo9tqOEK1S4IiaySafJr7K82/EPpBEFXJoa5VnNNQtlONAH4i+/uB
sHRTvzCF1+zvQMhtrzqfhOKknr4JTPqzPYer1dNEsoOhjCYmFTzj/B+1pUA5
HB9NXr+RYZ3ZN7VIk526XE9x4TCil2U1cAPtT4R39Y3fq5kAOTpcKEoPWOB8
qN3Tqk22mjdPHWTNvEw3qoDWmIHMM3mesF90/5ba8Tk1W6qqqIazXgKq6E8C
dsQw2piRS3HJXHRNnGeP1CJkmIaeModISsZV9YtQNejIPNsSfRiUe/KEYHtW
y0OF3RyfH0YJKN6qdhcOZ1nXSae5uvoOds+775k43+9/+Z87cUUqVGc6xOCa
OfykFMzp8IJjgTVmZ6sYkwI9FXmeDxXUjacYEVX6QrVlHrc7JJOH7i9zgure
aAtAyZNhHRF8gAuHRVOx9DMsDd6EfOmDDssSeYRuV+TKMBw1L59iZFAroR02
XyppNYxMJa8ItzmqWKrInrxaBsosB1rqFEVWXtXIfX/7kR5obRg8C3c/6Mrx
QL4fys910KV1v9fdYiRqJJc+8Gz+sRxLQ4B9pgMxOZqebaDw/XUYC32rGUbf
5uSp7qEazx1zwIGdOB3QguFhhqHqOKI/jTsYMsEKqys0iLjtHjLBIB5+YbYn
vLhMogQFyHbJdfWfE4b0US+c5L18PXRa9tJ8e7now/+em+VgSzX9YFjGetgs
37cRw3rAUwp8zMlKCp91L1nJsANRGAnmWS386TzXO6q4xRHDkj6o9fSnUH62
Q+0365T1kYaFIr5YLdvktuf1RoAKH4828v5Dw4SwlXRWM3llbhH8hFns5ZwY
aaHDE6DcGnjubA0RM/3QWDKsRcx4/tcFjcX7RDwaRx06yvT3BdvRjGZO7vHb
5EaSfYvhxHR7Hnx1TWvPZgCYIqGQSl6KhDGHyIbs0FHjSzXQbN1E+6jQXgaK
knbPbvNWG/PyWNQywExIsv8eAy9QfpJDYPg/0V0PVQChhAeGpJ0dgsca5gMG
tB+Cy+y3Jqf2aCZYQ/NlRnm0enM+y6nRHga96pHspenSOkno0f4C6jZaDzda
y72WCa0yzlFoZXxZEUDiRaVrio1yIPQlWLAApqAdN+eo54vHqr2T7n7oLl2U
zadh14npLqIdPbo144VKSnRu3Mqr6zI3T7pz8YimKNGVJtThvW2lTm/dR4MC
TFP8TG8m3HuLWUP8O+dBMSpZr65qcH2SPJq9pCXh/yaaoTDqkRar5hF6ud01
j7QW8stodZtdXkg1WaQQ1CR/q2QsIZ8ju0kb+d77+QryS39bzXvECGl9y2S5
jikbtPiheqHloSoPB3JMIeO4eVXHPM9G5PnvTDWCvQXce2MSwdAs51z0qI96
vBCutWDAsKriZVFexLMGJJYKm6Zfu/IRMfsnDxiPD3aZkP7eY2RiSkkNPNoU
GpP9scTkiUDw4+O9gGTG/XmBAprM6GpBwhIxeZzA6sqc9hjZt2h1RfqW8+97
hoTq3rGJGWzRb8GBZqti0fcgIGRe7AC19794/Dljgk35nufjNb0Bzq353WFD
eXTNGkdho+uLMkLp8qU5/kabAWCMUfHmoukOAF78eniMmi3PvtDf0LhH9gwh
W8eoMldUlsJVYuLSM38uhrL4u9r88MQ0F35BGkPBWtrCslScZ013CAn4s6dU
KOJ5wjEsS5fY2ts7ooGE5nK6r6iWoY7fqh4wr9eAIEc3oRbPXQYUF6mPY/3o
JKz3XlhWW3wZ8dBTolCP5zmWmh/zFMHYBfBEQIDnXEyLoWfsF6fMbrHE2wW4
MpWTpsBocebNAf31MFHarJtD1Hq9M3R37+Hk+ZLtZoDoVCMgfD5QoaHVwO6C
+zZnpeRvNlY62RFGTbkLxP+hiT5wKIKg+bSHQ1tMWZOVAxh5TmQMgtKpdt0T
z3vznYd/miMTPz/e9rPOOwWnugI9nGeIQ3xOj2OjoHHGurfxwnh4nuDtbebb
U6UYpK6rCHD7SQQ0vaeKRVoq4aW6Mqsim+LMPdLq8FKbnfaN/+GLx+qUkrHa
F4n7nK5CbcFbKlCyFcSf6EI1h50neRc/8IyGF+o5DOneysSE5iUCPemoeG+0
xvb0FIZnKcbieqV5UFOKdTQNTButjFwq1HtaPmq+S0C/R/AN6vTKIl6PEXk8
hHJIS8Kcq2avP9Ka4gqg7tB2lN8xf2htkbxAGXqO5Bv3CC3fRWUSfYF1TukX
jyvOIg0sIbR65q8pfh0/4aOsGjrrB9pqE4EnwdfV567uU8g/94c5wla9UDR1
dPFXteG8MKgDFa1pOs/Y5uclcEU13DIQKfDxkQYzJdKfnn6Gpg5BzVzSv5aI
1YiZckOAnLVtxNIjzBPJ5bIlHlE5uyWeu+6JepuQwWyTPg9eGrt3GhAie+ND
xipKMdfsqFbGUOqrE+0cLBUp+Ln92VddJt5b6C2Eb1qKB/CvBoDQ1wmzChsU
1gCLl6ZSx0qz3O6p3LNdSH5Hma40mjm3Le6oTBsP0fWlBMBeAkAOw1iX9A5v
wGc5gLFKdofR+vhGKEqnpcrRPoWAnM3YlvVpH7fcacckhikkdSiG+oRC/SCl
71clNBhTlqM1wk/YnntA8E3FhSUuciCVuDCbxo3vSqcjYxrlJ7N/xgT9VVSZ
H9rydgeC/L7VhkAlMYapPsupdmWCgNFl/zNoOlwOA6Be9GU6thstl64MCcZg
3J4j/Zj8bF2U9JoggbcIszdVQPR6RJjTDXcwigVHzEtdSSxU5qjx6YoEBMPO
kJOGPn+hB140Jn3TdBt87r1Pe9oea1V3BnnbmAeJmttKSLzlLtD2VgcSL5sn
mwV959+3uRGSyxUSP3eLF6lIYlEVBuvax5+DmkWNQdVAVl26eSQLXm+PVG6V
4HhhuuVxniKjfqBrLVQnsP2w0+xlCQg69xVBMM0Y1KNxPd2Q5XodNHp0Q08G
l7SXpzpYQg5rpL2+uRl1mHF1Itzj9IawzezCICZ/TsHzRFdsJtwP/+mH+nKr
qlnDPerJoKuyP33SZ3mg/EWl3g/U9EIfx2XKlSqd7j5nORA0Jf7FQE4MwUjP
qmGm3YMdFDQlE8LXb3zqxeRqLUFEUMrIC5cmNMaNF4rjAA+IudYpzPhzJFfL
yg2bKr9Iz8vED1fph/4GyXiQQ3+yOUzKhhCINMtJw5fgcdHofD7RzriJ4v2d
XmAoDdxxjym0X5YEpzf2fKdFOYZVuNnEtJfCL4zSgQ7tml6zZFENEb1I6a4f
NFxYBQnWCFevWr6vREzbezuEjziEk7g2whkF7Em95Q7V3H5Q4qu2qJmtL0hU
MxS0jBgqKNYAPaym5B94KXjU0i3DW+D7odZJ7JmdxJRastj2N6rEyl7G6c8l
ahnhWSQJqo2tOgIjxbe8diCD6zlkeAkGJibVd4YNz3ohfFx3vFzwqJbxaOck
asmlaqv9wB98nD3XqLlL5KU7IHSmQ+gkhxjuj/ohdPsb9YTEdt8LvJsjTFwO
q+a1XVknVAUq4jFHp+6CavUd3+V6U7r23yHuF+X+ZyJCGdFcZj9DO160E93Q
vdA4Cii0eUaiknPQi6Bc1ELiHg6JdOLwctxMTGLja8UWOVTytIZLEERGmUh6
ew5KzplNFcQ1d93fFGgGAstct3c0eFZczXeYttPmTcjAbF4wEekln2oGLIZT
gE8ts9/+1qmTv/sTXfjagug85+YGt4l+aPO8VIOs9aJ8lrTQdrWk3j1ZaRvu
vu93j8sxhdxAtcUfeZ7Hu+w4gYylK5dJqNVeeM2yRupS7CU9uEP3/7ROYBkd
CH6msd1b7jw/4yaHB4jeialMDl6l12JDXMtBhqVMPzzqRVX+iRJaaXpfuvsh
N4tsWyyC5308bQeJ5vTWCLXSczEA4UWNcDsoablrkZKSWf1j9alJom+780ca
g9dPDAYmuueRPL0Puj2xxoixcjkBS3vBHIcbCZp4O8zAMrLRko2m1/XUXupC
Ar1gOcdt2YsB4Bri5Zic8aZw6HViMaYfd6B4h0Gx1SIUDYrRggUs9IIylj5l
aHS+XCMult2AphD2FTtwbp/L8DdURR7ScytKRA875sr0HCNK7GAz7gc7z+s3
UO7FYjCiuohtZSy+5k5m6EooSolGka3pRvY2fipjuIpd1lyFt26ACk8xkKKP
cLYlRV8U3KkOuF7iWALYBC4G/bCWCerFfbzHulu82C7FsA3nYCpJmpwCgtIc
He1xCqPKnwXPgOWYYJgRbT9Qn2n5ki1tnaF9j3YvitALdQsNt8E+xYF9tz5h
VwfDtfkFb73ywPQ0LyTl/VJdEUWYElYL/Py56uFK30H821cfjxmwk47RqUdu
xlTtU60i9Enzs1dOkTk4RfWEhlBNGsnKKGUMdhvSnh/97n0g7UllIq2vUBCt
sfnFBNVL1vCuykXGv9vfqL9tgOyJ1VkDOa2ZvGLT2JBSgGyaYjc5YMyyYoGH
lvqCMYdFxkkv5nDIGRXxPPdQ9kJRvAS1dZQbk5wR6FJ7tW3VTAdobnrk5Z95
MddrJI6vRrVBGXKK8rX3Wy1W3OQUX1mAvl7ygKY4Hoq2VJxpYYJcjoPpMCDR
EXKwssq54Z9hUntD0RDCR9dPHYrQHW8UNKtg2ygoP9uochS8DO9b+SoEP2GJ
sru+OJpvs+cZo7xHN58p4/2dfCcq7ZjCiqY/1Lcl4f5RCVyGVRWOul5caEMU
oQdu+L85WbIPLhNtetOF+rjnh6GnBV5kDlUfcKq9DjN+7rnnnnwyAaj5+kzC
iu98zaNODEJtPg3hq544avopUBJgfXcCukwFgp+AQ3O4pv9mwwa0Pbd4PThW
fmxCu34Q2GuksQXSA5kzSd7X3eHLyvFKYbxnFh+AZ6+XHjDGxptwtQjGCNUG
1s9TAff59tdBuWbP5CRdzCaC3eh767AXPske7F6IJS2xhF1HL2Dn+eBrmuTy
hI6we4mCCbu3WgbCvOgrzjG+Ij78zdsL4MV3WSfMJufX/eIvyoOf7fW/8S9e
IxvuEXYbhhrsaArQ49tnEsSM2nMz6k8cxClLpadEtOVi9sp7CXvJ9QxiLNdJ
c4TyXjFBiAElroW/GWLAVX/DbsLH3lyfDW0F3IQSI4TLeA+0QckgNjehrx8X
6i51PjSey3yb/kYoS01ZoSytncatXswYTzpIN34gDCCJCZ+9O14ESIKeMNMu
izL2Xm1Azsej6cUExacVUj8ipy0GtQisbcPVc72f3VKe9zz3pabYU2NR70UY
xBXTkrgCBEhQBabE1QSx4DocWdqmPFe7PPW1DgPXi+0NU78ZVz8DWhu4nhv/
vi3lZzcwpunCE/CtF9/G971DSyC+xAh/obR5GFF15nPg4VCWOyzAi8tBIpjS
MVJTUBLCsTqTDl50cUB+oihbPxCqPSRQ0R7vA+0G5+IJuNl70wPRBrLKzfiY
qpvRVg4elFGCEIYkwQf3URdg5sJmswNlOtRDUDfa4ofDE8p2avj7Ti7NEb9+
BpSJ4hJ1AOY0gGy7P92WOG7PHIMGjveC+KjpEwP8BOlCww2EhHwGgCUFDeGv
uDrtWvgW9VEpB8iV+6me8INhCkNkmVx4qlNkS/eA50Qp1IykJo65mAvedMkp
D7ts6JpUZwiytzXwuw0F+c/DGiAR6wAgM97hMtmfmAS23ycBfxrXxRyBXLjd
tEUgF1sIvpukJPu4T+WQg+y47m3S2hSvt1k31NVPN3D0n/KCC7mnBzNiUpva
oAxHJZUMB1SoBnAni9WRezybz4xYLvZYXsQy4VVg5EXKxIOO/Lfe/oN83t6G
ValZwSz8dht5ibDISovk1lOIFAvTAgIW+D2qky/LPVuNshzFhCY2VNvxHPdX
pyleve8M2j5BcLNnN/SCQnkyBsSI5Kf+6tuxfg9NLmi65OtG1+QjmQ8bKy+s
uy1skdIFIo0ibA+5RoTM+4ChvDoHQo/bwp5Lc5+G7PGcEd945MMIILjLE3yC
U0ZHKDgNXn/kNjRT5vxoD2H0IpwD3c0Rzr2py3ksameLfBclZXGRhpRUlgen
2O1TI/SEMiMCGABRjX9rlKKemZVZxac5RLJ8mb1zWxzQVT3B9XQIIbXnfvMm
1/9/vkM2ZxHJLtNr4R5jQbxo3bOuv7kkl6dYpSefhq/w5bXdbtsrFOvsf8n9
W9iqxhcutKKy7mqmTuPOGgDldgmHlwTAc/hLp7ijGiDXFKbINyAqjpJFyuKk
G+mmlLh1y6sMIawNZZ3oXld+mIZYXg/YmigHdfvaZGnw/zvCiCfTl6GL4BAL
XdzdiurcsbPXWBTHf83vq63C8lCOQZZ67k2HEFVp6cbuOX8w7rE8dLYdnAq0
0hcpPM5osKZ4Rob41eIZfWvdgEOMF+1DIIg1HPEIhL701wNisA8gGjZX5H0v
JfARxtCUa06sI5msFus4VOO1s9Y97c1dD4NdHQzojIi3M1GaeRgMNWAAHqU7
rTKnHajkKeBM/mrdnzAKUmPg1qg4GKTfh60VVfE2ILgbp0vxpQ9u6bApvP2O
z/KkU4HgSXrpn6VAqILPFa5NFuQdoP+uFw3MHnAQ+Wodke0SDONlEWl+CeNw
kI6Fn8Ozr7ns4Lm6lyg0L4aNCWy9yK9+YyOv1TlSz5FCJvdelunFAyOMJL+u
bP0mocp3gfc8R4hCySe4N249aEhB60U6NYdH1lFgOfVms7CvfMQsIU1kJ82Y
4SHDAxO8FPO8exM1OLOvwsJ9j3lnfTBkGrcC+zbctoniBUL1Ey/Z7Zq1bwBD
YCGBe0lbl0lbiJ7dWqVv8kKIwY6fR+zA+oq75ztITBKOd1bKtvUjx2I3pp49
xAHDi5RsfZ2jsQMIME7ZW1q9SrJaXXBfXCQ8BtEzipSlYVOudZ4Dy2Rpwjmn
95YULrlNs8f4x4uRmtKIyZDmFNBYVl1Mv5BgIY3X5kxXlfrtBU82nS+od6di
MsUh2vggixNvF0FAyhljqpQXOLWLAFIKVTRp60CWD5pzyQLoGEV6xcNV7quG
d362nQXMcYCY6gDB0ScQ3m6CS4X2llJPVhzXL8F72dp0eRZloT2nZ0dyzFDR
P2MVRpoiMRinQmjdizQdbwFn3AGHbpilJgYlQ0Wro416L1rkXPdc7UI1HizU
I9GDi0wv4RKLNABU3y3acNywwKtmZBX0Ii2brOi1bYXvcu5pGwmOSU3bkGym
xppMC33D0b4Xq0UjpKoa9MGEKyEl7cWKg29q80Iv1cbtiEgv7NSz/pFABjeU
W5HvPP2ym9lpljVfShw7F1IXaT7i+elz40Vc4Us5yVgGIgP5Iy0KI73I043S
NJxiM71Rmr0iswpCbM7CVzqdMj5AZ8KZ1e5KfbvJLA3nNZzmeISpRDxs6MjG
F4eg5euffAHhl2lIBqKZYigvbwbUeQkoBnY63oheYKcnTb3Azt9omIS1pTkN
6GUx1riKs1bBSxtAw7nigGCEy5ULbR0jLrrQPL+3+ZX0jor1/kv1sFBaYCTD
QMuZcPynz8yEtm1UvDDQXQUYh+HYe+4qNZoKmhOBoUd+70HLSF6R9DWDoT4v
FmRcxsEL3sIWEGtCEUBZArL8A8ejWkqHcrvSFClKm4y31Z0jQJBAykVsr7n0
jAuHlKcoQe1U+z+xG3eAmOcA0fDOtM8mLDgjerIM/HSd2f8aQwS9SEt6BXt8
NFc6x9DIEWEKWnh0NCtLcGB0L+OCF9PBoMrtFgRm0aapreEcGqQvHDo1obGf
oIGQWnYfNiqi4a2g4tagaDR554KTuFXky//Ov69SOzGpKSzJQShzVlK0soah
edO8EAx1cZZXlxF0td0WcY2/dcLvd1d8/+5ajxc1SDHTSLzQRr6preQgC2Zi
HkAqlcyqcKa9X9uKkTRNHcdJpHuTfRwIlgoEEt/jSek/UwiS/oGQ6kvuebJm
aqqbBn3/aUkkrXBwj+2pMaGDGjt8S5Dvq9ZvToxvY8WzDGZ2YmSBWbMJib6j
1AsP0TfEc/hPUdob4wL1nGd/6Wxb9mkvNo6Gg1Ji4miM0wx5Spg/V7hs3HpI
HeEv/+H57spKNCDrbl2ddw8DNbpVTzY0SZHODnbKyywdmuNx+4c+9KFY3Ukn
ndRds2aNF1q+yja9rLGBe1SfwUvHkbmEaJyTqqhCJYbQWGwUjYdO1Kj0gsh8
K7yG1evQYFjoafbKKzl/RGfQfi9fvjxeRwk1I9XWk8QSyjVt7zDQddMyOWEq
rOPA8PXvNPRu3LgxdkO7hW6yW99oRkRf1uj0WIPeuZsjGCeeeGLXnGDCIFSt
cvbpfHcM3U1cZTygi3m5XVcMKGmM/lpvVqxYkXvz9WYMhqwnXuBk6B1zbQFN
tjBiLWzYsCG3QNOoY87O58eevFCxOteh2rPZ0WyD9ss+2ajHEtc1U03LfRnR
WAWDVcJDq8dMgzhbFVOyJKefj3/mv8UMkTiwxM8Jp5we5lMyV//J6WfU7uH/
cG2+nWycdubK6CaBo79B+w0vJjyWLHap3DHHHNPTFQquCSjVBDUqbbBLONQB
8stWPaZVH9XT6Ex1HwKDPDM+Pt7DlVOmTOl+97vfNYNYGopbb/9BPOfHyS9+
8Erh62+5dZHdDv92//gvb6zdXn3j9xbYFMbT4SuKhFZCgU7yGrjmpluid9Oo
lUOraB39GLbeoId9zJF3ORxBgiB/WcUcw9rLzbDY5pmn5gfQqADEza/NkTK/
D4aMBgc0W3ZFOaKFmt9kT0JxXscPhMjatWtpi/dSL0jG8bqKviobBzhJF0i5
cmOm77qiDA4tqxjrHnvsseDL65vp+KQ9WapUJrn4YmnxF3LXm/2cjnpa9reb
e7JCxlbH3ZqhIUR1I+7MS3ZQ6U7PE93MhCpvau7Ip6wjDadGNDZyG4RvPK3x
LMOogomlHm9u9c+kilK+ax6NAQdVTT9QspM2/2hz86cY0WUUGKrb9vNfeJYr
jrmXD11bfbi51VNtrpeW0nPvrTLw6w5l/z6axKA/2Nwk5Src+eg0Sm1J4zKp
/a596iUezOUumSkllljU0iXlw5P6bPe3m7vOa/0F8aboGvjGwumaefqKwN5B
53GaWTHx6Cvg+bdQNnh5ujEJqPwf4LSx2Ln2Jrv9nmbgKEYnirslmHDz5Bgl
fWpUY3HjhwGmqEsN02Yn6Hi7SSLBFF6KmKUSibyyv/SN/V0i195sf1ugohX8
VxE/C1ZnuTlSjjG1+iwja+hTiOlF087FD2zJlp11m+J+DoV4jgLUjVczmgzI
hQ1xR0miRZ4hqvxYGeW9XwXFR080GG8qppZ+B2APBnLyWB9lyJojUs7qSzFm
NiFRViOfNEZ3QJ61YBEzZI5GVv/iQ1W6QAwgkvhjYHggyKVZlQaIWCYo5FFe
KwyDCkNnbIdIHM4krl69mtV2/j3D++5mppknxX/JiGDNPwA0EBTlUcVyGlCg
M4ooaVhiGWFs9cdve1qteLME8kREhllfmROgu+vLnznrS6YBc9GY2QvDSBMM
HtP0S+LArwfCvzkx3/QX5pzKofuI0GvruiasYJcY/VSJ4MawacwEUrSXVXzn
1tfSW2rMHUL1LGa55eKh/KHOnHsJGW3kvnnS/t3A18fg9xuQjXJc7EJr9JJX
AjSbA69RlIEl65OyJ8ZbaaVkpU6eDfwNOw5mPxceyIYpWvQnovTNkDTk1Pdv
i1wfQ4/vbTHjjDEmozHKDEsly0tMejYPaRIb85oMnSQ9msuCjuFeVLoGlxpW
WcQ3WVFobqYbn26ZyUoTUf2roezXA88dZJLWgPcRCjz2NS5BDYssc0ULw8f/
EbCtqafwTBVBPFzT5tErlB+XwS4tVsoUv90/Rd4cbevysF/NvzEwpjKmkRxT
03T8FEd5AzgEIJY7GnjPFF6M+jZZS57jRr4ry5xHNU0lgmNeAntj+kd6YvqB
QkCLJyJ6/O1xxPvfFLX9kzD0a4dgjXUmx2M7sAtZSFkHGygcCJB7fqlsAega
7R5ajhpwG8koQ4FnYrWmMU+UhQDTK7SVkyM7ATPKNMfsMJHcCvbb+V9D8Gr8
MimfjE2bNi2e+5FfFixYEP8GfsrWEkt4EL9x4uqKN1mucSNNl3ymDECvafLz
Qn3UUvxep90ZfbY7/030zyBKVQzVDm3GxsZ4BK+Hw+NWi2Y7WFrUjLFha+AV
ygh1G+AbEgadTdF7nDZmO20c2Ge7NSrr523q/MDmOeC62yWJHshgSerXBxiS
Zkiivn+MU+Vsp8oD+2zm6DpFOCkHWytFephJvUkTChwu1RIoUqlhZcc4z57g
PGvWXHK8OlUMWJf0QD/+XqXPDOvZdZ6Rsdy5qRw9AuUwOp41OkVw5MgibLZW
pHJlCrWlVj5Xv88T4lBV7T65mIa6TM259ftgKVNj3Pvq1OHd70HL7sf/v9X+
P0dBj3ni/fPq9/WQQ++zD2rS1z4slPrJz/H+OfX7apD07qvhybuv5one+z3b
2FjkbCXB39j0lmvUh+P/qxS1vtSh+Jg5KpOhJloS9Zl+BnlH/+/s9P8BFqm/
ug==\
\>"], "Graphics",
  ImageSize->{426, 252},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.47",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1147.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  A two-dimensional vector field. "
}], "Text",
 CellChangeTimes->{{3.399551132859375*^9, 3.399551156390625*^9}}],

Cell[TextData[{
 "\tBoth ",
 Cell[BoxData[
  RowBox[{"p", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"q", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " are continuously differentiable, so we can use the mean value theorem to \
show that  \n",
 StyleBox["\n(11-32)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"p", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "+", "\[CapitalDelta]x"}], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "t"}], ")"}]}], " ", "-", " ", 
      RowBox[{"p", 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "t"}], ")"}]}]}], "  ", "=", "  ", 
     RowBox[{
      SubscriptBox["p", "x"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "1"], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}], "\[CapitalDelta]x"}]}], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}], "\n"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"q", 
      RowBox[{"(", 
       RowBox[{"t", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        RowBox[{"y", "+", "\[CapitalDelta]y"}]}], ")"}]}], " ", "-", " ", 
     RowBox[{"q", 
      RowBox[{"(", 
       RowBox[{"t", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["q", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["y", "2"]}], ")"}], "\[CapitalDelta]y"}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]}]],
 "\n\nwhere ",
 Cell[BoxData[
  RowBox[{"x", "<", 
   SubscriptBox["x", "1"], "<", 
   RowBox[{"x", "+", "\[CapitalDelta]x"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"y", "<", 
   SubscriptBox["y", "2"], "<", 
   RowBox[{"y", "+", "\[CapitalDelta]y"}]}]]],
 ".  Substitution of the expressions in Equation ",
 StyleBox["(11-32)",
  FontColor->RGBColor[0, 0, 1]],
 " into Equation ",
 StyleBox["(11-31)",
  FontColor->RGBColor[0, 0, 1]],
 " and subsequently dividing through by ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]x", " ", "\[CapitalDelta]y"}]]],
 " results in  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "\[CapitalDelta]y"], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "y", 
       RowBox[{"y", "+", "\[CapitalDelta]y"}]], "  ", 
      RowBox[{
       SubscriptBox["p", "x"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "   ", "+", "   ", 
    RowBox[{
     FractionBox["1", "\[CapitalDelta]x"], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "x", 
       RowBox[{"x", "+", "\[CapitalDelta]x"}]], " ", 
      RowBox[{
       SubscriptBox["q", "y"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         SubscriptBox["y", "2"]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", "=", "  ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe can use the mean value theorem for integrals with this equation to \
show that  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["p", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["y", "1"]}], ")"}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["q", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["y", "2"]}], ")"}]}]}], "  ", "=", "  ", "0"}]]],
 ",\n\nwhere ",
 Cell[BoxData[
  RowBox[{"y", "<", 
   SubscriptBox["y", "1"], "<", 
   RowBox[{"y", "+", "\[CapitalDelta]y"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"x", "<", 
   SubscriptBox["x", "2"], "<", 
   RowBox[{"x", "+", "\[CapitalDelta]x"}]}]]],
 " .  Letting ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]]],
 " in this equation yields \n\n",
 StyleBox["(11-33)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["p", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{
     SubscriptBox["q", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", "0"}]]],
 ",\n\nwhich is called the equation of continuity. "
}], "Text"],

Cell[TextData[{
 "\tThe curl of the vector field in Equation ",
 StyleBox["(11-30)",
  FontColor->RGBColor[0, 0, 1]],
 " has magnitude \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{"curl", " ", 
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "-", "  ", 
    RowBox[{
     SubscriptBox["p", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "\n\nand is an indication of how the field swirls in the vicinity of a \
point.  Imagine that a \"fluid element\" at the point ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"x", 
    StyleBox[",",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "y"}], ")"}]]],
 " is suddenly frozen and then moves freely in the fluid.  The fluid element \
will rotate with an angular velocity given by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     SubscriptBox["q", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox["1", "2"], 
     SubscriptBox["p", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", 
   RowBox[{
    FractionBox["1", "2"], "|", 
    RowBox[{"curl", " ", 
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}]}]]],
 ". "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tWe consider only fluid flows for which the curl is zero.  Such fluid \
flows are called irrotational.  This condition is more precisely \
characterized by requiring that the line integral of the tangential component \
of ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 " along any simply closed contour be identically zero.  If we consider the \
rectangle in Figure 11.47, then the tangential component is given by ",
 Cell[BoxData[
  RowBox[{"p", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the bottom edge, ",
 Cell[BoxData[
  RowBox[{"q", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the right edge, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "p"}], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the top edge, and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "q"}], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " on the left edge.  Integrating and equating the resulting circulation \
integral to zero yields \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "y", 
      RowBox[{"y", "+", "\[CapitalDelta]y"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"q", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "+", "\[CapitalDelta]x"}], 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "t"}], ")"}]}], "-", 
        RowBox[{"q", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "t"}], ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "x", 
      RowBox[{"x", "+", "\[CapitalDelta]x"}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"p", 
         RowBox[{"(", 
          RowBox[{"t", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], 
           RowBox[{"y", "+", "\[CapitalDelta]y"}]}], ")"}]}], "-", 
        RowBox[{"p", 
         RowBox[{"(", 
          RowBox[{"t", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tAs before, we apply the mean value theorem and divide through by ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]x", " ", "\[CapitalDelta]y"}]]],
 " , and obtain the equation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "\[CapitalDelta]y"], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "y", 
       RowBox[{"y", "+", "\[CapitalDelta]y"}]], "  ", 
      RowBox[{
       SubscriptBox["q", "x"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["x", "1"], 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], "   ", "-", "   ", 
    RowBox[{
     FractionBox["1", "\[CapitalDelta]x"], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "x", 
       RowBox[{"x", "+", "\[CapitalDelta]x"}]], " ", 
      RowBox[{
       SubscriptBox["p", "y"], 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         SubscriptBox["y", "2"]}], ")"}], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], "  ", "=", "  ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe can use the mean value for integrals with this equation to deduce that \
 \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "x"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "1"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["y", "1"]}], ")"}]}], "  ", "-", "  ", 
    RowBox[{
     SubscriptBox["p", "y"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["x", "2"], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       SubscriptBox["y", "2"]}], ")"}]}]}], "  ", "=", "  ", "0"}]]],
 ".\n\nLetting ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]x", "\[Rule]", "0"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{"\[CapitalDelta]y", "\[Rule]", "0"}]]],
 " yields \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "x"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "-", "  ", 
    RowBox[{
     SubscriptBox["p", "y"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", "0"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tEquations ",
 StyleBox["(11-33)",
  FontColor->RGBColor[0, 0, 1]],
 " and this equation show that the complex function  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"p", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "-", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "q", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 "  \n\nsatisfies the Cauchy-Riemann equations and hence it is an analytic \
function.  If we let ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "z", ")"}]}]]],
 " denote the antiderivative of ",
 Cell[BoxData[
  RowBox[{"f", 
   RowBox[{"(", "z", ")"}]}]]],
 ", then \n\n",
 StyleBox["(11-34)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ",  \n\nwhich is the complex potential of the flow and has the property\n\n\t\
\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], "   ", "=", "   ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Phi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Psi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"p", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "q", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}], " ", 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                ", 
   RowBox[{"=", "  ", 
    RowBox[{
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]],
 "\n\nSince  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Phi]", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"p", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Phi]", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   RowBox[{"q", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 ", we also have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"grad", " ", "\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"p", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
     RowBox[{"\[ImaginaryI]", " ", "q", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ",  \n\nso  ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " is the velocity potential for the flow, and the curves  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "1"]}]]],
 "  \n\nare called equipotentials.  The function  ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  is called the stream function.  The curves  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 "  \n\nare called streamlines, and describe the paths of the fluid \
particles.  "
}], "Text"],

Cell[TextData[{
 "\tTo demonstrate this result, we implicitly differentiate ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 " and find that the slope of a vector tangent is given by  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox["dy", "dx"], "  ", "=", "  ", 
   FractionBox[
    RowBox[{
     RowBox[{"-", " ", 
      SubscriptBox["\[Psi]", "x"]}], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], 
    RowBox[{
     SubscriptBox["\[Psi]", "y"], 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]]}]]],
 ".  \n\nUsing the fact that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Psi]", "y"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["\[Phi]", "x"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}]}]]],
 "  and this equation, we find that the tangent vector to the curve is \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    OverscriptBox["T", "\[RightVector]"],
    FontWeight->"Bold"], "  ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Phi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "-", " ", 
     RowBox[{"\[ImaginaryI]", " ", 
      SubscriptBox["\[Psi]", "x"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"p", 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "+", " ", 
      RowBox[{"\[ImaginaryI]", " ", "q", 
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "y"}], ")"}]}]}], " ", "=", "  ", 
     RowBox[{
      StyleBox["V",
       FontWeight->"Bold"], 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "The main idea of the preceding discussion is the conclusion that, if \n\n",
 StyleBox["(11-35)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]]],
 ",  \n\nis an analytic function, then the family of curves \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
    SubscriptBox["K", "2"]}], "}"}]]],
 "\n\nrepresents the streamlines of a fluid flow."
}], "Text"],

Cell[TextData[{
 "\tThe boundary condition for an ideal fluid flow is that ",
 Cell[BoxData[
  RowBox[{
   StyleBox["V",
    FontWeight->"Bold"], 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " should be parallel to the boundary curve containing the fluid (the fluid \
flows parallel to the walls of a containing vessel).  In other words, if \
Equation ",
 StyleBox["(11-35)",
  FontColor->RGBColor[0, 0, 1]],
 " is the complex potential for the flow, then the boundary curve must be \
given by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "K"}]]],
 " for some constant ",
 StyleBox["K",
  FontFamily->"Courier New"],
 ";  that is, the boundary curve must be a streamline."
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 11.5  (Invariance of Flow).",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"\[CapitalPhi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "+", "  ", 
    RowBox[{"i", " ", "\[CapitalPsi]", 
     RowBox[{"(", 
      RowBox[{"u", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "v"}], ")"}]}]}]}]]],
 "  \n\ndenote the complex potential for a fluid flow in a domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " plane where the velocity is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["V",
      FontWeight->"Bold"], "1"], 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "  ", "=", "  ", 
   OverscriptBox[
    RowBox[{
     RowBox[{
      SubscriptBox["F", "1"], "'"}], 
     RowBox[{"(", "w", ")"}]}], "_"]}]]],
 ".  \n\nIf the function    ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"u", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "+", 
     RowBox[{"i", " ", "v", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}]}]}]}]]],
 "  is a one-to-one conformal mapping from a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane onto ",
 StyleBox["G",
  FontFamily->"Courier New"],
 ",  then the composite function  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["F", "2"], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        RowBox[{"v", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}]}], "  ", "+", 
     "  ", 
     RowBox[{"i", " ", "\[CapitalPsi]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        RowBox[{"v", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}]}]}]}]}]}]],
 "  \n\nis the complex potential for a fluid flow in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " where the velocity is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox[
     StyleBox["V",
      FontWeight->"Bold"], "2"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "   ", 
   OverscriptBox[
    RowBox[{
     RowBox[{
      SubscriptBox["F", "2"], "'"}], 
     RowBox[{"(", "z", ")"}]}], "_"]}]]],
 ".    \n\nThe situation is shown in Figure 11.48."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{694, 309},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.48",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1148.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The image of a fluid flow under conformal mapping.  "
}], "Text",
 CellChangeTimes->{{3.39955116471875*^9, 3.399551172609375*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.5 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 "\tWe note that the functions   \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{"x", 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "  ", 
     RowBox[{"\[CapitalPhi]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}], 
        StyleBox[",",
         FontFamily->"Times New Roman",
         FontSize->12,
         FontWeight->"Plain",
         FontSlant->"Plain",
         FontVariations->{"StrikeThrough"->False,
         "Underline"->False},
         FontColor->GrayLevel[0]], 
        RowBox[{"v", 
         RowBox[{"(", 
          RowBox[{"x", 
           StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontVariations->{"StrikeThrough"->False,
            "Underline"->False},
            FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}]}]}], ",", "  ", 
    "and"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", "  ", 
    RowBox[{"\[CapitalPsi]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], 
       RowBox[{"v", 
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox[",",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "y"}], ")"}]}]}], ")"}]}]}], ","}]}]],
 "  \n\nare the new velocity potential and stream function, respectively, for \
the flow in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  A streamline or natural boundary curve \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 "\n\t\t\t\nin the z plane is mapped onto a streamline or natural boundary \
curve \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], "=", 
   SubscriptBox["K", "2"]}]]],
 "\n\n\nin the w plane by the transformation ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"S", 
    RowBox[{"(", "z", ")"}]}]}]]],
 ".  One method for finding a flow inside a domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " in the ",
 StyleBox["z",
  FontFamily->"Courier New"],
 " plane is to conformally map ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " onto a domain ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " in the w plane in which the flow is known."
}], "Text"],

Cell[TextData[{
 "\tFor an ideal fluid with uniform density , the fluid pressure  ",
 Cell[BoxData[
  RowBox[{"P", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "  and speed  ",
 Cell[BoxData[
  RowBox[{"|", 
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}]]],
 "  are related by the following special case of Bernoulli's equation:  \n\n\t\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"P", 
       RowBox[{"(", 
        RowBox[{"x", ",", "y"}], ")"}]}], "\[Rho]"], "  ", "+", "  ", 
     FractionBox["1", "2"]}], "|", 
    RowBox[{
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}], "  ", "=", "  ", 
   "constant"}]]],
 ".  \n\n Note that the pressure is greatest when the speed is least."
}], "Text"],

Cell[TextData[{
 StyleBox["Example 11.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  The complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "z"}]}]]],
 "  has the velocity potential and stream function of    \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", "x"}], " ", "-", " ", 
    RowBox[{"b", " ", "y"}]}]}]]],
 "  and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"b", " ", "x"}], " ", "+", " ", 
    RowBox[{"a", " ", "y"}]}]}]]],
 ",  \n\t\t\t\nrespectively, and gives rise to the fluid flow defined in the \
entire complex plane that has a uniform parallel velocity of  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], "   ", "=", "  ", 
    RowBox[{
     OverscriptBox[
      RowBox[{"a", "+", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "_"], "   ", "=", "  ", 
     RowBox[{"a", " ", "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}]}]}]}]]],
 ".  \n\nThe streamlines are parallel lines given by the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"bx", "+", "ay"}], " ", "=", " ", "constant"}]]],
 "  and are inclined at an angle  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "Arctan"}], 
    RowBox[{"(", 
     FractionBox["b", "a"], ")"}]}]}]]],
 ",  as indicated in Figure 11.49."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{380, 212},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.49",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1149.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  A uniform parallel flow.  "
}], "Text",
 CellChangeTimes->{{3.399551177796875*^9, 3.399551188265625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.22.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "The function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "z", "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}], "z"}]}]]],
 "  is the antiderivative of   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "=", 
   RowBox[{"(", 
    RowBox[{"a", "+", 
     RowBox[{"\[ImaginaryI]", " ", "b"}]}], ")"}]}]]],
 ".  It gives rise to the fluid flow defined in the entire complex plane that \
has a uniform parallel velocity vector given by  \n\n\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], " ", "=", " ", 
    RowBox[{
     OverscriptBox[
      RowBox[{"a", " ", "+", " ", 
       RowBox[{"\[ImaginaryI]", " ", "b"}]}], "_"], " ", "=", " ", 
     RowBox[{"a", " ", "-", " ", 
      RowBox[{"\[ImaginaryI]", " ", "b"}]}]}]}]}]]],
 ".  \n\nSince  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", "x"}], "-", 
     RowBox[{"b", " ", "y"}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"b", " ", "x"}], "+", 
        RowBox[{"a", " ", "y"}]}], ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"\[Phi]", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
      RowBox[{"(", 
       RowBox[{"x", ",", "y"}], ")"}]}]}]}]}]]],
 ",  the streamlines are parallel lines given by the equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "=", 
   SubscriptBox["K", "1"]}]]],
 "  which are explicitly given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"a", " ", "y"}]}], "=", "c"}]]],
 "  where  c  is a constant.  They are inclined at an angle  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "=", 
   RowBox[{
    RowBox[{"-", " ", "arctan"}], 
    RowBox[{"(", 
     FractionBox["b", "a"], ")"}]}]}]]],
 ",  as indicated in Figure 11.49."
}], "Text"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider the complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["A", "2"], " ", 
    SuperscriptBox["z", "2"]}]}]],
  AspectRatioFixed->True],
 "  where ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a positive real number.  The velocity potential and stream function are \
given by\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox["A", "2"], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       SuperscriptBox["y", "2"]}], ")"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", "x", " ", "y"}]}], 
   StyleBox[
    RowBox[{" ", 
     StyleBox[" ",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]}]],
 "  \n\nrespectively.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "The streamlines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  form a family of hyperbolas with asymptotes along the coordinate axes.  \
The velocity vector  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], " ", "=", "  ", 
    RowBox[{
     OverscriptBox[
      RowBox[{"A", " ", "z"}], "_"], "  ", "=", " ", 
     RowBox[{"A", " ", 
      OverscriptBox[
       RowBox[{" ", "z"}], "_"]}]}]}]}]]],
 "  indicates that in the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ", the fluid flows down along the streamlines and spreads out along the x \
axis, as against a wall, as depicted in Figure 11.50."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{362, 203},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.50",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1150.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The fluid flow with complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["A", "2"], " ", 
    SuperscriptBox["z", "2"]}]}]],
  AspectRatioFixed->True],
 ".  "
}], "Text",
 CellChangeTimes->{{3.39955119315625*^9, 3.399551209796875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.23.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "A", ",", "f", ",", "F", ",", "g", ",", "x", ",", "y", ",", "u", ",", 
      "v", ",", "w", ",", "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["A", "2"], " ", 
      SuperscriptBox["z", "2"]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       FractionBox["A", "2"], " ", 
       RowBox[{"Re", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "]"}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       FractionBox["A", "2"], " ", 
       RowBox[{"Im", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "]"}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The  complex potential is   F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z]  =  (\>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182962015625*^9, 3.400182991859375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"0.2", "k"}], ")"}], "2"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "10"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182857046875*^9, 3.400182857296875*^9}, {
   3.4001830835*^9, 3.40018308378125*^9}, 3.40018339196875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["z", "2"], "  ", "is", "  ", "z"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"g", "[", "w", "]"}], " ", "=", " ", 
      SqrtBox["w"]}]}]}]}]]],
 ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "w_", "]"}], " ", "=", " ", 
     SqrtBox["w"]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The horizontal flow in the z-plane.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"g", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image flow in the first quadrant,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping z = g(w) = \>\"", ",", 
      RowBox[{"g", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182865359375*^9, 3.40018286565625*^9}, {
   3.400183089109375*^9, 3.400183091046875*^9}, 3.400183394796875*^9},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider the complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", 
    SuperscriptBox["z", 
     RowBox[{"4", "/", "3"}]]}]}]],
  AspectRatioFixed->True],
 "  where ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a positive real number.  The velocity potential and stream function are \
given by\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"Re", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
       RowBox[{"4", "/", "3"}]], "]"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"Im", "[", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
       RowBox[{"4", "/", "3"}]], "]"}]}]}], 
   StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}]}]],
 "  \n\nrespectively.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{309, 196},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "The streamlines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  form a family of hyperbolas with asymptotes along the coordinate axes.  \
The velocity vector  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["V",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    OverscriptBox[
     RowBox[{
      RowBox[{"F", "'"}], 
      RowBox[{"(", "z", ")"}]}], "_"], " ", "=", " ", 
    RowBox[{
     FractionBox["4", "3"], "A", " ", 
     OverscriptBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "+", 
         RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
       RowBox[{"1", "/", "3"}]], "_"]}]}]}]]],
 "  indicates that in the upper half-plane ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Im", 
    RowBox[{"(", "z", ")"}]}], ">", "0"}]]],
 ", the fluid flows down along the streamlines and spreads out along the \
positive x axis and negative y axis, as shown in Figure 11.55. "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "A", ",", "f", ",", "F", ",", "g", ",", "x", ",", "y", ",", "u", ",", 
      "v", ",", "w", ",", "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"A", " ", 
      SuperscriptBox["z", 
       RowBox[{"4", "/", "3"}]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"A", " ", 
       RowBox[{"Re", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
         RowBox[{"4", "/", "3"}]], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{"A", " ", 
       RowBox[{"Im", "[", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"x", " ", "+", " ", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], 
         RowBox[{"4", "/", "3"}]], "]"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The  complex potential is   F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z]  =  (\>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.4001830029375*^9, 3.40018300334375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0.25", "k"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "16"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "00.1", ",", "2.5"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["2.5", "3.5"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The contours are\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.4001828735*^9, 3.400182876234375*^9}, 
   3.400183399921875*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"4", "/", "3"}]], "  ", "is", "  ", "z"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"g", "[", "w", "]"}], " ", "=", "  ", 
      SuperscriptBox["w", 
       RowBox[{"3", "/", "4"}]]}]}]}]}]]],
 ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"g1", ",", "g2"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "w_", "]"}], " ", "=", " ", 
     SuperscriptBox["w", 
      RowBox[{"3", "/", "4"}]]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "w_", "]"}], " ", "=", "  ", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      SuperscriptBox["w", 
       RowBox[{"3", "/", "4"}]]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0.4"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "4", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "4"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The horizontal flow in the z-plane.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"graph1", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g1", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "5", ",", "0.4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "4", ",", "0.4"}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph2", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "0.01"}], ",", "0.4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "0.01"}], ",", "0.4"}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graph3", "=", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g2", ",", 
       RowBox[{"{", 
        RowBox[{"0.01", ",", "5", ",", "0.4"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", 
         RowBox[{"-", "0.01"}], ",", "0.4"}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"graph1", ",", "graph2", ",", "graph3", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The image flow in quadrants 1-3,\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<under the mapping z = g(w) = \!\(\*SuperscriptBox[\(w\), \(3/4\)]\)\
\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182881765625*^9, 3.400182884296875*^9}, 
   3.400183115421875*^9, {3.400183181125*^9, 3.400183199609375*^9}, {
   3.40040351801975*^9, 3.400403533254125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{406, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We use the fact that the conformal mapping  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{"z", "+", 
     FractionBox["1", "z"]}]}]}]]],
 "  maps the domain  ",
 Cell[BoxData[
  RowBox[{"D", "=", 
   RowBox[{"{", 
    RowBox[{"z", ":", 
     RowBox[{"|", "z", "|", 
      RowBox[{"<", "1"}]}]}], "}"}]}]]],
 "  one-to-one and onto the w plane slit along the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], "\[LessEqual]", "u", "\[LessEqual]", "2"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ".  The complex potential for a uniform horizontal flow parallel to this \
slit in the w plane is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", "w"}]}]]],
 ",  \n\nwhere ",
 StyleBox["A",
  FontFamily->"Courier New"],
 " is a positive real number.  The stream function for the flow in the w \
plane is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", "v"}]}]]],
 "  so that the slit lies along the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "0"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\tThe composite function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", 
     RowBox[{"S", 
      RowBox[{"(", "z", ")"}]}], ")"}]}]}]]],
 "  determines the fluid flow in the domain ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ", where the complex potential is \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       FractionBox["1", "z"]}], ")"}]}]}]}]]],
 ",  \n\nwhere ",
 Cell[BoxData[
  RowBox[{"A", ">", "0"}]]],
 ".  We can use polar coordinates to express ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 " as \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["F", "2"], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{
      SubscriptBox["F", "2"], 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], "  ", "=", 
     "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "+", 
        FractionBox["1", 
         RowBox[{"r", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox["1", 
         RowBox[{
          RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
          RowBox[{
          "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}]]}], 
       ")"}]}]}], "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox[
         RowBox[{
          RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "-", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
         
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", "cos\[Theta]"}], " ", "+", " ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "Sin", " ", "\[Theta]"}]}], ")"}],
           
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "-", " ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
           ")"}]}]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "cos", " ", "\[Theta]"}], " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}], " ",
         "+", 
        FractionBox[
         RowBox[{"r", 
          RowBox[{"(", " ", 
           RowBox[{
            RowBox[{"cos", " ", "\[Theta]"}], " ", "-", "  ", 
            RowBox[{
            "\[ImaginaryI]", " ", "r", " ", "sin", " ", "\[Theta]"}]}], 
           ")"}]}], 
         SuperscriptBox["r", "2"]]}], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"              ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        FractionBox["1", "r"]}], ")"}], " ", "cos", " ", "\[Theta]"}], "   ", 
     "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", "A", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]", 
      " "}]}]}]}]}]]
}], "Text"],

Cell[TextData[{
 "The streamline   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"r", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "\[Theta]"}], ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"A", 
     RowBox[{"(", 
      RowBox[{"r", "-", 
       FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]"}], "  ", "=", 
    "  ", "0"}]}]]],
 "  consists of the rays \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "1"}], ",", 
   RowBox[{"\[Theta]", "=", "0"}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", ">", "1"}], ",", 
   RowBox[{"\[Theta]", "=", "\[Pi]"}]}]]],
 " \n\nalong the x axis and the curve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"r", "-", 
    FractionBox["1", "r"]}], " ", "=", " ", "0"}]]],
 ",  which is the unit circle  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], " ", "=", " ", 
   RowBox[{"r", " ", "=", " ", "1"}]}]]],
 ".  Thus the unit circle can be considered as a boundary curve for the fluid \
flow."
}], "Text"],

Cell[TextData[{
 "\tThe approximation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       FractionBox["1", "z"]}], ")"}]}], "  ", "\[TildeTilde]", "  ", 
    RowBox[{"A", " ", "z"}]}]}]]],
 "  is valid for large values of z, so we can approximate the flow with a \
uniform horizontal flow having speed  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", 
    RowBox[{
     StyleBox["V",
      FontWeight->"Bold"], 
     RowBox[{"(", 
      RowBox[{"x", 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], "y"}], ")"}]}], "|"}], " ", "=", " ", 
   "A"}]]],
 "  at points that are distant from the origin.  The streamlines  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  and their images  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   "constant"}]]],
 "  under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"z", "+", 
     FractionBox["1", "z"]}]}]}]]],
 " are illustrated in Figure 11.51."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{333, 214},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.51",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1151.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Fluid flow around a circle.  "
}], "Text",
 CellChangeTimes->{{3.399551216765625*^9, 3.39955123075*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.24.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Consider the complex potential  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "z", "]"}], "=", 
   RowBox[{"A", 
    RowBox[{"(", 
     RowBox[{"z", "+", 
      FractionBox["1", "z"]}], ")"}]}]}]],
  AspectRatioFixed->True],
 " where  A  is a positive real number.  The velocity potential and stream \
function are given by  \n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{"x", "+", 
       FractionBox["x", 
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"]}]]}], ")"}]}]}], ",", "\n", 
   RowBox[{
    RowBox[{"v", "[", 
     RowBox[{"x", ",", "y"}], "]"}], "=", 
    RowBox[{"A", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"y", "-", 
        FractionBox["y", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"]}]]}], ")"}], "."}]}]}]}]]],
 "  \n",
 "Enter the complex potential and determine the velocity potential and stream \
function."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "A", ",", "cont", ",", "f", ",", "F", ",", "g", ",", "g1", ",", "g2", 
      ",", "solset", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", 
      "z"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", 
     RowBox[{"A", 
      RowBox[{"(", 
       RowBox[{"z", " ", "+", " ", 
        FractionBox["1", "z"]}], ")"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", "Im"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The  complex potential is   F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[z]  =  (\>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<) + \[ImaginaryI](\>\"", ",",
       " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], ",", "\"\<)\>\""}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.4001830130625*^9, 3.40018303440625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"0", "+", 
        RowBox[{"0.2", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "7"}], "}"}]}], "]"}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "55"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      FractionBox["1", "2"]}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where  c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.40018321321875*^9, 3.400183213484375*^9}, {
  3.400183407546875*^9, 3.400183411046875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     RowBox[{"z", "+", 
      RowBox[{
       FractionBox["1", "z"], "  ", "is", "  ", "z"}]}], "=", 
     RowBox[{
      RowBox[{"g", 
       RowBox[{"(", "w", ")"}]}], "=", " ", 
      FractionBox[
       RowBox[{"w", " ", "+", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], " ", "=", " ", 
    RowBox[{"z", " ", "+", " ", 
     FractionBox["1", "z"]}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"solset", " ", "=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"w", "\[Equal]", 
       RowBox[{"f", "[", "z", "]"}]}], ",", "z"}], "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", "w_", "]"}], " ", "=", " ", 
    SubscriptBox["solset", 
     RowBox[{"\[LeftDoubleBracket]", 
      RowBox[{"2", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "0"], " ", "=", " ", 
    RowBox[{"PowerExpand", "[", 
     RowBox[{"ExpandAll", "[", 
      RowBox[{"g", "[", 
       RowBox[{"f", "[", "z", "]"}], "]"}], "]"}], "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "1"], " ", "=", 
    RowBox[{"ReplaceAll", "[", 
     RowBox[{
      SubscriptBox["Z", "0"], " ", ",", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["z", "2"]}], "+", 
         SuperscriptBox["z", "4"]}]], " ", "\[Rule]", " ", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SuperscriptBox["z", "2"]}], ")"}]}]}]}], "]"}]}], ";"}], 
  " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "2"], " ", "=", " ", 
    RowBox[{"Together", "[", 
     SubscriptBox["Z", "1"], "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "3"], "=", 
    RowBox[{"MapAll", "[", 
     RowBox[{"Factor", ",", 
      SubscriptBox["Z", "2"]}], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "4"], "=", 
    FractionBox[
     RowBox[{"1", "+", 
      SuperscriptBox["z", "2"], "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "z"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}], "2"]}]]}], 
     RowBox[{"2", " ", "z"}]]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "5"], "=", 
    RowBox[{"PowerExpand", "[", 
     SubscriptBox["Z", "4"], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "6"], "=", 
    RowBox[{"Simplify", "[", 
     SubscriptBox["Z", "5"], "]"}]}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[z] = \>\"", ",", 
     RowBox[{"f", "[", "z", "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[w] = \>\"", ",", 
     RowBox[{"g", "[", "w", "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "0"]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "1"]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "2"]}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "3"]}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "4"]}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "5"]}], "]"}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<g[f[z]] = \>\"", ",", 
     SubscriptBox["Z", "6"]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[g[w]] = \>\"", ",", 
     RowBox[{"f", "[", 
      RowBox[{"g", "[", "w", "]"}], "]"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<f[g[w]] = \>\"", ",", 
     RowBox[{"Together", "[", 
      RowBox[{"f", "[", 
       RowBox[{"g", "[", "w", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell["\<\
Use conformal mapping  z = g(w)  to make an image of the flow.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "w_", "]"}], " ", "=", "  ", 
     FractionBox[
      RowBox[{"w", " ", "+", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "w_", "]"}], " ", "=", "  ", 
     FractionBox[
      RowBox[{"w", " ", "-", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["w", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3.2"}], ",", "3.2", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.2", ",", "0.2"}], "}"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The horizontal flow in the z-plane.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"gr1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g1", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "3.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{
    RowBox[{"gr2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3.20001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
       RowBox[{"{", " ", 
        RowBox[{"0.00001", ",", "1.20001", ",", "0.2"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], "  ", "\n", 
   
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "3"}], ",", "3", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image flow across the complex plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<and around the unit circle |z| = 1,\>\"", "]"}], ";"}],
    " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping z = g(w) = \>\"", ",", 
      RowBox[{"g1", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The velocity potential is \[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The   stream function  is \[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400183221984375*^9, 3.400183237375*^9}, {
  3.400403545301*^9, 3.400403561754125*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 11.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  ",
 "Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the segment from",
 "  ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "  ", "to", "  ", "z"}], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 "Solution.  We use the conformal mapping  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"w", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "1"}], ")"}], 
      FractionBox["1", "2"]], "  ", "=", "  ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "\[ImaginaryI]"}], ")"}], 
       FractionBox["1", "2"]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "\[ImaginaryI]"}], ")"}], 
       FractionBox["1", "2"]]}]}]}]}]]],
 "  \n\nwhere the branch of the square root of  ",
 Cell[BoxData[
  RowBox[{"Z", "=", 
   RowBox[{"z", "\[PlusMinus]", "\[ImaginaryI]"}]}]]],
 "   in each factor is  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["Z", 
    FractionBox["1", "2"]], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox["R", 
     FractionBox["1", "2"]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      FractionBox["\[Theta]", "2"]}]]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"R", " ", "=", " ", 
    RowBox[{"|", "Z", "|"}]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{"\[Theta]", " ", "=", " ", 
   RowBox[{
    SubscriptBox["arg", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], "/", "2"}]], 
    RowBox[{"(", "Z", ")"}]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}], "<", "\[Theta]", "\[LessEqual]", " ", 
   FractionBox[
    RowBox[{"3", "\[Pi]"}], "2"]}]]],
 ".  The transformation  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], ")"}], 
     FractionBox["1", "2"]]}]}]]],
 "  is a one-to-one conformal mapping of the domain D consisting of the z \
plane slit along the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "=", "0"}], ",", 
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "y", "\[LessEqual]", "1"}]}]]],
 "  onto the domain G consisting of the w plane slit along the segment  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "\[LessEqual]", "u", "\[LessEqual]", "1"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ".  The complex potential for a uniform horizontal flow parallel to the slit \
in the w plane is given by ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{"A", " ", "w"}]}]]],
 ", where for convenience we choose ",
 Cell[BoxData[
  RowBox[{"A", "=", "1"}]]],
 " and where the slit lies along the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", 
   RowBox[{"c", " ", "=", " ", "0"}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tThe composite function \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], 
     RowBox[{"(", 
      RowBox[{"S", 
       RowBox[{"(", "z", ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{"A", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["z", "2"], "+", "1"}], ")"}], 
      FractionBox["1", "2"]]}]}]}]]],
 "\n\nis the complex potential for a fluid flow in the domain D.  The \
streamlines given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "c"}]]],
 "  for the flow in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " are obtained by finding the preimage of the streamline  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[CapitalPsi]", 
    RowBox[{"(", 
     RowBox[{"u", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "v"}], ")"}]}], " ", "=", " ", "c"}]]],
 "  in ",
 StyleBox["G",
  FontFamily->"Courier New"],
 " given by the parametric equations  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"v", "=", 
    RowBox[{
     RowBox[{"c", "   ", 
      StyleBox["and",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "   ", "u"}], "=", "t"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "   ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "\[Infinity]"}], "<", "t", "<", 
    "\[Infinity]"}]}]]],
 ".  \n\nThe corresponding streamline in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 " is found by solving the equation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"t", " ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "c"}]}], "  ", "=", "  ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["z", "2"], "+", "1"}], ")"}], 
     FractionBox["1", "2"]], "  ", "=", "  ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], "+", "1"}], 
      ")"}], 
     FractionBox["1", "2"]]}]}]]],
 "\n\nfor ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " in terms of ",
 StyleBox["t",
  FontFamily->"Courier New"],
 ".  Squaring both sides of this equation yields  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"           ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"t", " ", "+", " ", 
         RowBox[{"\[ImaginaryI]", " ", "c"}]}], ")"}], "2"], "  ", "=", "  ", 
      
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], " ", "+", " ", 
       "1"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox["t", "2"], "-", 
      SuperscriptBox["c", "2"], " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "c", " ", "t"}]}], "   ", "=", 
     "  ", 
     RowBox[{"1", "+", 
      SuperscriptBox["x", "2"], "-", 
      SuperscriptBox["y", "2"], " ", "+", " ", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "x", " ", "y"}]}]}]}]}]]],
 "  "
}], "Text"],

Cell[TextData[{
 "Equating the real and imaginary parts leads to the system of equations  \n\n\
\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["t", "2"], "-", 
    SuperscriptBox["c", "2"]}], " ", "=", " ", 
   RowBox[{"1", "+", 
    SuperscriptBox["x", "2"], "-", 
    SuperscriptBox["y", "2"]}]}]]],
 "   and   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", " ", "c", " ", "t"}], " ", "=", " ", 
   RowBox[{"2", " ", "x", " ", "y"}]}]]],
 ".  \n\nTo eliminate the parameter ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " in the last two equations, first use the equations  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["c", "2"], 
     SuperscriptBox["t", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["c", "2"], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["c", "2"], 
      SuperscriptBox["y", "2"], "   ", "and", "  ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox["t", "2"]}]}], " ", "=", " ", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}]}]}]]],
 ",  \n\t\t\t\nthen get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     SuperscriptBox["y", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["c", "2"], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["c", "2"], 
     SuperscriptBox["y", "2"]}]}]}]]],
 "  which can be rewritten as  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["c", "2"], 
      SuperscriptBox["y", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["y", "2"]}]}], "  ", "=", "  ", 
    RowBox[{
     SuperscriptBox["c", "2"], "+", 
     SuperscriptBox["c", "4"], "+", 
     RowBox[{
      SuperscriptBox["c", "2"], 
      SuperscriptBox["x", "2"]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "2"], 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["x", "2"]}], ")"}]}], "  ", "=", "  ", 
     RowBox[{
      SuperscriptBox["c", "2"], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["c", "2"], "+", 
        SuperscriptBox["x", "2"]}], ")"}]}]}], "\[IndentingNewLine]"}], 
   " "}], "\[IndentingNewLine]", 
  RowBox[{" ", 
   RowBox[{
    RowBox[{"y", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["x", "2"]}]]}], "  ", "=", "  ", 
    RowBox[{"c", 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["x", "2"]}]]}]}]}]}]],
 "\n\nand we can solve for ",
 StyleBox["y",
  FontFamily->"Courier New"],
 " in terms of ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " to obtain \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"y", "  ", "=", "  ", 
   RowBox[{"c", 
    SqrtBox[
     FractionBox[
      RowBox[{"1", "+", 
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       SuperscriptBox["x", "2"]}]]]}]}]]],
 "  \n\nfor streamlines in ",
 StyleBox["D",
  FontFamily->"Courier New"],
 ".  For large values of ",
 StyleBox["x",
  FontFamily->"Courier New"],
 ", this streamline approaches the asymptote  ",
 Cell[BoxData[
  RowBox[{"y", " ", "=", " ", "c"}]]],
 "  and approximates a horizontal flow, as shown in Figure 11.52."
}], "Text"],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{314, 189},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.52",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1152.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Flow around a segment.  "
}], "Text",
 CellChangeTimes->{{3.399551242421875*^9, 3.399551252421875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.25.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "A", ",", "cont", ",", "f", ",", "F", ",", "g", ",", "g1", ",", "g2", 
      ",", "solset", ",", "x", ",", "y", ",", "u", ",", "v", ",", "w", ",", 
      "z"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "z_", "]"}], " ", "=", " ", 
     RowBox[{"A", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], " ", "+", " ", "1"}]]}]}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"\[Phi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Re", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", " ", "Im", ","}], " ", "}"}]}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Psi]", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", 
      RowBox[{
       RowBox[{"Im", "[", 
        RowBox[{"F", "[", 
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], "]"}], "]"}], ",", 
       RowBox[{"TargetFunctions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Re", ",", " ", "Im", ","}], " ", "}"}]}]}], "]"}]}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The  complex potential is   F[z] = \>\"", ",", 
      RowBox[{"F", "[", "z", "]"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>\"", 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The   stream function  is\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400183052796875*^9, 3.4001830533125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", "1"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cont", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"0", "+", 
        RowBox[{"0.1", "k"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "14"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"gr1", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"\[Psi]", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.000001", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1.8"}], "}"}], ",", 
       RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "0.9"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gr2", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"\[Psi]", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "0.000001"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1.8"}], "}"}], ",", 
       RowBox[{"Contours", " ", "\[Rule]", "cont"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "25"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "0.9"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.45"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.8"}], "}"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Contour plot for\>\"", "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", "c"}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<where c = \>\"", ",", "cont"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.400182891140625*^9, 3.40018289403125*^9}, {
   3.400183264890625*^9, 3.400183303578125*^9}, 3.4001834230625*^9, {
   3.400403569801*^9, 3.400403579441625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "The inverse of  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"f", "[", "z", "]"}], "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["z", "2"], "+", "1"}]], "  ", "is", "  ", "z"}], "=", 
     RowBox[{
      RowBox[{"g", "[", "w", "]"}], "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["w", "2"], "-", "1"}]]}]}]}]}]]],
 ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g1", "[", "w_", "]"}], " ", "=", "  ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["w", "2"], " ", "-", " ", "1"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"g2", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["w", "2"], " ", "-", " ", "1"}]]}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Iden", "[", "w_", "]"}], " ", "=", " ", "w"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"CartesianMap", "[", 
    RowBox[{"Iden", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2.2"}], ",", "2.2", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0.1"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<u\>\"", ",", "\"\<v\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The horizontal flow in the z-plane.\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"gr1", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g1", ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "2.20001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"gr2", " ", "=", " ", 
     RowBox[{"CartesianMap", "[", 
      RowBox[{"g2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.20001"}], ",", 
         RowBox[{"-", "0.00001"}], ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", " ", 
        RowBox[{"0.00001", ",", "1.00001", ",", "0.1"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{"Show", "[", 
    RowBox[{"gr1", ",", "gr2", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.05"}], ",", "2.05"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "2", ",", "1"}], "]"}]}], "}"}]}]}], "]"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The image flow across the complex plane,\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<slit along the segment from z=-\[ImaginaryI] to z=-\[ImaginaryI],\>\
\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<under the mapping z = g(w) = \>\"", ",", 
      RowBox[{"g1", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The velocity potential is\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Phi][x,y] = \>\"", ",", 
      RowBox[{"\[Phi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<The   stream function  is\>\"", "]"}], ";"}], 
   " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Psi][x,y] = \>\"", ",", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.4001829025625*^9, 3.40018291925*^9}, 
   3.400183316515625*^9, {3.400403587176*^9, 3.400403600941625*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Green's Function",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/GreensFunctionBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399551120640625*^9, 3.399551121140625*^9}}]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{957, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[95382, 2483, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 271248, 6928}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 120, 2, 29, "Text"],
Cell[1028, 36, 3787, 124, 211, "Text",
 Evaluatable->False],
Cell[4818, 162, 4274, 142, 107, "Text"],
Cell[9095, 306, 19908, 335, 305, "Text"],
Cell[29006, 643, 6365, 214, 185, "Text"],
Cell[35374, 859, 2364, 82, 177, "Text"],
Cell[37741, 943, 3217, 108, 163, "Text",
 Evaluatable->False],
Cell[40961, 1053, 4372, 141, 125, "Text"],
Cell[45336, 1196, 1547, 47, 73, "Text"],
Cell[46886, 1245, 1979, 69, 141, "Text"],
Cell[48868, 1316, 9096, 309, 540, "Text"],
Cell[57967, 1627, 3832, 128, 151, "Text"],
Cell[61802, 1757, 1517, 49, 173, "Text"],
Cell[63322, 1808, 1236, 40, 65, "Text"],
Cell[64561, 1850, 6222, 210, 356, "Text",
 Evaluatable->False],
Cell[70786, 2062, 24253, 405, 362, "Text"],
Cell[CellGroupData[{
Cell[95064, 2471, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[95208, 2477, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[95382, 2483, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[95731, 2495, 4592, 150, 317, "Text"],
Cell[100326, 2647, 1611, 56, 110, "Text"],
Cell[101940, 2705, 2666, 89, 179, "Text",
 Evaluatable->False],
Cell[104609, 2796, 9694, 167, 265, "Text"],
Cell[CellGroupData[{
Cell[114328, 2967, 103, 2, 29, "Text"],
Cell[114434, 2971, 2277, 78, 143, "Text"]
}, Closed]],
Cell[116726, 3052, 2723, 97, 148, "Text",
 Evaluatable->False],
Cell[119452, 3151, 4893, 83, 163, "Text",
 Evaluatable->False],
Cell[124348, 3236, 1541, 53, 47, "Text",
 Evaluatable->False],
Cell[125892, 3291, 20135, 344, 262, "Text"],
Cell[CellGroupData[{
Cell[146052, 3639, 111, 2, 29, "Text"],
Cell[146166, 3643, 157, 5, 29, "Text",
 Evaluatable->False],
Cell[146326, 3650, 2475, 69, 274, "Input"],
Cell[148804, 3721, 223, 8, 65, "Text",
 Evaluatable->False],
Cell[149030, 3731, 1789, 51, 215, "Input"],
Cell[150822, 3784, 457, 15, 31, "Text",
 Evaluatable->False],
Cell[151282, 3801, 3716, 104, 336, "Input"]
}, Closed]],
Cell[155013, 3908, 2932, 102, 141, "Text",
 Evaluatable->False],
Cell[157948, 4012, 8508, 142, 210, "Text",
 Evaluatable->False],
Cell[166459, 4156, 1618, 55, 74, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[168102, 4215, 113, 2, 29, "Text"],
Cell[168218, 4219, 157, 5, 29, "Text",
 Evaluatable->False],
Cell[168378, 4226, 2452, 67, 237, "Input"],
Cell[170833, 4295, 223, 8, 65, "Text",
 Evaluatable->False],
Cell[171059, 4305, 1790, 52, 226, "Input"],
Cell[172852, 4359, 526, 17, 29, "Text",
 Evaluatable->False],
Cell[173381, 4378, 5572, 156, 436, "Input"]
}, Closed]],
Cell[178968, 4537, 366, 12, 26, "Text",
 Evaluatable->False],
Cell[179337, 4551, 3344, 58, 163, "Text",
 Evaluatable->False],
Cell[182684, 4611, 1887, 64, 125, "Text"],
Cell[184574, 4677, 4475, 140, 351, "Text"],
Cell[189052, 4819, 1220, 43, 113, "Text"],
Cell[190275, 4864, 1998, 71, 77, "Text"],
Cell[192276, 4937, 16586, 280, 267, "Text"],
Cell[CellGroupData[{
Cell[208887, 5221, 111, 2, 29, "Text"],
Cell[209001, 5225, 1136, 40, 118, "Text",
 Evaluatable->False],
Cell[210140, 5267, 2629, 71, 246, "Input"],
Cell[212772, 5340, 223, 8, 65, "Text",
 Evaluatable->False],
Cell[212998, 5350, 1905, 55, 246, "Input"],
Cell[214906, 5407, 566, 22, 44, "Text",
 Evaluatable->False],
Cell[215475, 5431, 4543, 156, 544, "Input"],
Cell[220021, 5589, 132, 4, 29, "Text",
 Evaluatable->False],
Cell[220156, 5595, 4657, 133, 458, "Input"]
}, Closed]],
Cell[224828, 5731, 480, 17, 26, "Text",
 Evaluatable->False],
Cell[225311, 5750, 4682, 80, 149, "Text",
 Evaluatable->False],
Cell[229996, 5832, 3159, 108, 188, "Text"],
Cell[233158, 5942, 4285, 147, 358, "Text"],
Cell[237446, 6091, 3699, 131, 428, "Text"],
Cell[241148, 6224, 15499, 262, 242, "Text"],
Cell[CellGroupData[{
Cell[256672, 6490, 111, 2, 29, "Text"],
Cell[256786, 6494, 157, 5, 29, "Text",
 Evaluatable->False],
Cell[256946, 6501, 2472, 71, 260, "Input"],
Cell[259421, 6574, 223, 8, 65, "Text",
 Evaluatable->False],
Cell[259647, 6584, 2993, 84, 292, "Input"],
Cell[262643, 6670, 531, 19, 38, "Text",
 Evaluatable->False],
Cell[263177, 6691, 4491, 127, 468, "Input"]
}, Closed]],
Cell[267683, 6821, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[268143, 6833, 407, 7, 29, "Text"],
Cell[268553, 6842, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[268700, 6849, 281, 7, 26, "Text"],
Cell[268984, 6858, 269, 6, 29, "Text"],
Cell[269256, 6866, 299, 7, 29, "Text"],
Cell[269558, 6875, 281, 7, 29, "Text"],
Cell[269842, 6884, 278, 7, 29, "Text"],
Cell[270123, 6893, 249, 5, 29, "Text"],
Cell[270375, 6900, 320, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
