(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    390914,       7931]
NotebookOptionsPosition[    387574,       7828]
NotebookOutlinePosition[    388289,       7858]
CellTagsIndexPosition[    388215,       7853]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.8  The Joukowski Airfoil",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe Russian scientist ",
 StyleBox[ButtonBox["Nikolai Egorovich Joukowsky",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Zhukovsky.\
html"], None}],
  FontVariations->{"Underline"->True}],
 " studied the function \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "z", ")"}]}], "=", 
   RowBox[{"z", " ", "+", 
    FractionBox["1", "z"]}]}]]],
 ".  \n\t\t\t\nHe showed that the image of a circle passing through ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "1"], "=", "1"}]]],
 " and containing the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", 
   RowBox[{"-", "1"}]}]]],
 " is mapped onto a curve shaped like the cross section of an airplane wing.  \
We call this curve the Joukowski airfoil.  If the streamlines for a flow \
around the circle are known, then their images under the mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"J", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " will be streamlines for a flow around the Joukowski airfoil, as shown in \
Figure 11.60.  "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{741, 241},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.60",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1160.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Image of a fluid flow under ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"z", " ", "+", 
     FractionBox["1", "z"]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399555098703125*^9, 3.39955511959375*^9}}],

Cell[TextData[{
 "\tThe mapping ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{"J", 
    RowBox[{"(", "z", ")"}]}]}]]],
 " is two-to-one, because  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"J", 
    RowBox[{"(", 
     FractionBox["1", "z"], ")"}]}]}]]],
 ",  for  ",
 Cell[BoxData[
  RowBox[{"z", "\[NotEqual]", "0"}]]],
 ".  The region  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "1"}]}]]],
 "  is mapped one-to-one onto the w plane slit along the segment of the real \
axis ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], "\[LessEqual]", "u", "\[LessEqual]", "2"}], ",", 
   RowBox[{"v", "=", "0"}]}]]],
 ".  To visualize this mapping, we investigate the implicit form, which we \
obtain by using the substitutions  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "-", "2"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"z", " ", "-", "2", "+", 
     FractionBox["1", "z"]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "-", 
       RowBox[{"2", "z"}], "+", "1"}], "z"], "  ", "=", "  ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "2"], "z"]}]}]}]]],
 ",  and    \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"w", "+", "2"}], " ", "=", "  ", 
   RowBox[{
    RowBox[{"z", " ", "+", "2", "+", 
     FractionBox["1", "z"]}], "  ", "=", "  ", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], "+", 
       RowBox[{"2", "z"}], "+", "1"}], "z"], "  ", "=", "  ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], "2"], "z"]}]}]}]]],
 ".  \n\nForming the quotient of these two quantities results in the \
relationship \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"w", "-", "2"}], 
    RowBox[{"w", "+", "2"}]], "  ", "=", "   ", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "-", "1"}], ")"}], "2"], "z"], "/", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"z", "+", "1"}], ")"}], "2"], "z"]}], "  ", "=", "  ", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "-", "1"}], ")"}], "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"z", "+", "1"}], ")"}], "2"]]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tThe inverse of  ",
 Cell[BoxData[
  RowBox[{"z", " ", "=", " ", 
   RowBox[{
    RowBox[{"T", 
     RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"w", "-", "2"}], 
     RowBox[{"w", "+", "2"}]]}]}]]],
 "  is  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", "+", 
      RowBox[{"2", "z"}]}], 
     RowBox[{"1", "-", "z"}]]}]}]]],
 ".  If we use the notation  ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "1"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]]}]}]]],
 "  and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox["z", "2"]}]]],
 ",  then we can express ",
 Cell[BoxData[
  RowBox[{"J", 
   RowBox[{"(", "z", ")"}]}]]],
 " as the composition of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "1"], 
   RowBox[{"(", "z", ")"}]}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "2"], 
   RowBox[{"(", "z", ")"}]}]]],
 ", and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "3"], 
   RowBox[{"(", "z", ")"}]}]]],
 ",  that is\n\n",
 StyleBox["(11-36)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "1"], 
         RowBox[{"(", "z", ")"}]}], ")"}]}], ")"}]}]}]}]]],
 ".  \n\nWhich is verified by the calculation\n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "1"], 
         RowBox[{"(", "z", ")"}]}], ")"}]}], ")"}]}], "  ", "=", "  ", 
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        FractionBox[
         RowBox[{"z", "-", "1"}], 
         RowBox[{"z", "+", "1"}]], ")"}]}], ")"}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     RowBox[{
      SubscriptBox["S", "3"], 
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], "2"]], ")"}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{
    RowBox[{"=", "  ", 
     FractionBox[
      RowBox[{"2", "+", 
       RowBox[{"2", 
        FractionBox[
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "-", "1"}], ")"}], "2"], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"z", "+", "1"}], ")"}], "2"]]}]}], 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "-", "1"}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"z", "+", "1"}], ")"}], "2"]]}]]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                                  ", 
   RowBox[{"=", "  ", 
    RowBox[{"z", "  ", "+", "  ", 
     FractionBox["1", "z"]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tWe can easily show that ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{"z", " ", "+", 
     FractionBox["1", "z"]}]}]}]]],
 "  maps the four points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["z", "3"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 "  onto  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["w", "4"]}], "=", 
    RowBox[{"-", "2"}]}]}]]],
 ",  respectively.  \nHowever, the composition functions in Equation ",
 StyleBox["(11-36)",
  FontColor->RGBColor[0, 0, 1]],
 " must be considered in order to visualize the geometry involved.  First, \
the bilinear transformation  ",
 Cell[BoxData[
  RowBox[{"Z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "1"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]]}]}]]],
 "  maps the region  ",
 Cell[BoxData[
  RowBox[{"|", "z", "|", 
   RowBox[{">", "1"}]}]]],
 "  onto the right half-plane  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Re", 
    RowBox[{"(", "Z", ")"}]}], ">", "0"}]]],
 ",  and the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["z", "3"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 "  are mapped onto  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["Z", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["Z", "3"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["Z", "4"]}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Infinity]"}]}]}]]],
 ",  respectively.  Second, the function  ",
 Cell[BoxData[
  RowBox[{"W", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "2"], 
     RowBox[{"(", "Z", ")"}]}], " ", "=", " ", 
    SuperscriptBox["Z", "2"]}]}]]],
 "  maps the right half plane onto the ",
 StyleBox["W",
  FontFamily->"Courier New"],
 " plane slit along its negative real axis, and the points ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["Z", "1"], "=", 
    RowBox[{"-", "\[ImaginaryI]"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["Z", "2"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["Z", "3"], "=", "\[ImaginaryI]"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["Z", "4"]}], "=", 
    RowBox[{"\[ImaginaryI]", " ", "\[Infinity]"}]}]}]]],
 ",  are mapped onto  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["W", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["W", "3"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["W", "3"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["W", "4"]}], "=", 
    RowBox[{"-", "\[Infinity]"}]}]}]]],
 ",  respectively.  Then the bilinear transformation ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", "W", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", "+", 
      RowBox[{"2", "W"}]}], 
     RowBox[{"1", "-", "W"}]]}]}]]],
 "  maps the latter region onto the ",
 StyleBox["W",
  FontFamily->"Courier New"],
 " plane slit along the portion of the real axis ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "\[LessEqual]", 
    RowBox[{"-", "2"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{"V", "=", "0"}]}]]],
 ", and the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["W", "1"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["W", "3"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["W", "3"], "=", 
    RowBox[{"-", "1"}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["W", "4"]}], "=", 
    RowBox[{"-", "\[Infinity]"}]}]}]]],
 "  are mapped onto  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "2"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    SubscriptBox["w", "3"], "=", "0"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["w", "4"]}], "=", 
    RowBox[{"-", "2"}]}]}]]],
 ",  respectively.  These three compositions are shown in Figure 11.61.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["S", "1"], "[", "z_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"z", "-", "1"}], 
      RowBox[{"z", "+", "1"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(S\), \(1\)]\)[z] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "1"], "[", "z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(Z\), \(1\)]\) = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[-\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "1"], "[", 
       RowBox[{"-", "\[ImaginaryI]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(Z\), \(2\)]\) = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(2\)]\)] =  \!\(\*SubscriptBox[\(S\), \(1\
\)]\)[1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "1"], "[", "1", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(Z\), \(3\)]\) = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(3\)]\)] =  \!\(\*SubscriptBox[\(S\), \(1\
\)]\)[\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "1"], "[", "\[ImaginaryI]", "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(Z\), \(4\)]\) = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(4\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(1\)]\)[-1] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["S", "1"], "[", "z", "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         RowBox[{"-", "1"}]}], ",", 
        RowBox[{"Direction", "\[Rule]", 
         RowBox[{"-", "\[ImaginaryI]"}]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399555962640625*^9, 3.399555963671875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["S", "2"], "[", "Z_", "]"}], " ", "=", " ", 
     SuperscriptBox["Z", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(S\), \(2\)]\)[Z] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "2"], "[", "Z", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(W\), \(1\)]\) = \!\(\*SubscriptBox[\(S\), \
\(2\)]\)[\!\(\*SubscriptBox[\(Z\), \(1\)]\)] =  \!\(\*SubscriptBox[\(S\), \(3\
\)]\)[-\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "2"], "[", 
       RowBox[{"-", "\[ImaginaryI]"}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(W\), \(2\)]\) = \!\(\*SubscriptBox[\(S\), \
\(2\)]\)[\!\(\*SubscriptBox[\(Z\), \(2\)]\)] =  \!\(\*SubscriptBox[\(S\), \(2\
\)]\)[0]  = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "2"], "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(W\), \(3\)]\) = \!\(\*SubscriptBox[\(S\), \
\(2\)]\)[\!\(\*SubscriptBox[\(Z\), \(3\)]\)] =  \!\(\*SubscriptBox[\(S\), \(2\
\)]\)[\[ImaginaryI]]  = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "2"], "[", "\[ImaginaryI]", "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(W\), \(4\)]\) = \!\(\*SubscriptBox[\(S\), \
\(2\)]\)[\!\(\*SubscriptBox[\(Z\), \(4\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(2\)]\)[\[ImaginaryI] \[Infinity]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "2"], "[", 
       RowBox[{"\[ImaginaryI]", " ", "\[Infinity]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399555966125*^9, 3.39955596759375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["S", "3"], "[", "W_", "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{"2", "+", 
       RowBox[{"2", "W"}]}], 
      RowBox[{"1", "-", "W"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<      \!\(\*SubscriptBox[\(S\), \(3\)]\)[W] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", "W", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(W\), \(1\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[-1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{"-", "1"}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(W\), \(2\)]\)] =  \!\(\*SubscriptBox[\(S\), \(3\
\)]\)[0] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", "0", "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(3\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(W\), \(3\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[-1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{"-", "1"}], "]"}]}], " ", "]"}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(4\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(W\), \(4\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[-\[Infinity]] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["S", "3"], "[", "W", "]"}], ",", 
        RowBox[{"W", "\[Rule]", 
         RowBox[{"-", "\[Infinity]"}]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399555970234375*^9, 3.399555971609375*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\
\)[\!\(\*SubscriptBox[\(S\), \(1\)]\)[z]]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{
        SubscriptBox["S", "2"], "[", 
        RowBox[{
         SubscriptBox["S", "1"], "[", "z", "]"}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\
\)[\!\(\*SubscriptBox[\(S\), \(1\)]\)[z]]] = \>\"", ",", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        SubscriptBox["S", "3"], "[", 
        RowBox[{
         SubscriptBox["S", "2"], "[", 
         RowBox[{
          SubscriptBox["S", "1"], "[", "z", "]"}], "]"}], "]"}], "]"}]}], " ",
      "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(1\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[-\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{
        SubscriptBox["S", "2"], "[", 
        RowBox[{
         SubscriptBox["S", "1"], "[", 
         RowBox[{"-", "\[ImaginaryI]"}], "]"}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(2\)]\)] =  \!\(\*SubscriptBox[\(S\), \(3\
\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[1] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{
        SubscriptBox["S", "2"], "[", 
        RowBox[{
         SubscriptBox["S", "1"], "[", "1", "]"}], "]"}], "]"}]}], " ", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(3\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(3\)]\)] =  \!\(\*SubscriptBox[\(S\), \(3\
\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \(1\)]\)[\
\[ImaginaryI]] = \>\"", ",", 
      RowBox[{
       SubscriptBox["S", "3"], "[", 
       RowBox[{
        SubscriptBox["S", "2"], "[", 
        RowBox[{
         SubscriptBox["S", "1"], "[", "\[ImaginaryI]", "]"}], "]"}], "]"}]}], 
     " ", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(4\)]\) = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[\!\(\*SubscriptBox[\(z\), \(4\)]\)] = \!\(\*SubscriptBox[\(S\), \
\(3\)]\)[\!\(\*SubscriptBox[\(S\), \(2\)]\)[\!\(\*SubscriptBox[\(S\), \
\(1\)]\)[-1] = \>\"", ",", 
      RowBox[{"Limit", "[", 
       RowBox[{
        RowBox[{
         SubscriptBox["S", "3"], "[", 
         RowBox[{
          SubscriptBox["S", "2"], "[", 
          RowBox[{
           SubscriptBox["S", "1"], "[", "z", "]"}], "]"}], "]"}], ",", 
        RowBox[{"z", "\[Rule]", 
         RowBox[{"-", "1"}]}]}], "]"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399555973734375*^9, 3.39955597575*^9}}]
}, Closed]],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{790, 682},
  ImageMargins->0],
 " \n\t\t\t",
 StyleBox[ButtonBox["Figure 11.61",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1161.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The composition mappings for  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "1"], 
         RowBox[{"(", "z", ")"}]}], ")"}]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399555124953125*^9, 3.399555135640625*^9}}],

Cell[TextData[{
 "\tThe circle  ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 "  with center  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "0"], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", " ", "a"}]}]]],
 "  on the imaginary axis passes through the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["z", "4"]}], "=", 
    RowBox[{"-", "1"}]}]}]]],
 "  and has radius  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "0"], "=", 
   SqrtBox[
    RowBox[{"1", "+", 
     SuperscriptBox["a", "2"]}]]}]]],
 ".  With the restriction that  ",
 Cell[BoxData[
  RowBox[{"0", "<", "a", "<", "1"}]]],
 ",  then this circle intersects the ",
 StyleBox["x",
  FontFamily->"Courier New"],
 " axis at the point ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", "1"}]]],
 " with angle  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Alpha]", "0"], " ", "=", " ", 
   RowBox[{
    FractionBox["\[Pi]", "2"], "-", 
    RowBox[{"Arctan", " ", "a"}]}]}]]],
 ", with  ",
 Cell[BoxData[
  RowBox[{
   FractionBox["\[Pi]", "2"], " ", "<", " ", 
   SubscriptBox["\[Alpha]", "0"], " ", "<", " ", 
   FractionBox["\[Pi]", "2"]}]]],
 ".  We want to track the image of  ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 "  in the ",
 StyleBox["Z",
  FontFamily->"Courier New"],
 ",  ",
 StyleBox["W",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["w",
  FontFamily->"Courier New"],
 " planes.  First, the image of this circle  ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 "  under  ",
 Cell[BoxData[
  RowBox[{"Z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "1"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]]}]}]]],
 "  is the line  ",
 Cell[BoxData[
  SubscriptBox["L", "0"]]],
 "  that passes through the origin and is inclined at the angle  ",
 Cell[BoxData[
  SubscriptBox["\[Alpha]", "0"]]],
 ".  Second, the function  ",
 Cell[BoxData[
  RowBox[{"W", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "2"], 
     RowBox[{"(", "Z", ")"}]}], " ", "=", " ", 
    SuperscriptBox["Z", "2"]}]}]]],
 "  maps the line  ",
 Cell[BoxData[
  SubscriptBox["L", "0"]]],
 "  onto the ray  ",
 Cell[BoxData[
  SubscriptBox["R", "0"]]],
 "  inclined at the angle  ",
 Cell[BoxData[
  RowBox[{"2", 
   SubscriptBox["\[Alpha]", "0"]}]]],
 ".  Finally, the transformation given by  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", "W", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", "+", 
      RowBox[{"2", "W"}]}], 
     RowBox[{"1", "-", "W"}]]}]}]]],
 "  maps the ray  ",
 Cell[BoxData[
  SubscriptBox["R", "0"]]],
 "  onto the arc of the circle  ",
 Cell[BoxData[
  SubscriptBox["A", "0"]]],
 "  that passes through the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "2"], "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubscriptBox["w", "4"]}], "=", 
    RowBox[{"-", "2"}]}]}]]],
 "  and intersects the u axis at  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", "2"}]]],
 " with angle ",
 Cell[BoxData[
  RowBox[{"2", 
   SubscriptBox["\[Alpha]", "0"]}]]],
 ", where    ",
 Cell[BoxData[
  RowBox[{"\[Pi]", " ", "<", " ", 
   RowBox[{"2", 
    SubscriptBox["\[Alpha]", "0"]}], " ", "<", " ", "\[Pi]"}]]],
 ".  The restriction on the angle ",
 Cell[BoxData[
  SubscriptBox["\[Alpha]", "0"]]],
 ", and hence ",
 Cell[BoxData[
  RowBox[{"2", 
   SubscriptBox["\[Alpha]", "0"]}]]],
 ", is necessary in order for the arc ",
 Cell[BoxData[
  SubscriptBox["A", "0"]]],
 " to have a low profile.  The arc ",
 Cell[BoxData[
  SubscriptBox["A", "0"]]],
 " lies in the center of the Joukowski airfoil and is shown in Figure 11.62. \
"
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{648, 574},
  ImageMargins->0],
 " \n\n\t",
 StyleBox[ButtonBox["Figure 11.62",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1162.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The images of the circles ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " under the composition mappings for  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "1"], 
         RowBox[{"(", "z", ")"}]}], ")"}]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399555190796875*^9, 3.3995551999375*^9}, 
   3.399555235609375*^9, {3.399555356859375*^9, 3.39955536490625*^9}, {
   3.3995555505625*^9, 3.399555558578125*^9}, {3.399555605984375*^9, 
   3.399555612875*^9}}],

Cell[TextData[{
 "\tIf we let ",
 StyleBox["b",
  FontFamily->"Courier New"],
 " be fixed, ",
 Cell[BoxData[
  RowBox[{"0", "<", "b", "<", "1"}]]],
 ", then the larger circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " with center given by ",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    SubscriptBox["c", "1"], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", "h"}], "+", 
     RowBox[{"\[ImaginaryI]", 
      RowBox[{"(", 
       RowBox[{"1", "+", "h"}], ")"}], "b"}]}]}]}]]],
 "  (just a bit to the left of the imaginary axis) will pass through the \
points    ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubsuperscriptBox["z", "4", "*"]}], "=", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     RowBox[{"2", "h"}]}]}]}]]],
 " and has radius  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "1"], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "h"}], ")"}], 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox["b", "2"]}]]}]}]]],
 ".  The circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " also intersects the x axis at the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "2"], "=", "1"}]]],
 "  at the angle  ",
 Cell[BoxData[
  SubscriptBox["\[Alpha]", "0"]]],
 ".  The image of circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " under  ",
 Cell[BoxData[
  RowBox[{"Z", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "1"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"z", "-", "1"}], 
     RowBox[{"z", "+", "1"}]]}]}]]],
 "  is the circle  ",
 Cell[BoxData[
  SubscriptBox["K", "1"]]],
 ",  which is tangent to  ",
 Cell[BoxData[
  SubscriptBox["L", "0"]]],
 " at the origin in the ",
 StyleBox["Z",
  FontFamily->"Courier"],
 "-plane.  The function  ",
 Cell[BoxData[
  RowBox[{"W", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "2"], 
     RowBox[{"(", "Z", ")"}]}], " ", "=", " ", 
    SuperscriptBox["Z", "2"]}]}]]],
 "  maps the circle  ",
 Cell[BoxData[
  SubscriptBox["K", "1"]]],
 "  onto the cardioid  ",
 Cell[BoxData[
  SubscriptBox["H", "1"]]],
 "  in the ",
 StyleBox["W",
  FontFamily->"Courier"],
 "-plane.  Finally,  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", "W", ")"}]}], " ", "=", " ", 
    FractionBox[
     RowBox[{"2", "+", 
      RowBox[{"2", "W"}]}], 
     RowBox[{"1", "-", "W"}]]}]}]]],
 "  maps the cardioid  ",
 Cell[BoxData[
  SubscriptBox["H", "1"]]],
 "  onto the Joukowski airfoil  ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 "  that passes through the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "2"], "=", "2"}]]],
 "  and surrounds the point  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "4"], "=", 
   RowBox[{"-", "2"}]}]]],
 ",  as shown in Figure 11.62.  An observer traversing ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " counterclockwise will traverse the image curves  ",
 Cell[BoxData[
  SubscriptBox["K", "1"]]],
 "  and  ",
 Cell[BoxData[
  SubscriptBox["H", "1"]]],
 "  clockwise but will traverse  ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 "  counterclockwise.  Thus the points  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["z", "4"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["Z", "4"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   SubscriptBox["W", "4"], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox["and",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], " ", 
    SubscriptBox["w", "4"]}]}]]],
 "  will always be to the observer's left."
}], "Text"],

Cell[TextData[{
 "\tNow we are ready to visualize the flow around the Joukowski airfoil.  We \
start with the fluid flow around a circle (see Figure 11.51).  This flow is \
adjusted with a linear transformation  ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["z", "*"], " ", "=", " ", 
   RowBox[{
    RowBox[{"a", " ", "z"}], "+", "b"}]}]]],
 "  so that it flows horizontally around the circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ", as shown in Figure 11.63.  Then the mapping  ",
 Cell[BoxData[
  RowBox[{"w", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["z", "*"], " ", "+", 
     FractionBox["1", 
      SuperscriptBox["z", "*"]]}]}]}]]],
 "  creates a flow around the Joukowski airfoil, as illustrated in Figure \
11.64. "
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{349, 211},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.63",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1163.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The horizontal flow around the circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.39955561990625*^9, 3.399555643875*^9}}],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{366, 152},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.64",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1164.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The horizontal flow around the Joukowski airfoil ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399555621578125*^9, 3.399555647375*^9}}],

Cell[TextData[{
 StyleBox["11.8.1  Flow with Circulation",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "\n\n\tThe function  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"s", " ", "z"}], " ", "+", 
    FractionBox["s", "z"], " ", "+", " ", 
    RowBox[{
     FractionBox["k", 
      RowBox[{"2", "\[Pi]", " ", "\[ImaginaryI]"}]], "Log", " ", "z"}]}]}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"s", ">", "0"}]]],
 " and ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " is real, is the complex potential for a uniform horizontal flow past the \
unit circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ", with circulation strength ",
 StyleBox["k",
  FontFamily->"Courier New"],
 " and velocity at infinity  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["V", "\[Infinity]"], "=", "s"}]]],
 ".  \n\t\nFor illustrative purposes, we let ",
 Cell[BoxData[
  RowBox[{"s", "=", "1"}]]],
 " and use the substitution  ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   FractionBox[
    RowBox[{"-", "k"}], 
    RowBox[{"2", "\[Pi]"}]]}]]],
 ".  Now the complex potential has the form  \n\n",
 StyleBox["(11-37)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   RowBox[{"z", " ", "+", 
    FractionBox["1", "z"], " ", "+", " ", 
    RowBox[{"a", " ", "\[ImaginaryI]", " ", "Log", " ", "z"}]}]}]]],
 "\n\nand the corresponding velocity function is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"V", 
    RowBox[{"(", 
     RowBox[{"x", ",", "y"}], ")"}]}], "  ", "=", " ", 
   RowBox[{
    OverscriptBox[
     RowBox[{" ", 
      RowBox[{
       RowBox[{"F", "'"}], 
       RowBox[{"(", "z", ")"}]}]}], "_"], " ", "=", " ", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       OverscriptBox[
        RowBox[{" ", "z"}], "_"], " ", ")"}], 
      RowBox[{"-", "2"}]], "-", 
     RowBox[{"a", " ", "\[ImaginaryI]", 
      SuperscriptBox[
       RowBox[{"(", 
        OverscriptBox[
         RowBox[{" ", "z"}], "_"], " ", ")"}], 
       RowBox[{"-", "1"}]]}]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe can express the complex potential in  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"\[Phi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}], "  ", "+", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
     RowBox[{"(", 
      RowBox[{"x", ",", "y"}], ")"}]}]}]}]]],
 "  form: \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}], "  ", "=", 
    "  ", 
    RowBox[{
     RowBox[{"r", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "   ", "+", "  ", 
     FractionBox["1", 
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}]], "  ", "+", "  ", 
     RowBox[{"a", " ", "\[ImaginaryI]", " ", "Log", " ", 
      RowBox[{"(", 
       RowBox[{"r", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], ")"}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{
    RowBox[{"=", "   ", 
     RowBox[{
      RowBox[{"r", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]]}], "  ", "+", " ", 
      RowBox[{
       FractionBox["1", "r"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Theta]"}]]}], "   ", "+", 
      "  ", 
      RowBox[{"a", " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ln", " ", "r"}], "  ", "+", "  ", 
         RowBox[{"\[ImaginaryI]", " ", "\[Theta]"}]}], ")"}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"                    ", 
   RowBox[{"=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "+", " ", 
        FractionBox["1", "r"]}], ")"}], " ", "cos", " ", "\[Theta]"}], " ", 
     "-", " ", 
     RowBox[{"a", "  ", "\[Theta]"}], "   ", "+", "  ", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", " ", 
        FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]"}], " ", "+", 
     " ", 
     RowBox[{"a", " ", "ln", " ", "r"}]}]}]}]}]],
 "   \n\nand we have the formulas for the velocity potential ",
 Cell[BoxData[
  RowBox[{"\[Phi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 " stream function  ",
 Cell[BoxData[
  RowBox[{"\[Psi]", 
   RowBox[{"(", 
    RowBox[{"x", 
     StyleBox[",",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "y"}], ")"}]}]]],
 "   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Phi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "cos", " ", "\[Theta]"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", " ", 
       FractionBox["1", "r"]}], ")"}], " ", "cos", " ", "\[Theta]"}], " ", 
    "-", " ", 
    RowBox[{"a", "  ", "\[Theta]"}]}]}]]],
 ",  and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "cos", " ", "\[Theta]"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", " ", 
       FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]"}], " ", "+", 
    " ", 
    RowBox[{"a", " ", "ln", " ", "r"}]}]}]]],
 ". "
}], "Text"],

Cell[TextData[{
 "\tFor the flow given by  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{"x", 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], "y"}], ")"}]}], " ", "=", " ", "c"}]]],
 ",  where c is a constant, we have  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "cos", " ", "\[Theta]"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"r", " ", "sin", " ", "\[Theta]"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", " ", 
        FractionBox["1", "r"]}], ")"}], "sin", " ", "\[Theta]"}], " ", "+", 
     " ", 
     RowBox[{"a", " ", "ln", " ", "r"}]}], "  ", "=", "  ", "c"}]}]]],
 ".     (Streamlines.)\n\nSetting ",
 Cell[BoxData[
  RowBox[{"r", "=", "1"}]]],
 " in this equation, we get  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[Psi]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"cos", " ", "\[Theta]"}], 
      StyleBox[",",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{"sin", " ", "\[Theta]"}]}], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", " ", 
        FractionBox["1", "1"]}], ")"}], "sin", " ", "\[Theta]"}], " ", "+", 
     " ", 
     RowBox[{"a", " ", "ln", " ", "1"}]}], "  ", "=", "  ", "0"}]}]]],
 "  for all ",
 Cell[BoxData["\[Theta]"]],
 ", so the unit circle is a natural boundary curve for the flow."
}], "Text"],

Cell[TextData[{
 "\tPoints at which the flow has zero velocity are called stagnation points.  \
To find them we solve   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], "=", "0"}]]],
 ";  for the function in Equation ",
 StyleBox["(11-37)",
  FontColor->RGBColor[0, 0, 1]],
 " we have  \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "'"}], 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", "z", ")"}], 
       RowBox[{"-", "2"}]], "+", 
      RowBox[{"a", " ", "\[ImaginaryI]", 
       SuperscriptBox[
        RowBox[{"(", "z", ")"}], 
        RowBox[{"-", "1"}]]}]}], "  ", "=", "  ", "0"}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "'"}], 
    RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
   RowBox[{
    RowBox[{"1", "-", 
     FractionBox["1", 
      SuperscriptBox["z", "2"]], "+", 
     RowBox[{"a", " ", "\[ImaginaryI]", 
      FractionBox["1", "z"]}]}], "  ", "=", "  ", "0"}]}]}]],
 "\n\nMultiplying through by ",
 Cell[BoxData[
  SuperscriptBox["z", "2"]]],
 " and rearranging terms gives   \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["z", "2"], " ", "+", " ", 
    RowBox[{"a", " ", "\[ImaginaryI]", " ", "z"}], " ", "-", " ", "1"}], "  ",
    "=", "  ", "0"}]]],
 "\n\nNow we invoke the quadratic equation to obtain  \n\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"z", "  ", "=", "  ", 
   FractionBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"\[PlusMinus]", " ", 
       SqrtBox[
        RowBox[{"4", "-", 
         SuperscriptBox["a", "2"]}]]}], " ", "-", "  ", 
      RowBox[{"a", " ", "\[ImaginaryI]"}]}]}], "2"]}]]],
 "    (stagnation point(s).) "
}], "Text"],

Cell[TextData[{
 "\tIf  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"0", " ", "\[LessEqual]"}], " ", "|", "a", "|", 
   RowBox[{"<", " ", "2"}]}]]],
 ",  then there are two stagnation points on the unit circle ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 ".  If ",
 Cell[BoxData[
  RowBox[{"a", "=", "2"}]]],
 ", then there is one stagnation point on the unit circle.  If ",
 Cell[BoxData[
  RowBox[{"a", ">", "2"}]]],
 ", then the stagnation point lies outside the unit circle.  We are mostly \
interested in the case with two stagnation points.  When ",
 Cell[BoxData[
  RowBox[{"a", "=", "0"}]]],
 ", the two stagnation points are ",
 Cell[BoxData[
  RowBox[{"z", "=", 
   RowBox[{"\[PlusMinus]", "1"}]}]]],
 ", which is the flow discussed in Example 11.25. The cases ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"a", "=", 
    SqrtBox["3"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"a", "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "a"}], "=", "2.2"}]}]]],
 " are shown in Figure 11.65.  "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{648, 727},
  ImageMargins->0],
 " \n\n\t\t",
 StyleBox[ButtonBox["Figure 11.65",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1165.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Flows past the unit circle with circulation ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"a", "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"a", "=", 
    SqrtBox["3"]}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{"a", "=", "2"}], 
   StyleBox[",",
    FontFamily->"Times New Roman"], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", "a"}], "=", "2.2"}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.39955565340625*^9, 3.3995556756875*^9}, {
  3.399555774453125*^9, 3.399555782515625*^9}}],

Cell[TextData[{
 "\tWe are now ready to combine the preceding ideas.  For illustrative \
purposes, we consider a ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " circle with center  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "0"], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", "0.15"}], "+", 
    RowBox[{"0.23", "\[ImaginaryI]"}]}]}]]],
 "  that passes through the points  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["z", "2"], "=", "1"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{
     StyleBox["and",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], " ", 
     SubsuperscriptBox["z", "4", "*"]}], "=", 
    RowBox[{"-", "1.3"}]}]}]]],
 "  and has radius  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["r", "0"], " ", "=", " ", 
   RowBox[{"0.23", 
    SqrtBox[
     FractionBox["13", "2"]]}]}]]],
 ".  We use the linear transformation  ",
 Cell[BoxData[
  RowBox[{"Z", "  ", "=", "  ", 
   RowBox[{
    RowBox[{"S", 
     RowBox[{"(", "z", ")"}]}], "  ", "=", "  ", 
    RowBox[{
     RowBox[{"-", " ", "0.15"}], " ", "+", " ", 
     RowBox[{"0.23", "\[ImaginaryI]"}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["r", "0"], "z"}]}]}]}]]],
 "  to map the flow with circulation ",
 Cell[BoxData[
  RowBox[{"k", "=", 
   RowBox[{
    RowBox[{"-", " ", "0.52"}], "\[Pi]"}]}]]],
 " (or ",
 Cell[BoxData[
  RowBox[{"a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "k"}], 
     RowBox[{"2", "\[Pi]"}]], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "0.52"}], "\[Pi]"}], ")"}]}], 
      RowBox[{"2", "\[Pi]"}]], "=", "0.26"}]}]}]]],
 ") around ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"|", "z", "|"}], "=", "1"}]]],
 " onto the flow around the circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ", as shown in Figure 11.66. "
}], "Text"],

Cell[TextData[{
 "\n\n\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{369, 230},
  ImageMargins->0],
 " \t \n\t\t\t\t",
 StyleBox[ButtonBox["Figure 11.66",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1166.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Flow with circulation around ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.3995556550625*^9, 3.39955565525*^9}, {
  3.399555807734375*^9, 3.399555830375*^9}}],

Cell[TextData[{
 "\tThen we use the mapping  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"J", 
    RowBox[{"(", "Z", ")"}]}], "=", 
   RowBox[{"Z", " ", "+", 
    FractionBox["1", "Z"]}]}]]],
 "  to map this flow around the Joukowski airfoil, as shown in Figure 11.67 \
and compare it to the flows shown in Figures 11.63 and 11.64.  \nIf the \
second transformation in the composition given by  ",
 Cell[BoxData[
  RowBox[{"w", " ", "=", 
   RowBox[{
    RowBox[{"J", 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["S", "3"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["S", "2"], 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["S", "1"], 
         RowBox[{"(", "z", ")"}]}], ")"}]}], ")"}]}]}]}]]],
 "  is modified to be  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "2"], 
    RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
   SuperscriptBox["z", "1.925"]}]]],
 ",  then the image of the flow shown in Figure 11.66 will be the flow around \
the modified airfoil shown in Figure 11.68.  The advantage of this latter \
airfoil is that the sides of its tailing edge form an angle of ",
 Cell[BoxData[
  RowBox[{"0.15", "\[Pi]"}]]],
 " radians, or ",
 Cell[BoxData[
  SuperscriptBox["27", "o"]]],
 ", which is more realistic than the angle of ",
 Cell[BoxData[
  SuperscriptBox["0", "o"]]],
 " of the traditional Joukowski airfoil."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\
eJzdnXvUn1V153/8bu81N+4t1iBQ8VK1pRc7CqOuonWqtWVstTdWh1ZHWaWX
RW07Tjuy6krqaCm1pWR6oXSsSwbIlAbWKKm1KLaGVoNtgCgQCC+XgEDeJBAC
yRuSZ/bnnP09z36e93kTdGr/mN9a7+X3XM7Z97P3Pvuc88MXvO+97/7FC953
4c9fcOoPXnzBr7z3wp//1VPf9MsX26XBMb3eMR/r9XpbT+0N7f/K/g2/Pl/Z
pzeobr/99mrHjh3p273pd7l10UUXVZ/73OfirVv81uHDh6uXv/zl1RVXXNG7
r3mLxmZnZ6t3v/vdzVvD1Bj9v/rVr64OHT58b/PuRz7ykXT35JNPrh588MHW
3be//e2Vw047fjcDN6r2PPlkddppp5UnfvuDH+w1HhlX69evL7f5Afx9+/Zt
i08Nqre89a16otdPvwfVJz/5yco/vbvz45/1x+++++6EbH4w/wbSJR43sErr
epzXt2/fHh+/Of2ZAryC1dlnn50eBWxdA8t74ivT1cc//vFEQP4GTqT/zz//
/PT6/Px8o6Nx9ZnPfAaSJ5j1lj3dd7D/5m/+psjIXU1u85Y/3RaE/99uvSj9
may2791f3b5rX3XvU89WD+87UM3vP1g9ffBQddB0wqT6j4/WwqD6+H2PV5f8
84P8mJDxe1X12//yYLV2y0PV7299pPrTu79WfeK+J6r/Pbezuunh3dVnH32y
2vT4U9W/zD9dfWXPM9WcQaCen1p4Tj33PtLR9R84ixcOHa52HziY3gNy2rpt
59NvipDNpLvgdqv1Rq//56FdCQqgufKer1WXf/XR6nfv2FGt2fKQUQLIlxfI
ub7O7vNchP7TO3ZXX3jsqYLBnbv3VXc9+Uy/evDp/abYjz+7kADbZT8GZB9s
DAfDp2jR+zrw+pBDzHPQ4NFnFhJeQE9Pn3lkT3X9A/PVX2x7rPrDrzwChNYZ
EA+AvjpwKLXfOzcT4KXpz7GJlPufO5QYqmYNzkR2gAcREWaDNX/N9idSF//j
rq+lbj58x8M0P0tPg9TpZGIp9yGOWMt7/L3u/p1DqGQ2TDTSj2Fi0mHU6k0U
eQMUfuA8BDMQe10U+4kOiv23dG02PYc00IZQ++ITexNaNzw4n6QTUP/77Q/D
21Ei2nRi86V37igY3GiPQmREBZYiOtb0GzM9X53+LC+dPRNoKjFU57xtolh9
/mtPJiKYwPQhsPELMl29PZPrz+95rA8djVSAB6X1Y6Aa7wzOfiL5skRyHoI1
vAu7kEPoSlcmf6n7na67aM/bOmj2viBloICwSv9vdSlDzq+yfuiT3seJYLNJ
H2D7x+59PEmi+gdd+oZ/9I0kWvtvzYR7C3/6CaBBkka6tR9js/0eJo6PC/n0
Q5tbdu3rJ6GZTaBBTUnqjQ/uSiDAWngHDyEP/DSQJxxiWAzXuQXUYAbUYjGY
QwFAMgDP7SDYRT4OAbn4DLG/tHNvdfOji1Qy02omAQKtAA4Z5FH4hMyjgoiN
99p7RybUe9KfFYk1B1zCeGxnEOvNO/c2zBhI0Q3dYcJG3j0GgWuYrog0bG4h
3XttB9bv8gEbOOifd4wdSZoxgYiwq5T3mYl9meuTRBSeYWVAW6K5P/f7sxnr
1d57VPbzgmIDAW8hXBIMQbH+/iyo0N4w/kaQP6sD+Z9x5MXyuaf3FysMUgid
LLCMCVIGI7iHGUWPxG/6c724MCP9QjcmCJIkJconCCJgIKtRGQI41Oe5Ei84
bXYfnTadkmG2Oj0LYlvcICOcMiAv7SDOjzlxNEwBGpIJgQEdzoNOLRk1cSQV
wCijsadWhJelpoeF7dDNbv9ApNkocdAsZ1F3kMv6vjIhR2eX+6hNh5h1APv7
x55Mo4KP1qlzkAWAhsX6xuiK9GMgkX60g2d5B+mnu0eeOZDoBV1P7aDrW5eg
KyADPryibRsdCl1xUiADQoeRQdsQ1BZdMxuXlaYB5Z4nn03yCYgbH85so/nL
sgFN3hwjlhP/1GCb5E3scSjlpGj4wDZDJaCSF4E0TCWoJ1LzMInrEvxr7Xm6
6+ex0poyJIFPw6lrQS87WQPJBiyya/weCN1E4gl+f18HP4GYBoEWxFE52W+g
lAGXGEmhMeDwIrmr7rDIiJzYwc9zvwF+Ir7AoQFWgwYiH9T/JT4kgZbMYh4c
ni4+D024gc4YjUvrKE9WjF285hz+jvRnVcPmRt9GXJZjhXxDFwY4jUKXZ5Xs
ZadlUH0ghwSp/6nsQJqa2A0uAg7IT7qpkDOpn+wY2X/GDMRDxkoumqRjzvVY
yvWyFtMlpmI6xI9DJzCI6WvdOMYhDGRlN+Rh4b4sc6aH8LJ3doezAIzYcnlW
tI2hMEoMgyeKs4Vd0RBAlyjpTg+JDJ0zvXVYJKwwLXI1xXcXZSGFPykHSG7b
rcFt2127bb0fzMLwmvQn6VBx2aJAmPD3FO4AAUZuSzYBfQhmZAGgjVlG7Fv+
DQuBwn6M5PweFCthsmNNGpx2TeY9XnOkkmRNBJsb9RQCiF2QXdjVYjFbHF9Q
wYhsM7mW4qARsP2q2h5kIh6bpFX+L7dB5Xof56OExBh673OHq4d3PZmk4z3v
vZAc03cF9zt6NZGNcjEub/hXtXXAWl3f4WI8lQeyM93w0LxiSAV6NB1dt7a3
Gr0XMAKstrf6o1lEfjL9GRcR8ZA9OXD2N8dwKxaFS8itkEa8gYyRGaEEKWml
0dqhm2q4D1gACe+cayOCm83XytKXHGewRzJFWCwJBIQCqJzHhMkimbnKtB5V
a776RPXrN/9zNTExUb3yR95RXfYAoSvGaDqByPh2bTBI0imI5uHYJCJo+gGW
im7MkE+ny4OiNvaGfeP3TGmJv/zQ+nXeE+6MosQ1JSibTt8VaGx4oBloyONe
qKVCMZ+kArrwGirXDiLahgOQCEC2BYFzZ97FofdLrfBSWqbugG7DA42Q3Lub
SsYX+eYerEIseIfRT2x+pbO5a5QSu9vpnk8+tq/6w013JF6+4fx3Vdc/sldG
xcPFBMYqz6XEQev4HIJze7b4K4gPHLnhwSMqiigeQyhJO4YGqiKBa0IUcVmI
WiTpGDLkJzT9c5nYL3ArTccyefQiQIzt7q5PF4Mjl/Z21wkgUQBtOrcULzAe
Wzx8Ei/OcnedVDUm7qJf+4061B8WN9HFQE4anc9l5TewjCB2TdE932bS73FS
Gz1LetCTRIPUzCjhp9YXsvfuJn4yXYMGMGWzj7wwDIFbqzBxqjHQi9iRj+D4
C5HSgyRSzTzn8jIIXba16TfIYYTSsgHKkBi0PxoYI02RmyJTLaf862TMyzrc
0R932tB7dEVBnLY81zMM3WhUjRGbohhjrkeHeaBBx+ESz9CskpWYFdOT3hsi
HadTE7LMniArziTy74NvHudXyFUsCbD1OVooAy/NKKQDwt01mXP66ZtD59M6
6Pw2p/Mh9wDvTe7F3uQKofGXZRs7DENbWwYxr/O15e7J7ROdY1I4RhJuvkdu
x5TeNFsi8p/haYcDIR7qSgBeH/LAIczO7Jhs5MehEZ1Dp/XZKPYRfVNRjYX8
QG00PrmLZrLoEU7BCX6k7XY9j432m2ueSTXs+T2RxBZO630NQ3D621ucjtFe
NHXu9I8CCxB1bokFEGOuzhT1vrWD0292TuP4aOgBVVgCpyGaUWrQwWmEAaFQ
XCdZFQYaMpR7kEYxLGigLoZsNqkH+quMRzvxJiL56OHC8Kr059hGSB8FQkls
lEze2bXuwIMInAcQ96DODFlAdFUAyUsCIIVsQYlOPwrTWs6CXBPE77KQxZL/
FbNYu/P8i3kLi5n3BmeeJpFEaboEURC07oaeskDSNS7zCCLozpUzbWpRZiWL
3HwZ52tXZ6bMi4lAsjBJ7pqZdDdgvXN8tG3NPfR51i7PZeVJP0biYdKXKXmY
aTBCgpSRwnb4/0YZnh0UzqCDU+n3dAIIZHieNm7yjAksAXgfNsZuGZTW4Xb0
1CGvAXtGK/rpckbk62ryIZNsWRlmaV4BmCYglGOLk5fo08g5v2vvvsT5Cy64
oPf9DkOc/ABzsewmT4aFCaOexEC5Gdi6KVhqTMRpQZB3h6RMDP3By0N/eXzt
eQLpLdZHqJgUZDfO3ZGZhgGPMZ6inGDmHPjJYiXgDYRTkEAvZsNe7PHxgY7c
p9ImmnFBO9x1HflsL62v9WFaM77KaP/tE89UG7ZuTw742y/8perupxeSvMIu
2SY06cwQogsENEos2hymXBABN4MxTFQ2lEcwXEiWfBZswYuC3stoQzieBdTG
2DBTQu6r3OmIiZmWVfVZgzxUJB/4J9wwtE0bMCERGrcxDMOgQFyToVH840zK
LtdxDSYpC6SpIaRI+S35UopzPnjHI42w9ne27c7ZOBNuFEyOlpwt3rcBx3xd
vIhRwl+mhL42m+HoJ/MxTOYkZEOyVRkn+eeSYlpeNxHNLQ6KuhNaD9PvcYEa
VfFwt1aZ2ZItaxtP2X7Nv7sVEMul8LLPAIOie5ol5uKWysEGr+zdgdsGE0wA
VL0JA5So3BICAOCywfYdwRunUW6Dwo0hg1e8xMnUMlIBPMrxa5gwDF/Ryn3Q
6pP2c/t9c8nsSeduDUacpq7zXIjnXPp0m1K3x9czz4NidEnGjfjP0JV2KxWi
Gc7oJYeU1Ld7oIrYYq5QZvCASpfnoKwnj3iNRx6YMDi7yaMyNYcWv8RzT9GG
y07Z/6+LvBmlHlXR4E5ZY84SBJEnPCtIsrE1cxOm1f9jMB8a7+lY5uMv8qz5
MDjK9OhRUGPey15/uQ9Pjz32WCkwm/RrypvhAfSTdRwldgOIfsi/9hF5LzrR
dRs7BunyoHhaO1PClt/DlIJT3sT+TiSSNidgX+oEnncTic2DGahc0ZXJBp+g
fTSL1uiLgzsbazM0JGrqvBF7plxxAeScGDcuawRx0UGOlQvKZmiGduwOhHL7
ynNKZuXvKwSJgvZtLkIxXesFNDmzZ60r44IshClumZ0DLVGRh4lMmAfbFhXo
IXKqCKV4Tk0f9jxnEq3PeXIJInjwIacFN5lLtArllUsCvzOcQ+3iBgyeUnVh
ckwhkyyw4hn8tjhaUdLhSqgxPU7jRy9ZSbqYlzW7PxGsAfqpXI3G9lBEZnKN
FztMooVHRtMGxRCu9FYk+eUSt5R0RRHBDxm4zid0ZR7CiGOUqSMsgaEkBLIW
05RyQE29Xui8398x6iuGK7yfKlPykffK+mn64gUdAvAWN6toRIyZoKWmpzW6
gxXaC/HAHqrsyoNRcV0Vds4Fcyp32B2jetZqZlH9lGZfNFqGAaDnVXl5+mNF
px7H8pZ2mCEfBoymQs2bZ+69cm+mUXOIcYLQtEFbmtcA+9uS34L3MlPCGyXe
Y4WgJqKawchUw7Df6IZd1SVYOjj2bR1CIBW9zr2eoqbTjfoBupffgeiG6c3j
O+TgjS4HC14zgSTCOxgC39YGOYBqXENGoDRUVyR7qjus7bqwdt1Lu7QjVle1
px88WfgjMYjNtZsx58CTRh8NZnSKKNCQITKEZsYpJZQ2e1JJTpX6Ue0ZM0+r
QqjZjpZUvhXV0Tjc0+QPFhP6KMQj4xxpo9BIExqxhGBNcWWaLL3WHQuvg4x1
QbMdLP33LjyAvyuUIMX8hKljDEyRV3rYEkKeWg4XzwdqxjiMwIWrmumMUSnd
xxy2Ufmdmau/usRQh1YIWKNFPwx1dIhZgQVKU6E4JhinujWSjwV3t7kPstEn
xID58pgRqo0onSk3oHyTk8MYkymtGQvyAa8OUVq73mdDTelGHgDoAQHVByzV
2zCknhLamw+Vc0pm8R5TBZHc7ZID+YkaAJ5pVMx9iysRd6MawBhjwU8Ht4DO
kbj1HmoWL2uixBTRL6UVDMFp7m4thEFbkwabfFBAoFEczcv7BKpPi0w3JszB
i1m4mAS4Y2+aex+4F6VqLHlQLr1ywKTCqAzczN4tr04l6iqnhTyp5NenkQPn
JgvnFEnFOQ3r4wVOO7oDIsgLQ3glTA4sNXMUUgLu+AyKa2X3XKudgStSy5fU
s40ldXq529MNnsTY7GIcApGeIkiVF9F1DKsakchEqRTjFtzmUV5BYr/dwRGN
NVmJiUSL2pzuSiKMw6QDfWEG+6kWaFwcJsVXG3INyiSwmqBozAVyfhQZ8Bis
LJXS1oa15jVGiVAqVLO/U84aBeGaJpKBkSrhjKx2oYIACAA2nOfJlg1cUGL9
aEwkuTrKrUUz25n6WAXp8WYaUoxV50QBmEp6FWvC5PIsjlQXlyZtDFMVynjv
yUsnPHwbNQbybXnWyDTB9MXoiLzynorwXXZPCbY8jnOAd7VnS8qsxri4lTCQ
EdvdypeEOLmdjfi5X7642v7sIaS6n+oehiVHRCcpN2QiZ5yQ0FAJ1k8j9EDC
VZeU2euq3/Cfvju+YSbCX59MlKXJUHNY8jQGRQZoooQSIozSSXUKcVTmMDE7
MMRY3BNZMDtAj3GgLU8SxxmqPWG6QBnI67vCrXGZi1Tam0eNPy5Mq10Ulyq5
UE4YGOVLr62LpUUlpe2jF982OqcE900xDU37xPqyVqYZIkOBWCBhEH5rcFcB
lh6QHVry2LWRlGS0BDLUVNWt9cRLM30y6xDK7Ys1IsaEyWSGR8Vj5C+0op5t
kFyEUfEi9YMP9R3e7B7nORgR9LrH1w8Vlugnpgv6OcKKr/a7sVgqvmpUBTbj
q6u9kFmBhpbMSCh9Tu+l7vV2DdwyMut9Ds8ndhflR+LApqA+VpbEuakpZ6Xy
Iwg0zyJA9FFb1HHxUTVguusyQNGsoVhfij3QXMy19ex28b80ZStl2OIU2V+m
anNQrPQVVFPpJcHLIIyKly8xKq7u8Mrf5mKglC2qj866GAw8fuArYNOkp/q8
ualFE46SASjTFVtdHrINqr+KaTZD+Ycy789q2QHN5XbZgTCcj0MZiyZwGK1k
cOj8KjfE+h/l9nBc3AVWbjMswcad2Zlf6QMBAKnsDxSEsluO2AodIaeKNwzD
U5yn8gAhnNL36/KA1Eh0KFcunnrKy8fdJk//g/MUgDFSvINcgWMY6OhGPEUT
fHL5lBCsxFLs6Aeoai8U/KpoD7OGHYkOeFDrnG72quLaHY+c3RIKQTDd195f
Z02YTRmkgW86GVFQUtpORWwwAulAc63tU4JCR7cyFDX0IrPoRiwH+AMiSd0E
l6N5ZwahnfmC5xvcJY/zBzjSqzqY9gPONJxrCQTvIlImvHH0UD4FRYv1wCeF
BEF7uWU0zIF7JbCXN605ItmgVonXT2X2vdkdhjgm+fou80vsv/Z0Btgo6rhU
2GSngh4ZB4OlekGHx4Ztjas6WnmmWPKiKc1WwnGqg+rnOGcPemg75/kh0Efm
4sCtoRDyQM6YyzwxGIWYRwmmvvZQus1gO8dodPCiyJNdI6+44oq0rPzcN74x
rRdnpTpryFn7/sUvfjEhtm/fvtd22GWSLWFFceIHVRYndvAJMUF6TUSW4hOS
Zcx5offUrnJRoiGWxMY5e43JG8xOxLlns4sDZ9LifMZkY9lDzGW4k9FWYmzH
5np24GSX2d0eoUBzn/zxCH82xYEfuuuJkmiVOdn0eKcxU53M/Px82mWAvRPY
wgBGXXzxxWmXARb0IyHZ4tmolPF7dv/+yj8mWvkar7H2/+STTzY42XlgOkWk
7BXAdfY9YL8HNmGgm5tvvrnaunUr3X+nIwdwAEzc8PbP3lX90N9+xSjyho13
Gvns/+qCf9hWXfyl+4sso5PIu9HneBcFJdUQFW63RAHDwSUqIN532R9V73//
++G/kolymxRBxoSir0HoxUpB6WwsqEjhVK6Gy8ui3E2V9Q6LDzWHIIeYh9PM
oZEOZtEMcg/Db7n/0bRDw4f/7p+SDv/e1kfrGemJRXkUuff45d/i5MXdpTnu
Izs5J5DfR6gR+M/PP5u6etF3fncKEPG8XuzUwa9nMw80Fs1Fg9FkNBrNNol3
zuc9JwD3ueeeM5ue0bT/JTlu7bMksTcFz2kzCLRH0rUiC15uIpc20zXCZMIz
7WMGLSPG2BBkCgivvPLKxF5EGAibsjmVIARqoDQ9LfaIrSjA0rB1zFclYwTF
3vZ3X0Ucq3M/vbX6xX/cngQVGdBSqZQmMbOArLz/tgeq99x6X/WTt9yTBHmQ
BHmcBJnr+HNyq4xLxzu6WKPHTPy4jC7A1N/7yqMkdVKa7vRXv7b6o/v3FK9M
io33f7r7JYw8iBx289YwV6DS0a6E0TCETErjeCoHUVe8DhVUaIBW4CxhqnyO
vs/sm0GghfYMwkrDcI25Ofm9srGeVSgZhbgGYDKYNiCeXX1G9a6P31j9wbb5
UmqoMPSRZw+mvEZRrDThmAYMhl1T/b7HA5f6fAJQPeblYhI+rR4zMSoxQpfg
I1aIDuYNwR8msZopJu+ss85KUoqCYPJ4j2EOS0t7NtR5cDxMSoBppF27r+GY
15BQpBjpRjKRYiTbJN5VY8q1+7bbbktPauuW97z3wt7xLf1A0wAC+/vRj340
dQqQbJcD0Aa8I7K0fgS77VMZOf/AMg104xdu25Fyy0b7KVefwx4Byaxu3vVs
9Zf3z1e/ufWx6vwv7aje9Pm5pFK8joqhWnAXaUGGGYGO98FG7QAOsvtXuw4l
fVjz1Sd6/WDlUcGoH2b8znC6ChxUJJbkkAE3+zeBOTeCXv/I3uoTDz1VfezB
/PMnc3usB+trUH343j1jr9VCMi/58gOp/6Frkt1OMPnPgNftURqEMjQ/TL8n
q1t37a++vCf/kIS7Y8fjiep/f+ddwLjaGcjogEnHImBwSnbaegI2zPaOZ3Oi
e+ySDJOQRiT5JJdk9vuJYz0ihoTCZJnwYRi8JQD4AvgEDPIykBhbs8dywtjh
B7lL1LTHad66O86hgV+IGdD0EWG7hsjdcMMN1Re+8AUZ+pFLMzwCUGQd641k
arckgPIxoixgADFUl3cAUNYfSISctTFw3AAyOiasBkQhANqgSYpiTZ7gCoqx
OPfmbWnQNWE81lE+cPBgWk+Ig3XlffPJ5Ju57yPMdhtRxmWBUdhKxN4G92Od
F1BEOzk9e2ChenTP3uqrTx1IUot2XJ5WRJl8eZKda3j2qdZ5IblwWvAgfxOd
X+YwL5iE7184mIB86plnU9HtqNoxj9DiBdy3bwHgMXnzu/vcZTg2OHjBfhrO
HuQzw+HkHqWGHzJ5+8ITTye4bIQy9gDrsPrje3Jty13zT9HqdIc4rnQSwDEZ
1sgxBEXiODiKOCJ3MqoG6mpXckxb3IyLV6E45s84qzwIsoIgID8wHYXgOwpi
11wqze5ABSSeG3Srra6i0yOJsh+jlP0eMAwMQMfoAuDaW8vemgmeEpd46Xh+
9xnl7MZ3vu4H0ijCjVX5hn21htCHN//4O5P5M3dgwp/HZVPvK9PvkUandJ22
gKTPy728ERnexAmnv9gkjN+5DYjP2y9KvwdlQAHTZX7N4UoAjdLvyfQe172f
AqZ/z48NCig0tNybE2/5dopfowkDKgE29N+QhCYB3dqYbkFofx3zgYYzH8z4
PWxovXEj9ZFwWd1qqN49bbLARp8IEAYLeUPnzEpN+7jE8Cp7xgdLwqvsoLbS
pWiQBlCEF1qmS7/pfSEctG4a4c7uOF1DjPloozYj6soik3wAA3DoF/UBTOgg
mUROEXK7b8jk3zd+8lPVh9b9afr54+v+uvrrjZ9OKshzpk4Dxvhe3pSNy7x0
avo9kbQUHQEuEJFnDUKTqctxITPce9UH16VAy9o5PTUxqP7yxk9Vv/W/bqjO
v3K98cQe6FfvvOzP7L0r/uzPEyj0i5eBZhuoJ/h7Gz51U3rXIDYZthbs2i+s
+5+8nBoY8LvPJUOePoUe6Fr/9pK12BuUtrmWSTIqFgiWgRP3zkn3ZiJpkvrz
l++0S/vqi56HCZRhQpB7AGzPrUhNDUvX3LIHB6CfAU8Uy2Ka5U52AT2Aqfhg
MNiHqRcGwEUwgIN1fa4YQbkHQekNAAHUiDzrBOU2rdVe37jEbTgFCKtHQstc
yhFRlPew16YiCrxiUqgRfOzjDwoBqgig4RYHb25l85vjlT37F1jQnWIc/uLd
E+eySPgTX76r+rttDybH6P75PWnpiA1tHpqtSPKPXdYwgm1WYKrB3y1a6hsT
gq9JKH+mg7rDRzL6Nfe1j0NqpD3vHx9K0RugAIINaD6bkbciItgg6GDQvuWJ
fcm/wxnD7fvQXbijuIOTCSXic9oBHeJr0GHAt4FWmT2ooqTR65zeTz57IGHN
4yQYoMjv3/GQL3/PE/1ATbd0jxv5WF6acKw3S5DDa+Zo94QZPvo/7d6f2Ajx
cMD6LlAMkIzVXAckInMFlmQQYIBAgipgRPtgB+aRkXbf/ZHJJL9xQIYxaBz9
GBwakDF0iDmP+KaVyb6hmAZgI+gZJwcCjsNh3oDjBvCkN4aXTwBAIKEgGEcN
khmHhslrn6p+9+4nEuh4+6RycMqpz0cuNIV/pnOEUAqZ4wfykKcinD9Y1juP
UrxBlEucyT2I3seBdKEi7hG3rP3eCwK4WgRD3K5V6S5QgwRuzXBAJWbBGTSv
VMVUmn4lQxyLqdj9AozADOYTitCME6PXaP7ePPGsSo2SYRtUDz1zMBHKZMiR
GqbADURxTw9r6ZKvtDfg5szVBFDoql7ByejeyzyYTInLFNXfN19mYWBbmrta
8Jq8UbJJcucYg3BKj3c1RnQwA0iViYwiel4hOOZb9mlLOglmYjSRTXtjucOt
jLBqE+OcoJeClDSgJoWBG55iCMAVnJl6QC5ULI5nDKko+3ilI0QftE+7xL2k
ivopVTRKqSJUFQ/7n+b3odm+69ZEY7fNLaGUmdoM1cyQN4JVwISRevTAoer+
R7+WNwe46KJXeexUFk+YLSMqIN34hZ3P5AkiY9VlX/laPbNYlwsq3UieR8VW
RrkTnbYwH6NKgGyRUE5/DVJABC0PhMVfMqRIJkESgg3cyENrJVBc1N/eI8BL
gVYJgAMHUpCAOJim5kU5JaqB9f5xAZoqk6KxdjuWgNT12/X6APgG3ZHVMLX5
Qu+GyQFY/uub53xCOBc7INYomV3HhDRYDolI1dE9CxtOdWOnNXKAhnJ6JWS/
lSPTthpQUXseaCecOd/N0Xg1SKtPUgFGY5KFR5nvh61p+yD2B21t/+Ct2ONT
6fagFIvbW4YLvycTf5AhTXJrFx/f3jVqkJaPXecVYpq8U4WY1nvDarhhJMpm
x64xRPMeqW5Z0vZGeIBwlRd6hq5VD6lNBdrSRP2C5qgPh+U4WXm9CiXPVe3x
KUvV/GlJiU9bN0ocIAIEUeZSZZ7qCoogNNQ+fa8LDeDAGmTN8wwuNOPkzyA0
YEf2ADaa3TnViaEtJjDmmAJGa0wA8WPKZF3CPjvW6cleNEg+y/O/pdwt7agR
VluopFe1RMxX+5ZoZZUOXKBWEkEFPtIi4hrjJhyhlvukMP5pHl1FCYvWI001
anBUVTznhWFaaZzX4vS+21s+EKylqueWKHdAHmAeiHn1nAYY3paCWkff72jS
J08iQbAX4VS2H+GEXUjYprwaDqla7aZXiRsmjTRBNLe3LllACc2yjNJefBMl
rR43l/FdG0wY8j5G2kSw1sRBeZ4n8jZIo/KufvKKtF1pT5iwK6jXHg/T82AI
NmbPk+z1kxiOyrwIxIF+LPQ5zgequMEJ8FPupP0oNa2qovxYga6KKhMK38vo
3zkzY4WAKk+0FKKUtY+TFpE3i35MqYAZJEUCZkqizg4Wln6j81bGrnGSWeYf
AVWZOEOvazOKH3aqgT0cuSobrayxU0ljMf0gDOiM/CIgHZs4ezyV6za0igQR
QvO0FZlGIy3SlCH7km9m4YWCiYd90POJXGkcyGKlYvm1pvHtPY08B8OqB2TJ
14kOvN4TiNEmerU3lYHEYv6WmRIQs7Hu9d4YDYELOojFAnejbCQydAcdJfBN
dU/oIPIPeUdgwaPYLImmKRe6hz4CMQghBIIHBiRC792/zNVYNeYoj9etLKLv
1S6gstp7clW8lkjEZXtxWfN1LvP0aEatwYRUb1eGiTi7rLXLcWSKZRuafTnk
G56gYSp/KEWQg9QxvMVIyPHF0kJkSGHNn+st0TLsR7hBF2E3Koo1SmjDNYCC
oEbYrv083uhEpSPgpkXUxjp12ziRGA9+3NfoSpP4Sn0fJpxHqbUIvIZCu98P
I6sWUMiAiFSrfaSOe4Js7mBOvVpoWFgAOU0mnGkne0saUdoxQljo0KgagWZa
dixmeo2XZisRJnjYwGuQcEKQ8BCm/FF6Rbzhn9mENzv/sDagjTOKO4WJKfzL
NRS8xWVgVK0ZQmVE7SoxktKqdoCWsWVIRlHaYWoVews9DauBv8UgzpMtjdMC
K/pl4hha9Z3qYIsu+7JVLZZq7+KRF+fvamyLHqvBtORAS+DSFh7NxcS++GN1
6EH1jKr9UE3jUvWu3EOywxpyd+KyMwMSMFwT6uCPKtq9SeckcoBeQR5r6q1u
9FWKhaggUtgtVM8e7YmdvIK1RI+Y8gQaBWNpZ7ZMZdJMyiu9JjQf1z8GYelF
bafpjxopeQYzZQgOnbfgLGvKD7gZvir2gMhIrbXckyRf7kENrobWNchT1+gG
U+U3r2n6fIisfL4v+dqGuLWer2k9MzBAM86qv9M2nsXnqx1yboGmViDhyJ7o
5KIHKAtQ8JG/kC5vbJwZyXe4AS2srfMcCpnUW31VAqIDVdEYY2Am9mxDNdnr
Mu6PSCwu2++4vsIHHDlXcXUfZJK4AFDpJbMUsw81IQet2nCsGWNUAMLa2w0D
vN0N8FRQFa7Rm0QbvPjO9VhTqAWT2m0xOmtr6x01tHfU+lYFuXuAudC794oO
DxActMja/cpY7aU6MY0IRrHjgk1D5HgMFBA7I+aED12YC42RUIFgMO/at7qx
o6H0J9IcQr/2mltKhQ0VDjKC3IPVsZptnfsWWtup3Qa0lFCbwCOUyT2334Dv
n7KQ8rAbMZ7o+3PagYS6sn4qS1tWNujwoKDU6GwKq5Rx9IMMeeQ2WeAHduhy
nVfS3JtX5pZ0tnGOEh+iIQkTfn5TmFIWIolu3ls4Gwo4gcpiT1X4sTsIUQwM
Y1JG8ZvcNEmRr8TM3Ot9j/M/xhDYFG9RqwZUicktX5Xttc/5VXmc/CCyppZj
Fx1uyzZCJkifl4Euy/WFC4eqL25/qFSekKrRFnVYAAyESE9CcMLph/hgKRgF
Rtwde7AJP3iYVNIw/R6kB3kB3k25SywPTrzDz5XRC4TSdA/ijaIqvqML6EtW
asp1EUeI12lKC7/QZshj1F3lTSmKQaJVGd7eEyGu8eMZVdYixz8TfeZ8JIHq
WUst77icUiC99IptFX5pLyFEHBcevqxwnoE+xgL4AQJ3WfykN/CGBpCaCPpn
XH7jaqdcvTLbqCNVLKCEolxOBy0v+TB+iJXwHvbYj+HJ71HZ6kKjoA0kpism
5UY0xcwK36LbqzkgTAAiSmvSRUwbgy0JGPES0uEtwT+VGKFLiL+1IVLJOUHr
fWlG4aFUUDlR7U2M5VodZCGW+Ct/jVg1YqOZ9KogEfYxSaggl+ZfEMBTDTBg
MNU3CO6l51VRWC1PI/AH8U59HqYBROG53frpDkc5AZzqlnrNrXtOd6TpER2X
245qMniyV4psYdClRU4TmZnljmEMVbWsK6Y9VIuKDW0kpOvNYbWXhJbBxy3+
tPEPzQuN10S+ZAMY05w+nGtzzbhy+ppgjOecXbhrKktW+ArisDYfWJAhACIc
FZRRU0BHUlQkUsaKe4jFT3Zw63Uu8IyXEIkxWBWIMAjrVAoYs16AQtQL0EKv
F2QuhyXJ4Fj0w0CCttOCZxRLojpuAqFtacNe83FdzmUh7bnx4XrfO48ipTna
7yAmpbU27sYHm8eVdU3pMLbG1RzWjoyuEp08krYmqwNUgMGSTAdDDL6iFrJi
Lam8j1aU8+IvM2JdJ4qd49cwaCgh6QMZMIwkOgvu2qULpEE2G8hahtBn1pSq
4lbDByCuqxNZWBcl0E3CYyinvLR2lBWTyqYfU411Mdo1Qn67UuN+uMdp3nI8
AUaL3bQwsqwRGifLd5W3qmy3vXaCtwLWCjXlzCIxtGTaMu1ER/nAMPi6PmJl
X5geFM0BgPXwjg6evNYNGtSgOQU96B2CxWbB0bmD9XnJd+YHusWAwrzOTOAH
eg0/jIRKBpA0AQlfwHiS9yylEcUU9dQ5l/qMAviEtihgjJMEvlDzpd6sAkZI
iTzLLMY1dnGFKs/40kNVudIydo6tEYSvUlz0OPn81APySD1w1zh+58c7WPH9
fg3u0YS57EU9eA/C5Fm+WlBcPYqvhnqgRkaYLm4UPR+mJ5FAcDYEYkW2uMGI
r2072/lpGRiaULzgcY2vq3xVaFH6BlraFbJesDIuUVMc5srk70T6Cv80oAMQ
jxHETXboA/KO4EofoBTdMuLDBYIhM+1v72DC9/k1cOGVemYun10ArjXvc2AE
VrglXTox/XVxQbXIygQgfbh1PjkcGaB8MuYrbsFhuGbbWyIjZdu0XY1vYKbI
CBtDQ1p7iwXWbAUKRAfaggZweQ7jN9GSfokgxsiIL9oDF69pQHban9dB++/x
XjEQ9Ch2MYYja5g4CT9IIVHIp3q+1AMVk7avj+wrA6UUQzIs+op2ecNxUI0k
Rx5UIqAxALfAt5A42VtXq/GgwrIoeFzWfaLSgAsd01qd2u+ATQggAwydKrKT
/4aFFZt4bn9gEyoIykuwCSJFNhG4mqH6kQ42fZdfo1eMcRzGsXMAH4fxec8J
RBUBE+iBIKmmHKwY2uvnFjFKMQv6IXFGS+uYZVy4BBiqZLFXc+653udf20Ro
S5/gMmNHGrwblIWMl5Q9mCbLNr5d85zWoTxi7RRFR8C1tti9YbKDNO3ozQaT
CWqXuoeKruNPYlAiPzENsok0baIjfoIe4iB+whjj5w938FOGmlegglwATV9S
E6KtKJBbjPSakAP33EDhI/gjfXWyOI/9QOuIKvTBMMN2Hsdq1nMH47KXHn4Q
dtAX+sojjiHnZt9LScvitC+VTFyMN+mGM7QaDG667tqPFSF1171dKKTNHknt
3VsHxfKtn/LJH2APZgenn3EMFbenZwK7GWtlZb8BdiN3Hex+Swe7v8OvwQoE
3x5tuBnEO6RSpL6EHVAk7xOU1ZfesdKor/LIUJBrVwd3RHlk9BBsljt95r1o
iv5N6WTjYDmUxQq4L9Zru+1c1wRAOI7tSG67KrnktudpME9gTBZJUlwVA+iy
lrs+pYCwC/9Te8jX69nycIM8o+tpz+dMrkud7+z6L6bTK3hGpoNXPQtxFKZP
dDIdOcL4vrmD8zpwFEThcm24h8nfh2sItGnlZOhiQ5gYgAgYLBLPYjxKLLug
gIWm0EZf0F0YrwJJRp9S3TFMSnuTT2EY008KNNIcIbRStQlmQskJnDJZYm2+
r51ylW7MxOhpo+x4mrX2oPOpx5L5ihuVawm2jyQ9xQcg45wumgEYIFiHz4tZ
DQoMPf8PrMZGAx62+U0drH5xYDVUqfP2KaFcwhRTCek5UCLX7GsSkwEQsx7O
62gbBSy6W+cNCMzLqrVDtfe1rg4EoQODJi2bh3mC4xgDQcilQCHmNuJscAw9
nNO+EerLA6NjCfbiYCYvHxaTlc851t9HlUFT4zC9+7TYksyFDkj9kZgLR8x8
6AANqInVjJMrWGKu2WOeZmgyWIVceI3IEpaplCRlHgM19DEIp4IYAYiARXEg
I561onyAhRjrwhQOJAdJhnkxF3bBKtorcpBHeoY9L6fS9JwCECQsbPwZ+bou
zMHHY9mMkj7X813emKaZpbzup8ekKY3RD7RBqKyRFY4ggCN6MayX2mKrpgJn
kVz5OpeHZ9qc1YCHd1E4m3UFCKCfsSQmuzB3DLOv72Du6pa1pOe0FLWuz2Ae
H+YaMlLM/V6jgAUs2tasOJGuMxJyLa/Uv6TUfUHMuTznq+QaVACFxqr7bLHp
CIkym7iqxWYF+o29u2rfPO5AZR34dFAa6tO59dnJG5UBAEw9bC3Jf9pCoWGl
EUohq3SWkUouiAeFhbNAybX4DKgzqi2ls87ZcfB2cBZgvOJU/iLIsAw/45wO
1kbMIKvqBZnXE3/RfQi3JXtY4q+cpmvvb1QUQQd8EuZbJgN0qBAskPgCGaM+
igl0YjCyAA15dm1daOaFUknlFR8v+AkTt3taYl1O48SarXW+cdwmd4w1P6DT
FNuzRUqTGzuaG7hOJY6oOhir2yrKTxZWO+loc24g49l8AGUdZEEg3jXO62Rh
aIRcxalqz7GmJyZbz8VRngGD5sBs7JjRPYYvGnloXT+TPQbAq33urM0MSnDb
wHtNh9Cc5FgCCiM6tuMDeVudstYAB46gHRTkbqv4QUM2/PR6wqL2dI3FdUVW
AcxBrwpxJkTHH2HBvZl1PkmAQFjChlrQE6oQ52V1Rsni2bxREmSGPN6Zc+8/
zn/EIxTA5IbW/McwDFY8z5tnR5HKp+ikc9i37oiLYKJXoeROiOQV1Wleyzcl
FAXBGYHwglnVw0F0QOUg5kg+WlgIuzu2s1iQQVOES8kWwG5yL1NbNtEO7dcZ
yywUJNwUg6H339chYMc5ezCejAug4+WipS1cT6aZ8TQkAjJNEkykJVAG9wK7
SZOGgjwMmIj5jQkhxBDuICwSrJ2eSAArUYe/QEeTuJrKJCjygglpv9itdSaB
d2gf6OQPGAdU/Kn8aKxrv95jQBcUl9HpRibhGq9e2xzyeW6XPLmgsrgovdoS
ORz70NiO9c4di8QQSp8Q8NRGOChcvWXYoEyHY7KVSlLqXPRDctqODnTGBKgg
bo27uYwo4/AMYEdXGKOK5ygzA5oYYFjeXv2mmlLxAD6f1SGJy8Pwq4SpL8NA
AqNg0wUUZFyoHdisppAHMIpXOEyY0zusMnmVMCI0PlHVcHfhbD1Rnd1iCHfV
ttplAjD4iOk2dVWQq4HIDVzMbkgMfdvixmIZzVbFxTIN/2mqcRZlrPLXNsLo
dy7W9gBhopHYuvXxeqe69naCKoiPpToLJdit/UCQMr8p6u0mN/JKbWA2Ialk
BTMAOeukQS6OuL01txY9VcVGEAby1p5q3ed8mQzLu437KJ2sVO1PTZRVPsgf
zpP0aqGcbN6UQSU/9ntljDad4n3aqTcAq+Ua66ydDCWI2sgZ3SrZoCwHpBtA
QZl8kQVOYQZrZyNnDZEZQLFheab1aB2vD0vhsKddFKrt9kUavpu0HCN8NQlj
WZQxUcquJDHXB4mJa3xUvSMhDDNQufDZTxKrJxV1EFs4LrqRtsewl01xcmpN
6z81wgBMED8UAbbvKumW7LAxDKxbogZRZg94QV/BMDgpUpCbr4BZkQKsRi+1
6WYdVOWZLiWy8c5cVLRAQlWWkA3t0CajFBnpeEjtGsAORnwgXDzayoMw1Ryr
aS0ZpEqRQUG7sSJZ04GAcLQVrvsZxpJd0RDq+0LmRoDI27RiMiI5BD5Ghvgo
MMoRLWew1H7opscX+6FYOlUHGFniFpCgssU3Q78q7to6WVYR05ryQWF72zzD
6ys8886NcT/0xvzeqKzk3OTkg7na3EgRFQIvgUGRMZmayFKB0VIV1RDP2pWu
P+WJ9TjyIDsKGkaBc3Rx9fYn4oSgdr9EZNGM2vKMS5AGkjyHRSwLPGYb22/C
Vc1gtXel35+Pf1dAtt9T8Kw+Z/8KLTv95Tt3lrriKJJa/AUEKtLEN9GWOKoi
1RbIfkpETDFsrCfH2tNLMXeBegYfVzJ/oDv/CMohRRUzHUpohWEb6FEqhEbm
WvP0MT+hupUwYazoNZ/fUB87C3d9GeR3t1qiFx3cWBLko3LkAdbR65l6K4Ic
bckr0IscXVqPGcUuIv1Nna6ztrSngJfQr112BTib3G0cu7ESvcQ6YPyAByjy
dZTUN2lSwlSDEW4bBl+V6ZRBj31FparS+UGCsHcEt2jR2jxJZE+B8FAb5+o4
4X4Kro9NTfIaP2HnzrTzWyzmZ8tC7iuKi+cgGIYyXVpjo/WEMROlY2Vhjj0z
4+qCBuFq8HhMwlzjJgPzIknd47RELGMy1SeOqLstE4Z1EADngLkOAmo3Fw4a
/ErMqaIEFd/QltRxObo47qpsHf5sFlKtjSbSR/pA9Co/0kUSCmZIAcPUnBtP
bc+glHK0dAr4qGiadsPZTk/zF2B920jVftAcQhdjkTDaKBwRyvgCVzeKBEal
2GhLHm2SRs548+0DBLTXDDSyEbaPuPR9cZXX9CeXcAbhTZX6+e5MkkGJsUSZ
MZotQNhpR4vFD5aCotnG4QJAr/kvncOkqnMgKo7QWGULjfXRRgDJl1aUugco
YWH4RDzdX9TTUbZKSrDO+bpBVoEZdkDBfyn3qwXi1uDmrnTWzPtxAKrqryf0
sigCkwIRdwTflUXx7MDc7qLpbCyVdvDcf09ZP97xnFYRRU1U1msyB2W3g7ji
Lc7tyVjCLugdix0YMRCue7PWKkRZOEruC5DjoRbamh9t35+PnrEu8E4H5dhN
zuia8N/ye3RYLaAd8DxYP9UCHZtse/yw9WPb4VR1TDy5W7t9+LLaSQdbJ0po
wh4QJRYtkRsE+6S0vYmBYiW5pxvznqhxqlBVT0Y7DdWAiFp3hPjYD0TLQFnR
8jO21MnhuLWADgdVwZAL3IVZ4F7fEjhQbfuu2pgAjhSHYqosbY4FmvKFtLJO
PiP6elOYtmDAYLoby1/m47uDPrkzPkioQFieFfTHMtQAT5XV1Tf5Ycxy+rSg
Fsi01EGHb2iJE4sY2UioDgeXl5306UfHNujgJzmVcFfbVHiq7IiiMmqIivQ4
Jnk0a1HM4LBMhtBa6OCZMDUWInGZqBiJx4RiFJqorQJMW/rj/P9SFpdzvUdt
7d9wJrM8KwVhRFVyCfpCqzj3jlAhbPXE1aDU2MSsCcBoHW5MIzTncIdln2xP
xsqXiJWhqBNszdvELGssmmcc3uQHqegkIbqApDpQjpUukwm4bytiwI8OoNv0
WH2iWhQ3Lb/XzKFGW5QmbRTugcafzO0px17FKkptLHRcS558jur5yJNCBd/a
IK4xw8FESeA0I7WESvNxjQUiWQSv95nnPTJC+Wnt9RSqb4GJpz3sTTBdnEXp
B9Of6eLtafYmpsKxy3DCMI7r8NNuHGGEQ8ib6Y8sI748rDESbs7yUSgT6pli
RKKSHR11vFCKnafLLA8ExaLqcNGw+p6m0l5Ffc8CpZORLJK/LMmf/966o2wg
v9YPjdZZiGt9EU0890COONvSsZth2hrt134jEVUJ9Fha3ZwpzKOwVKQpIKM0
cnKtTDDcuaOhWmFlg1RL+T8d0QD4eqW1dE1WB23AjruhCq90i8qvZ1F5S4dV
DHO5QUp6ik4O+OoB4A4nPabvXEefJoNyaFVoyx/c6CIQ6hAk6ViEEstk5sRV
AxBZsxvZO5tJHcWDnmQoILyMxR4/AjRNq5hHqXNxdeKcBE/bn93q5zfBWBCI
x8raO/GcCiWA48JgncS3qAy/KS6+H1EJ6LR6rGMOgFYYHLF2IBL96I4YEI9A
kwyGnyRFyzYRoqsaZcX5iOX1PspIUv5rlpS3Ofv3eNLAWdpIbm72uTVl+DCv
DHUx44IwhuSMeK+NzZBT0972RKDbFmVMVR+mnLDX9sXlOTpNWzk5g/sVcuU9
Zc9WGJp60GyHKgZ1xlRd8dX098JJT9NBfFW725EsB7t5WdthmXfwubg2eVw1
tCuRnAokBqxqI1IX+AtTFPADmWnnPU+m7Vmoz2eReW9X01//QPFTY2AiUWoe
JTNsmPkya1Yv6tFcfKj1KfXxYh+ao/kBHQ15UPuKzjR2TYP2fgBxEl6aRncx
JTbM9vIxtQNNnKaOYvWJTkHUKnivGe9FZ2ebr3lsmtfMsg21eRWDtdRgCddx
8XKMeroFxENArLW8WjlKuPnBzOAfazHY7XeJBMCJ6zA4Lm2BpJ57j6qGR+I7
bU0FmCTVoeIaoVNyU+WtIpY2+sCAKn8y7PAMdUab9qWLh03r4HhMo7a1CIfG
l20tdFRo3rduZzowVAa/PNf3CY14FhvcggLs1traClEnnOkQHK25V1mvhMTr
iZYFtGEPt2HXmiUMq7guQdHYC/FDRIIPg1h5RKJeIMqcp6bbOidJdFPzO1lG
3ukyonQvbJMruNZlhDeeCkYAGN1tLK1DDt7FBu1UAN6cm2mOJ+OEtii2yGJO
NZZNISxy9eI+XGNvCsHRgbjc9/OC+ik3ONQeCumRcnzmZDk6M76NZWpMjy9P
W+QqXiBMvXnXQkozw5b2gcO+9069GqXebwLqKkfaysFLVzTci/kKHxDFjvAh
eHpl5fvBkMS9entc+9LMYEnOPpzF4Kec6PNe5QBf4nKLq91VwK2SZ6Ehp5HP
q0v88hllGSptW6blb/GMWSWJUXZl5sq2C7MlUQDA28O2lzp7Glfoao8Aklms
DzCH0lf5mZlIjj06TiWBKxIjuCT3TUKjM6vgr9Zls/Xwjvnd5fSU4wJjtXlU
2RBw647ox9EFjOWRujqyTtpBPjS7rita5Pa3X0HqlDmI/h9kT1ly9/9+LzP2
/MBYn98qjF3jow3BR+3EZ6t++65FxbnQCEmEEwd1qsW4zGFoLrU1B6DBE4qq
dNMET6sdIKLK6rTZoc7XwmnWYsS4J4VOcvY9wHptzw5L4dVAdKUBdNeBjkK7
uoAG1JrOc5NP61uVwpe764aYmHz/Qab3fwp2G7p2KMetjcKWYZkEbhQhDMvm
lj4xp21I6im9p+VM1tWyk6VKPe6ooVVK+587dGYrLkGe8wg6Xc7djqcbaiuD
cNy1NhxQsUZcsFYKYesoJ66SX1NHeUqq+mgUCd4Kcnoxxxt25bkiE/znnYrp
pC7PmwSXWTtbeuAtN+eZ5+ptKkpEUftfXvyV0ttCSKmksLlpvTvZTFm/d41X
O93uW5nIP/UAMxndb3HbBqXnff8fdlVXdoFRJm2Cf2/eKBKGJveq7CSx9JoV
n2PrYoPmkos8jkpxoIbueiJ9VAauyIv4npx4H7t7f5IZ8p+DWKMbLbHmLQRz
Lif2pwPjtZkhKNWTj9k/ui4kUNDQPLou3htQouYllqPgnshLS24ts7xTiVk6
nhCgMOPYAb5z3YYHIwfP5myXHyzskK1cdEoiZ62hF/IkUHf6wABqz91tdVHn
cjduWjo2t7ee9Gc8WxuyUFo6ph0cNVQeLNU4dR00bWgB81Icw+D/eebYhUdW
ivbeNHW4UO9rzb12ZklroOK6yzxVt7KxVyes047Uyvtqi1TtBS8PDiyKa5bZ
qsOR7ZGZ5O5MN3bFRZU5NIDT8hQQ+hGQx7V0BFukBaBlk7dx2fnm6iblZ79B
on8sE/2iluBryjE6bFq5qnqHuh5tVBIKcvVrsZws+aBYgTP3dNnqWUc+7vep
PJmhXQfqPJcS4H4YsBmrA9p7pHkMjVbIKHbX5m1hr8VSEaoj1JUsQ3K02HU2
SJQMVrPketSo/1Ct6ycyOX/FXwcMnWnK6/WMbL3t1Y1eVemuiMqbNBenV1tb
ymu8iwvz5wKlsEovcQJpwzcIFPeWkBcD4pu8CNK3j4lVs/KZtGZNe43KqGs7
LGRiY32YdVc6EHageNdmMr0vCK3G9/XugMYqBk1oqIohbusZN0iOi9qbKyZm
i83VcQA6B1zHAWhk9Eg+r+VZkbqAixwepEnkOTcTcA2wUGqaQsigny/Xbqyz
1Rn1G73mfc6zwitagnZrvV965/JNUfCvMgX/S9BbbY97fc5Jl9e1+49PiqX8
xzL3suKABSVAg/c1F46OlIFrssSlGkkgth+ky+sD39Ffm3xRmaVd/iEWQsb+
/hPp93RCCO251ncXBFKOUGkd9TtymY8sRCA3hikyIRbnw1WBEYq3ovJprkFJ
ejNAN2Sq/pZTValMYPdJzkageI1W8vhGlGWzfj94ypdDMMZq5zodLYLu4hX4
lI9n+T7wzw8em/5dVaqphHQ6ufuhp1JNDbTR+a+41GgliIIFdNf+wsrxq/Ie
viCsnjGOu+Oo8I5HMGSfypT4baeEZhs3elJxTYcvoJXpWkaOu3p8YAdQzXsO
DEhtFB4E4YCQnB8igRFCCFFa1dvL51mEDbHb8xp1PJxHAC2AR7JxohDbuDeW
1gRsaErBpzPua4OrHevEWwWQcFEZg21hshYT2VV5r8mpaIG14YOCm2Yp+rhY
D62YcQfmsxnQj7SGDMW+jdLfmUYBg1zAWNceZqq9MKKm7EW/9hu9vg/UMok6
/kMpStpCS7RDCT5AjA/ixFjcU8QY+Q8Zkd930igfreqcDeFoGve7vOWVZat6
lWXQu0wT5MQ0QVrZeNgj98JIOKp3KE6XcGryoSLHJ6GPB46o6EgGk2ZBmuBI
akmwxAnPaRo/n8GcTmu75MsPiBbKK8uEaVtEd8O/lGmxzg1JFJE41bf+/no/
H6UN3QE1oczxvfunLkpZ8n3fGPeN7ffIH5bBqecbhvUp5iYCs6vPGICeYYBd
5iBLdgHWYU1hL4rbMwZ/4WMMplDyoslLYgtIiNwwKhiX++nImEFSMT+wPa9C
NXQkrvpBzBAMe7Wnw5t0UjvN0SzNp907F9Lo3edMxyEHU7Kk4sorK//0vpKh
vaXDWbqveStq8b/6rbErMYeAcXwg58Lxw//79u3bcvQ3OU2Oo6A5aY6zOfnf
9PcIb6riihMvOZCQb7cf/XHOLORMzef5OK1/HY/rOOVvDjDf3NafJ6rapVen
SXOypL12x9HfQDo4/88PCT3CGwKJN3SY4BFA+rcU9X/LW7mWdiIRDe5wfCyD
GhaAs/Y4vjgHkmemE5A5WJFnUR6Oa+RUVk5p5TRtPiiZTmvl4FFYSEzAmY3a
RJnn6Yv2aYszZ2mbfmmX53mfU3D5cJ1naRfz036GA03z4HtKapvnaJM+BRcH
oAIv7wEXJ5HSJvioH67znXcJmoGJd3i2jS995lTsiUl8eI9+43uYJtrkf+7z
Hvc531TPAxcfeALtaZ/TUu29fNzHcekg4IgSJBa4AonDojkAsX1Nz4mVL1pa
EvIusJMln4+e6uzd5FCbqltTQxcGPcZloKIpnfIOhDr/R0e/8pfmOPmY5kAW
iLnGfQhCO3oeiCEWDIzt8gEknuFdCV94xoVheWqDa27pEwWBl3bQe6wE93kf
WBBKa7efTj+uTxYHVJ2LzFHSNMcr/K+j5g3dzK+TUk/tV/lOb4g7PetVnkUt
4BEY8Tz3+YifXKcN69IxOz5RgPc5j5k2RFkoxvv8D7h8hxOAyzX1GaloMB1V
LCaSoPI0yPNBuPnOudraoQpF4BpQ86FnejVse5k603HESB8kFR5I0V2mFLog
ZjRpOuXIj8sp0PrQRTr4PUPRvg2NaMKky6FIJ9cnmvLxIc+bny605aPupUv6
bm0JwjimDR2EAHV6DauF0BubvJuJJPCREBDdu+rppJ/F2A+iqBR0QBfF4YP6
m+j1RA6+i8B8EAnawII9D74jhRhNdAkpAhWBpAyj+J5Pna7YwMdYLo7TGQBK
cqSVfCRV1lrkOLSCXeI4HI4sdRYLxfZtZIomsHgiEa+gkYs5Pk6kg+PRZhl7
+smY5CPUUTB9nOOSet7yN5IEQyVegUGR2eo9MhsqHonZsoambT2dwQVDJZ9i
rtkQvRIu+W53nfw9x+mCdmB3dQ7z0fmahXyqDGVYYCgqnjJc0ovZld6RmBpc
zciVwRK3/dj5ocMta7aYn4PCz9oxGCXLi1ODSjZVsanCOngAadXzz5ebR1Nd
WEPfZqELN2mL9iM3Dy/m5uEjc/PszB3zZMwGIYD4NN79kty0a2460zfZP7l/
aDo/kbeMLTxv99WEbNuRWOsKGi10vI0UgUnNr3GyO/CQZwOP20ZaPiVOEkYa
AGGds7iLw9ovFYmQ36RXbEwQkzEikckyfPUwMmiocTydnKawHWIy7TDk85H5
+/pVVoeagowg0zBsCGivedlUj2qc30Ys01l0Fe0ASOmkxjaaNSaVPBbXYZz8
BTQhDmpEZkBda97isXfxMzlnBvdrDZxOMAELYwX3IRZoI8bYE563diUccQjB
DDkaS3P7hGIT+NADrwgTKMbzIioOHZ6Y/FIoQZuIAPek6+qPa2Bt0lMogXfB
cwimMBCPvxHlNqzpHrlXbEYXJrzZIq5KUHCZXhmx0SrEA0x4DZ7TG9/5gJWa
A0uTl55iDu5BMbpQAMD7fACNa/TFBzmDsrTNdXQpPONtLk/gq03+QlF5isgJ
ssY1+ob/UMzaFs9hmsDldf43S7c0zwfxFaO5vdR7YYkhkH4ggQcYEUZxLALf
kQupP/9rFKYP3oGqEj1FZsKINtQ+lIYTZpSOoOo3uw5AX/RTxsbZ35BIo+tr
AnKOTE+qDxKQH3Z4RN3T8Y6HWss+sZR2X+Mdgwb4RHOuZukGwOEIz2DaUv4k
RUrafAw76p9S5xuBlNGMnJroeE61U0CEXEB5mO6xzaB0rFVMHWokmiJLiiZp
yzOXiUjSeOv3XG8J8rubWo7aolvZfe3hB2ioV30S7SA6BaU2DpSAjPFBh+oG
+9+EdiqxBKjoDhYCLX/hh8e7ZaffeCLVSqe5wGpFKFxCoZAGjUiHgzSE+yd7
S4dcGwDUkNIifkSUJ01Iyq5LUF8mBfOPo6RZdGQQw4hQ8YG20Mjxd/Q/663L
5NqPfcu/Qd/f9vOEhkXKUS3jmNBEC+kMNMcd17QBINaY6zDCZFarwqECxI+4
wXslJYAb/0q4IZI8j6LzUQYHehgjW7hxF1wibpgYsVAnkAW+lPqEeE2HESiw
59uKjufyBFXvc37LMxup4753r3iMJ+6Oj4/ToOWPpx8U30i1LT41SuIKVfQU
nL83P3KL0zr0i61v3ZWsOpMbdzN83MUnaWUwVdJitO59q8OM8GOYoTQ84X97
TvECqgjnucVfsimySDyKD4BfLsmJxFzWcS3bxpWL2tX4gjXkmvRUYOkZULD/
+1xMVrAPCTTY8UT7jXTbLnpw4ea2OBNwg+sY54z0TKIJzSgLipnlPb63gC6B
Etfk8nnAr+DPYM70KQ2HBkRMvkLM2CaE0+MOT6/v4TnfZfpV3Mp36RUfH3Qa
XRqMGmW4RZd2ueSieCU2wTPOC+96XEjDcwLNnouU4JIoB9THZEH8vPeMYrhf
5PZlXOJiWW6Mh0GXgZ1NrWJ6PNxIj/PBFcIF4nFsC3bETLBSSsiodmgQSXiE
mEkrsiBLfAag3Rw5K44tTqQg4zs0wHQDMSDxHqaMZ5SHZfQEW54xsNquAY9y
i0Mzs6BMlW5ogm5oAnvBczj2dUIzh+eyJRjsOqJ6ZUktKxxkVGEUwn5CFkBW
P1I5UMNCQFGcAAWx9COHlXtYuogubUpsICfvgZ84omCJPhTpiURKLfBOsTwz
CUQNeoDFY0JFoGMnY46H7gCP+xqrink4Kd1WihkqI278LxddkCAMQIZfw3ea
dBuRMKUNKEkbUJho4xiEtZZwbrmX7nuZDhKDPLtcNgdVWjJOaNQCkd/jGahQ
YzpRBn1Fq4oyiVol1xonFC3Iq+OZgauVol49o++KdN3e6j2BBGE9LHTTMZ34
rCkLpY34HwurJuy6mohzoPna95YcmCIIxJ2uNNWkeBeVADphqJy0Egtk5/go
m0QbiKuoBHf4DqNBAyzFASUsJLI8p0SERiXg5JqiFjm7ioxBGTyIbEUexZjA
zvvILrhoQPH3NR4osVgHzKck9JFFPsgioNMMIMJASMo70kQF3ZJvJYdAn484
hpxrQtc10+QZ81fkGcq6yV0kz3lUyDIn70NyqRiQMUYyB9fpWh85RFBY6XjQ
5JpRUJ4j0PNqfEzpacNImhHydemRrvyd4qOYaw3JkRKHKZ7EYVJGHDnhulJI
Jmu9KNPNvOCgmHMoILOt3JlQqPM8xyam8byKScKMUZFH4NR95c2Vavc4UeQI
ubZ0m9eEepxckly152A0uWSMkCQjTjGJiC1SLjaEfdHDgkcgKUON0IOkphgb
ryxPQHoysLQaaQLOUZA95lePAMZtUhfuecx1yKzQBxj5qG351VyncSw/vizJ
X8xwKmesMVXkoSkAhPE5YJ8qEQJCBNn0rCarayFZWpCj0D5fQQ5mvqR5dO1o
Asw1z8L6uzOLpiOlKBLCOM3Zd9yBH4MLrpoGVwTsQttbSmo1NcXQKbbRlsSu
LbUITktq0Tnl9GheU9OIZ4fUahioU3Hj8phnENtSC/IAqTDgaFLbSrYDyPOQ
WuV+aR1WLyW5bho1nvAYUlunqqcaEwpIg6ct0rMMfyQAJ8Kz4jjc1bPQAdMU
52gllc9HcqNZjl6FJBfO0pc9/3VLLu35REiR3JBGazCpS3Iz7SYTQ5FamaVO
UzteJLTuTCs6w8Iq+34EeZ3wTkES00In3Eql57WfEacFPCYqchrTf0jV85RT
uQmSUw2yXpFxVDmdSHJKSyT1ID6jvFehFeFoy6n8enJN+ZkV5RlpDpSNEAoE
+X2Qz11NZ/RxZZ5GbWhQkPbpHbDV9FcU2i4B1bU4CxpmyL3vU0qMoo9y81Ba
yiAfFThijYmyyTh0CKrGQOCn3ZbwFbpqoD6SCQZ3zQzKz+hub7JUjEYxBSb6
sOua7pLQS1gkorLskFcTxyNnL6CCmtz6aIrVpdpjcFaRUa6yzTIud1p5kCU8
CMm4HhH3oaYrXPrulIkyzu0j2GIMUko+ubyKrnzaMq5aB/RBeo3MUA3cT1I7
UZxx3tFYVQcAJOlzPlJ5ExknQNW78AfMFBclO8Grx5VXJfZujxNo2G/FCdCf
JiTqjLwQR11gZ7Kzf0aiPe0iHpoMRMxRPZVJicfKVKiEyIPcdA9wNdUgxqmy
EZsubwtZiiVfLTGX9UDb6AaQ+N+Hj9Sc4gp58apva05Hr0jNa6YNbsJ1VYpB
MrnRPKMqMtcMF/NXlPwQqCkpgmVUsacWfkEGcV6VA7QJjMqIyfIJfVk1eQFc
k6wrdFRhKu3Rl6RRySf1IUk7grAj5tI8BSItQc+3h6UChNZLxmC2lNtBbJBA
bPXdK0PLRIwxLQ+auUhQj9FyfE1VCLoWB1PETele0QecoQ3PuwvR92QI7OB1
0oJ5AF6ZoKELh6iEO2peOc7DPjCrbhdylgnYVakn0UMzoJpLEcRKg3ENSW0J
dpkL5h7P0Z7yFXLckBKneVEW/rd2xBrpF4/Z8KORAwSQDW6paBeCMLOdiXF6
cfOgHxAoNc51moUYEAXkNWJBZxFQbYtgmAWwFRa0wXOxklPgqiDYc2pFEA+5
myqsPVN4BN9ZsxpKHgfx7b3Mn9dgYw5fGePlcOLAvtyvKaUFfzSlGsaBPON4
DGw55ghQEdAIKp+aL+YYqHQaqWYWy7SCcQZbISHUfUEZd0AGKrA/0cUA+sqO
WF/TAUknfUFcRQl8+/f+OuxTvFcjtt1FVDaauxpTYDZIKZ2HTdfY4eUrwlNU
NVr0RgFeZf5MbIVa8DwKanGWwERDE7BySsjjvM4fPeRWvAuNQTFXGY486KmM
QtrlNkagc8nFtUyHidTMP60Kz0EV8sUnhWvQmvhfQCOIPIcYvD5cg0+ogUOc
wPnLf93/NWGIdrmNas8lKukDdI1bw0Qnn4xAhxvzk6PEHhivKnY0YFvzEc0e
8EH5iUMbj4wblch83Ojek5/6bPqTU4Y0gDho2FJNt0HZehq7BQNxYWSrEChw
MWtwzzeP3r1j/i/LgVUg\
\>"], "Graphics",
  ImageSize->{417, 213},
  ImageMargins->0],
 "  \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.67",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1167.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Flow with circulation around a traditional Joukowski airfoil. "
}], "Text",
 CellChangeTimes->{{3.399555658328125*^9, 3.39955565853125*^9}, {
  3.39955584053125*^9, 3.39955586296875*^9}}],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{419, 202},
  ImageMargins->0],
 " \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.68",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1168.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  Flow with circulation around a modified Joukowski airfoil. "
}], "Text",
 CellChangeTimes->{{3.3995556565*^9, 3.3995556566875*^9}, {
  3.39955585509375*^9, 3.3995558614375*^9}}],

Cell[TextData[{
 "The following ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " subroutine will form the functions that are needed to graph a Joukowski \
airfoil. "
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "F", ",", "F1", ",", "F2", ",", "F3", ",", "F4", ",", "dx", ",", "dy", 
     ",", "r0", ",", "w", ",", "z", ",", "Z"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"JoukowskiFun", "[", 
    RowBox[{"dx_", ",", "dy_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"r0", " ", "=", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "-", "dx"}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"0", "-", "dy"}], ")"}], "2"]}]]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["Z", "1"], " ", "=", "  ", 
       FractionBox[
        RowBox[{"z", " ", "+", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";", 
      "  ", 
      RowBox[{
       SubscriptBox["Z", "2"], " ", "=", "  ", 
       FractionBox[
        RowBox[{"z", " ", "-", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
       SubscriptBox["Z", "3"], "=", " ", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "z"}], " ", "-", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["z", "2"], " ", "-", " ", "4"}]]}], "2"]}], ";", 
      "  ", 
      RowBox[{
       SubscriptBox["Z", "4"], " ", "=", " ", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "z"}], " ", "+", 
         SqrtBox[
          RowBox[{" ", 
           RowBox[{
            SuperscriptBox["z", "2"], " ", "-", " ", "4"}]}]]}], "2"]}], ";", 
      " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"w", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{
        RowBox[{"r0", " ", "z"}], " ", "+", " ", "dx", " ", "+", " ", 
        RowBox[{"\[ImaginaryI]", " ", "dy"}]}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"F", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{"z", " ", "+", " ", 
        FractionBox["1", "z"]}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"F1", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{"F", "[", 
        RowBox[{"w", "[", 
         SubscriptBox["Z", "1"], "]"}], "]"}]}], ";", "  ", 
      RowBox[{
       RowBox[{"F2", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{"F", "[", 
        RowBox[{"w", "[", 
         SubscriptBox["Z", "2"], "]"}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"F3", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{"F", "[", 
        RowBox[{"w", "[", 
         SubscriptBox["Z", "3"], "]"}], "]"}]}], ";", "  ", 
      RowBox[{
       RowBox[{"F4", "[", "z_", "]"}], " ", "=", "  ", 
       RowBox[{"F", "[", 
        RowBox[{"w", "[", 
         SubscriptBox["Z", "4"], "]"}], "]"}]}], ";"}]}], " ", "]"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For a fixed value ",
 StyleBox["dx",
  FontFamily->"Courier New"],
 ", increasing the parameter ",
 StyleBox["dy",
  FontFamily->"Courier New"],
 " will bend the airfoil. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"JoukowskiPlot", ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gr1", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F1", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.20001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", 
       RowBox[{"gr2", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F2", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.20001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
       RowBox[{"gr3", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F3", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.20001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", " ", 
       RowBox[{"gr4", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F4", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.20001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"g0", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", "  ", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "2"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "3.2"}], ",", "3.2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.75"}], ",", "2.05"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["2.8", "6.2"]}]}], "]"}]}], ";", "\[IndentingNewLine]",
        
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<A Joukowski airfoil formed with the mapping\>\"", ",", 
         "\"\<\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<f[z] = \>\"", ",", 
         RowBox[{"F1", "[", "z", "]"}]}], "]"}], ";"}]}], "   ", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "6"}], ",", 
      RowBox[{
       RowBox[{"k", "++"}], ";", "\[IndentingNewLine]", 
       RowBox[{"JoukowskiFun", "[", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], ",", 
         FractionBox["k", "10"]}], "]"}], ";", "\[IndentingNewLine]", 
       "JoukowskiPlot", ";"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399555992984375*^9, 3.399555997015625*^9}, {
   3.3995560455625*^9, 3.399556088390625*^9}, 3.399556227296875*^9, 
   3.399556380046875*^9, 3.4001922204375*^9, {3.400404017671875*^9, 
   3.400404042515625*^9}, {3.40040410915625*^9, 3.400404109484375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  For a fixed value ",
 StyleBox["dy",
  FontFamily->"Courier New"],
 ", increasing the parameter ",
 StyleBox["dx",
  FontFamily->"Courier New"],
 " will fatten out the airfoil. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztXUuvHEcVLk/3zJ25D/s6MbFJiGMSEl4RUcRDQkREClEgRuH9EGITKyDZ
iyiRiWADG0BigbIiwAp2LBALNlnAgk0WCLFCYs1vGaZOddej6/u6T3X3vb5X
suXpvlN9urrqO886XVXzyq23bv/w9Vtv3Xnt1o0v3r315u07r/3oxktv3N0V
VReMufAbY8xvbxj793b3Z3PY7v5v37EHWzLi70vyd2VcbVJkfn7/+v3r5//6
f+3pCVt+jRP9y54ORJ8qd62hWfl7tv6eZVO2jeoZonOaujUbezziDXnPnla2
vFY+eTlTC/vo9uy3hW1uzZv+D3taAgz3zlBPUp44vhzZ489cJ/5uT7UtWJXU
eN2SVco+rTptSOmMp5Uygf7HrnHvdhFuKdfgyQt7PLRFU/CX51x0vTNpF/ua
7hpUJ9W3nXnDNf2vvjO0fasY1bmkZ4gjfXR7QpFKf6wRffzoyo49i6Lfdl//
4iVvAe4mGHmWlNqr00BL6NYRZO3FPWUHmwp2Ra86jP7kpKJPO0XmeAvr5AG7
z4eURp9WucdUH/UI9bz2mvE918s/+oIFqILqehWJQx/StVe8mvVpigAdMvYg
O1F7BLHbYahmbLxkC266vv/Oi80+q1RUh3aBYo+AOA0/vZeaya4mATu7K9hM
kMmgeS84TN+2p03cjJh8DaqtPM4bcBXFCVrbJXftl3g2Tc32WupbHcwaW26v
rYA1Rrig+lA/ai/Wn3TtkQjl2BYgUULVJo+Xo3EUSPGlDdWw8oYeHwCDs3Kt
zqEoCkL2mHWilnnNQgUt3JTusi14wnXyrj0dxJZlSAtQtdJF0VlUS+X5gKBF
xNTlTTFNci8NwLTBceW5qbXvwSNoo4QpHJb2XbUFhw7rn45RLUZnjIvRNHLp
+G16xn3CjHvlleS5R7YI9XzVPjN1Q+JAOHsyJ34MDMpo8AukoFFI39hJUrBw
PY+0O0OqinHpIJ8ZTqpWV5U2YjA0jyvQKJ09r4D/Rj2i9e0xPzQ3c3nIo2bz
0qOlDX4WXqLQYK4RAmK1K686HXy1ulqzCorGNUmIrBqpJV57SAhoyHjMHOMJ
MVwubWJpLNV6e17EPg64cxIpmTaVEjkAZOKRoszg3XdF2vRKLDumKQ/DTm3K
gkYpyQhnSE4G6ZpWopAcDUYKpUiiwCus21r71WQrDI4lF0wgpWwRozWXnGjp
BE+fKx8QkWBKJg7wxZ5pmUdjlGuWDNUSs3YkQzV03nXSkLCK3UxqHIk3yfi2
++tRZrxpMJCM/GIO0tguigVLzHRr6+IIoqVFKYtRBiAuOwwtnZ2/Cy+aPcFe
K3JykQbXNWNZ0HjtGK8Gdk/v+1O22H+qkRixt0XmUJDUBoVFQlBo3UdWu/Sd
KAwUiS9ZppoZRoALL0qLWGzGmPja6wgNBVeMLT2hYEE8RR3ZumuTStXzhFjf
hIzEjCMjtmk6FUcnZDgR+FvFN239Z8GkBeEtdFdYUwvCxR4BTULhRv9pzodm
YdZMBDljM6d0HBmvuQM+xCbt85BIhLdVOP7zviISACc1Ne68aMsV+9c+aBbi
Re2bkL+cxMKpffm87ra8bSIJv4oYcs0WDQVxy6m2o1XZDsr9Cb3K2/5FgDXU
0Sj+U/aLGFU01iNePs/9GYMVJowsRg+oHPtNd8yqfaWkxbj7XHtNhPeEwrWN
F3j8TmrbWF6iO3Ezg2v+RCZumVGmyS7sQHVGpT+1ps3cjGVVP90kzqHO1l73
DsHVynMOgbzw+tjVW3uW2z7jedgBPs99NnpI32z2p8K0cAeXeE6YJqBcZJKH
gAq2MrayzkYGVfy817PWmMZ1tBZwGSuYMtwoto8g3CBh0WnwonEmR0xGkK3e
97Due50IUH8hKMHSq0eENHQ2uTIo4oApJo7mdo5jJEpQlsEPCsKKQjkBbuNh
jXtn4lHbTU88aKKbeyvmPWjHEuc/xnAUvLSTRGiPv7YVw0GF1vQjxMP7FaT0
VE47PrxqazEv+76ZBnT5aNPalVcCOuMotx4Xmb+qfbNGRsll7qHh2rLbvkTl
RzMuqAX22WDwEbPLRM+4GTEpaiedQyplqxLPgEAKmYiqwclkOOkzl6NY0yZO
jZcJqFDaNmyA9T30fUuU2zQjAYxKhz8vg7JgGs3wUKLJHGxxYrkgD3AxsGt2
lrxuT612thAZY6DIUsGTiV3I5xx4IQ8M6Hh44x9o8IT8L4Gyg7bZ6qAnmW8y
BsRV1IyWVsoeKGlGrAkPAclFtgUBewjKuGSnVsYYKNyXPKZaWQtJH20WBDen
Z/4ZcNCmd0AtYoRsME9kKumqJnxBvjkrk2bcBCg/6FFGzjXDzJhUcocA9vGv
xtvObNL7yKegH0bLfVnfuOybAPirrhYSZNFg5DLz6ecJ0DCDOsrEDkP2AXuU
0Y32afQVwKbcD54KZEvP42NwB9K6bwGgHrfHOoZ2ri4eTRW/GKPHWPSI7O/F
Bp9uDGW/fwdgENLAKsNWgItw4XoQoNl1ZI7uP22PElhrTbU2zXFCgfc6chLt
v01TFtNtAN0+oLskxzqh2/39tj3KO44DcBNqxFpBN5P2a4VBbIOQhZrD1S+D
shft0UlP7eWm+UyZbX+KngM187I9LkqAeMHfgabjSGb5hIY2RfnfZ2zRd0H7
nwes7zzqqXCVB/bIKPYjjKzM5+SYvYI7mMDmuVANidgpShbRMUv7WXsUO3ME
aj7Jbi/SMGp6Z7vp/+23QX8/7fuLhq/oBdJps35GA+O2PsBuF4HzrAcHhZ5n
QS9mj0mGQ1QUyz/jxfaAteCGLdIGsHG3PxYHqfGNSEFR/PkN0OCnPWcP2/ui
q9vmfSLqvhZiMdAPnGBcGSaj0Rf0CiA+ao9ChqALkwCQhznHwi7cGVyyF5d9
HYD3YS/2dHZfm9eRwuZWajgWDOkziGDIWqE7EFpPerRQF8MCCfSe5xyLH6JL
/KpxcRZ6xtcAjI87oEwWBGYPN8atjUDO67QBTeZVjoesk7HFqH0VoHbdHpO3
oHHl/RMMpTnP2oJCUy7VSryOHF/feyRU21dAtx7xwkBzGzWzcjgdEOSqpdVG
oqeoZ4iuWT7TtD8iRuZWepi8UW2GjRTpq16AOvCs3XO3PdOP5Lai1wFnC1qR
gA0LElYey+5sW2fYtq8AOK94waVr7ugkAf/Sv2sBEae1b+DPAsTIKonDpFm/
bP5MkO3dF5QyOeYCaQrnz9CctDaEmYsPdNHcFPTXXkLR61Aktehd8pGvBTm/
zqon7JWMPhmA3vB9MLhJPjv/4RIn0WWvPUdpu2yGYpBjhNC+R6hoTXD/VKei
kdsRMzQnmRNEvD5g2kcD5ij3mU9Kst+76yIak/wSYMSeUyUUS5gmkiQbvXni
pnaTpWQHeGC6L5RP4VVFabV0lE2nWofViEj3QwhSdXjUfOTOFwGjaq8xdJFa
HZSe+U66CnMV26NzyBQpW8eqlD2Urlxo/SlmY+fhz0PemDBTu8NQuVs7T5KO
VTJoTGfrnDGjq7PKRuR1kTcITmTtSVrTFxum3ec5J+OmZ78RuktUviUNvlf7
Ek7LCmnpg+G5Duz3ASnWjusDTHRJHdlNpxXhLGUqlJ/K0I21A4losiEjcywJ
MR2FYeKtPpGLsH9/jMXMuiDkByla/ZqS8bd1zTR4ShxQZtcqf69c/LhnH1rm
mMX67cM1M8t9XEAnuAurtJO0w1YoZ9CeSRWHSvWsMjHNTF7wKjX3a7tv1z37
NPuVmtaMUuBDtEBjif6p/MkuBWfcCVG6JQMgcCSkeWKv09JtOyvRMxA7LbnO
LAJdhE4nIOdq3IQWdDiat0+fEag8DAq5L+LBvRMBsriZrqghniiscI6Jt43d
RawLqlm0P8WMdMjet/vuxUakZ7EbCZWC6aBsWMW+YihYHC1LRoxXmiChi9y0
IVyw2eh1OF9j6+9N0iEdp4ozXVNYTzY6wlsdULeuWl1mjKHvI2i8J65NmwKT
zjxiyfgUYvWK0UvM21L3laywypiBwlwKKI3ZBjSyWBxo2glNqgsmvidg2OLk
Q/CS2txQmOSA/NU99hbSuE2sKEPC2b/XZXfoyoJ5kw59aFDwkCFhXU8YQZqW
8auryFn027OSeRzU05Ym3uMgQrHTbRRm6zNHwdOM9umETuso0N7wLacNuBfE
CCQKCOshtaPvEApPjvnvnaigEEW9NbaXHsrSKhiFTMzizZDaSwUb6WV0UlPy
IxexJ0HBgTqb4MVHmwxaew2c25PQBECUKHRSciJ7DfRvkZ+P4GO4KyZX1AE9
GnsIlU/pcD1ECHTOXLLjw5BqtHsvjYbzhi1ycbqRH4+6DPzUqDFH02+angv7
T1C4VywamGLax9C1/8JC6qKUA9rFhMaPM1jwnIMfcW35lT0dx3qoct11qy5R
+9vEQOarSQyVbVHnPnTq0Imz3YRtSFW6T0fzWetN4UySnpWdxv+oy+/tqX8D
WToRJIyqKdKbmA9jMBeMDjyguALm/Ow1/TC6rbQ/g4J0S/B7zj3yD6ANwmMe
aWRpMCRAqG8Vq3dwX80Gtodjc9NnpbIK4u5TDzw5UyH4SKbCvbJ3P8BGZ+80
AQLxDI3tJ56B9k5Bp62Popr84Fef2Y8wV5pze02qd/PWzJ89CtqQLYlnhhq3
jvGdF8vMyB8x0znHwFo64pblRD8V2TP7oy/46jyy6IdeD2MDhtEz/i6yWTrd
0yaEht93XX3XK5g29VgU7lLJQPFhuaoFIELMo914PAx8XnVQ/C3juj6SnMtK
TIGiNfJU8iky0ukfOBTCr+pqqzhsxWK77cjlzNo/7CRRE+1Z7N8d9/U9z3ea
/UBRwpOM9UFvgjSSHdjELr/pmvFP3wykS9PxG0fXn6gIHQyJzp+47vzbF5zl
ptuPyHbz68v/cYIVrPMc8kteUYpd/6V7yv/sSRalH0QtbInPyA+Z379+//rk
6z4rn7oqRtm5jsrie/bA9bC/1i8iyjWgrFUtynZmG+qInxxrfh2VvtPcfuH/
R6XPmg==\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"JoukowskiPlot", ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gr1", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F1", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.60001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr2", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F2", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.60001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr3", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F3", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.60001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr4", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F4", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.60001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"g0", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", "  ", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "4"}], ",", "2", ",", "2"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "4.0"}], ",", "3.2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.55"}], ",", "2.1"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["2.55", "7.2"]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<A Joukowski airfoil formed with the mapping\>\"", ",", 
         "\"\<\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<f[z] = \>\"", ",", 
         RowBox[{"F1", "[", "z", "]"}]}], "]"}], ";"}]}], "   ", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{
       RowBox[{"k", "++"}], ";", "\[IndentingNewLine]", 
       RowBox[{"JoukowskiFun", "[", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["k", "10"]}], ",", 
         FractionBox["1", "5"]}], "]"}], ";", "\[IndentingNewLine]", 
       "JoukowskiPlot", ";"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.39955627496875*^9, {3.399556309359375*^9, 3.399556333796875*^9}, 
   3.399556374578125*^9, 3.400192226078125*^9, {3.400404053265625*^9, 
   3.400404073375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Increasing both parameters ",
 StyleBox["dx",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["dy",
  FontFamily->"Courier New"],
 " will bend and fatten out the airfoil. "
}], "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Text",
 Evaluatable->False,
 ImageSize->{403, 149},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{"JoukowskiPlot", ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"gr1", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F1", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.60001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr2", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F2", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.60001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr3", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F3", ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "3.60001", ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       RowBox[{"gr4", " ", "=", " ", 
        RowBox[{"CartesianMap", "[", 
         RowBox[{"F4", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.60001"}], ",", 
            RowBox[{"-", "0.00001"}], ",", "0.2"}], "}"}], ",", 
          RowBox[{"{", " ", 
           RowBox[{"0.00001", ",", "0.60001", ",", "0.1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}]}], "]"}]}], ";", "  ", 
       "\[IndentingNewLine]", 
       RowBox[{"g0", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"gr1", ",", "gr2", ",", "gr3", ",", "gr4", ",", "  ", 
          RowBox[{"Ticks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "4"}], ",", "2", ",", "2"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "2"}], ",", "2", ",", "1"}], "]"}]}], "}"}]}], 
          ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "4.0"}], ",", "3.2"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1.05"}], ",", "2.0"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", 
           FractionBox["3.05", "7.2"]}]}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "g0", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<A Joukowski airfoil formed with the mapping\>\"", ",", 
         "\"\<\\n\>\"", ",", "\"\<\\n\>\"", ",", "\"\<f[z] = \>\"", ",", 
         RowBox[{"F1", "[", "z", "]"}]}], "]"}], ";"}]}], "   ", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"k", "=", "0"}], ",", 
      RowBox[{"k", "\[LessEqual]", "5"}], ",", 
      RowBox[{
       RowBox[{"k", "++"}], ";", "\[IndentingNewLine]", 
       RowBox[{"JoukowskiFun", "[", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["k", "15"]}], ",", 
         FractionBox["k", "15"]}], "]"}], ";", "\[IndentingNewLine]", 
       "JoukowskiPlot", ";"}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399556368828125*^9, 3.39955640184375*^9}, 
   3.400192232296875*^9, {3.400404083140625*^9, 3.40040410059375*^9}},
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Consider the modified Joukowski airfoil when  ",
 Cell[BoxData[
  RowBox[{"W", " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", "2"], 
     RowBox[{"(", "z", ")"}]}], " ", "=", " ", 
    SuperscriptBox["z", "1.925"]}]}]]],
 "  is used to map the ",
 StyleBox["Z",
  FontFamily->"Courier"],
 " plane onto the ",
 StyleBox["W",
  FontFamily->"Courier"],
 " plane.  Refer to Figure 11.69 and discuss why the angle of the trailing \
edge of the modified Joukowski airfoil ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 " forms an angle of ",
 Cell[BoxData["0.15"]],
 " radians.  "
}], "Text"],

Cell[TextData[{
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{648, 588},
  ImageMargins->0],
 "  \n\n\t\t\t",
 StyleBox[ButtonBox["Figure 11.69",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1169.gif"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The images of the circles ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " under the modified Joukowski airfoil. "
}], "Text",
 CellChangeTimes->{{3.399555871140625*^9, 3.39955587128125*^9}, {
  3.399555912484375*^9, 3.399555913921875*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe image of the circle ",
 Cell[BoxData[
  SubscriptBox["C", "0"]]],
 " is the line ",
 Cell[BoxData[
  SubscriptBox["L", "0"]]],
 ", then two rays ",
 Cell[BoxData[
  SubscriptBox["R", 
   RowBox[{"0", ",", "1"}]]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["R", 
   RowBox[{"0", ",", "2"}]]]],
 ", and then two arcs ",
 Cell[BoxData[
  SubscriptBox["A", 
   RowBox[{"0", ",", "1"}]]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["A", 
   RowBox[{"0", ",", "2"}]]]],
 " in the respective ",
 StyleBox["Z",
  FontFamily->"Courier"],
 ",  ",
 StyleBox["W",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["w",
  FontFamily->"Courier"],
 " planes.  The image of the circle ",
 Cell[BoxData[
  SubscriptBox["C", "1"]]],
 " is the circle ",
 Cell[BoxData[
  SubscriptBox["K", "1"]]],
 ", then the \"cardioid like\" curve ",
 Cell[BoxData[
  SubscriptBox["H", "1"]]],
 ", and then the modified Joukowski airfoil ",
 Cell[BoxData[
  SubscriptBox["A", "1"]]],
 ".  The details are left as an exercise for the reader in the book. \n\n",
 StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell["\<\
The \"legacy version\" being used to implement the commands \"CartesianMap \
and PolarMap.\"  The following Initialization Cell will load these \
subroutines. \
\>", "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Initialization Cell",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text",
 CellChangeTimes->{{3.399722161203125*^9, 3.399722165296875*^9}, {
  3.39972222759375*^9, 3.3997223229375*^9}, {3.399722389046875*^9, 
  3.399722641234375*^9}, {3.399722683734375*^9, 3.3997227230625*^9}, {
  3.3997227559375*^9, 3.399722850765625*^9}, {3.399742279828125*^9, 
  3.39974228209375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Graphics`ComplexMap`\>\"", "]"}], ";"}]], "Input",\

 InitializationCell->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.39955592203125*^9, 3.399555922515625*^9}}]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{974, 606},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 388105, 7846}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 115, 2, 29, "Text"],
Cell[1023, 36, 1123, 33, 143, "Text"],
Cell[2149, 71, 29742, 500, 300, "Text"],
Cell[31894, 573, 2447, 86, 233, "Text"],
Cell[34344, 661, 3668, 139, 354, "Text"],
Cell[38015, 802, 12092, 440, 156, "Text"],
Cell[CellGroupData[{
Cell[50132, 1246, 99, 2, 29, "Text"],
Cell[50234, 1250, 2244, 59, 186, "Input"],
Cell[52481, 1311, 2048, 52, 172, "Input"],
Cell[54532, 1365, 2171, 59, 186, "Input"],
Cell[56706, 1426, 3689, 93, 172, "Input"]
}, Closed]],
Cell[60410, 1522, 18520, 320, 714, "Text"],
Cell[78933, 1844, 4771, 183, 147, "Text"],
Cell[83707, 2029, 29491, 504, 627, "Text"],
Cell[113201, 2535, 4797, 186, 141, "Text"],
Cell[118001, 2723, 812, 24, 71, "Text"],
Cell[118816, 2749, 17919, 304, 264, "Text"],
Cell[136738, 3055, 13498, 231, 205, "Text"],
Cell[150239, 3288, 2185, 78, 247, "Text"],
Cell[152427, 3368, 4580, 146, 282, "Text"],
Cell[157010, 3516, 2079, 69, 113, "Text"],
Cell[159092, 3587, 1819, 60, 288, "Text"],
Cell[160914, 3649, 1385, 47, 67, "Text"],
Cell[162302, 3698, 68315, 1140, 782, "Text"],
Cell[230620, 4840, 2209, 82, 96, "Text"],
Cell[232832, 4924, 30413, 509, 301, "Text"],
Cell[263248, 5435, 1410, 44, 107, "Text"],
Cell[264661, 5481, 28618, 477, 266, "Text"],
Cell[293282, 5960, 27436, 458, 255, "Text"],
Cell[320721, 6420, 183, 6, 29, "Text"],
Cell[320907, 6428, 3144, 94, 273, "Input",
 InitializationCell->True],
Cell[324054, 6524, 283, 11, 29, "Text"],
Cell[324340, 6537, 4307, 73, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[328672, 6614, 107, 2, 29, "Text"],
Cell[328782, 6618, 4312, 105, 375, "Input"]
}, Closed]],
Cell[333109, 6726, 289, 11, 26, "Text"],
Cell[333401, 6739, 5239, 89, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[338665, 6832, 107, 2, 29, "Text"],
Cell[338775, 6836, 4232, 105, 375, "Input"]
}, Closed]],
Cell[343022, 6944, 285, 11, 26, "Text"],
Cell[343310, 6957, 5963, 101, 163, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[349298, 7062, 107, 2, 29, "Text"],
Cell[349408, 7066, 4215, 104, 375, "Input"]
}, Closed]],
Cell[353638, 7173, 702, 25, 44, "Text"],
Cell[354343, 7200, 29054, 487, 641, "Text"],
Cell[CellGroupData[{
Cell[383422, 7691, 99, 2, 29, "Text"],
Cell[383524, 7695, 1301, 51, 83, "Text"]
}, Closed]],
Cell[384840, 7749, 435, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[385300, 7761, 407, 7, 29, "Text"],
Cell[385710, 7770, 132, 4, 31, "Input",
 InitializationCell->True]
}, Closed]],
Cell[385857, 7777, 281, 7, 26, "Text"],
Cell[386141, 7786, 269, 6, 29, "Text"],
Cell[386413, 7794, 299, 7, 29, "Text"],
Cell[386715, 7803, 281, 7, 29, "Text"],
Cell[386999, 7812, 249, 5, 29, "Text"],
Cell[387251, 7819, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
