(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    282494,       6977]
NotebookOptionsPosition[    277968,       6845]
NotebookOutlinePosition[    278655,       6874]
CellTagsIndexPosition[    278581,       6869]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["12.3  Vibrations in Mechanical Systems",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tConsider a spring that resists compression as well as extension, that is \
suspended vertically from a fixed support, and a body of mass  m  that is \
attached at the lower end of the spring.  We make the assumption that the \
mass  m  is much larger than the mass of the spring so that we can neglect \
the mass of the spring.  If there is no motion then the system is in ",
 StyleBox["static equilibrium",
  FontColor->RGBColor[0, 0, 1]],
 ", as illustrated in Figure 12.17(a).  If the mass is pulled down further \
and released, then it will undergo an oscillatory motion."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{474, 350},
  ImageMargins->0],
 "  \n\n",
 StyleBox[ButtonBox["\t\t\t\tFigure 12.17.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mechanicalsystem/\
MechanicalSystemMod/Images/Figure.12.17.jpg"], None}],
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The spring-mass system."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399623639671875*^9, 3.3996236721875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\t We will determine the ",
 StyleBox[ButtonBox["Simple Harmonic Motion",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/SimpleHarmonicMotion.html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " of this mechanical system by considering the forces acting on the mass \
during the motion.  For details see Section 12.3 in the textbook.  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "\tIf there is no friction to slow the motion of the mass, then we say that \
the system is",
 " ",
 StyleBox["undamped",
  FontColor->RGBColor[0, 0, 1]],
 ".",
 "  We determine the motion of this mechanical system by considering the \
forces acting on the mass during the motion.  Doing so leads to a \
differential equation relating the displacement as a function of time.  The \
most obvious force is that of  gravitational attraction acting on the mass ",
 StyleBox["m",
  FontFamily->"Courier New"],
 " and given by \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "1"], " ", "=", " ", 
   RowBox[{"m", " ", "g"}]}]]],
 ",\n\nwhere ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " is the acceleration of gravity. "
}], "Text"],

Cell[TextData[{
 "\tThe next force to be considered is the spring force acting on the mass \
and directed upward if the spring is stretched and downward if it is \
compressed.  It obeys Hooke's law,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "2"], " ", "=", " ", 
   RowBox[{"k", " ", "s"}]}]]],
 ",\n\nwhere ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " is the amount the spring is stretched when ",
 Cell[BoxData[
  RowBox[{"s", ">", "0"}]]],
 " and is the amount it is compressed when ",
 Cell[BoxData[
  RowBox[{"s", "<", "0"}]]],
 " ."
}], "Text"],

Cell[TextData[{
 "\tWhen the system is in static equilibrium and the spring is stretched by \
the amount ",
 Cell[BoxData[
  SubscriptBox["s", "0"]]],
 ", the resultant of the spring force and the gravitational force is zero, \
which is expressed by the equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", "g"}], "-", 
    RowBox[{"k", " ", 
     SubscriptBox["s", "0"]}]}], " ", "=", " ", "0"}]]],
 "."
}], "Text"],

Cell[TextData[{
 "We let ",
 Cell[BoxData[
  RowBox[{"s", "=", 
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}]}]]],
 " denote the displacement from static equilibrium with the positive ",
 StyleBox["s",
  FontFamily->"Courier New"],
 " direction pointed downward, as indicated in Figure 12.17(b), and write the \
spring force as\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "2"], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", 
     RowBox[{"k", "[", 
      RowBox[{
       SubscriptBox["s", "0"], "+", 
       RowBox[{"U", 
        RowBox[{"(", "t", ")"}]}]}], "]"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "k"}], " ", 
      SubscriptBox["s", "0"]}], " ", "-", " ", 
     RowBox[{"k", " ", "U", 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "The resultant force ",
 Cell[BoxData[
  SubscriptBox["F", "R"]]],
 " is\n\n",
 StyleBox["(12-16)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "R"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["F", "1"], "+", 
     SubscriptBox["F", "2"]}], " ", "=", "  ", 
    RowBox[{
     RowBox[{
      RowBox[{"m", " ", "g"}], " ", "-", " ", 
      RowBox[{"k", " ", 
       SubscriptBox["s", "0"]}], " ", "-", " ", 
      RowBox[{"k", " ", "U", 
       RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"-", " ", "k"}], " ", "U", 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{3.39962348696875*^9}],

Cell[TextData[{
 "We obtain the differential equation for motion by using Newton's second \
law, which states that the resultant of the forces acting on the mass at any \
instant satisfies\n\n",
 StyleBox["(12-17)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "R"], " ", "=", " ", 
   RowBox[{"m", " ", "a"}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{3.399623489015625*^9}],

Cell[TextData[{
 "The distance from equilibrium at time ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " is measured by ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " , so the acceleration a is given by  ",
 Cell[BoxData[
  RowBox[{"a", " ", "=", " ", 
   RowBox[{
    RowBox[{"U", "''"}], 
    RowBox[{"(", "t", ")"}]}]}]]],
 ".  Applying Equations ",
 StyleBox["(12-16)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(12-17)",
  FontColor->RGBColor[0, 0, 1]],
 " yields\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "R"], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", "k"}], " ", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], " ", "=", "  ", 
    RowBox[{"m", " ", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.399623469671875*^9, 3.39962347209375*^9}}],

Cell[TextData[{
 "Hence the undamped mechanical system is governed by the linear differential \
equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"k", " ", "U", 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", "0"}]]],
 ",  \n\nand the general solution to this D. E. is known to be  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"A", " ", "cos", 
      RowBox[{"(", 
       RowBox[{"\[Omega]", " ", "t"}], ")"}]}], "+", 
     RowBox[{"B", " ", "sin", 
      RowBox[{"(", 
       RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}]}], ",", "  ", 
   RowBox[{
    RowBox[{"where", "  ", "\[Omega]"}], "=", 
    SqrtBox[
     FractionBox["k", "m"]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox["12.3.1  Damped Systems",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\t If we consider frictional forces that slow the motion of the mass, then \
we say that the system is ",
 StyleBox["damped",
  FontColor->RGBColor[0, 0, 1]],
 ".  To help visualize this situation, we connect a dashpot to the mass, as \
indicated in Figure 12.18.  For small velocities we assume that the \
frictional force ",
 Cell[BoxData[
  SubscriptBox["F", "3"]]],
 " is proportional to the velocity; that is,\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "3"], " ", "=", " ", 
   RowBox[{
    RowBox[{"-", " ", "c"}], " ", 
    RowBox[{"U", "'"}], 
    RowBox[{"(", "t", ")"}]}]}]]],
 "."
}], "Text"],

Cell[TextData[{
 "\t\t\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\
eJzNfXe8XcV17tEt0lWXQHQb4ziOe3CJSxzbP2M7ECex49hxmpM4uCW249g/
x91IQh01hCQkOkhIQggJUEGAECAEqIFu7/303nvbe79vzZqZvc8Ree/fJ+Nz
99lnl5k1q3xrzZo1X7n1F//5/Z/c+osffvfWG275+a0/+88ffvd/brj5pz/H
qdYZLpfrIP5fvdqFYwtH4v8fsyzLtbBkGPFSZTJTvpjInwqlnvcnjvkSBz2J
x6ZiuyfDj4yF7xsJ3Tsc3j4U3DLgd7VsHvS7lmzo96/p8W3op1NbxOf2odA9
Q6H7RiK7xum2x6eiT3rieBAe90ok1ZXITmZL8VKtYpiteGuLZRlfpbe73k+f
15j4pP/jn1E3DX+xeiGefd6fwsPW9/lWdPuW9/iWdXv58/YuLz5XdHlX9/rQ
mp0jwV3jkUfGovsm8c6kq+Wp6YRrAd7+lDuGQ5w6MBVHN/CsHcOBuwYDaDme
qB/Ugj+uDnpijweP2zMePuZLdcXziXLdNE1uZQt9thuGUSwWcZJaa5qua0RP
TPyCMwYOTIs74mqj66/I183uePYpb3rrQOj2bjdeenuXf2kXvX3jgO/BsdAR
T+KVcLo7nh9Nl0PFWrZqgD71Or0XD3LNoqdcy+/jfzg2TKtuWLiuXDdCxQrI
2p0oYNzQWzxx80BQkqfHg4MVnf6tg2GQoC+ZrVALLe6JeqQh2/tF0UvXTPx5
7bXXfvrTnx44cKC7u3tsbKwFr7yafm016UqDDmn0XIvodquOz0S52pvMHvWn
tvQRSdG7bYPBRydjRzyxl4PJ/lQuWlbjLp7CbxZPWUwUlK1qpYZ04AvIFioU
exKFF0PpQ97krokQ+ItHCXx3zBvvT5YytbolGmNaNbTwS9z+WaVS6ZprrvnZ
z36G7xgq9CWTyYhxcrUazGGGyaM5h++/EM2s6fMu7fKg2bsnon2pQqYKStXF
NbOaaM/D7GpRQ2yq/2Tf1NX8Bsd3MZJt3AC+Q9Bwgfxqqs4Qgc1cvQZRxGAK
hvGu7/O8EcuKd7bWlZy4Pup4A/HifDmCyWRy1qxZ9913H/8Elr2Ofpknns8E
M2p1E+IBXgQXvhTOQCz53TQSrtmW3WVxi2ocNaBFcnyroz/cgLamHneIbhv2
wwzde1cLvYv6P5seTEJjQNheiKTW9PnR5/3T8YpZdX1cvEM/EQfzuI8khx/6
0Id+8pOfyL43U/tK+lgE3hanavzaZ/zJpd3+e4eD6aqgolk3Zbdk/6hfM5kf
jTbJl5crvpzVPFJ6nA3x+8xooQbtAuE+GcqL32ofFpJWq9UqlQpaXCgU8CmG
HH3oQNNOnjx5ww039PT04FQ0GgWz4uKr9WgJuuB1I5nC0k7/XcMRKGrNhviw
e21qnhMj2Co6Rv8JgZbjJO+d+RacqSRQ8Ngi/Q5L9bMu+07sj4+KUX94NLRp
wFcTP4h+zkLTV65c+Zd/+ZednZ04liPDIyZaOvOee+753ve+h7NPP/303Llz
Q6GQ6OsCIcGSR4bTefR16zAejW4ZptRQcrRIebSrdrZKlsLhwqY+zeFe8+9i
jFUPwXF0oqZ58Wl3cnW3F9qpBmp9RLTz17/+9ZVXXulU9NwLwfPtL7/88sMP
P7x161b0VtkA11xWo/geKVXBwTCGZVPLqiW1HbWZTtT4UOoAGi1WCS7qm2sh
qFculnK5XDqdhjSPjo729fUNDAyAUaampqDPcB6faCAshbRMDTIrlVOLfCQb
JptjiVulRFrGCV9qZY+/VKuzPkHf3/a2t4FhXc0abbY9klIm0YZEInEtnemQ
XCj4LFIqQ2ttGw7BTAlufwdYH7145ZVXYFVAuWXLlv3whz/8+te//rGPfex9
73sfFPYC/Fu4ePasDqiujpmzOzpmzpkzZ9GiRTh9+eWXv/e97/30pz/913/9
19/97nd///vfb9myZc+ePS+99NLg4CCe7JprKU2jiHAqlIEFhH10LRGtO3/+
/PLlyzds2PDcc88dP3583759Bw8ejEQiojfXgsY7dux46KGH+vv7n3zyyUce
eQR0PXPmzNGjR3EG442vwWDwtttue+yxx/BCGEX0YPfu3bh76dKlCxcuhCBf
vHjx2WefhclkLstms4cOHTp27NjZs2fxUpAKp1944YVVq1a5Zrz++usuZicm
pOvtTEMHvwAJrOrxb+jzQOYF983K5/Nr1qx517veBRLNmEGAjj7b8beFvrTh
r4u/tIizAHriKnGSPuy72tvbr732WsjixMQEjyu9WygXaoGmHlpH+s91o9vt
bm1t/cxnPhOLxUCt8fHxW2+99cMf/jB4FNegT9dff/309PSJEyeuu+46iDlu
Wr9+PfqNgy9/+cs7d+4sl8ttbW133HEHzsTj8csuu4xt9G9/+1uM8eTkJLgZ
dP3kJz8JIuH8F77whU984hNQEaA9BO0b3/gGCL9kyZLvf//7rhlohct1g4Nm
zHnlurW217+2z6to1vq1r31NUmA2fcx1zcD/XJIO4nwr00zTU3xv05TDQZu4
7A//8A/BL1oOZvLAnQokl/Z4S3VLWgpXGwYalEKfcYGQoGvBtj/4wQ9wCL6C
dsQBaPH+978fShDHkGwI2/PPP9/S0gLCwUCw8cZPOA9qQiCZTDiuVqss7b/8
5S//7u/+DpRC0yAKUgdgBK6++mpYEVD0/vvvd82wJdaBE97GSl8xWrFmAkWv
7Q+UaiZLUitkQxJA8NF8JzXEH+Y4wVetLbPmLWxtFxRsa+K6DvEdT5MaZKZz
xESDzkWyt3W6k+Uqvl2mNAu0Gxj05ptvFohiNvoHzhkaGsI3iCm6Bw4E/Q4f
Psx9W7hr1y68CAQBxcCRM2fORO/xIHyFLvvNb36Dq1ivgfKSVqA1ROm///u/
cSe4W57Fk8FjeOPixYsxCJKCTklt1ooCW7VBEYPtQERQk2kIEYcGc7FgCgYT
nNUxQ5KHJLK1xXXFDX/069eHPvKVfxQS2m7Tjond0kRR8YxWsAqUkqUw1kwF
4q3OWGFZtx/qV2i9VhASlPuLv/gL9kauPX36NG6HFkTz8QBYlK6urne/+92g
JH5/9NFHP/jBD6LdqVQKX0EKEJJlGaAa+oIJiU/oaxCSKfatb33rPe95D3Qn
eA4CIukI3YzeQ/6hGwUdifFc7xScpw0VLPydQ4HVvYF4tcY4oXXv3r24Q/d0
gS2XTqmdIXXekj96/6rB6Mf+/p9nkGjbcgvugQMzu5HP8e9iNAvywBdxNdNH
tPr9PKqwFXjGihUrcPz5z38e1EBn0Uf0CWegggE7ceXmzZuhncBus2fPxiOg
Elmr79+/H5d99atfhRoA9Xw+36ZNm/QDYcY2btyIA2gzHEPdAfeBVA888ADz
WnsTfwlpbYNagDld3ukLlUoC57f7/X4o05tuugmDAX5gTpnbLKktklxL3vXe
5T2Bj3/jW5KDbI5qU3wHY4sGwcYBvkmLqiCfNZAq/+6iB74mAYpFDv1nCRAA
It5yyy1CMhYya+GZEFUcHzly5N577123bt13vvMdGDBcAsRw1113YaD/6Z/+
ydUCM+m6Gv2HdV67du073vEOgAJYAlActIONAVPCzMyfPx+SCi7E/SD6r371
K1iX//zP/4QFA5tCkeJ9uHEGqYRLJPRap201CcrWTVAzCKQOn0P09J1NXh4G
B1yAZkJr/PjHP/72t7/9zW9+E7r7lj+/GTbwTz/1ic985tM3f/OfVwwHv/rT
33zmM5/71Kc+9bnPfQ40ACPAUv3bv/0b4M0vfvELABUgA4ww4TSBUdvhWA6n
S7d1eifTeYit63IHJ+IBLKkdIBjkaXh4mNsTDoeBPwALRd/mgOlwBtqNxRQG
A/qOj9U1bYzAQV4ySEqzgo0CgQDML9sEKAAwIKCMawaNA8tnh/b10Ly7h0Nw
EoOFsvL4WjUdlV2haw1bMyq8LrX9bP07DV08fYe7+NLgKLkn8MJ1uzTtyfOy
IwRWA9oU/4w2+62qFbhjLFMCYhnJFG3JhvhhxGSrwIYQUwCySzxFoUHbQU4o
Oza7pKrIFhHKmAESsVwKtLHIJPePewPHzHhkPAixmkiDL2vcJ41B2b4R3OcW
KxrIPi12erUAXkDKpVq1btb8xerSruk34gX8VKGTdahJ/EqeI1NDez2SXpKK
yodQfs4c9tbqoq38ruFcESpkLFPBRYLvOt544w0oDyi3U6dOAReD1wHMVq9e
3ezLi+hF66uvvgpBA5gT/nWDTlc+KD72jEcxFhgRbm+HNPZmXT7OMHXbLdfH
DKMGbzJbN8OF2kS60pMsvhLLHA+ln/Km9k0nHpqIbRsLbx6N3DHgX9EXWtEf
XtbrW9YVWN7jWdkfxlecXDcY2TQShnq8bzy2ayqx35s+5km/FMqdjeV6k3lv
oZap1SmoZjgCECLYwc6KSd6YHFL8fzxVvr3PPZwuCB6g2JdrFvAFvA6oKABd
qH14D9DqrAdboS17e3vpUMQcmB6fU94sdXXPeBz0mMqV+a0yhsQSZpnefPH1
SOZEIHnQk3hwLAK/cUO/f2W3R8Q68Ukxw/V9gR1DFL08MB075I4dDyZeDKVP
BdIvhxKHvZEV3YHHp6Lno7lXIqmXg8mTwdTJUPYZf/qQO7F3IvLIaOiuQRhZ
n4wIdruXd3rW9Hpw8oGR6L7J+GFv7JVwGh1OV0wRlTHFeNZ5rILlKly5zljO
VLbIgSSFl93epDtdV9jycoNkPUNy4p7JGNQJ9B9HpuDfg8UH0vkjvuR2EbZc
3uPj+CFccrTw0Ynw8774xUR+NFsEPi1U5Shq8WePnFzOcg13vRnPWdLDFbz3
Nm3B8K+KkTbquXrNW6h0J3OvRbJP+9L3jYTW9FBsGXevIr4KLO/zPjwRuRAp
xsraH6uFi5WVnX48Hl8va5KNtrekwnzLaopdXa5l5gZmF3VDXWiOo+40BufN
eAZ0ylfqGM8dI+GlXcQIYIdN/TTILwVS0HHpar1my/kiOwan5FwFPYRGEJQO
l+qg65vJPAbWjrRadpzHMByKSz23Dj8KRr8zWXjaE4cpEGzp5jj2romQO0MG
KFyqQiZBmma6kOxc1cQxl9u8sUgTjFsNgV/RM92dKPfGc2v63bd3BfC67SPh
FzxZcAhcLNL0dgxF3MS+2GwV3aI+R4omPLI34wVphdpMOUSyYaYd52oXLm9d
ak4VRZyHr5lKHU94ZCy6qsfLXPmEO96fLqLrF8PgARG1dvZ1btP3d9r9XGxK
SZdSf9gN9egH8F3Z4987FelOFELFWtXUdBAtsWND3GZT2VcHn5mSylICguXy
ik7/G4mcwzY38mibDByK/2SckyVoVrZad2fr0EJ39PoxChDS06G0xCb26M1u
euof2L2cLwKDmoesY74EGBcd7UvkTbu5OgqmUYKK5PHMgsH2uEOjBhZB8BjG
ADymYpUzZX8s/U/HpGfrZ+Nfumbsn4hiCE+FUvT0L9otnquMQY3NwivBFFr8
1HRC2VeDaat5x7DY1tJZYQ/nOHwLR1uLFTxHtRUn2tVYztZjaYtpU1TOEAIJ
Zkd3D7mT+M3R4jmm/TJqInAHTMTjkwlT0F6iA4rP1vg1rZYjUsqBa60b25Q0
tXOz46UKaYh4TjST77JHmrG905fSXCFeVbNkpLaWLNXX9gbB5K4v2S1fwOwt
GcSglpzwE4M8MZ3IlE0tmg4Kw+dxBKFJijka0BDntAwAh5W93jdiWUVDxdcC
slia3cVH3aoJvCh+nyPu56fRHxD9XKRwR693w1AwWzW49YLD55n28JLmfTaA
pvtX9Xmediens2VWPlJaVetcivZzLYnZCoYFbfJGLC84vFXDAOXxKZbgERLm
lTVHuW5BiLaPEBJf2RXoSmQFBQ0HZyzSkytqoCVLng5kVvW4b+v2wPQ/MBo+
Hcl48uVaXetAjeFNheFNixFxsWZyc7nnLi1bDhaw2Vdxlmux45QgvVkvVg34
jwen42vE3O2KrinAgOl8SfGO5ZTKNn1WcfTlepAw1mD5l/2p9YNkqEGOOwa8
94+G903HjvuT5yJZ2EY49+W6wRMHcq5KjneHbhl/ooOCc/IsDZIW1zTwlzgG
NXOGGcwXOmMF4KsnvVHgg7sGQtDf6M6qHv/uyfCZaDZUKKvHM6c3aJuZmsZE
Qpo1Zen7iJqCovOwAu5cBWgMQwVUt6JLGh/Y1xVd7jv7Ag+PJ494EkB4F2L5
gVTRnStFSlXobrBItUbT5oawNNy1C1ECQ3hmlWBWHQeQtHzdTJar0UJlPEuG
FtAT3LxvKrJjOLSuL7BUmDtXC/rlascRUMdjU7GLsXS23jB/YSnqOjn+JtFb
MRf0DkDuqUzh9UgWIPS+kQggLZiJ5tsBH8TkNM/jA97gK9q6utdz52Bo6yDB
eOA+GH8A/q1DNFe/dSCwdSi4aTC4ps/P97pacXcrHcxe3jW9rsezbShyYCr+
nC/Zk8iBIGLmyHJ9RbTnalvaLEvxhERjgmP/kAKFlhWr1CezJUAdkORFf/xZ
bwKURusfn4ztm4wC7eweD94zGkBndoz60eKN/Z77R2M7R4JgwIfGAc4jAKuP
TUfB5wBLx33p5/2pU4HkhWhmKFuEU5eukkP+DdGmtzW16XLFIUpupbqhdgrt
MNfp87EuAeu/ES1AvBi4sRZp1xwuo5UtSnQlWlC26K9EO659q3a0SU0tTrc5
xxwqSbylw1K+JkmHYQHLXIzm2dM1Gj1HQ2o3m0u+Jt4s566VnIkLhE2d7VQe
eA14Fy7RuXjWtNQsn9ZBer7T7hFHY52oWyI1RVUn3lB6TaMspX217VCznhjj
85G0Sz/LtFutnkXf/1K0gXMNAoHAb3/722Aw6LpK0lxYgtmq8fIZj45FzpOc
GpaclHNShVRWq5xf/iv72W3f/va34Yd/8YtfTCaTbznz7aC3oP8sUxGU+7Rv
Ogp1KWMlpuYWlhiB4+34BJOxVCpt3LixrX1Wq4g0fv7zn0PX+JHaq74k8na1
frfoMS55zh89G86TbmRa6plJjbUM3VQZ+1GuusZCSyzpl89JpVJf+tKXOMTZ
RjFPCnh+5vM3JRIJibsuac0l+msyX+1lr3GRpXCaSMKoykYbZtN8vxpzYaik
jheSI7F5sVi8+eabOcavAtM87eRy/fkXb46moEytYr0OLQ3MAdXtasFfVyuO
4G/hP9eV9NFRph8N/FQSF+Zqpq9Etm0Rfm3F/a75MOQixaFuOiRSagBHQols
oxjXDo3b1qxZoyPqrWI+osU1r4Xj6zNab/jon/zPi51rBgLLhMZeKfJQlouM
oquBJVytwpK76bAF3qCrlQILPR6YLNciOjlbXOu/vdcPGzKaFYkLDBGlnyXz
FMy6sJeqjSJ2cNlPfvITGcXmsPYM9SEO3vPBGx95c+RYIP2kJwkEdthNnzi+
5rAn5eo45BVnPHF8w3l4ldDjOFhEvy582p064ovCsUM/YHzuHQ4Hy1XRMkPG
9TSOQpu+ZLdpAUTtYx/7mJ58mOGIst94443+YACYg7v4DluKVa5Ug1SLuNG8
l4NptAEWD1Byz0SIJUmmpKhx/HN73GY65dHj8eCdNFY8W/nhj37E7/Uxomye
7RM6fpbTQWGmJvILGZyHU4lyfXW3f/c4JZjgE2MJpcQchSbV9VN1n75gt6w5
52me1+v96Ic/NkNxffvsebuPHddhIPEIs1lTXKVkXf9zer+aagsxrmC8cQLd
RqZs3T0cBhH70mnBWoYDS1m2bC5oehfbmVQq88UvfB7t+/SnP73u6IlNUzl3
WYq89qn1k4R2fp9q1RKn34fD7mQOwGnvVFxxjxGpVDYPElo5EciK99Z0y5in
hI+FJoko0TxcMjo6/M/f+lev1x+vVtf1R+8fjRpGTb2AvTvT+gBdPddQSUCi
AeTq5SvWXYN+eP+9yaLFVt8Q3qk7V13TB9A1BWQsQtd2vKc5C+jTol0O3+Qt
86pEBGCB6KZk0/3TSYzIBeEnSJutwwCW8T6r0Ro5Pc5XQ3C4/Q9OhGWc2Abn
pjWULEOVbBkOJGnG25Hro3nPOSc707LeIgI3x3KgBWVhZg6nC1BpQE8AiuJC
qYksxaAuQWUVnRPBxntGKXlzOlfVvTNtPWH0pQpQjztGIsFi0bJTUAyFND8n
2tvM8YyTDENhGeYElaNHT3/Jm4UT8JQ7otnKzmQSdF3AyZem4tCueB7NfDVc
sFS+HksdvFbuO64BJKecwl6ORxvNNvIzoq1vmbvYnF21UFKC2Yr8KQs8v6E/
CENFvoxVV7BRUP+9lsWxSpOVj2geTBzGGPC+RAlgDXMVTEnOwUQXjvoTkLH7
R0IVlRKm+GDepk2bzp8/jy9AJOvXry8UaOrk5MmTP/vZz0ZGRizbk2ye9Wlz
ZAyxjzgLDsSynqlXwnlOv+OoHWcoz7UvFn/OhbIQ8HORnLKzJsudzonkjEKc
mQUQe9CdBN1PBONou0Ts7C+55v793//9Zz/7WXyJxWKXX375gQMHcLx9+/br
r7/+1VdfHRoaeus5q0Wmeq9+If897CYdOZbNO8Iq9CFG4O0aYeHTXSjCk1rb
H0hVavaVUvotO+qhoySm9ayfUoP2TcYLlarhYHYXc7lrzuHDh9vb2/v7+/H9
b/7mb776VUqfHh0dveKKK4aHh51SQBQTWr0NjhceevdwCPzwQR5xUwVDLeuR
MSh5/6lAmqOsC1S7auC4+4cjkObd4yFOwVEKqM5E+TPZJhC2o6Pjv/7rv/D9
vvvuw/H4+DiO3/e+94HOzRZTWMVZaArEfnlP4HQ4pTjWEDbA1lTVYKEMrtw4
EMiVYSVF5ETnGc5j1R0tkykAmY8HUqaiojSkpm4h/nzta1/7yEc+Mj09jbZd
dtllW7ZswUm0GRS8kgfdtEYyZaCWTQO+LAmMtAzvbWzTqUB2eadHBMApKsca
3dJ56YIj5wpUbfpLNRB9bZe/P5VrFDzDJVtGJL/99tsXLVr03HPPnTlz5kMf
+tAvf/nLN998884778SQptNpxkezOKHydCi7tNt/JlLgFzC9ZvLbvfky3HUA
NfwgNMg8EQbRIVFD67mKYT04HgWMBO3V6NQl77Odcs3HmG7evPkrX/kKGnX/
/ff/yZ/8yfPPPw/q/e3f/u2///u/1+t1OZqXKymciRHdNhgA8QpVCYCEXM+E
ew/uCxaqSqkbkmY6K1NYoDkqfENXePLllbSAwE+Orzjj0Jzkf3IDarWasAI0
eeuwV5er8WSO7U4UwEUvB7PiiroYT3hNxlimgjfsHg1LZjGl/W2VwmmYMluA
f8YLXwsTqFzR5wtBNsyqU5vblkbofBtPasZfJLlXjRcsM+gCe4nHiza1pcu1
bSPgZU9vuqDxGT+GbUS7PZamTTnp07MhGEyXVvcFofUD+ZKDz2Y6W8Kf/6+M
+kWSTpI652MZSOuOYXTdZGsz68VQmtD1eFQDV1PRsMMZd1OaQ1uKmSymk9kC
DOqmwXC4UON22jmH8olGpW7dNxJa1us7Hcpr6jUlvV+jKDtP2jgdVxgLwsRP
5yu6NRh/oX/mar+TKQkPBiO7YyiMMTA1PUSuhFTdPALXP/nkkxDQ22677dy5
czgxNTXldrtxAFOycuXK3/3udzCRUMd4+WOPPbZt27ZcLocrd+zYkclkcC/U
97Fjx9iG+v1+fMXJI0eOwP/nvHUREZ8r52DFHARItGHAk6pUNTEh1xyJ4blJ
g3GKdgGmMmUo7WfcMUVES02P1cWYLhDEqWv7U6jV9rmJF/dMhmt1U1PPMi9Z
dSG+Xx8IBD7+8Y//4Ac/qFYJ4/3DP/wDVIIlEirXrl0Lbtu6dSu+7t+/H/b2
5z//OQ6gev/0T/90cHAQGgX93r1797e+9S1cA6UC2kCOH3rooX379i2wucCO
uWtf+1QoBxYExFIulr6AeneNbqtDNtrhyG8e9G0bilQEeSSX1y2mmeTyRWq+
XLIId/d5Pzje88RUrKrtvDItAhG/g+kC9c0pmJyXNWvWLE5Y4K/PPPMMjtG7
W265xRLBiyuvvPL3v/897u3r68OZH/3oR9ddd125XIbGhVYDI8AigZVcDlrM
c4RIOPhNS3i2D9CysJzM7bfnbpkq7PMtssVPTFvBgJ2O5FZ2BW1gZck5bNYp
QjoWSJzs0Dag1yE3TSkd8aQUWqafhS6Hh2UuW7bs0KFD+EZ5Zy7X8uXL16xZ
Y4mcbHx99tlnOaYEu4YzkArAr1/96le4IJ/Pg5UWLlwIMdDZjfh18eLFgDmm
Xnkj5y/E0LA11LHErgSh7pOBHHfDtC6NClwpx1l2iWmSqJkb+v0QFnYtJE8o
U48Tgjvamde0kmNPhywIfJxVfTT387w/JZbxGJfMIjv8vLnglKeeeiqVSrW1
tX35y1+GFli3bh1+efHFF5lT+LrZ+AHMs3fv3nnz5i1duhTn/vEf/7G1tfXs
2bPSAk5MTMyZM+emm26C/mnW28L28wz5XGdoTTo4pvXAWAR8PZzMW44sM+X9
iSjenJq6A4/dO5FY2et91hurq5PNUW8Rp5hvCytRWFIyVCgD5sF1htSyM8X2
4e3gDyCeJ554YsaMGYA7eA+4B2D81KlToMXx48ctkcP5ne98B4oTLLJkyRJo
U5y88cYbcT2U7p49e/AVD2HlA++ku7vbKTXtLMw8sKYl/XaaA4Ytg1bdORIu
ikSP5pkWwSuzbTNrGQBwYLA7+wIUW7Q490KAAzZSuEbEeucr58sQPCr1yHS2
CPu1utsfyFeYztI/WrFiBQwA/BMAedGGq2AqIPqcBwYa8KCCMPfcc8+GDRtu
vfXWZJLg3dGjR+++++7f/OY3+MQFQImwOqAl7n3ttdecNFikVypZDm/CoiVG
1n1DEeCicxGBiySjGFc7tYY4uX86Ca17Jpp1mGUV51KeuopU1aXvKHDTLIjH
zpEgAOtRb1yZbJmBQCsVwALQhRhwxgRQjbAJ0JSQDtaagsqtnJypV+IQ+oOq
TCQS2u+EzoRJIqwsZjAYnXSE6e0wa+67Bv1HvOnD7uQhdww6rOUpd8w1k1av
TidEZDP+5HQU5xfTqta5hzyRp7y01HNVb+Cufn/JqGllwBhQRqjtGY9FDu4h
y9yquCdRrtKy1C7v/aPRgpA8KQFMgY0bN1577bXvfve70XzOMbz33nsh0nPn
zsXQ32D3ZE7NqE/lyg+Nh8Wsnn99nw/4bvNAEI7Plv5gy139QVfbpgEvjAFO
4lsHzs7GoWvhnUMBMO1dgwH0ZnWv74gnka06OMHpcddlTxbXeFzFWBpSUVqj
mcL2oeDt3VOQ46JwjISUq8wezhfBCHz9618H68KmOVd3Qo7hPzAuoKvfIfom
vIMO8OEBchDc8JTgy1kiVRM0b4FTT3nZlExctSjBsANnOvDNNbtC2ZoGew/T
+dLGAfiRvntGA5laXc2aMjqQuppnHkwOAqlxM7rj2dt7aTWkCHfKnA7GRTyP
pybkIG3AdbDZAwMDjO7bTp8+DRQIsAON1ax/RUSYPbOF/KpkvQ7cjDZuHQqm
qzXLqun5O8tSMSa54NfOAhGwjhJHavcMETo7OJ1wRHnlJ3vTC7SZZiG+GM3S
ZEGn/5VgRsbULIbcdh6Po8UfsnltkV7NietTVRMyAY7bNR6D/ybO1y3T0W5p
IRvyjSxerZeu1g97E7CND09E4JpqLGGy/8uxcVOqHrMvWVnbRwtxz8SSdUst
iOQYj7A20jZb1iVZUipXyfa3rrP7s9CBjaXGwnCv6fVA84mcJW6SJJx4Nrkf
rvmOWFlD4tWLoSSvMn89lra0l2DbjgWWjV0Bpg96YhiJR8aimZqdA+sE5fzU
OW/VJ0fM5O12j9o0nDNNzjOcfSGWv13kMrwQTNnhJXEg3GBeKWzp3Fjqlsin
NusyagvHFo7Smh7fIOWO0lWSr0zKa9gzGUGfN/R7w8WKZg7xf5XcR+hTvqdh
JFovOdMsLY6xmql8yLoitoxP9iRyK3tIUiGyloLBl/ABW5EG5CXmLCRHKiFg
+vek8iJn190VL/IZlj7y9eHWQlahVdyZso15uIU6RCEXn9bmNY1Uc2Y3j9yH
1bOTldqBqSTe++hENFqoOZG7ZgfGKTrrUvY3U6nfPRwdyRS1DdVZfEaoaGwb
DEJQH5kkB1ZQ/QpbtRumEj2OadnnI8X6o5Ox2zs9x/3JbNVGv3bk4MPM1EIA
ckb9gdGgSJgmpdnAzMrFlHpfv9uihL0VXe6LsTSP2HV2fNqyUrXag+NxSMj+
iTjl5+uWKbQgmcFkdSMDk5OF0vpB39Iuz+PeoI1hdehPtlzkQBDXV6rmPlJj
lPGcKhv6jpnSrFsGKz3Tzlu1gmXKiHwjkdNobY5qF2e009zx/uk4hO6BkWiq
UhOSeDlTuGGeTDwddF7fFwDlMOzFGtsmQ+FLEWlyUHuOrXXwGrN+OpQGr24Z
Dg6l8jV7ZtdiQO/SWaZtYbE0mrKoTV4ld5WllpzCbgLoAIaCrcdTRcsZh5ZM
IUMn3mLp3rEo5O25YLJoKn7kFRCW8rW5tWI19zweeGmZTMudqaC1oMtj0+GK
IdVDi1JFagxFKjGaK3Lf5ayXcjoV1JLuSle0AP8Dw9eTyAgmrmsbNh+kwZvW
9QUC+ZrmQke3LIlPHO1dqPwUzYXGcLqA0aEs1kBa87+0yW2KspIdTJPzN/HT
VaYeZG6uZY3nSuv6qfOvhTNK08rJvNPhFM/vvxHLagm0lMfosCAOTljkMOo1
55jBGgNLYDiP++NVR5PlWnVxFyWOd3vRZjlTp/P6ee06vXruaLq4stsHW/iM
F8ZeKpuJdGlVdxDYqCuelx6p6IYy/fJ1lumMZIv2tjkpInNyVb9KhvG4WJ4A
oEdLZFRGo4owUihfrTEwZca3rKvAVNDIAv/ipcoT06kVZFnDoWLtmDcOLwOy
FS7VXTLHRLZRksZUFQnoR47b/qklLTWw5WEvtWzLgO/NZL4zWUDH34xncIwD
zluGo9CXKHbH8zOJKNeAabvwXzx/MZHnA7oRB1G6FzYFx8Op3Ll4Ac9E0zi/
Y+tQIFmx4bec/eJZ9E9Z0krJnwzKLV3a4waIW9nt4RQRmGiXqNLSLrJG/Bh/
PBvOmasF3ElnZXUYSv3r8dK1ftfl8ns3zZfjgSJF0I+vvPBhaZdvZU8QChpf
X44A0lS1kIvxcbSOslPrpi1n3cncMV/i2UDqeCDnannen3LNeoHW2cTQzkfH
4y8FEi/60897k/zb7Od8yef9Gf4P5uaEP4HTz/nSJ3wZvmIR/RBM8HXPBbK4
6NkAXURffemXI9mqacdu0IYvOdvGIsgJ0DxBK9WoxGikfcBhJICJnGIOnkM0
VTaC4chjMy2Z12HaLM2g3OXkRMuerGalzzMjwg4x7T5jWY3z5Fr6cI2/WF3Z
6Qa02jUeOTAdeSGYeSNaGEkVotVqVWXLqcxa8cK6DkSyHhSxN6XIbI0nBUfi
RPPPbUrNarJOOm+dMIOW1mTJvGOIihsxu4DflvdOw/3D1zV9lBR8xJ2+EM2h
+WVaQFdz9s1s1GfOOQpBq7o086qVTgmYpZGrDiHxM6waJecZplxJYwCJAkuF
y2VvoTKRKQ4mCxcTRZiDI57UA2Ox1f1+UQjKs6qHpG7vVBwKDrKaVfhV8oQc
WJUQLWCxtFeGWFMovcgvNLawbk8nSLI35FgI8a1auj6Jac9aLmaDAHPsK1Rg
CY75MncPh6XgdrnX9vv2TcZfj+YSxZoeI5deTSOjkDxiN4s2/a2l/CiRKxos
lM+GM+jvaspp9kJDrOvxwA8DiZQm12FuydG2/8njIDJIr7ZMm5N4dhCvTpUq
5xO5Q+4kACBUCZQO/Nr+dFmrNI2R1GHd8UyHl9imaMFtyRkmLNFLodydfYGl
XdP3jUROhXLZuo3YbQ/Nfp5ePaJcekOv12LfhnsFvf9qJH2b0KHbh4IJkY+m
e24qDSda2Ga7ZA2+i2Rv8UaaOYKl9Oaq94+EMHCPTSXKpg76Gbbci5Hp0HJg
SfMtFQzxH6825itKdZpvAISHXatxwqGgveNZjtxKcedi+9kq3GE58j9wcHA6
AcxBEybS+645x7jNAUMsxxysxPNO/caKlVEz5XB0e3nWT4BX2UYRcXZ4MY7c
ZjszuE2/0VSrjNQL6ZRzTU9j9Su7ghLPvvB3CRQUB9ANvck8LOL2wYBe89Ww
TkB7CZJUVk2u5rVHiaGCWrEnfqC3qeyDS7PdpWzPtewsUUNwl2Fq1lWZmYIG
cvKNedbUK8f4Or2aAr8c9SahxF4Kp1Ttu5qjL5dJQir8rp9gn+SArCNPxRLI
mWsiQQnVyX/AR0upVqecDIp21kUIrqpEWmhKlcckjaHUSPY6MD4rrppnz6zK
xsjkvPFcgXLOBvxwNN96bYPo1Yd1i+34OwfnTNNhukQESug76J834oUXgqkD
k1FAwF3jsZ0j4a0D/u0iGWFVDyXRru2l0ChcqC3DgbuH/A+ORXaPxQ55Uofd
8ZfCGRiygVTRmy/mamZVTpPZ/oOUNY0EHMTULdFf34wX8K5VPf6RTFnlvjf1
UszwLpSuCpGqLmw6kT5dMqYyZWEWUg+Pxlb3emjlLOUAE+pbQgWL+oN3DYSg
x+4ZDe0cpTzG3eOR3eOhh9TqifuHowDYcA7uHAxRsZ5+Wtak13Pc0R+8fzhy
ZDoJS3khnu1L5KfzBYBpkSVtKt9BDV1d2TVZqWI6X9o7FYVGgY8DNGyvfuD0
XpdTD5hi3a0pqxC6luBZpZr5xHRoRZdcnLKqN3TfSAgcfjGancoV4Q0WqgZY
sGLUKxZxJvtP0D08p0YRX0ExU9RndLXgQtds6MpcjVbRTuXyPcnKy8E0rB0X
teR1Nh2UWN1JxQfv6PXvnoi+FsHbyrhHtGsBj06iVgNFtg9BoRNWf9abEtmL
tjep0aacm6Z22WoLDJqr14CKON3roCfRnyyUag7LYbG2as70EzrynTYzmfqv
nTRRNih/eCxTOh/LPOGOopHwzlZInO/f0uc74olNpCswSM/6M4L5aBkQjFOw
XFdq3HDm1ZMxb1gTZtm2gzVZh/Cr/XhwxaE4TF6vYo86Z9uIPjXmu2idqfSY
/tRd1REY/Cta5mCmcMid2DQY5DGjapG0Ot9PMa2xMMABc6SaAZJhuZpl2j4K
r5N1TNrJPwPpPPoCkX81nIkWKnXD0nhNzg+rQD+v1ONeiZkkew25bj34zZev
wzt8OZg86k7dOxzmVf/AW7vHEnB+1vd5gLogocd96el02V4raZs5mYjplJdF
lvYiFDTpjBXEij7y2yDYLwUy8AuSZfILKPKr0Y/UQbz+pTEX2BC1TcGakUpl
PFc6F8kCBkMGNg/6ePHbsp4AZGPbYPApb6oznoH+Ye2bqdRPBNIbB2jl/upu
/3F/PENzJKC/YdfCcOAT0YerNAyUbRASAqXxlDsmlhQSnUAbyvkZoAXuT3qS
Lwez0L6w2SOZojtXEf47NEFLvGq0hIsVOna911uogf37UgWoLIgvPELwyp7J
yLahyBqoyK5pVbWW1m8u7/RtHfZBBF8JJfHuqmnpgKMWKXyWyvUXQ0koMogR
hOb1SEpfozjZuQL0CtNyirulGEXOQlUAYLPFF/zpp92pvRMx6LUt/UExem44
4uScCw3eii9cctTVJhba8Rc6pN8F79PyjrV9XlBo+2gAimz/BE1Unggkz0TT
Q6lctGRUbfCuJVav2qq5JEoV7BQrm1CwPI6Qab6jzljEsQLXXkPEoiXnDoR2
mqstMFgf/QRWj5TK09kiRqwvVboYzbtaKMi06Fw0fTaSwuGbyTwGCgdAirgI
igkjmarU8nS/gBemXk893+G0auIaDJCcw6VqB1hOzEGRG5qg6vUd8UXl3IYp
VwBIK6RnpBvmHUxVV5SQn5rjFH1XObemjA4Yb5klN4ebUW/EATpYxyuMWRpl
JMKO0s60ZyKUuOssQ/RHTFlTdRfJW04uFHhili1fUsfVlEKWUWGhz2Zdqg0u
zeS65LvtoTmiksqK2yuaOyyFBFU/ZOhWZ+SA2VZ0B572xFWSt+m0OE1rDGXN
Henvz7TsVfUKb3IOrBoaG+ybalWcXfXMQR4ZvZ2l9RIVh8oVV3T6H56IuRrl
pgGDLnCiOikSBnu0sgmaP5qRbPN6zBY952Wfu4SnTEtWDNVibZpW01ojhboX
6EkSxUIWr1Ll47pIEoa4g/aqonFjD4XEd2gzLdJUalqly/F1CF+dq3iIVjBG
lCOq57yEpWlvQACyV6qehOQmleju9F/lHIgMVamR42dVa8bO0QjkYTRb4l9d
tnQrKePsY0upd73UTLT1XXhURfwHcBktlFhv9SSLb8Ty0FCvhlIUpgxmTwYy
r4TTF5JFaK6uWGYwXYII+ou0khueeUUslK2byjPWlY2VO2KqugLKt+K2cD/n
KXtCVxZrFowX8M0Rt3KgxaUO6bBnz3TStqFigQRLClVzNF2GfT7kju2diuwc
CW7qD6xR5dt55b4dAfbS+sE2YXJ+L6ZReKoYtsbtmruW1g+G7h4KPjga2zcJ
Q5M87k++Fs0AMwXylZqhqt+aKqtS5kmLswtMBwnS5Sqclg39XphgUFJeKmo/
mZYTJXxA3SXzhS0RX5rOVw5ORzf0+5d2Ta8QqQtoI1w2WPnDntSpUAZ2Bt7K
WLboK1RixXq4UEtVzYJY6FkyDLiUGKmIOO/OFofThe54/kKsICxyct9kdMcI
QQUKYypbfA2TaOtQYL8nAbcB+KgiZ8GcnjR1AG4hnrVN1Gpb1+95NZJWoEut
UnX4Bott3aFhkPALV4uKU8BdD4zFXwlnR9L5eLUm0sn0Km4ZgJY5fH/ARFRP
AfdRRfpkpQZv6Xwk/ZwvvW8yua0/AEUL0EOj30nl9QF9LsbSeDaPFTAdWAUD
s6zXs7LbA2rCFJtqws7GD6rTTj3YajbqaUIV/WlaBfXASAx4JFwuGzpKy7NB
zXmXzhVvSis0ZAXYXscV+i5L1FUIFuo9qezLoRggDAAwiIfxIiduPAReXdcH
ROmDk3/ES8C4rm0UIBBXjjc4y4F5T2g9OxsWn69EUuADYNOSWEqgz0tqiz+q
4slbWMpGjc+5hrZdVlWrRB2MoVTxwFR844CcvZlFMFgU7wE/PjAWGUgVMVQu
iQ40BaSuNJ11SOwpY1Pm34A3HxglyAAF8PhkAjKSswM+l6xCdFbJt3RcTSQp
OKC7wc0O5ipo2uuRzIFprscR5EXI7HUeD6TAh+Fi6cVQmuc8l4ni7/5iWT/M
1TBX3ejxXCUDKnYVb1qLfcidXNEzvbQ7sIwmtjw7hkNPTydE6ZFCoFSB1w6d
JIptSBTs6iDVeA1X+OMqHMCYcF+gvqAsuuL55/2J/e4Y/DFZIaOLq1xQja0N
vb69ExE8HReX1ZpL5uD5eMSZaO5uKgpKsYNjnmSuZjiTo/ivq2l0tLGWrC2l
rJ6u1uCMdCWyJ/wJOLR39AfREIH3Z0IjrOkJbOindL6tA7TZRge43TWTS3VA
JcIbWCX8BnH9XCh4aMgtA360Ha4QxqczJuJXuSoku2KYtowtUhwtbQiohFY8
TjEc3x09wf5kwdZ0hu3Nid5crSebLVPNqDUxiSkRcL1mRcuV4XQJWu5kMHXY
SzubPDwag1+5eSjUgV645u0Y9qHfj0/GoI+P+RKnQrQBCMyYP1soqWX2ynoq
yeI6QhLYW9L+mrq5tvdDs38XE8VVfeRbjqRKDhE2GnGnAw+bQtoM52Shwrft
2hPirqqVhwxzDatWtzqqZvOKapM1pJwXV+BRM4OM+ercLpXPJleuCP3BicoA
m958Gb2hlWhVWz4cPdFV5w3LwbVtKl3JUrkAbTLVRKI3tYuEjXpnNtFFV0br
0NZewW5p7Hglkkphka+Ta7j0yKAhR90J8CzwhMYIDSOhMkakR2Wq4LJDD9vZ
kaLKnKOKSMPaY9kB9qK06FkOMbSkR7HEUo91MLKlo+RO5U/7JHSBZaO6PU7q
N2IYs9Hq2ZU61MgL6qj1Xw2/KcvabjiabDbWKrHno/UMkETQbb3JImw6pM1U
1QxucDzdVE/v0D6no9uGA68622LPq8nGyB0tLJXNYtdQZt5w2ZRXd9jEl/MZ
Cx1peXawkY8BWCC25yIFDZiaZ2xs2ki0YIral/ZaNlO7oUKJA/sA7ocK5cls
Ca5DdzzLMYnTweQrwRTA1yvBzKuhNHwAztYYSpYnM2Vvvgg1Rns+CNSlfVBp
u1qUR9Ze03zlWGm0SHfNJp2gWK5eO+qNQ2UfdCerlPor9UpDH/WIiAMR1xQp
iYoiuCtRro5kymfD+YPT8ftHo9ANK3ttiyZCa9OtqnyTABey0tRCB96gLEog
Bajke8ei0MbPBrOvh/MDiXy4VC2atjzKdURyBqChUoSaeeP47lSmDCONxx+Y
jPHUPnfFEV26RmWOSYxoiHHz5KtA3WiFappXpbP4ACfuHg7DR987EXvKmz4y
nTzmjZ8MpV8Kp1wtsByuDwBz4NRhN1UhAbTaNR65dzi8pT8If0aE3NyCBARW
mBboMuwqcMC5aHoqVy5UtXo2ZcKZJVeU8XkgCXjRK7oo9wGYhpSwHFo5Ferg
UNprx3W5A1PRxLM3V0Ojbuuepv2hBgK7J8NHPKkXghm4Je4cbdNVroswmJof
abUU1r+k7peQ9CvFmwn3AJhFSlVPvtyXKpwJpeHhHPWmH5+IwroCMazpo4rJ
K7rx6blvNPBSIAO7CCnI1nmec0G+YgBLwUpvHCBjCaQBcciZVY1fNXh0amvT
oWmJX4dTFXDb2v4ABiJeos13mlEx6yeHUjNm/9+vULb8apAFIC9crHQnM+jd
AyNRLteLUd3QG9gzHX1iisA/sX23+57RCNpi+8ksQXWld5osjqm0Nc91W6fC
ydu7AheiOYEsDJW5Q9LWGKPRtSoNZRA5A7FdtVohAfEzz0/jRVdZKmgEfIam
AktyDiBV9xHTNzCPJaPiBCANSlpkvzpR8zyeBdVqYSJdAV3Wdnuf9sc9haJh
aAwzW+MmSytjnRUuo4NqTrPBp1GzfoJKtBSqTvXtKHQLpoP8AN4BTS8jneIH
dl3b79s/Ed0/Hb9jwMsntw2GexKFmlrC2qLcIe6c5qw/VO9YjDfGCsUDEzAD
U1AC6/t8u8diT07Fn/Enz0fzXN8Nfk6tbmoW5Vziq2WLyRugVe3piolLxzKl
NxI56AkQF/oBMPm+ofDmgeDKHj/X+wOg3jMZOx0p9CRy7mwxW+W5wPlA+OOp
4qvh3N2DtGwH4B/snRdrXPWQkP27voE3LFdzlY9mr+symwuv1vyvnifRkkm7
vNXPh3O7J5K3d04v73Mv7aI6sZy9RxWKB4No0COT0X1TEWDoDgyD6+q9U9Hd
E9H7R0Lbh0JUwrvHo2r/+fXUwnLaRtAPbXTMl7qYyIZLlLCls7CE0DC3yxwI
DNzrkRRPqeCxEG8eOLaHdn7HW1Ynaq6i0eFwihsUDMlH82yomMFyvYs+F9s2
X5fBYPYR1ZvhecJtgx/x6HgSpoJjAWTt/KJyFoe44GjjYzFPwPCpVVRNwnfP
aAhUe3o68mI482aiCD8xUakI70KufJJaTr9dGQvmZRHPE8rCnytDgS7r9UC/
F2vcPlkctLmCsR1Hc1BDriZyRk6baeKo9j3TdGArpg8jD00e06rqCAejtbow
GBjDULE2lSkNpwsXk+kOymGdPZTKj+dKIpxW5X0R9Wov0VquvqdhcdNuAnpu
ZI7DTaR/gE+iipQfAuyobKXsh6r6zvQolUqHDx++7bbbDh48GA6H/5da32+9
ppbHaGhoaPPmzb///e9PnjyZSqUMuTORTTHFOZJoTqvD/7QnaA+DPi+0TLvj
/rolUzp0v0xLRn8dGtVyzC+1Mq/o2Ng8naSq9TjwO5UEC+c0o4u17B19fX3v
fOc7BwYGdLkN/myWtGb9w5j/7Nmzn/jEJ7Zv3/74448fO3bsueeee+WVV0Cf
uTZ9VL6bYHI5C6WcSkO1UmpxU75IjzSd4DpbcgarjdcDsZDq9Xaa0oZaD+sA
Bcq/VnFy6XUbEmUZfQkKNkJZGyrqxav8I5HIH//xH9OKz+a+O2vmj4yMfP/7
36/VatK+LV++3OPx6KuEBboksufY0UZZWUuNb7s9W2k5/VBTIn8VX7P9AKtp
J0vLMYs2X9tfSysO0cmxLK3neogy7MRMLVfMwVFXV9fY2BgkZtWqVffee28g
EOB2vSMWi33gAx946qmnduzYgR/QcVy9f//+3/72t/v27cvlKOH5zJkzv/vd
7zZt2gQa4MyWLVsgd6+//vprr73261//Guej0ehvfvObL3/5y9/85jc///nP
f+QjH/nGN75B1GOOISwvsg4cvoBaSeBc9aNSzxostcPHtGkm+i2fIecNdQ63
nhhhfDxL/mJZz3uTy7oCMO0kUaLSy2Xf+973wOmPPPIIuoIx/vjHP86FqeLx
+HXXXbdz5063233+/Pn/+Z//GR0d7e/v7+joeOyxx1iKQE+Xy/XLX/5Sxv3w
rLlz54K/QKXW1tb/+I//wOmbbroJZMFFoCfoRnRnLfPW+qqZJxdbthax1M4P
uhKFimnYuS2mfJA6Q4oZkJi8QsrTo8qVVLOyRtMBXJe4KnQJ4Q5iPra8trxJ
JpZAUNBzjqV4eDRbBGy4a9BvrwzmWIWrNZ/Pf+tb36I97FjX/tVf/RXIi0OQ
50Mf+pCqjjoHjPYv//IvmUzmiiuuwBBwx3l/qwceeIC1Hljs+uuvBzdBl+GA
d13Dc1avXr1r1y7wJl7GdR6c1NOxlUtobK8fleeU7aKuVqV2FYEdgcT/qGiZ
7lylN10AbjjhT8A4QavcPxq+eyi4bTAAAAEXcXWvb1Wf+OzxwgfdMhLZORgE
uAJYgOv4tCf6QiCO27sThel8JVmh8mrO+RkH49ZMrijomlmz7CQsNhVqtpeG
A3D69t4g3jidqTliSCLiw9V4YdOgti2l1RfASl599dWQfz0MoDsT5/Tp03/w
B38wNTV11VVXvfrqq/w8vVut5G8Q/tprr4WCxVBAOHjPsbVr1y5ZsgTvuXjx
4i233DI9Pe1SO8EqgVZ0b17f2DyXLda/Xs47juolh2q6SfrbOcPsTxaOeNM7
hkMre4HLAo48GAJyM9k/AmAHadb00WcLxsfVyseraGaTFsNcxjOdzn2ruQL2
6m6q5fPEdOLFEG3M7CuUqIS3StDQ9nuhcw7KEqszH56IEFrs9MC9tjM1WBMJ
xCvxTm9v74033qgLvDRKRDtUNKg8OTl55ZVXgqxM+8vwc3t7u94FCbTHCFC4
yTDe/va3A8Pg/OzZs7ksCi745Cc/iYF27PDaZPOJs0XdieukwVExCjYj2Vr5
uCe5bSgC7wHUXNdDEfhnfAkwHVgYHul4tgz4Fy6WgA9TFSqhDQ9I18ytQWrw
pVA1MpVaqkrxp0ipGixUPfkq7hxI5+E+vRHLnw6lAcThmGweJH+QtlQRcgSx
gtNxyJ14JZzF9XiOc011slw9G85CBml2ozt4wpfy0OJihZlUIJvl/Eqv1/uv
//qvoPYHP/jBJ5980hQFwIBrwLVQ7z6fD5bxz/7sz370ox/BBkLtwAzi1wcf
fPDChQszZsyASWTu/+lPfwrlD6jY3d0NsYB2wunPfe5zv/jFL3DAFXtwjcux
H+2sarUKhNnZ2WkJRAEluHfvXq4RssCxtlz2K1ux7hEpC/BiweGD6RK5rayT
1X7HrrdZIgwGjTudq74ZLxzxJGj7F1HwHiMFEm7o8zw1nRA16CvHvHHwPdxB
0PXh0VikVNKukAaMptw35z2weUBG6Mb69evL5bIWXxh6WP+HH34YhmzevHk3
33wzsPepU6dAsnXr1kGlfPe734Wm/8pXvoLe4ZZEIgEYANJAueOBX/va13h7
OfD0z3/+cxjBW2+99Wc/+xlgA+1KONfmUY47WODdH//4xzj+zne+A4N84MCB
4eFh9mYW6xVS2nE5Hcis6PQ/G0iI6IbtmlpyRty4RO/wWnMNJU1LrhlQAqsy
QIQXcwWcm+l86ZlA/K7BAAcbl3f6dLH8vVPxqVyZtbO2IjpwQv4g+7pbt24F
YdesWSN7Cgr6/X6+mCE6zoBwhJls220YQFv4QUfieUzAVoUCqRhoeNysrRzO
g59541dZ+ahV3blx40bAPLwB8Aza3hI1LQVNF1laBahZx+4krdM4MBWfzJKA
1+qWXpej8HybI0ZkqFW1ekWCpoSateC5Ynt2WVs+0yyb9VilDmaFYr8Qze2d
iNBkXJcfjHv3cPTh0QglIHR7HxyjWvP+XNG0bJMtsXRz3JPtH7o8f/58cLX8
/ejRoydOnLAsWdG1FQPApWAusURCM8r1uwCAixcv/uxnPwsZkBVutLFWaMsS
KxpX9XmW0tYQ7u3D/pOBTG8y78vTpOrMJjoIVPs2ad7qFJMIlCpwr18Lpw+L
JWi03ptWVbp5Y7C7h8NHvemuRBY2hlPH0zXjpXBmy4DYtKM78Nh0lEvm2jvK
cD8E782Cr/OpT30KEBRQadmyZVB8tNuowNJ27jW4DJIMLMZVFQT01j/irZ/+
9KchjvAIqJrOOwQdfMXqUU9s02CY46mcpLtxIPDgWASDeMyTPBsVi1nThSmR
ENUeLlVdiyLlGv4G8qUxzqdK5M5Hc6dCmWO+FIzuo2OROwdDq8XKCzbMnHED
BXfvcPhJTxIcEipWDKXF1JDL2TQg2t54YcdIhAI2fR6Zt6ocZllDh6t2w6LC
nIJHwBOwyPBguBr17t27WT5kNZZLIzE//OEPYVFgNqDKSIM1Y3ZdPQ2oYTxX
eimQ2jcZv2sgdHsvzVDwxhorZNV2ud6WZuhlvlUr/rby3IvQMBqkYKDX9vq3
D4Vg+Z4NpN6IZSfTxUS5ziwhhl37wpo7OUkoWzeecEcp2afHx/Wg7ZkZJ2L8
3yNyovJyg5bGJwwDUCMICbaAzRgfH+eaFXrlliOjGJ4GbFa4UPPkStAqQ6l8
r1gj/WY8dyaadc16PZJ1zTsbo+/4D78BJIxlSlAL3nw5XKpnalWeXtPzjM0Z
Rvb+FGpGz4b1ciWpJcpWgM1gMY4HE5aacrbkBO//bd+w6y3bw4D2/ehHP6pr
qrXyjp6WpfYctgMUMjaidu6w1Oy6zg5qiODJVW2mlmDO223TdU3kyLWx7Nq5
DHIDRfal4b3BO4EGGcwUWFHB/XO9u6k/19kjOtMZXYXphRlvHv/rmeqGiknI
kgKW3kNTzwfMtMxL5qmb/XidsyZnxMT1c+sqD5qN96thqmcsimyrVeXOyCjp
7YUWI1keG+fKEm4/RAOIA37iJRjgGtUC5/XtpppINRVfmdY8m6NtXmtVhSUN
O1ta5t+1yw43rKnjMI9zvXQ71CKkEaBM0K3O+KaBGziC6BwbU9fzabNUjTNG
sM6WqSuvdfKiaAOPi24Zv9Oxh4wtW6LhmjJ6naJzR0NHLNmhil8IJKFnoG3E
t9pbR/rtirfNUib237lEozZHtol3hWTMdKI4Pmquh9QUJ7ccO6hJ3cC7l9lX
mPanzOtiNA8YBKgNMD2UVdXkDeuSnfi4IpauImhjQaWF1NpZcQsJu2tOVcxb
lgHoqnVvoTKUKV+IZs5FstCMLwfTLS+G0q4FOMDfk0HaSPRcvPBGIgfIMZou
wrbC+GdqdDv8BTzKEYu0V+JyZy6JUzo5S0fiClXzwHQM5gc2WdKIM0TEPOIS
Jf26F/wWOgknEM7v8UDqoCfx6ESUtq7q97EPubSLLBjXoNCTKo4VLK7383yV
qkQR4N8AKeCzb+gPbhsOPjAa3jMePjgdf8afBmJA/+FPlus1U+ki0aC6xoUy
jMW8Ztbhp8JbWt9DxS/OhjN1Jfx8Gc8sihmkKyxTLV8XNJzMlHlZ/FKRB7iy
m9bEbB+mmcvjvvSZUBrmajRLgAYoJ1Ysu1qKNVPsHPP+IkXaKHMbMBqmB4M7
ks0NZAqwcdBvwEgHpxNw+jb2cYkN2WM2+DiJ177gTw8naXmprmvmED0DBAeT
iB0t/OsGad8px0UGj5rIpFhg6vNiMhumdmUvPO5pIKtdo9FzkdxUpgBv3dQ7
t+r1LKbKLTDIUug8Mfq13riuWXORXJcIcJKuik1d4/kXgpnHphI7B4P02h7p
q67rC+weoxRqf1HuNQhAc8SXXN9HLIOBB4UylZqtRB2C/pY7Rkqvy6K9H3Ir
uqYAu87EkiC+neWmWEXW5TId04Q87nze1nT29aY9Y6/UBecoXWO/XTwuVakN
Zqj+y/7JyMZB3i6Y9qPbORbaPRq9g+qxUC7NHniPGbsYlsYqjdbyC7qfQn9c
rfUTbjgTpQ1O9k3HCP+bdoYyIwYVg1IFm+0JOI0W2kzL0j6zQ9fL9ZK2UKk5
u7pSKvBGLiaKj08mIJwy/tDjaaGlA/PAwveOhS8m8mLFZM00bdbVuVbOvPeG
xdniCgjPbrEmFtyydyraGc8Aw5qOxlxiIxp2H7d4Jp3pZdl6kGofw33oT5ZO
BzJ7JsMUd+r2yZBhF213cSKQdudKsUoVvgM6Rmn33b6dA5HpfEXzi1YM/Od/
X8dIr4UMHHZHpTITMcedI8FDkzGIPyCuJ1/mzFvaIVAFhO0ZwMstlXfB5OP9
Aks1M1mqQ/cNpktnY7nnfPHHp6L3jUTgMavsEFnB5wq4Y9CX8BUClGpjOdOp
0LA34xmuLokb0Mhs3c5L5C7I1Qmixt7lJjnqVXh00KK7xmOcN+DcNhAaEgRF
9x4ZC++ZpFQDrpPqaqH6qFfCe6Nd+yYicBDvHYveNUg7CfLNMA7LewLQyxju
tX3ebYOBh8bD6BTeBL3Rn8rBA6jKOfTLdVEJs0En0MmeVB6vp/Ufg34Mo6U2
LuGLpcbQ+504/pEpAM+lysZ4ttyTKLwaSj/jS4B0cLYepM0Ew614ZOuWAb/r
yjuHAneNhNDH3eORg27a9hGGGU4sr1lMliu0WlEsNDcdomo4jnnuR6EDOSSy
+hS+9CSLtDdQlxdektb0ls5tfK/l2DvTnjFUOQatiiAORCi2msR3fLTSAvhW
7UDLfQflXrimpWpRGPVG8NCEY6S/JXWjafkKpbW9wY19wWSpbuOF91qOOV6V
c/sWu+nJmh36hZzL0LBOWbynaQbelFpK1hh01uBmRn/SQ1X2XgqntEVkCt6o
nmM6I4BEBV71p/lfGlv2EVolze1dYU0ZfVLI2uklyCleZRS4RizVi4PZe3Qi
LGd5HO1x+FANO9lJ+qg8ZpUloHIqNBwwWy2zwYOAn2g6atFqwnCWiqwOxUTv
iZegNvZNRpmMDqlv2i9SZ2Rpys1ruErNLlg6f5z/06spNUs1zNJqrtMO4IHp
yIqeaVELTzZScr+o/bvQFl7FnWIRBxV0SJSr4VLVWyxBt05ni6OZgqsV0Mw1
bzJbmsgU8d9Uruwt1PBzsEzJgulqvaCSWDqaOFPPMDtiJYLytG6gYlhvxNKw
fQ+NhGlrJR2PdGZ4aixhrzs1pXZfBKUP7N6XKALTPzYVu2covKGfrCiXieV4
Datz1tGtIitpRTev1JN5gHwNpSf1e7cNhyj05kvBunTF80BeVDJSZ5lrbakr
Uas+qZwLe7oRrgWVbe7yPjEVk8WclbPnzCpstxy1VjR6WQQPDyNw0pegElWi
piPayKXixA6t3vtGQjARYm6UCmy1gAIiPxd+ThJ/IbPP++K8zyt6BGsA10vs
VUtkoV53esTuhh14IuzOzuEIkMirkfRYrpqqmkpKG2Z5oZlgTLiU3QNjESDT
uo2D3rqizBINWuyUN9OCs/XwRIwKTXQH4Axs6ae1hnB8+9M0KYbX18TELcmK
5idWuKzjFwjJJvaBvxcslAezRZjx5/2pJ9zxHcNUbZvHFI5TC+yr64p7hkIn
Q1nojkylXlNeqUVlMGktJy+hgsV4MZinpXtWw2jZkiPGawGvRNW5AvBtABs2
DfhejqQHkwX4KDzpVFdRJnuaWhmwZuQl9PS7tCngi7TawAGtny3XPMUK8AoF
ewNZkO/2XmIJtB3ABXb2qDvxyFiUIv+dnl3jkYvJdKFqqYiZwi3MYQ7kSBWw
6pauYESXAnRTRlQsI/Es74DRsD5Y4wb+Rui4OT6kstj03IqDBobOY1f7+/AP
4Hk4HfeMh2+/6BO8uWBFl/c2SkD2P+/PVOzaRlSvR7pjyi44Kg/Ml72WHGdM
5Cok332+o970VE7uNmE1yrD47twR2JII2I7wk9pnT1et0xE66BroICDB8Vzp
9UgGCO2ufoWIezyAZ3Bxj/pTmweCFLnuntw8FOC9q5mhRWlRQynyhpGZ3eQp
cqOH0/n7RqKcbTkfTHfCl4H7Ckd+MpsLF0tQ3eAVlZciVm1J1at9r3fL3tBK
KoI1EOpMDVq0DEU+nS2PZApwxsFkL/qTB6bi28TUKFezAwWBDWnhgj8DtZ0Q
s1roRqFWQxvQ0U39AZrRm6BVlSAJ5zS6brF0XKA5CkgLCNFkIOK9k2FRZjrA
e6uKTIQOKDpoLDQBevT+kdBj4wna+9SbaIFac33wsDsORxcU3zce4nwSXAZC
wy2kJXu0YtUt4iSs8Lxq4R5tqA7/JVapS4/ZdIoJE0eqGwyOKOdOVmLrUAAy
6JAmO5ta2PkFDieJJu69+fKb8cJzviTaBl29aVDWEkV7SOW6LoOQsT5n64Sf
1vb60UIK0kxGjnnjMEFAxFOZAhStirJbHQ46msqWdnAWN3QynrJrNJpXK6kZ
Rf6xJe3obJZXPC5bNYLlKqz6YJIwdzdVm+2K5VwLuhOiimqMZhCGs5WJNM0g
wONLyhoipm5JU+49/ptv2bXsiHZgv2M+Kv68ezJsKw1Vs+6DljNWyitKZVxb
xRN07NSRt+ackVbKg3MG5lqmHgPq5mPTtL7lbCyvJ02dCMixgo0zBxUzkDKc
pdvBV3Q0aALxNKGtxXm1fkwRws7gp8eAjhCf3RNxS0eCHK2YbS911ApVo1Zd
ja9hDTfvMNfa5KnMdo4Gj49ah9jBJR7GMhUuhy9fYzi599LVlK06qOPieQvL
EKMwS89BSybU8X+jkRt0Bm4DlfUYmaomi3hM7aUAlfo96o2bqmKqQs96raYl
MwrseqYyg1/k4PF+0q5WtYN0G9WOsGQtPZnH6EDdliKds5Ka3c7m+DeNMSz9
6l7PnYO0V4asACrGcJGeycdFmbrpzpI8cWoOPAJQHLh062AYfjmQCYR8JuVT
zYePfvdQ8IGx2KPj8YPTVGsXYP3NeG48XYCiKYk1SooLxOjO05zhbD8+zkey
UJXrenxA63YuNLfeGftq2OvY9hwworRquzueBYyADhVL2/yuVlnt2M7vWtUb
cLWgC65WdAJ9oG6I3LD21Qqhyni0uHceR2s49R8+/77J+MkAoWoY5JKqpKKo
L7OPWZ/N1+2PlssPjkcp3Nnl7aPFxWqTWsYRDlx2ndM34s+CYV2IZnaNx2Ba
lnb7Yb+AgaEeD3piz/iTJ0NpWGyYKrg1UHCxYjlbJ0teqtX5U/CS6z1cwitQ
gnUsjmVKUMm47WQwdTyQgjmCksELMMDr+3y8vgiAFmzy8GgIw38hlp9MF2OV
akVCLJpwBGJJ1yzo3hdDaVoa0xXYPR6BRWLPknWcy7GidIETOvEntPHdI4Ti
QXiA/4l8sVaXM6OGmhWtayLaq0qVhyj01g2s7BgrVYw6XD+g755UFjjp3uHI
qh4uU01AGkjjsIei9LAHMMC0fYMY8d3jIarqT41Ti9SlLNBjG9fna30hLe7p
CE1P0u5dhqXgvco0J2xlOuIEll4F6szndq6Hlk9lrjYtZzY9aA/Yd9gbQy/I
61nW7RZrM2fhAGjGXeA95mRhDruaU0PMiJGlwPJ2deBzEZqChONJiSWiFdQA
4612beZ2yd1BnTEG1oJLnN47L6iKYiwSOfDX6l4aacAXHKzqDq7sJEG7byjc
kyyKxZTOSLMUD3u2SdBiAZOQvDCzdjGah9MAAuwYCDw+FX3Rn4bS8eaLpRrZ
duIMInkzFuZqiXhCRWyp7slXe9MF+Jkc5Ns9Eb1rILRKpB9C0rYOhA57Uq9F
MxPpCkNSyM5L4YxYu0aYDno+VCibatwlkHf6WjewTOusSkcwDQf+Uu05Xxo6
Rdbd6STBw3MfGCVPkme3gL564wRuIGnoXrhUhVp1tcSKVdfiMEV/y+Pp3IhY
ywkAei6SQwOPEFyL4ClwSVXNCu8yWeedeKYdCPiYL3UumobbaaqZzUXOrDqM
wHCKqleQc9vrPR3K683O1UIXwzFXZu+prGaOOkBlX6EEA/LENLn/Ajf6ZWYL
ca1UtDr/hcoJiYyXNlp/2uXmshnizDy1Hpnyiu4di8IeAdiDrzy5EmC/aUcF
23U72CC7VC4EfYNBBWn4beh7U76YkpEPKW0FgcqXawCOA+k8Ln85mISYQ08d
FVuBwUkH3+2fjLRA+lwLDkxGwUHgl6fdyaPeJJwLKFc4oW/EyGGfzleypSrj
zvkNmqR5RgueC5wEqPoLkbzDSEpa/7HSJTwOOhanZjm0dXSsW1LqcYFlx4s5
614jPoiqKAHjHk6X9NJ0fuOHpSRdunKnQ2oty/mDaJxCjvO0/nAAFrU3jVJ+
Z0IZWtk+LQAdz+nYb6anLFCPVfpHItbmSsrOOhQm7/UtaztrrAT4mCvTjr0T
cVXXz/m2xqprnKFHf+c7WmA61qMY7Pi6xPpttR5CjNbpcApDeMid0DLhjDhr
W9CMZSx+DL2zOSNC2IiFzlIjJodvhMaBL3TXCM1SgdGsphXmH256Q7uiX6Nt
Er+JzJr5ptqai7UBoIMo2uuDG6h5lujAz/940zMada99Xn+XWFv0aIGlrZ6K
RmVrhHegujBQx3yZuqyYIvH05y1L5rZJdrHUtiKWo2SKaTnwgvhaUzO6i/Qb
LUv1RdybLtdOh7KbB0kPQ83ALrGWa15/+AW7HWrXbu051A0bnOtMWEfVa2kl
HSaDP8OF2pOeJKA1zM5qghMZ2gLbUpfJ6wl2fVG/3bGzg1rxJLIw+JH2ajtL
VZtTc0vzLZXXUBOxwzPR7O6xmNgtm2oaAcgDS6rW6iwZ2Xv7/Q01THgfIcvW
Rq5rTMGdAJ8wW+cigGPJR6ci24ZpK88VPdOb+gMnfCkAsVSlKhad1swG42jY
21RoGb2J2UYt0NcgTfsAl/N9gIDefLk7UXg5mN41HlnfQ+EKLle7tMu3dcB/
IpAM5Ct1tdWryskRMzvWpbt5OkZ8gc1tREEjXq1NZIq9yeJrkSzEA4YJJnNN
r4fr4/ldc6i33bRtH5RBZ7KgCrax3+ecYddndW2MBs/Y0QZHTWFKlDA39FIO
BRd1EtY0wJOwwNYwSYDn8A4A7bhYBDOEI1NSJvGYlpqTl94/V1Oy3roCpGjH
ZaaSHdwWKNVgVQ+5Y4PJwmCmMJUrg8LJchUukl3sxNLrOi9ZM6njVoqpLEvn
yDkBqK3XRJSxFYAIfQb2c33v//OzAgteqwAW97Cmhdc5faJrzlqmXE5u08VU
rqP4qv1kdrns2kutkWId4kxvp5HUtUEd2kKPrlgVbmhRllhK7Vcn9AQ7qhz4
UZLCmac6xC/8ws/YPVV7yzmwDetxye+6v9J7nqM1LBtMvoUVvGnLJHvcEtdd
pd8coe21Am/E8vI+Q2oOu9vak5Q7XdT0YnVZfZQvrXEg2zRUTVUVr9fqWq/2
dhoPEIH7LtDwEsh4Z4oqTqJF56iOZP58LIPjC9HcxUS2M1Z4I148m8gCHF6g
kxmAPfzaGU/hawuOXJ+8EMdPhQvx9FnaHKpI18TT+KSqo3E6D8d/adf0QU+s
K146i4fjZKxwHs+PpS9GC28mip2RvHg4JVLjEw/EeSpqGc3gMlx/nn4qoGE4
fzGRvxjNciNxHi3ELV3xvGHYWVemYh5L1bmRO3eJ8f6aXsyRrRvrRPR6h9hG
YOtAYNtQBJ9bhoPQhtDA24dCdw/57xoMbB70A7bgJ5GDRlYXOgv+0NZh352D
VLvujkEqTHnnkB8+19bBMH7aMkAxbPwEZUevGIriJ3ylbIyB0F1weHoDeMWm
Qf/dg6EtQ1TSB23Aq9f0kfLHgaiKR84drseT0Ybf93o3DnrvGaLEHzwHZ7YN
htf0EfrQqRsqZKV9OMPR9y9bDkkA7r+914uxZ4tMmxEIAo6my+v7AvAxS1zn
waCqd7ggUq7tGA0+PBorigVAMGCiuoaJX+FLgHSiCj/lkRhqtSgHHV4PpuQk
Hc150w/+YnXbYABkzwhPniZ6xBY44YKxY5hqKYt9YWQlbkOkjQNqgERwcgyT
q/TSgCdLdVDmkbFwul516mC1049pOEd+blP1YGDQ3WIXDRgd1vr0jJprXrpa
fyGYAtYIUrDCUPsx0hvPwq0eCcFACs1yPbWQIoJpdOe4P0mJUY6kAF+hsnci
sncqLigm98irUY4VBRHhyYji1zXNsiAO/GyQpS/BkcUlPJboLEDC3bSgJM75
ozy4pVr99Whu50j4bDjLLVSpa/Q07rmIpMw2G/AZ/f+wO37/CG3ybddtplza
F/xpQLueRMZSmpTp+il47BjKZwMp/Rz+CxLd2Rd4zhtzGAxDjJ2FcdzGWx0r
XuR70VpAjlOhjGyoNO8mzsOJf1XkUKiEQGKwdLl691DwsCetTS4/J1SsgFYX
aKdUtSLMkNpN9HqOwvA6lYGY8LGpGICIO8er1K6mbeBEd4AuAS1fEZTUXgXF
obO0z8lLoZypRMuU2sOE+ANIlYhBLa2bMYh7JmOrewNwp5l2i3VUHQ46Vdj0
pSzlRPAz4UxDsLuiRY14Zf5n2bCgaR4eDcnKPXw2VKzdMeA/7ksbhm1Z+Q28
1x9H89trdesFWgjoJ/6wdN1m/DKWzT8wQjl9YvMttScampIsV8CXYI5ohTUK
x4mMcKm+ayx4/yhvy6rPk0cOkkGv6R0U3625DOPz0GToeX8irfZb5cEG5t0+
EDzqC0N8NS/jX6xS3zsZvnc4PJJR1ToFsQH9HxV1l1JFlSxt2WmudnREItCP
2hSYyWoxYxiPjEUPTMXLjBVd7xC5p7Sq/cGx0Np+33S+oGYgST1hQI/5qFIf
pE7bUx7+wXQF3HBW8qil2Q5QHpoLA09BbM7y4lGH7ALcgh36UgW+mh8EoaBN
oztxnjnxMilVpjWVK8J6nKfd6mVRaRZuPGHLsI8KhGt+17NHCk64Pmb3/n3C
BJLmSVVqtE3QSJicGDWnwdrwmCcNYeylnVTrTuGCfV03EJzI5G0AJJoeLlbW
D/qgJhRV5PjBKmwd9ML2AU7q3XTkruCvkMDT8h5LU0wcwMLf0euHGuaHyByx
yUJheZ/3qDcN0nFGBFPyfDQPAT0vtviSDGDY7vGf2P2mPQv0ZD4Ghlyr3hA4
mNcw86ozeHrr+gJjlHTJHWTWMgA8YOTPxHPSx1LzAeB7uEv7JuMZQ+UVieuh
g/dOJmlfVtrbnkJd7PGht3f2hbrS2YZqx93JzMquwFla08ZPn8kPm8oU1vdR
DU54Ipy3jAsGE6XlPR54a4aeA1eql3v7Aaax8qn702XYgtPBlCzwJIlTm85V
7x+OPDEVS5TrSiOJPsOa7plI3Dsai1ar0kCIN2VqdQzw/SMhX6Ggx0tqJGi1
e0ZDUN41iZDfZalnPTgWeXA0FsxxkTfWbrRQdtdE6IGxGGVaKmbBQaFKa0J3
jgTH0wWN3EgJFMsHpmN4FDCC5bAn1ALm7fcreednyVpD8G6BhPCqYkUCIBbP
bLX+8GjkjgFvpFJRfr+YX4SE7xyOJCoVMvmC5lfipnPxLEBRj9g3U4iPHGtY
6jU9tMq/ZBgqdkGiBXzwhDsOkJau1qSv4rqG0c8xT3LnWAjGS2XGyKBHXzoL
Nx98rBQZ0QVW4+GJCM7D9GungnrnkOerBHowFbC1LX20XANe3DMe1sEGPbcO
MbpvJJKsSPVVV6t6rnxyKrGu3zeWLVrSo5LkPBPKrez2nAiktSvEn1DOwLOP
jES4BSp793o88Xl/Cog4lK/XVKst8ab97hjA7BRhHMuxlYPVGcst7XFD+/Fu
mgxIcAyCQed680X2v2yJ1rt/KrmT9UVwGsMLwy03L6/X7FiaZR2YjJ6PpZyr
IGjoDntjr4fzcpwcCyn608XHp6JVB0zhvTByhvmMP4tRlDNpaizLpgk01huX
G6zavhlk75A7ccSX1JnHHRzVE5q9DBQnzB6RkePVvemc6LPVwOWuGf8HkK0P
rw==\
\>"], "Graphics",
  ImageSize->{171, 250},
  ImageMargins->0],
 "  \n\n",
 StyleBox[ButtonBox["\t\t\t\tFigure 12.18.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mechanicalsystem/\
MechanicalSystemMod/Images/Figure.12.18.jpg"], None}],
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The spring-mass-dashpot system."
}], "Text",
 CellChangeTimes->{{3.39962372303125*^9, 3.399623747125*^9}}],

Cell[TextData[{
 "\tThe damping constant ",
 StyleBox["c",
  FontFamily->"Courier New"],
 " must be positive, for if  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "'"}], 
    RowBox[{"(", "t", ")"}]}], ">", "0"}]]],
 ",  then the mass is moving downward and hence ",
 Cell[BoxData[
  SubscriptBox["F", "3"]]],
 " must point upward, which requires that ",
 Cell[BoxData[
  SubscriptBox["F", "3"]]],
 " be negative.  The result of the three forces acting on the mass is given \
by\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], "+", 
    SubscriptBox["F", "2"], "+", 
    SubscriptBox["F", "3"]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", "k"}], " ", "U", 
      RowBox[{"(", "t", ")"}]}], " ", "-", " ", 
     RowBox[{"c", " ", 
      RowBox[{"U", "'"}], 
      RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"m", " ", 
      RowBox[{"U", "''"}], 
      RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
     SubscriptBox["F", "R"]}]}]}]]],
 ".    (For details see Section 12.3 in the textbook.)  "
}], "Text"],

Cell[TextData[{
 "Hence the ",
 ButtonBox["Damped Mechanical Motion",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/DampedSimpleHarmonicMotion.html"], 
    None}],
 " is governed by the linear differential equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"c", " ", 
     RowBox[{"U", "'"}], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"k", " ", "U", 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", "0"}]]],
 ".  "
}], "Text"],

Cell[TextData[StyleBox["12.3.2  Forced Vibrations",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tThe vibrations discussed earlier are called ",
 StyleBox["free vibrations",
  FontColor->RGBColor[0, 0, 1]],
 " because all the forces that affect the motion of the system are internal \
to the system.  We extend our analysis to cover the case in which an external \
force ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["F", "4"], "=", 
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}]}]]],
 " acts on the mass, as depicted in Figure 12.19.  Such a force might occur \
from vibrations of the support to which the top of the spring is attached or \
from the effect of a magnetic field on a mass made of iron.  As before, we \
sum the forces ",
 Cell[BoxData[
  SubscriptBox["F", "1"]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["F", "2"]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["F", "3"]]],
 ", and ",
 Cell[BoxData[
  SubscriptBox["F", "4"]]],
 " and set this sum equal to the resultant force ",
 Cell[BoxData[
  SubscriptBox["F", "R"]]],
 ", obtaining  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["F", "1"], "+", 
    SubscriptBox["F", "2"], "+", 
    SubscriptBox["F", "3"], "+", 
    SubscriptBox["F", "4"]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["F", "R"], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "K"}], " ", "U", 
       RowBox[{"(", "t", ")"}]}], "-", 
      RowBox[{"c", " ", 
       RowBox[{"U", "'"}], 
       RowBox[{"(", "t", ")"}]}], "+", 
      RowBox[{"F", 
       RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
     RowBox[{"m", " ", 
      RowBox[{"U", "''"}], 
      RowBox[{"(", "t", ")"}]}]}]}]}]]],
 ".   "
}], "Text"],

Cell[TextData[{
 "Therefore the ",
 StyleBox["forced motion",
  FontColor->RGBColor[0, 0, 1]],
 " of the mechanical system satisfies the nonhomogenous linear differential \
equation\n\n",
 StyleBox["(12.18)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"c", " ", 
     RowBox[{"U", "'"}], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"k", " ", "U", 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", 
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ".  \n\n The function ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " is called the ",
 StyleBox["input",
  FontColor->RGBColor[0, 0, 1]],
 ", or ",
 StyleBox["driving force",
  FontColor->RGBColor[0, 0, 1]],
 ", and the solution ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " is called the ",
 StyleBox["output",
  FontColor->RGBColor[0, 0, 1]],
 ", or ",
 StyleBox["response",
  FontColor->RGBColor[0, 0, 1]],
 ".  Of particular interest are periodic inputs ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " that can be represented by Fourier series."
}], "Text"],

Cell[TextData[{
 "\t\t\t",
 Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
  ImageSize->{380, 350},
  ImageMargins->0],
 "  \n\n",
 StyleBox[ButtonBox["\t\t\tFigure 12.19.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/mechanicalsystem/\
MechanicalSystemMod/Images/Figure.12.19.jpg"], None}],
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 "  The spring-mass-dashpot system with an external force."
}], "Text",
 CellChangeTimes->{{3.399623778390625*^9, 3.399623822203125*^9}}],

Cell[TextData[{
 "\tFor damped mechanical systems that are driven by a periodic input  F(t),  \
the general solution involves a transient part that vanishes as  ",
 Cell[BoxData[
  RowBox[{"t", " ", "\[Rule]", " ", 
   RowBox[{"+", "\[Infinity]"}]}]]],
 ",  and a steady state part that is periodic.  We find the transient part of \
the solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "h"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  is found by solving the homogeneous differential equation\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     SubsuperscriptBox["U", "h", 
      RowBox[{" ", "''"}]], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"c", " ", 
     SubsuperscriptBox["U", "h", 
      RowBox[{" ", "'"}]], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{"k", " ", 
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", "0"}]]],
 ".  \n\nThis homogeneous equation has the characteristic equation  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"m", " ", 
     SuperscriptBox["\[Lambda]", "2"]}], " ", "+", " ", 
    RowBox[{"c", " ", "\[Lambda]"}], " ", "+", " ", "k"}], " ", "=", " ", 
   "0"}]]],
 ",  and it's roots are  ",
 Cell[BoxData[
  RowBox[{"\[Lambda]", " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"-", " ", "c"}], "  ", "\[PlusMinus]", "  ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["c", "2"], "  ", "-", "  ", 
       RowBox[{"4", "m", " ", "k"}]}]]}], 
    RowBox[{"2", "m"}]]}]]],
 ".  The constants  m, c, and k  are all positive, and there are three cases \
to consider.\n\n",
 StyleBox["Case 1.",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["c", "2"], "  ", "-", "  ", 
    RowBox[{"4", "m", " ", "k"}]}], " ", ">", "0"}]]],
 ", then the roots are real and distinct, and since  ",
 Cell[BoxData[
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["c", "2"], "  ", "-", "  ", 
     RowBox[{"4", "m", " ", "k"}]}]], "<", "c"}]]],
 ", it follows that the roots  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Lambda]", "1"], "  ", "and", "  ", 
   SubscriptBox["\[Lambda]", "2"]}]]],
 " are negative real numbers.  Thus for this case we have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "h"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SubscriptBox["\[Lambda]", "1"], "t"}]]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["A", "2"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       SubscriptBox["\[Lambda]", "2"], "t"}]]}]}]}]]],
 ",        and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"t", " ", "\[Rule]", " ", 
      RowBox[{"+", "\[Infinity]"}]}]], " ", 
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}]}], "=", "0"}]]],
 ".\n\n",
 StyleBox["Case 2.",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["c", "2"], "  ", "-", "  ", 
    RowBox[{"4", "m", " ", "k"}]}], " ", "=", "0"}]]],
 ", then the roots are real and equal, ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Lambda]", "1"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["\[Lambda]", "2"], "=", "\[Lambda]"}]}]]],
 ",  where ",
 Cell[BoxData["\[Lambda]"]],
 "  is a negative real number, and for this case we have \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "h"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["\[ExponentialE]", "\[Lambda]t"]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["A", "2"], "t", " ", 
     SuperscriptBox["\[ExponentialE]", "\[Lambda]t"]}]}]}]]],
 ",          and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"t", " ", "\[Rule]", " ", 
      RowBox[{"+", "\[Infinity]"}]}]], " ", 
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}]}], "=", "0"}]]],
 ".\n\n",
 StyleBox["Case 3.",
  FontColor->RGBColor[0, 0, 1]],
 "  If  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["c", "2"], "  ", "-", "  ", 
    RowBox[{"4", "m", " ", "k"}]}], " ", "<", "0"}]]],
 ", then the roots are complex conjugates,  ",
 Cell[BoxData[
  RowBox[{"\[Lambda]", "=", 
   RowBox[{
    RowBox[{"-", " ", "\[Alpha]"}], " ", "\[PlusMinus]", " ", 
    RowBox[{"\[ImaginaryI]", " ", "\[Beta]"}]}]}]]],
 ",  where  ",
 Cell[BoxData[
  RowBox[{"\[Alpha]", "  ", "and", "  ", "\[Beta]"}]]],
 "  are positive real number, and it follows that\n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "h"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", " ", "\[Alpha]"}], " ", "t"}]], "cos", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", " ", "t"}], ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["A", "2"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", " ", "\[Alpha]"}], " ", "t"}]], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"\[Beta]", " ", "t"}], ")"}]}]}]}]]],
 ",       and  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"t", " ", "\[Rule]", " ", 
      RowBox[{"+", "\[Infinity]"}]}]], " ", 
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}]}], "=", "0"}]]],
 ".\n\nIn all three cases, the homogeneous solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "h"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  decays to  0  as  ",
 Cell[BoxData[
  RowBox[{"t", " ", "\[Rule]", " ", 
   RowBox[{"+", "\[Infinity]"}]}]]],
 ".  \n\n\tWe obtain the steady state solution  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "p"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  by representing  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "p"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  by its Fourier series, substituting  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["U", "p", 
     RowBox[{" ", "''"}]], 
    RowBox[{"(", "t", ")"}]}], ",", 
   RowBox[{
    SubsuperscriptBox["U", "p", 
     RowBox[{" ", "'"}]], 
    RowBox[{"(", "t", ")"}]}], ",", " ", 
   RowBox[{"and", "  ", 
    SubscriptBox["U", "p"], 
    RowBox[{"(", "t", ")"}]}]}]]],
 "  into the nonhomogeneous differential equation and solving the resulting \
system for the Fourier coefficients of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "p"], 
   RowBox[{"(", "t", ")"}]}]]],
 ".  The ",
 StyleBox["general solution",
  FontColor->RGBColor[0, 0, 1]],
 " to the nonhomogeneous linear differential equation is  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["U", "p"], 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["More Details for Mechanical Systems",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/mechanicalsystem/\
MechanicalSystemTheory.pdf"], None}],
 FontFamily->"Times New Roman",
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[{
 StyleBox["Example 12.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"U", "'"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " is given by the Fourier series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"k", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "k"}], " ", "-", " ", "1"}], ")"}], "2"]], 
     RowBox[{"cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "k"}], " ", "-", " ", "1"}], ")"}], "t"}], 
      "]"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "First, we solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubsuperscriptBox["U", "h", 
      RowBox[{" ", "''"}]], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"2", " ", 
     SubsuperscriptBox["U", "h", 
      RowBox[{" ", "'"}]], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}]}], " ", "=", " ", "0"}]]],
 "  for the transient solution. The characteristic equation is  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Lambda]", "2"], "+", 
    RowBox[{"2", "\[Lambda]"}], "+", "1"}], " ", "=", " ", "0"}]]],
 "  , which has a double root ",
 Cell[BoxData[
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"-", "1"}]}]]],
 ".  Hence  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "h"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["t\[ExponentialE]", 
      RowBox[{"-", "t"}]]}]}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "We obtain the steady state solution by assuming that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "p"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  has the Fourier series representation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "p"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     SubscriptBox["a", "0"], "2"], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      SubscriptBox["a", "n"], "cos", 
      RowBox[{"(", 
       RowBox[{"n", " ", "t"}], ")"}]}]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      SubscriptBox["b", "n"], "sin", 
      RowBox[{"(", 
       RowBox[{"n", " ", "t"}], ")"}]}]}]}]}]]],
 ",  \n\t\t\t\nand that ",
 Cell[BoxData[
  RowBox[{"2", 
   SubsuperscriptBox["U", "h", 
    RowBox[{" ", "'"}]], 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["U", "h", 
    RowBox[{" ", "''"}]], 
   RowBox[{"(", "t", ")"}]}]]],
 " can be obtained by termwise differentiation: \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"2", 
    SubsuperscriptBox["U", "h", 
     RowBox[{" ", "'"}]], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
      RowBox[{"n", " ", 
       SubscriptBox["b", "n"], "cos", 
       RowBox[{"(", 
        RowBox[{"n", " ", "t"}], ")"}]}]}]}], " ", "-", " ", 
    RowBox[{"2", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
      RowBox[{"n", " ", 
       SubscriptBox["a", "n"], "sin", 
       RowBox[{"(", 
        RowBox[{"n", " ", "t"}], ")"}]}]}]}]}]}]]],
 ",  \n\t\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["U", "h", 
      RowBox[{" ", "''"}]], 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{"-", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
       RowBox[{
        SuperscriptBox["n", "2"], 
        SubscriptBox["a", "n"], "cos", 
        RowBox[{"(", 
         RowBox[{"n", " ", "t"}], ")"}]}]}]}], " ", "-", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
      RowBox[{
       SuperscriptBox["n", "2"], 
       SubscriptBox["b", "n"], "sin", 
       RowBox[{"(", 
        RowBox[{"n", " ", "t"}], ")"}]}]}]}]}]}]]],
 ",  "
}], "Text"],

Cell[TextData[{
 "Substituting these expansions into the differential equation results in \n\n\
\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["U", "p"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox[
     SubscriptBox["a", "0"], "2"], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      RowBox[{"[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["n", "2"]}], ")"}], 
         SubscriptBox["a", "n"]}], "+", 
        RowBox[{"2", "n", " ", 
         SubscriptBox["b", "n"]}]}], " ", "]"}], "cos", 
      RowBox[{"(", 
       RowBox[{"n", " ", "t"}], ")"}], " "}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                           ", 
   RowBox[{"+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], "n", " ", 
         SubscriptBox["a", "n"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["n", "2"]}], ")"}], 
         SubscriptBox["b", "n"]}]}], "]"}], "sin", 
      RowBox[{"(", 
       RowBox[{"n", " ", "t"}], ")"}]}]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Equating the coefficients with the given series for ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " , we find that  ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    SubscriptBox["a", "0"], "2"], "=", "0"}]]],
 ",  and that \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["n", "2"]}], ")"}], 
      SubscriptBox["a", "n"]}], "+", 
     RowBox[{"2", "n", " ", 
      SubscriptBox["b", "n"]}]}], "  ", "=", " ", 
    RowBox[{"{", GridBox[{
       {
        FractionBox["1", 
         SuperscriptBox["n", "2"]], 
        RowBox[{
         RowBox[{
          StyleBox["when",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "  ", "n", "  ", 
          StyleBox["is",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox[" ",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], 
          StyleBox["odd",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}], 
         StyleBox[";",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]},
       {"0", 
        RowBox[{
         StyleBox["when",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", "n", "  ", 
         StyleBox["is",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], 
         StyleBox[
          RowBox[{"even", "."}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]]],
 " \n\t\t\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"2", "n", " ", 
     SubscriptBox["a", "n"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["n", "2"]}], ")"}], 
     SubscriptBox["b", "n"]}]}], " ", "=", " ", "0", " "}]]],
 "    for all ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ". "
}], "Text"],

Cell[TextData[{
 "Solving this linear system for ",
 Cell[BoxData[
  SubscriptBox["a", "n"]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["b", "n"]]],
 ", we get \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SuperscriptBox["n", "2"]}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["n", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["n", "2"]}], ")"}], "2"]}]]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "n"], " ", "=", " ", 
   FractionBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "n"]}], 
    RowBox[{"n", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["n", "2"]}], ")"}], "2"]}]]}]]],
 " \n\nAnd with a little algebra, they can be written as follows \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubscriptBox["a", "n"], "  ", "=", " ", 
    RowBox[{"{", GridBox[{
       {
        FractionBox[
         RowBox[{" ", 
          RowBox[{"1", "-", 
           SuperscriptBox["n", "2"]}]}], 
         RowBox[{
          SuperscriptBox["n", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["n", "2"]}], ")"}], "2"]}]], 
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "  ", "n", "  ", 
          StyleBox["odd",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}], 
         StyleBox[";",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]},
       {"0", 
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", "n", "  ", 
         StyleBox[
          RowBox[{"even", "."}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]]],
 " \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubscriptBox["b", "n"], "  ", "=", " ", 
    RowBox[{"{", GridBox[{
       {
        FractionBox[
         RowBox[{"2", "n"}], 
         RowBox[{
          SuperscriptBox["n", "2"], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["n", "2"]}], ")"}], "2"]}]], 
        RowBox[{
         RowBox[{
          StyleBox["for",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "  ", "n", "  ", 
          StyleBox["odd",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}], 
         StyleBox[";",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]},
       {"0", 
        RowBox[{
         StyleBox["for",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", "n", "  ", 
         StyleBox[
          RowBox[{"even", "."}],
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]]}]}
      }], 
     StyleBox["}",
      FontColor->GrayLevel[1]]}]}]}]]],
 " "
}], "Text"],

Cell[TextData[{
 "The general solution is\n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "1"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["A", "1"], "t", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], " ", "+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{" ", 
        RowBox[{"1", "-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "n"}], "-", "1"}], ")"}], "2"]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "-", "1"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "-", "1"}], ")"}], "2"]}], ")"}], "2"]}]], 
      RowBox[{"cos", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "1"}], ")"}], " ", "t"}], 
       "]"}]}]}]}]}], "\[IndentingNewLine]", 
  RowBox[{"                                                   ", 
   RowBox[{"+", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], " ", 
     RowBox[{
      FractionBox[
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "1"}], ")"}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "n"}], "-", "1"}], ")"}], "2"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "-", "1"}], ")"}], "2"]}], ")"}], "2"]}]], 
      RowBox[{"sin", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "n"}], "-", "1"}], ")"}], " ", "t"}], 
       "]"}]}]}]}]}]}]],
 "  "
}], "Text"],

Cell[TextData[{
 "\tFor illustration purposes, consider the initial conditions ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "0", ")"}]}], "=", "1"}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "'"}], 
    RowBox[{"(", "0", ")"}]}], "=", "0"}]]],
 ".  If the trigonometric polynomial ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], 
   RowBox[{"(", "t", ")"}]}]]],
 " is used to form an approximation to the solution ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "h"], 
     RowBox[{"(", "t", ")"}]}], " ", "+", " ", 
    RowBox[{
     SubscriptBox["S", "5"], 
     RowBox[{"(", "t", ")"}]}]}]}]]],
 " then the graph of the approximate solution (in blue) is given in the \
figure below. \n\n\t\t\t",
 Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.14383e-017 0.0795775 0.199366 0.398732 [
[.25 .18687 -5 -12.5625 ]
[.25 .18687 5 0 ]
[.5 .18687 -9.3125 -12.5625 ]
[.5 .18687 9.3125 0 ]
[.75 .18687 -9.3125 -12.5625 ]
[.75 .18687 9.3125 0 ]
[1 .18687 -9.3125 -12.5625 ]
[1 .18687 9.3125 0 ]
[1.025 .19937 0 -6.28125 ]
[1.025 .19937 10 6.28125 ]
[-0.0125 0 -24 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .09968 -30 -4.5 ]
[-0.0125 .09968 0 4.5 ]
[-0.0125 .29905 -24 -4.5 ]
[-0.0125 .29905 0 4.5 ]
[-0.0125 .39873 -18 -4.5 ]
[-0.0125 .39873 0 4.5 ]
[-0.0125 .49841 -24 -4.5 ]
[-0.0125 .49841 0 4.5 ]
[-0.0125 .5981 -6 -4.5 ]
[-0.0125 .5981 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25 .19937 m
.25 .20562 L
s
gsave
.25 .18687 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.5 .19937 m
.5 .20562 L
s
gsave
.5 .18687 -70.3125 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
71.625 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.75 .19937 m
.75 .20562 L
s
gsave
.75 .18687 -70.3125 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
71.625 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
1 .19937 m
1 .20562 L
s
gsave
1 .18687 -70.3125 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
71.625 12.813 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .19937 m
1 .19937 L
s
gsave
1.025 .19937 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
.00625 0 L
s
[(-0.5)] -0.0125 0 1 0 Mshowa
0 .09968 m
.00625 .09968 L
s
[(-0.25)] -0.0125 .09968 1 0 Mshowa
0 .29905 m
.00625 .29905 L
s
[(0.25)] -0.0125 .29905 1 0 Mshowa
0 .39873 m
.00625 .39873 L
s
[(0.5)] -0.0125 .39873 1 0 Mshowa
0 .49841 m
.00625 .49841 L
s
[(0.75)] -0.0125 .49841 1 0 Mshowa
0 .5981 m
.00625 .5981 L
s
[(1)] -0.0125 .5981 1 0 Mshowa
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
0 .5981 m
.01975 .59951 L
.02981 .6006 L
.0327 .60085 L
.03413 .60096 L
.03544 .60104 L
.03661 .6011 L
.0379 .60116 L
.03919 .6012 L
.04057 .60122 L
.04129 .60123 L
.04199 .60123 L
.04329 .60121 L
.04401 .60119 L
.04468 .60117 L
.04621 .6011 L
.04755 .60101 L
.04877 .60091 L
.0515 .60061 L
.05402 .60023 L
.05674 .59971 L
.06168 .59846 L
.06754 .59643 L
.07373 .59361 L
.08481 .58682 L
.09476 .5788 L
.10543 .56823 L
.12468 .54397 L
.14698 .5075 L
.16811 .46518 L
.20835 .36778 L
.25118 .24366 L
.27244 .17892 L
.29241 .12304 L
.31171 .07833 L
.33204 .04384 L
.34216 .03167 L
.34752 .02655 L
.35323 .02208 L
.35851 .01886 L
.3633 .01667 L
.36561 .01587 L
.36812 .01518 L
.36927 .01493 L
.37048 .0147 L
.37162 .01454 L
.37267 .01442 L
.37394 .01432 L
.37532 .01426 L
.37654 .01426 L
Mistroke
.37784 .01431 L
.37912 .0144 L
.38033 .01454 L
.38141 .01469 L
.38257 .0149 L
.38527 .01554 L
.38812 .01644 L
.39322 .01863 L
.39797 .02133 L
.40239 .0244 L
.41245 .03327 L
.43386 .06008 L
.45336 .09271 L
.49525 .18609 L
.53555 .28985 L
.55594 .33443 L
.56677 .35364 L
.57842 .37044 L
.58955 .38263 L
.59441 .38679 L
.59973 .39054 L
.60478 .39333 L
.60947 .39525 L
.61207 .39603 L
.61442 .39658 L
.61573 .39681 L
.61714 .39701 L
.61848 .39714 L
.61971 .39722 L
.62103 .39726 L
.62228 .39724 L
.62341 .39719 L
.62463 .3971 L
.62596 .39694 L
.62738 .39672 L
.62991 .39619 L
.63225 .39554 L
.63445 .39479 L
.63945 .39257 L
.64489 .38939 L
.64988 .38577 L
.66114 .37529 L
.68098 .34969 L
.70271 .31264 L
.74526 .21599 L
.78623 .1094 L
.80711 .06377 L
.81811 .04445 L
.82977 .02795 L
.84015 .01672 L
Mistroke
.84605 .01179 L
.85158 .00812 L
.85665 .00554 L
.86128 .00384 L
.86384 .00317 L
.86529 .00287 L
.86663 .00266 L
.86792 .00249 L
.86909 .00239 L
.87044 .00232 L
.87171 .0023 L
.87294 .00232 L
.87424 .0024 L
.87548 .00252 L
.87661 .00266 L
.87793 .00287 L
.87936 .00316 L
.88198 .00384 L
.88471 .00475 L
.88761 .00595 L
.89281 .00868 L
.90204 .01531 L
.91221 .02513 L
.93254 .05181 L
.95445 .08976 L
.99766 .18917 L
1 .19527 L
Mfstroke
1 0 1 r
0 .19526 m
.01975 .24757 L
.04057 .29976 L
.06168 .34351 L
.07365 .36272 L
.08481 .37671 L
.09009 .38202 L
.09583 .38683 L
.10089 .39026 L
.10625 .39307 L
.11107 .39488 L
.11382 .39561 L
.11514 .39588 L
.11639 .39609 L
.11751 .39624 L
.11874 .39636 L
.11986 .39643 L
.1209 .39647 L
.12213 .39647 L
.12325 .39644 L
.12454 .39635 L
.12575 .39623 L
.12697 .39606 L
.12828 .39583 L
.13064 .3953 L
.13344 .39447 L
.136 .39351 L
.14156 .39081 L
.14683 .38747 L
.15612 .37982 L
.16623 .36907 L
.18699 .33996 L
.20905 .29989 L
.24869 .2069 L
.27071 .14863 L
.2909 .09819 L
.31195 .05475 L
.3222 .03811 L
.33152 .02575 L
.34113 .01577 L
.34647 .01142 L
.35139 .00817 L
.35676 .00544 L
.35958 .00434 L
.36257 .00343 L
.36383 .00312 L
.36517 .00285 L
.36633 .00265 L
.3676 .00248 L
.36837 .0024 L
Mistroke
.36908 .00235 L
.36976 .0023 L
.37049 .00227 L
.37188 .00226 L
.37313 .00229 L
.3744 .00237 L
.37558 .00248 L
.37688 .00266 L
.37826 .00289 L
.3811 .00355 L
.38368 .00435 L
.38866 .00641 L
.39338 .00899 L
.40386 .01685 L
.41525 .02852 L
.43606 .05727 L
.45813 .09699 L
.49782 .18957 L
.51989 .24794 L
.54009 .29865 L
.56118 .3426 L
.58077 .37208 L
.5904 .3823 L
.59534 .38645 L
.60068 .39013 L
.60373 .39186 L
.60655 .3932 L
.60918 .39425 L
.61208 .39517 L
.61333 .39549 L
.61468 .39579 L
.61584 .396 L
.61711 .39619 L
.61785 .39628 L
.61854 .39634 L
.61989 .39644 L
.62112 .39647 L
.62243 .39647 L
.62362 .39642 L
.62492 .39632 L
.62628 .39616 L
.62755 .39597 L
.62982 .3955 L
.63225 .39485 L
.6378 .39273 L
.64285 .39006 L
.65271 .38288 L
.66203 .37383 L
.68302 .34621 L
.70239 .31294 L
Mistroke
.74373 .21975 L
.78347 .11601 L
.80558 .06664 L
.8258 .03303 L
.83579 .02097 L
.84106 .01583 L
.84668 .01127 L
.85208 .00777 L
.85698 .00534 L
.85934 .00442 L
.8619 .00361 L
.86431 .00302 L
.86653 .00262 L
.86786 .00246 L
.86911 .00234 L
.87024 .00228 L
.87147 .00225 L
.8728 .00228 L
.87348 .00231 L
.87422 .00235 L
.87553 .00248 L
.87676 .00264 L
.87916 .00308 L
.88136 .00362 L
.88631 .00535 L
.89136 .00781 L
.89688 .0113 L
.90801 .02074 L
.91881 .03278 L
.92862 .04596 L
.95062 .08247 L
.99262 .17616 L
1 .19526 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{406, 250.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
  ImageRangeCache->{{{0, 405}, {249.813, 0}} -> {-1, 0, 0, 0}}],
 " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.4.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"U", "=", 
      RowBox[{"t", "=", "0"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{"c", ",", "U", ",", "t"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"de", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"U", "''"}], "[", "t", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"U", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{"U", "[", "t", "]"}]}], "\[Equal]", "0"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"DSolve", "[", 
      RowBox[{"de", ",", 
       RowBox[{"U", "[", "t", "]"}], ",", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Uh", "[", "t_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          SubscriptBox["c", "1"]}], ",", 
         RowBox[{
          RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
          SubscriptBox["c", "2"]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The transient solution to the D.E. is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(U\), \(h\)]\)[t] = \>\"", ",", 
      RowBox[{"Uh", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399640956109375*^9, 3.39964095725*^9}}],

Cell["\<\
Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"b", "=", 
      RowBox[{"A", "=", 
       RowBox[{"B", "=", 
        RowBox[{"S", "=", 
         RowBox[{"t", "=", 
          RowBox[{"T", "=", 
           RowBox[{"U", "=", "0"}]}]}]}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "a", ",", "b", ",", "A", ",", "B", ",", "S", ",", "t", ",", "T", ",", 
      "U"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "EqA", ",", "EqB", ",", "f", ",", "F", ",", "k", ",", "L", ",", "m", ",",
       "n"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["B", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"0", ",", "t_"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox[
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "n"]}], "2"], 
      FractionBox[
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}], 
       SuperscriptBox["n", "2"]]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[n,t] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Eq", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"t", ",", "t"}]], 
         RowBox[{"T", "[", 
          RowBox[{"n", ",", "t"}], "]"}]}], " ", "+", " ", 
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], " ", 
          RowBox[{"T", "[", 
           RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
        RowBox[{"T", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}], " ", "\[Equal]", " ", 
       RowBox[{"F", "[", 
        RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqA", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqB", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"EqA", ",", "EqB"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["A", "n"], ",", 
         SubscriptBox["B", "n"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "0"], "  ", "=", " ", 
     RowBox[{"2", " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["a", "0"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399640960046875*^9, 3.399640961828125*^9}},
 AspectRatioFixed->True],

Cell["\<\
Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["b", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"0", ",", "t"}], "]"}], "   ", "=", 
     FractionBox[
      RowBox[{" ", 
       SubscriptBox["a", "0"]}], "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[0,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[n,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Is the n-th term in the D.E. satisfied ?\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"t", ",", "t"}]], 
       RowBox[{"U", "[", 
        RowBox[{"n", ",", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{"2", 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        RowBox[{"U", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t, t\)]\)U[n,t] + \
2\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)U[n,t] + U[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"L", ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"Together", ",", "L"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Together", ",", 
       RowBox[{"L", "\[Equal]", 
        RowBox[{"F", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399640964796875*^9, 3.399640966265625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Construct the Trigonometric Polynomial  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]],
  AspectRatioFixed->True],
 "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"S", "''"}], "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"S", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"S", "[", "t", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(5\)]\)U[n,t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"S", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "'"}], "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The left and right side of the D.E. are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 2 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] = \>\"", ",", 
      RowBox[{"Expand", "[", "L", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(5\)]\)[t] =  \
\!\(\*UnderoverscriptBox[\(\[Sum]\), \(n = 0\), \(5\)]\)F[n,t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 2 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] \[Equal] \!\(\*SubscriptBox[\(f\), \(5\)]\)[t]\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], ",", "\"\< \[Equal] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964097171875*^9, 3.399640974328125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Look at the size of the coefficients  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "  ", "and", "  ", 
   SubscriptBox["b", "n"]}]]],
 "  and observe that\n\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["a", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         SuperscriptBox["n", "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["n", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          SuperscriptBox["n", "2"]}], ")"}], "2"]}]]}], " ", "=", " ", 
    "0"}]}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["b", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{"1", " ", "-", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], 
      RowBox[{"n", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          SuperscriptBox["n", "2"]}], ")"}], "2"]}]]}], " ", "=", " ", 
    "0"}]}]}]],
 " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"m", "=", "5"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["a", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["b", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"as", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"bs", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", "as"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", "bs"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "as", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "bs", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964097784375*^9, 3.3996409796875*^9}}],

Cell[TextData[{
 "Maybe  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 " is a close approximation to the solution. A graph of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 "  is given below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"S", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "Pi"}], ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "0.5", ",", "0.25"}], "]"}]}], "}"}]}]}],
     "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is an approximation\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<to the steady state solution \!\(\*SubscriptBox[\(U\), \(p\)]\)[t] \
of the D.E.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996409826875*^9, 3.3996409865*^9}, 
   3.40022268271875*^9, {3.40022280090625*^9, 3.4002228014375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "For illustration purposes, use the approximate solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "h"], "[", "t", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "5"], "[", "t", "]"}]}]}]],
  AspectRatioFixed->True],
 "  and use it so solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "[", "0", "]"}], "=", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "'"}], "[", "0", "]"}], "=", "0"}]}]]],
 ", and plot the result."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Uh", "[", "0", "]"}], "+", 
         RowBox[{"S", "[", "0", "]"}]}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Uh", "'"}], "[", "0", "]"}], "+", 
         RowBox[{
          RowBox[{"S", "'"}], "[", "0", "]"}]}], "\[Equal]", "0"}]}], "}"}]}],
     ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqns", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "1"], ",", 
         SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"S", "[", "t", "]"}], "+", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"Uh", "[", "t", "]"}], ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"U", "[", "t", "]"}], ",", 
       RowBox[{"S", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"4", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1.0", ",", "0.25"}], "]"}]}], "}"}]}]}],
     "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is used to form\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<an approximation to the solution U[t] = \!\(\*SubscriptBox[\(U\), \
\(h\)]\)[t] + \!\(\*SubscriptBox[\(S\), \(5\)]\)[t]\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<with the initial conditions U[0]=1, and U'[0] = 0\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996410073125*^9, 3.3996410116875*^9}, {
  3.400222687484375*^9, 3.400222687890625*^9}, {3.40022281396875*^9, 
  3.4002228145*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"U", "'"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " is given by the Fourier series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"n", "-", "1"}]], "n"], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"n", " ", "t"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", "c", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"U", ",", "t"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"de", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"U", "''"}], "[", "t", "]"}], "+", 
       RowBox[{"3", " ", 
        RowBox[{
         RowBox[{"U", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{"U", "[", "t", "]"}]}], "\[Equal]", "0"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"DSolve", "[", 
      RowBox[{"de", ",", 
       RowBox[{"U", "[", "t", "]"}], ",", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Uh", "[", "t_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          SubscriptBox["c", "1"]}], ",", 
         RowBox[{
          RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
          SubscriptBox["c", "2"]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The transient solution to the D.E. is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(U\), \(h\)]\)[t] = \>\"", ",", 
      RowBox[{"Uh", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964102046875*^9, 3.399641021625*^9}}],

Cell["\<\
Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"b", "=", 
      RowBox[{"A", "=", 
       RowBox[{"B", "=", 
        RowBox[{"S", "=", 
         RowBox[{"t", "=", 
          RowBox[{"T", "=", 
           RowBox[{"U", "=", "0"}]}]}]}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "a", ",", "b", ",", "A", ",", "B", ",", "S", ",", "t", ",", "T", ",", 
      "U"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "EqA", ",", "EqB", ",", "f", ",", "F", ",", "k", ",", "L", ",", "m", ",",
       "n"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["B", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"0", ",", "t_"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"n", "-", "1"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], "n"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[n,t] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Eq", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"t", ",", "t"}]], 
         RowBox[{"T", "[", 
          RowBox[{"n", ",", "t"}], "]"}]}], " ", "+", " ", 
        RowBox[{"3", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], " ", 
          RowBox[{"T", "[", 
           RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
        RowBox[{"T", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}], " ", "\[Equal]", " ", 
       RowBox[{"F", "[", 
        RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqA", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqB", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"EqA", ",", "EqB"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["A", "n"], ",", 
         SubscriptBox["B", "n"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "0"], "  ", "=", " ", 
     RowBox[{"2", " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["a", "0"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641024078125*^9, 3.399641025890625*^9}},
 AspectRatioFixed->True],

Cell["\<\
Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["b", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"0", ",", "t"}], "]"}], "   ", "=", 
     FractionBox[
      RowBox[{" ", 
       SubscriptBox["a", "0"]}], "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[0,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[n,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Is the n-th term in the D.E. satisfied ?\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"t", ",", "t"}]], 
       RowBox[{"U", "[", 
        RowBox[{"n", ",", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{"3", 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        RowBox[{"U", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(\[PartialD]\), \(t, t\)]\)U[n,t] + 3 \
\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)U[n,t] + U[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"L", ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"Together", ",", "L"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Together", ",", 
       RowBox[{"L", "\[Equal]", 
        RowBox[{"F", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641028328125*^9, 3.399641029984375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Construct the Trigonometric Polynomial  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]],
  AspectRatioFixed->True],
 "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"S", "'"}], "'"}], "[", "t", "]"}], " ", "+", " ", 
      RowBox[{"3", " ", 
       RowBox[{
        RowBox[{"S", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"S", "[", "t", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(5\)]\)U[n,t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"S", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "'"}], "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The left and right side of the D.E. are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 3 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] = \>\"", ",", 
      RowBox[{"Expand", "[", "L", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(5\)]\)[t] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(5\)]\)F[n,t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 3 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] \[Equal] \!\(\*SubscriptBox[\(f\), \(5\)]\)[t]\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], ",", "\"\< \[Equal] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641032234375*^9, 3.399641034890625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nLook at the size of the coefficients  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "  ", "and", "  ", 
   SubscriptBox["b", "n"]}]]],
 "  and observe that\n\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["a", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], 
      RowBox[{"1", "+", 
       RowBox[{"7", " ", 
        SuperscriptBox["n", "2"]}], "+", 
       SuperscriptBox["n", "4"]}]]}], " ", "=", " ", "0"}]}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["b", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["n", "2"]}], ")"}]}], 
      RowBox[{"n", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"7", " ", 
          SuperscriptBox["n", "2"]}], "+", 
         SuperscriptBox["n", "4"]}], ")"}]}]]}], " ", "=", " ", "0"}]}]}]],
 " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"m", "=", "5"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["a", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["b", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"as", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"bs", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", "as"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", "bs"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "as", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "bs", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641037171875*^9, 3.39964103859375*^9}}],

Cell[TextData[{
 "Maybe  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 " is a close approximation to the solution. A graph of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 "  is given below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"S", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "Pi"}], ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.2"}], ",", "0.4", ",", "0.1"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is an approximation\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<to the steady state solution \!\(\*SubscriptBox[\(U\), \(p\)]\)[t] \
of the D.E.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641040875*^9, 3.399641043390625*^9}, 
   3.4002226915*^9, {3.4002228454375*^9, 3.40022284596875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "For illustration purposes, use the approximate solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "h"], "[", "t", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "5"], "[", "t", "]"}]}]}]],
  AspectRatioFixed->True],
 "  and use it so solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "[", "0", "]"}], "=", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "'"}], "[", "0", "]"}], "=", "0"}]}]]],
 ", and plot the result."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Uh", "[", "0.", "]"}], "+", 
         RowBox[{"S", "[", "0.", "]"}]}], "\[Equal]", "1."}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Uh", "'"}], "[", "0.", "]"}], "+", 
         RowBox[{
          RowBox[{"S", "'"}], "[", "0.", "]"}]}], "\[Equal]", "0."}]}], 
      "}"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqns", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "1"], ",", 
         SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"S", "[", "t", "]"}], "+", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"Uh", "[", "t", "]"}], ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "]"}]}]}], ";"}], "  ", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"U", "[", "t", "]"}], ",", 
       RowBox[{"S", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"4", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1.0", ",", "0.25"}], "]"}]}], "}"}]}]}],
     "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is used to form\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<an approximation to the solution U[t] = \!\(\*SubscriptBox[\(U\), \
\(h\)]\)[t] + \!\(\*SubscriptBox[\(S\), \(5\)]\)[t]\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<with the initial conditions U[0]=1, and U'[0] = 0\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641045953125*^9, 3.3996410485*^9}, {
  3.4002226963125*^9, 3.400222696875*^9}, {3.4002228551875*^9, 
  3.40022285684375*^9}}]
}, Closed]],

Cell[TextData[{
 StyleBox["Extra Example 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Find the general solution to  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"U", "''"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"2", 
     RowBox[{"U", "'"}], 
     RowBox[{"(", "t", ")"}]}], "+", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}]}]]],
 ",  where ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "t", ")"}]}]]],
 " is given by the Fourier series  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", "1"}], "\[Infinity]"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"n", "-", "1"}]], "n"], " ", "sin", 
     RowBox[{"(", 
      RowBox[{"n", " ", "t"}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"U", ",", "t"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"de", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"2", 
        RowBox[{
         RowBox[{"U", "''"}], "[", "t", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         RowBox[{"U", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{"U", "[", "t", "]"}]}], "\[Equal]", "0"}]}], ";"}], " ", "\n", 
   
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"DSolve", "[", 
      RowBox[{"de", ",", 
       RowBox[{"U", "[", "t", "]"}], ",", "t"}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Uh", "[", "t_", "]"}], "=", 
     RowBox[{"ReplaceAll", "[", 
      RowBox[{
       SubscriptBox["solset", 
        RowBox[{"\[LeftDoubleBracket]", 
         RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
          SubscriptBox["c", "1"]}], ",", 
         RowBox[{
          RowBox[{"C", "[", "2", "]"}], "\[Rule]", 
          SubscriptBox["c", "2"]}]}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "de", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "solset", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The transient solution to the D.E. is\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(U\), \(h\)]\)[t] = \>\"", ",", 
      RowBox[{"Uh", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641054390625*^9, 3.39964105546875*^9}}],

Cell["\<\
Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"b", "=", 
      RowBox[{"A", "=", 
       RowBox[{"B", "=", 
        RowBox[{"S", "=", 
         RowBox[{"t", "=", 
          RowBox[{"T", "=", 
           RowBox[{"U", "=", "0"}]}]}]}]}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Remove", "[", 
     RowBox[{
     "a", ",", "b", ",", "A", ",", "B", ",", "S", ",", "t", ",", "T", ",", 
      "U"}], "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "EqA", ",", "EqB", ",", "f", ",", "F", ",", "k", ",", "L", ",", "m", ",",
       "n"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"T", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["B", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"0", ",", "t_"}], "]"}], " ", "=", " ", "0"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"n", "-", "1"}]], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], "n"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<T[n,t] = \>\"", ",", 
      RowBox[{"T", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"Eq", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"t", ",", "t"}]], 
          RowBox[{"T", "[", 
           RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "t"], " ", 
          RowBox[{"T", "[", 
           RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
        RowBox[{"T", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}], " ", "\[Equal]", " ", 
       RowBox[{"F", "[", 
        RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqA", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"EqB", " ", "=", " ", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{"Eq", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "1"}], ",", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"n", " ", "t"}], "]"}], " ", "\[Rule]", " ", "0"}]}], 
         "}"}]}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solset", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"EqA", ",", "EqB"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["A", "n"], ",", 
         SubscriptBox["B", "n"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "n_"], " ", "=", " ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "1", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["b", "n_"], " ", "=", "  ", 
     SubscriptBox["solset", 
      RowBox[{"\[LeftDoubleBracket]", 
       RowBox[{"1", ",", "2", ",", "2"}], "\[RightDoubleBracket]"}]]}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{
     SubscriptBox["a", "0"], "  ", "=", " ", 
     RowBox[{"2", " ", 
      RowBox[{"F", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(0\)]\) = \>\"", ",", 
      SubscriptBox["a", "0"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(a\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["a", "n"]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(b\), \(n\)]\) = \>\"", ",", 
      SubscriptBox["b", "n"]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641057703125*^9, 3.399641059484375*^9}},
 AspectRatioFixed->True],

Cell["\<\
Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"n_", ",", "t_"}], "]"}], " ", "=", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "n"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}], " ", "+", " ", 
      RowBox[{
       SubscriptBox["b", "n"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "t"}], "]"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", 
      RowBox[{"0", ",", "t"}], "]"}], "   ", "=", 
     FractionBox[
      RowBox[{" ", 
       SubscriptBox["a", "0"]}], "2"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[0,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"0", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[n,t] = \>\"", ",", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Is the n-th term in the D.E. satisfied ?\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"t", ",", "t"}]], 
        RowBox[{"U", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
      RowBox[{"2", 
       RowBox[{
        SubscriptBox["\[PartialD]", "t"], 
        RowBox[{"U", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], " ", "+", " ", 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<2 \!\(\*SubscriptBox[\(\[PartialD]\), \(t, t\)]\)U[n,t] + 2 \
\!\(\*SubscriptBox[\(\[PartialD]\), \(t\)]\)U[n,t] + U[n,t] = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"L", ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"MapAll", "[", 
       RowBox[{"Together", ",", "L"}], "]"}], ",", "\"\< = \>\"", ",", 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"MapAll", "[", 
      RowBox[{"Together", ",", 
       RowBox[{"L", "\[Equal]", 
        RowBox[{"F", "[", 
         RowBox[{"n", ",", "t"}], "]"}]}]}], "]"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964106178125*^9, 3.399641063328125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Construct the Trigonometric Polynomial  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]],
  AspectRatioFixed->True],
 "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"S", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"U", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"L", " ", "=", " ", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{
        RowBox[{
         RowBox[{"S", "'"}], "'"}], "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"2", " ", 
       RowBox[{
        RowBox[{"S", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
      RowBox[{"S", "[", "t", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(5\)]\)U[n,t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] = \>\"", ",", 
      RowBox[{
       RowBox[{"S", "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] = \>\"", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"S", "'"}], "'"}], "[", "t", "]"}]}], "]"}], ";"}], " ", "\n",
    
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<The left and right side of the D.E. are\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<2 \!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 2 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] = \>\"", ",", 
      RowBox[{"Expand", "[", "L", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "0"}], "5"], 
      RowBox[{"F", "[", 
       RowBox[{"n", ",", "t"}], "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(f\), \(5\)]\)[t] = \!\(\*UnderoverscriptBox[\(\
\[Sum]\), \(n = 0\), \(5\)]\)F[n,t] = \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", "\"\< \>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<2 \!\(\*SubscriptBox[\(S\), \(5\)]\)''[t] + 2 \
\!\(\*SubscriptBox[\(S\), \(5\)]\)'[t] + \!\(\*SubscriptBox[\(S\), \
\(5\)]\)[t] \[Equal] \!\(\*SubscriptBox[\(f\), \(5\)]\)[t]\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], ",", "\"\< \[Equal] \>\"", ",", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"Expand", "[", "L", "]"}], " ", "\[Equal]", " ", 
      RowBox[{"f", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.3996410654375*^9, 3.3996410678125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nLook at the size of the coefficients  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], "  ", "and", "  ", 
   SubscriptBox["b", "n"]}]]],
 "  and observe that\n\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["a", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"]}], 
      RowBox[{"1", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["n", "4"]}]}]]}], " ", "=", " ", "0"}]}], "\n", 
  RowBox[{
   RowBox[{
    SubscriptBox["lim", 
     RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
    SubscriptBox["b", "n"]}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["lim", 
      RowBox[{"n", "\[Rule]", "\[Infinity]"}]], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["n", "2"]}]}], ")"}]}], 
      RowBox[{"n", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["n", "4"]}]}], ")"}]}]]}], " ", "=", " ", 
    "0"}]}]}]],
 " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"m", "=", "5"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["a", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "0", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       SubscriptBox["b", "k"], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"as", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"as", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bs", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"bs", ",", "\"\<...\>\""}], "]"}]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", "as"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", "bs"}], 
     "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(a\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "as", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<{\!\(\*SubscriptBox[\(b\), \(n\)]\)} = \>\"", ",", 
      RowBox[{"NumberForm", "[", 
       RowBox[{
        RowBox[{"N", "[", "bs", "]"}], ",", "3"}], "]"}]}], "]"}], ";"}], " ",
    "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641070546875*^9, 3.399641072015625*^9}}],

Cell[TextData[{
 "Maybe  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 " is a close approximation to the solution. A graph of  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["S", "5"], "[", "t", "]"}]]],
 "  is given below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"S", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", 
       RowBox[{
        RowBox[{"-", "2"}], "Pi"}], ",", 
       RowBox[{"2", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.4"}], ",", "0.6"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "\[Pi]"}], ",", 
          RowBox[{"2", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.4"}], ",", "0.6", ",", "0.2"}], "]"}]}], "}"}]}]}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is an approximation\>\"", "]"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<to the steady state solution \!\(\*SubscriptBox[\(U\), \(p\)]\)[t] \
of the D.E.\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(S\), \(5\)]\)[t] = \>\"", ",", 
      RowBox[{"S", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641074453125*^9, 3.399641077109375*^9}, 
   3.4002227013125*^9, {3.400222881109375*^9, 3.400222881609375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "For illustration purposes, use the approximate solution  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["U", "h"], "[", "t", "]"}], "+", 
    RowBox[{
     SubscriptBox["S", "5"], "[", "t", "]"}]}]}]],
  AspectRatioFixed->True],
 "  and use it so solve  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"U", "[", "0", "]"}], "=", "1"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "'"}], "[", "0", "]"}], "=", "0"}]}]]],
 ", and plot the result."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"eqns", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Uh", "[", "0.", "]"}], "+", 
         RowBox[{"S", "[", "0.", "]"}]}], "\[Equal]", "1."}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Uh", "'"}], "[", "0.", "]"}], "+", 
         RowBox[{
          RowBox[{"S", "'"}], "[", "0.", "]"}]}], "\[Equal]", "0."}]}], 
      "}"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"solset", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqns", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["c", "1"], ",", 
         SubscriptBox["c", "2"]}], "}"}]}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{"S", "[", "t", "]"}], "+", 
      RowBox[{"ReplaceAll", "[", 
       RowBox[{
        RowBox[{"Uh", "[", "t", "]"}], ",", 
        SubscriptBox["solset", 
         RowBox[{"\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]}], 
       "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"U", "[", "t", "]"}], ",", 
       RowBox[{"S", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"4", "Pi"}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<s\>\""}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", 
          RowBox[{"4", "\[Pi]"}], ",", "\[Pi]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", "1.0", ",", "0.25"}], "]"}]}], "}"}]}]}],
     "]"}], "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The Trigonometric Polynomial \!\(\*SubscriptBox[\(S\), \(5\)]\)[t] \
is used to form\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<an approximation to the solution U[t] = \!\(\*SubscriptBox[\(U\), \
\(h\)]\)[t] + \!\(\*SubscriptBox[\(S\), \(5\)]\)[t]\>\"", "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<with the initial conditions U[0]=1, and U'[0] = 0\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641079234375*^9, 3.399641081796875*^9}, {
  3.400222705703125*^9, 3.400222706140625*^9}, {3.400222887109375*^9, 
  3.400222887578125*^9}}]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.39962350084375*^9, 3.399623500953125*^9}}]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{983, 571},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 278471, 6862}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 126, 2, 29, "Text"],
Cell[1034, 36, 654, 12, 65, "Text",
 Evaluatable->False],
Cell[1691, 50, 65345, 1081, 403, "Text",
 Evaluatable->False],
Cell[67039, 1133, 484, 12, 47, "Text",
 Evaluatable->False],
Cell[67526, 1147, 761, 22, 137, "Text"],
Cell[68290, 1171, 573, 18, 101, "Text"],
Cell[68866, 1191, 444, 14, 83, "Text"],
Cell[69313, 1207, 802, 28, 65, "Text"],
Cell[70118, 1237, 723, 27, 65, "Text"],
Cell[70844, 1266, 420, 13, 65, "Text"],
Cell[71267, 1281, 893, 34, 65, "Text"],
Cell[72163, 1317, 914, 31, 125, "Text",
 Evaluatable->False],
Cell[73080, 1350, 110, 2, 29, "Text"],
Cell[73193, 1354, 637, 19, 83, "Text"],
Cell[73833, 1375, 33144, 552, 303, "Text"],
Cell[106980, 1929, 1108, 38, 83, "Text"],
Cell[108091, 1969, 598, 20, 65, "Text"],
Cell[108692, 1991, 113, 2, 29, "Text"],
Cell[108808, 1995, 1623, 54, 101, "Text"],
Cell[110434, 2051, 1244, 47, 119, "Text"],
Cell[111681, 2100, 49435, 818, 403, "Text"],
Cell[161119, 2920, 7071, 239, 529, "Text"],
Cell[168193, 3161, 317, 7, 29, "Text"],
Cell[168513, 3170, 1128, 45, 38, "Text",
 Evaluatable->False],
Cell[169644, 3217, 25, 0, 29, "Text"],
Cell[169672, 3219, 1151, 42, 65, "Text"],
Cell[170826, 3263, 2690, 92, 181, "Text"],
Cell[173519, 3357, 1365, 45, 92, "Text"],
Cell[174887, 3404, 3674, 121, 134, "Text"],
Cell[178564, 3527, 5093, 170, 310, "Text"],
Cell[183660, 3699, 2188, 74, 118, "Text"],
Cell[185851, 3775, 15547, 682, 322, "Text"],
Cell[CellGroupData[{
Cell[201423, 4461, 110, 2, 29, "Text"],
Cell[201536, 4465, 88, 2, 29, "Text"],
Cell[201627, 4469, 2163, 64, 272, "Input"],
Cell[203793, 4535, 399, 6, 47, "Text"],
Cell[204195, 4543, 5487, 165, 489, "Input"],
Cell[209685, 4710, 152, 3, 29, "Text"],
Cell[209840, 4715, 2952, 88, 324, "Input"],
Cell[212795, 4805, 229, 7, 29, "Text"],
Cell[213027, 4814, 3212, 90, 456, "Input"],
Cell[216242, 4906, 1675, 57, 122, "Text"],
Cell[217920, 4965, 1957, 56, 252, "Input"],
Cell[219880, 5023, 310, 12, 29, "Text",
 Evaluatable->False],
Cell[220193, 5037, 1926, 55, 152, "Input"],
Cell[222122, 5094, 549, 20, 29, "Text"],
Cell[222674, 5116, 3090, 93, 232, "Input"]
}, Closed]],
Cell[225779, 5212, 1030, 41, 37, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[226834, 5257, 113, 2, 29, "Text"],
Cell[226950, 5261, 88, 2, 29, "Text"],
Cell[227041, 5265, 2186, 64, 292, "Input"],
Cell[229230, 5331, 399, 6, 47, "Text"],
Cell[229632, 5339, 5436, 163, 490, "Input"],
Cell[235071, 5504, 152, 3, 29, "Text"],
Cell[235226, 5509, 2953, 88, 324, "Input"],
Cell[238182, 5599, 229, 7, 29, "Text"],
Cell[238414, 5608, 3235, 91, 456, "Input"],
Cell[241652, 5701, 1507, 51, 134, "Text"],
Cell[243162, 5754, 1959, 56, 252, "Input"],
Cell[245124, 5812, 310, 12, 29, "Text",
 Evaluatable->False],
Cell[245437, 5826, 1925, 55, 152, "Input"],
Cell[247365, 5883, 549, 20, 29, "Text"],
Cell[247917, 5905, 3096, 93, 232, "Input"]
}, Closed]],
Cell[251028, 6001, 1030, 41, 37, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[252083, 6046, 113, 2, 29, "Text"],
Cell[252199, 6050, 88, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[252312, 6056, 2055, 61, 252, "Input"],
Cell[254370, 6119, 399, 6, 47, "Text"]
}, Open  ]],
Cell[254784, 6128, 5471, 164, 490, "Input"],
Cell[260258, 6294, 152, 3, 29, "Text"],
Cell[260413, 6299, 2981, 89, 324, "Input"],
Cell[263397, 6390, 229, 7, 29, "Text"],
Cell[263629, 6399, 3260, 92, 456, "Input"],
Cell[266892, 6493, 1463, 51, 134, "Text"],
Cell[268358, 6546, 1960, 56, 252, "Input"],
Cell[270321, 6604, 310, 12, 29, "Text",
 Evaluatable->False],
Cell[270634, 6618, 1934, 55, 152, "Input"],
Cell[272571, 6675, 549, 20, 29, "Text"],
Cell[273123, 6697, 3108, 93, 232, "Input"]
}, Closed]],
Cell[276246, 6793, 281, 7, 26, "Text"],
Cell[276530, 6802, 292, 7, 29, "Text"],
Cell[276825, 6811, 281, 7, 29, "Text"],
Cell[277109, 6820, 281, 7, 29, "Text"],
Cell[277393, 6829, 249, 5, 29, "Text"],
Cell[277645, 6836, 319, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
