(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     61468,       2060]
NotebookOptionsPosition[     58413,       1959]
NotebookOutlinePosition[     59188,       1991]
CellTagsIndexPosition[     59115,       1986]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["12.4  The Fourier Transform",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
 "\tIn this section we develop the complex ",
 StyleBox[ButtonBox["Fourier",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 " transform of the function  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ",  we will use ideas that were introduced in ",
 StyleBox[ButtonBox["Section 12.1",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://math.fullerton.edu/mathews/c2003/FourierSeriesComplexMod.\
html"], None}],
  FontFamily->"Times New Roman",
  FontVariations->{"Underline"->True}],
 ".  If we let ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " be a real-valued function with period ",
 Cell[BoxData[
  RowBox[{"2", "\[Pi]"}]]],
 ", which is piecewise continuous such that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " also exists and is piecewise continuous, then ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "n", " ", "t"}]]}]}]}]]],
 ", \nwhere \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "\[Pi]"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Pi]"}], "\[Pi]"], " ", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ",    for all  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ". \n\t\t\t\nThe coefficients ",
 Cell[BoxData[
  RowBox[{"{", 
   SubscriptBox["c", "n"], "}"}]]],
 " are complex numbers.  Previously, we expressed ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "as the real trigonometric series  \n\n",
 StyleBox["(12-19)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], "=", 
   RowBox[{
    FractionBox[
     SubscriptBox["a", "0"], "2"], "+", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "=", "1"}], "\[Infinity]"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["a", "n"], "cos", 
        RowBox[{"(", 
         RowBox[{"n", " ", "t"}], ")"}]}], "+", 
       RowBox[{
        SubscriptBox["b", "n"], "sin", 
        RowBox[{"(", 
         RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{3.399623937234375*^9}],

Cell[TextData[{
 "Hence a relationship between the coefficients is \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    SubscriptBox["a", "n"], " ", "=", " ", 
    RowBox[{
     SubscriptBox["c", "n"], "+", 
     SubscriptBox["c", 
      RowBox[{"-", "n"}]]}]}], " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "        ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "n"}], "=", "0"}], ",", "1", ",", "2", 
   ",", "...", " ", 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    SubscriptBox["b", "n"], " ", "=", " ", 
    RowBox[{"\[ImaginaryI]", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["c", "n"], "-", 
       SubscriptBox["c", 
        RowBox[{"-", "n"}]]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "n"}], "=", "1"}], ",", "2", ",", "3", 
   ",", 
   RowBox[{"...", " ", 
    StyleBox[".",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "We can easily establish these relations.  We start by writing  \n\n",
 StyleBox["(12-20)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["c", "0"], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", "n"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "n", " ", "t"}]]}]}], "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{
       SubscriptBox["c", 
        RowBox[{"-", "n"}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "n", " ", "t"}]]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{
    RowBox[{"=", " ", 
     RowBox[{
      SubscriptBox["c", "0"], " ", "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", "n"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "sin", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}], "+", " ", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"n", "=", "1"}], "\[Infinity]"], 
       RowBox[{
        SubscriptBox["c", 
         RowBox[{"-", "n"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"cos", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "sin", 
           RowBox[{"(", 
            RowBox[{"n", " ", "t"}], ")"}]}]}], ")"}]}]}]}]}], 
    "\[IndentingNewLine]"}]}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     SubscriptBox["c", "0"], " ", "+", " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"n", "=", "1"}], "\[Infinity]"], 
      RowBox[{"[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["c", "n"], "+", 
           SubscriptBox["c", 
            RowBox[{"-", "n"}]]}], ")"}], "cos", 
         RowBox[{"(", 
          RowBox[{"n", " ", "t"}], ")"}]}], "+", 
        RowBox[{"\[ImaginaryI]", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["c", "n"], "-", 
           SubscriptBox["c", 
            RowBox[{"-", "n"}]]}], ")"}], "sin", 
         RowBox[{"(", 
          RowBox[{"n", " ", "t"}], ")"}]}]}], "]"}]}]}]}]}]}]],
 " "
}], "Text",
 CellChangeTimes->{3.3996239396875*^9}],

Cell[TextData[{
 "Comparing Equations ",
 StyleBox["(12-20)",
  FontColor->RGBColor[0, 0, 1]],
 " and ",
 StyleBox["(12-19)",
  FontColor->RGBColor[0, 0, 1]],
 ", we see that  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "0"], " ", "=", " ", 
   RowBox[{"2", 
    SubscriptBox["c", "0"]}]}]]],
 ",  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["a", "n"], " ", "=", " ", 
   RowBox[{
    SubscriptBox["c", "n"], "+", 
    SubscriptBox["c", 
     RowBox[{"-", "n"}]]}]}]]],
 ",  and  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["b", "n"], " ", "=", " ", 
   RowBox[{"\[ImaginaryI]", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["c", "n"], "-", 
      SubscriptBox["c", 
       RowBox[{"-", "n"}]]}], ")"}]}]}]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.399623907734375*^9, 3.3996239095*^9}}],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " are piecewise continuous and have period ",
 Cell[BoxData[
  RowBox[{"2", "L"}]]],
 ", then ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n",
 StyleBox["(12-21)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "n", " ", 
       RowBox[{"t", "/", "L"}]}]]}]}]}]]],
 ", \n\t\twhere \n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "n"], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "L"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "L"}], "L"], " ", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Pi]", " ", "n", " ", 
        RowBox[{"t", "/", "L"}]}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ",    for all  ",
 StyleBox["n",
  FontFamily->"Courier New"],
 ". "
}], "Text",
 CellChangeTimes->{3.399623942546875*^9}],

Cell[TextData[{
 "\tWe've shown how periodic functions are represented by trigonometric \
series, but many practical problems involve nonperiodic functions.  A \
representation analogous to a Fourier series for a nonperiodic function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " is obtained by considering the Fourier series of ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " for  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"-", "L"}], "<", "t", "<", "L"}]]],
 "  and then taking the limit as  ",
 Cell[BoxData[
  RowBox[{"L", "\[Rule]", "\[Infinity]"}]]],
 ".  The result is known as the ",
 StyleBox["Fourier transform",
  FontColor->RGBColor[0, 0, 1]],
 " of ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ".  "
}], "Text"],

Cell[TextData[{
 "\tWe start with the nonperiodic function ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 " and consider the periodic function ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 " with period ",
 Cell[BoxData[
  RowBox[{"2", "L"}]]],
 ", where \n\n\t\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "            ", 
   RowBox[{
    RowBox[{
     StyleBox["for",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]], "  ", "-", "L"}], "<", "t", "<", "L"}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
    RowBox[{
     SubscriptBox["U", "L"], 
     RowBox[{"(", 
      RowBox[{"t", "+", 
       RowBox[{"2", "L"}]}], ")"}]}]}], 
   StyleBox[",",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], " ", 
   RowBox[{
    StyleBox["for",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], 
    StyleBox["all",
     FontFamily->"Times New Roman",
     FontSize->12,
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontVariations->{"StrikeThrough"->False,
     "Underline"->False},
     FontColor->GrayLevel[0]], "  ", 
    RowBox[{"t", 
     StyleBox[".",
      FontFamily->"Times New Roman",
      FontSize->12,
      FontWeight->"Plain",
      FontSlant->"Plain",
      FontVariations->{"StrikeThrough"->False,
      "Underline"->False},
      FontColor->GrayLevel[0]]}]}]}]}]],
 " "
}], "Text"],

Cell[TextData[{
 "Then ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 " has the complex Fourier series representation \n\n",
 StyleBox["(12-23)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "L"], 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"n", "=", 
      RowBox[{"-", "\[Infinity]"}]}], "\[Infinity]"], 
    RowBox[{
     SubscriptBox["c", "n"], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", "n", " ", 
       RowBox[{"t", "/", "L"}]}]]}]}]}]]],
 ". "
}], "Text",
 CellChangeTimes->{3.399623945578125*^9}],

Cell[TextData[{
 "\tWe need to introduce some terminology in order to discuss the terms in \
Equation ",
 StyleBox["(12-23)",
  FontColor->RGBColor[0, 0, 1]],
 ".  First\n\n",
 StyleBox["(12-24)",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["w", "n"], " ", "=", " ", 
   FractionBox[
    RowBox[{"\[Pi]", " ", "n"}], "L"]}]]],
 "\n\nis called the ",
 StyleBox["frequency",
  FontColor->RGBColor[0, 0, 1]],
 ".  If ",
 StyleBox["t",
  FontFamily->"Courier New"],
 " denotes time, then the units for ",
 Cell[BoxData[
  SubscriptBox["w", "n"]]],
 " are radians per unit time.  The set of all possible frequencies is called \
the ",
 StyleBox["frequency spectrum",
  FontColor->RGBColor[0, 0, 1]],
 ", that is, \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"...", ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", "\[Pi]"}], "L"]}], ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "\[Pi]"}], "L"]}], ",", 
    RowBox[{"-", 
     FractionBox["\[Pi]", "L"]}], ",", "0", ",", 
    FractionBox["\[Pi]", "L"], ",", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "L"], ",", 
    FractionBox[
     RowBox[{"3", " ", "\[Pi]"}], "L"], ",", "..."}], "}"}]]],
 ". "
}], "Text",
 CellChangeTimes->{3.399623916859375*^9, 3.3996239480625*^9}],

Cell[TextData[{
 "Note that, as ",
 StyleBox["L",
  FontFamily->"Courier New"],
 " increases, the spectrum becomes finer and approaches a continuous spectrum \
of frequencies.  It is reasonable to expect that the summation in the Fourier \
series for  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["U", "L"], 
   RowBox[{"(", "t", ")"}]}]]],
 "  will give rise to an integral over ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{
    RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "]"}]]],
 ".  This result is stated in Theorem 12.9. "
}], "Text"],

Cell[TextData[{
 StyleBox["Theorem 12.9 (",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[ButtonBox["Fourier Transform",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathworld.wolfram.com/FourierTransform.html"], None}],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}],
 StyleBox[").",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Let ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}], 
   StyleBox["and",
    FontFamily->"Times New Roman",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontVariations->{"StrikeThrough"->False,
    "Underline"->False},
    FontColor->GrayLevel[0]], "  ", 
   RowBox[{"U", "'"}], 
   RowBox[{"(", "t", ")"}]}]]],
 " be piecewise continuous, and  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
   RowBox[{"|", 
    RowBox[{"U", 
     RowBox[{"(", "t", ")"}]}], "|", 
    RowBox[{
     RowBox[{"\[DifferentialD]", "t"}], " ", "<", " ", "M"}]}]}]]],
 ",  \n\nfor some positive constant  M.  The ",
 StyleBox["Fourier transform",
  FontColor->RGBColor[0, 0, 1]],
 "  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "w", ")"}]}]]],
 "  of  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "  is defined as  \n\n",
 StyleBox["(12-25)\t",
  FontColor->RGBColor[0, 0, 1]],
 "\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", 
    RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "i"}], " ", "w", " ", "t"}]], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]]],
 ".  \n\nAt points of continuity,  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "  has the integral representation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], " ", "=", " ", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
    RowBox[{"F", 
     RowBox[{"(", "w", ")"}], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "w", " ", "t"}]], 
     RowBox[{"\[DifferentialD]", "w"}]}]}]}]]],
 ".  \n\nAt a point  ",
 Cell[BoxData[
  RowBox[{"t", "=", "a"}]]],
 "  of discontinuity of  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 ",  this integral converges to  ",
 Cell[BoxData[
  FractionBox[
   RowBox[{
    RowBox[{"U", 
     RowBox[{"(", 
      SuperscriptBox["a", "-"], ")"}]}], " ", "+", " ", 
    RowBox[{"U", 
     RowBox[{"(", 
      SuperscriptBox["a", "+"], ")"}]}]}], "2"]]],
 ".  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.399623951*^9},
 AspectRatioFixed->True],

Cell[TextData[{
 "The fact that  ",
 Cell[BoxData[
  RowBox[{"U", 
   RowBox[{"(", "t", ")"}]}]]],
 "   is transformed into  ",
 Cell[BoxData[
  RowBox[{"F", 
   RowBox[{"(", "w", ")"}]}]]],
 "  is commonly expressed by the operator notation  \n\n\t\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "w", ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox[ButtonBox["Proof of Theorem 12.9.",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/fouriertransform/\
FourierTransformProof.pdf"], None}],
 FontWeight->"Bold"]], "Text",
 Evaluatable->False,
 AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.9 is in the book.",
 FontWeight->"Bold",
 FontColor->RGBColor[0, 1, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/books/cbook.htm"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
 StyleBox["Example 12.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"|", "t", "|"}]}]], ")"}]}], " ", "=", " ", 
   FractionBox["1", 
    RowBox[{"\[Pi]", " ", 
     RowBox[{"(", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["w", "2"]}], ")"}]}]]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing Equation ",
 StyleBox["(12-25)",
  FontColor->RGBColor[0, 0, 1]],
 ", we obtain  \n\n\t\t",
 Cell[BoxData[{
  RowBox[{
   RowBox[{
    RowBox[{"F", 
     RowBox[{"(", "w", ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], "  ", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"|", "t", "|"}]}]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"|", "t", "|"}]}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"|", "t", "|"}]}]], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"-", "\[Infinity]"}], "0"], "  ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}], " ", "t"}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}], " ", "+", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], "  ", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "\[ImaginaryI]w"}], ")"}], " ", "t"}]], 
        RowBox[{"\[DifferentialD]", "t"}]}]}]}]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"            ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}]}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", 
       RowBox[{"-", "\[Infinity]"}]}], 
      RowBox[{"t", "=", "0"}]], " ", 
     RowBox[{
      RowBox[{"+", " ", 
       FractionBox["1", 
        RowBox[{"2", "\[Pi]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}]}]]}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}], " ", "t"}]]}], 
     UnderoverscriptBox["\[VerticalSeparator]", 
      RowBox[{"t", "=", "0"}], 
      RowBox[{"t", "=", "\[Infinity]"}]]}]}], 
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
  RowBox[{"        ", 
   RowBox[{"=", " ", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}]}]], " ", "+", " ", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"\[ImaginaryI]", " ", "w"}]}], ")"}]}]]}], "  ", "=", "  ", 
     
     FractionBox["1", 
      RowBox[{"\[Pi]", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", 
         SuperscriptBox["w", "2"]}], ")"}]}]]}]}]}]}]],
 " \nestablishing the result. "
}], "Text",
 CellChangeTimes->{3.3996239236875*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.5.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Enter the integrand  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"U", 
    RowBox[{"(", "t", ")"}]}], "=", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     RowBox[{"|", "t", "|"}]}]]}]],
  AspectRatioFixed->True],
 " and perform integration."
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "F", ",", "F1", ",", "F2", ",", "F3", ",", "t", ",", "U", ",", "U1", ",",
       "U2", ",", "w", ",", "w1", ",", "w2"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"Abs", "[", "t", "]"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U1", "[", "t_", "]"}], " ", "=", 
     SuperscriptBox["\[ExponentialE]", "t"]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"U2", "[", "t_", "]"}], " ", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "t"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w1", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"U1", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"w2", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"U2", "[", "t", "]"}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]], 
       RowBox[{"\[DifferentialD]", "t"}]}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(U\), \(1\)]\)[t] = \>\"", ",", 
      RowBox[{"U1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(U\), \(2\)]\)[t] = \>\"", ",", 
      RowBox[{"U2", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\)[t] = \[Integral]\>\"", ",", 
      RowBox[{"U1", "[", "t", "]"}], ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-\[ImaginaryI]wt\)]\) \
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"w1", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\)[t] = \[Integral]\>\"", ",", 
      RowBox[{"U2", "[", "t", "]"}], ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-\[ImaginaryI]wt\)]\) \
\[DifferentialD]t = \>\"", ",", 
      RowBox[{"w2", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641121890625*^9, 3.3996411255625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "\nBecause of the exponential order  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["w", "1"], "[", 
    RowBox[{"-", "\[Infinity]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"0", "  ", "and", "  ", 
     RowBox[{
      SubscriptBox["w", "2"], "[", "\[Infinity]", "]"}]}], "=", "0"}]}]]],
 "  and the Fourier transform is given by the following computation:"
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.399641129796875*^9, 3.39964113475*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{"Together", "[", 
      FractionBox[
       RowBox[{
        RowBox[{"w1", "[", "0", "]"}], "-", 
        RowBox[{"w2", "[", "0", "]"}]}], 
       RowBox[{"2", "\[Pi]"}]], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<F[w] = \!\(\*FractionBox[\(1\), \(2  \[Pi]\)]\)(\!\(\*SubscriptBox[\
\(w\), \(1\)]\)[0] - \!\(\*SubscriptBox[\(w\), \(2\)]\)[0])\>\"", "]"}], 
    ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(1\)]\)[0] = \>\"", ",", 
      RowBox[{"w1", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(w\), \(2\)]\)[0] = \>\"", ",", 
      RowBox[{"w2", "[", "0", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[w] = \>\"", ",", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], ",", "\"\<((\>\"", ",", 
      RowBox[{"w1", "[", "0", "]"}], ",", "\"\<) - (\>\"", ",", " ", 
      RowBox[{"w2", "[", "0", "]"}], ",", "\"\<))\>\""}], "]"}], ";"}], " ", 
   "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[w] = \>\"", ",", 
      RowBox[{"F", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641131203125*^9, 3.39964113734375*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Or we can let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  work with some very complicated improper integrals."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"val1", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"U1", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Im", "[", "w", "]"}], "\[Equal]", "0"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"val2", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"U2", "[", "t", "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "w", " ", "t"}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Im", "[", "w", "]"}], "\[Equal]", "0"}], "}"}]}]}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"F1", " ", "=", " ", 
     FractionBox[
      RowBox[{"val1", " ", "+", " ", "val2"}], 
      RowBox[{"2", "\[Pi]"}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"F2", " ", "=", " ", 
     RowBox[{"Together", "[", 
      FractionBox[
       RowBox[{"val1", " ", "+", " ", "val2"}], 
       RowBox[{"2", "\[Pi]"}]], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"F3", " ", "=", " ", 
     RowBox[{"ExpandAll", "[", 
      RowBox[{"Together", "[", 
       FractionBox[
        RowBox[{"val1", " ", "+", " ", "val2"}], 
        RowBox[{"2", "\[Pi]"}]], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{"Factor", "[", 
      RowBox[{"ExpandAll", "[", 
       RowBox[{"Together", "[", 
        FractionBox[
         RowBox[{"val1", " ", "+", " ", "val2"}], 
         RowBox[{"2", "\[Pi]"}]], "]"}], "]"}], "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(1\)]\) = \!\(\*SubsuperscriptBox[\(\
\[Integral]\), \(-\[Infinity]\), \(0\)]\)\>\"", ",", 
      RowBox[{"U1", "[", "t", "]"}], ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-\[ImaginaryI]wt\)]\) \
\[DifferentialD]t = \>\"", ",", "val1"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(v\), \(2\)]\) = \!\(\*SubsuperscriptBox[\(\
\[Integral]\), \(0\), \(\[Infinity]\)]\)\>\"", ",", 
      RowBox[{"U2", "[", "t", "]"}], ",", 
      "\"\<\!\(\*SuperscriptBox[\(\[ExponentialE]\), \(-\[ImaginaryI]wt\)]\) \
\[DifferentialD]t = \>\"", ",", "val2"}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[w] = \!\(\*FractionBox[\(1\), \(2  \[Pi]\)]\)(\!\(\*SubscriptBox[\
\(v\), \(1\)]\) + \!\(\*SubscriptBox[\(v\), \(2\)]\)) = \>\"", ",", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], ",", "\"\<((\>\"", ",", "val1", ",", 
      "\"\<) - (\>\"", ",", " ", "val2", ",", "\"\<))\>\""}], "]"}], ";"}], 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<F[w] = \>\"", ",", "F1", ",", "\"\< = \>\"", ",", "F2", ",", 
      "\"\< = \>\"", ",", "F3"}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[w] = \>\"", ",", 
      RowBox[{"F", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641140125*^9, 3.39964114253125*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " Let us use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  to find the FourierTransform ."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Fm", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{"FourierTransform", "[", 
      RowBox[{
       RowBox[{"U", "[", "t", "]"}], ",", " ", "t", ",", " ", "\[Omega]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Mathematica's version of the Fourier Transform is\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(F\), \(m\)]\)[w] = \>\"", ",", 
      RowBox[{"Fm", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641145671875*^9, 3.399641147015625*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 " ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s  FourierTransform package does not use the same coefficient involving  ",
 Cell[BoxData["\[Pi]"],
  AspectRatioFixed->True],
 "  as is commonly used in complex analysis."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tTable 12.1 gives some important properties of the Fourier transform.\
\>", "Text"],

Cell[TextData[{
 "\t\t",
 Cell[BoxData[
  StyleBox[GridBox[{
     {
      StyleBox["Linearity",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"a", " ", 
            SubscriptBox["U", "1"], 
            RowBox[{"(", "t", ")"}]}], "+", 
           RowBox[{"b", " ", 
            SubscriptBox["U", "2"], 
            RowBox[{"(", "t", ")"}]}]}], ")"}]}], " ", "=", " ", 
        RowBox[{
         RowBox[{"a", " ", "\[ScriptCapitalF]", 
          RowBox[{"(", " ", 
           RowBox[{
            SubscriptBox["U", "1"], 
            RowBox[{"(", "t", ")"}]}], ")"}]}], "+", 
         RowBox[{"b", " ", "\[ScriptCapitalF]", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["U", "2"], 
            RowBox[{"(", "t", ")"}]}], ")"}]}]}]}], "\[IndentingNewLine]"}]},
     {
      StyleBox["Symmetry",
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{
         StyleBox["If",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", "\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{"U", 
           RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
        RowBox[{"F", 
         RowBox[{"(", "w", ")"}]}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", 
       RowBox[{
        RowBox[{
         StyleBox["then",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "   ", "\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{"F", 
           RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"2", "\[Pi]"}]], "U", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", "w"}], ")"}], 
          StyleBox[".",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]], "\[IndentingNewLine]"}]}]}]}]},
     {
      StyleBox[
       RowBox[{"Time", " ", "Scaling"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{"U", 
           RowBox[{"(", 
            RowBox[{"a", " ", "t"}], ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"|", "a", "|"}]], "F", 
         RowBox[{"(", 
          FractionBox["w", "a"], ")"}]}]}], "\[IndentingNewLine]"}]},
     {
      StyleBox[
       RowBox[{"Time", " ", "Shifting"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{" ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[ScriptCapitalF]", 
          RowBox[{"(", 
           RowBox[{"U", 
            RowBox[{"(", 
             RowBox[{"t", "-", 
              SubscriptBox["t", "0"]}], ")"}]}], ")"}]}], " ", "=", " ", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SubscriptBox["t", "0"], "w"}]], " ", "F", 
          RowBox[{"(", "w", ")"}]}]}], "\[IndentingNewLine]"}]}]},
     {
      StyleBox[
       RowBox[{"Frequency", " ", "Shifting"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["w", "0"], "t"}]], "U", 
           RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{"F", 
         RowBox[{"(", 
          RowBox[{"w", "-", 
           SubscriptBox["w", "0"]}], ")"}]}]}], "\[IndentingNewLine]"}]},
     {
      StyleBox[
       RowBox[{"Time", " ", "Differentiation"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"U", "'"}], 
           RowBox[{"(", "t", ")"}]}], ")"}]}], " ", "=", " ", 
        RowBox[{"\[ImaginaryI]", " ", "w", " ", "F", 
         RowBox[{"(", "w", ")"}]}]}], "\[IndentingNewLine]"}]},
     {
      StyleBox[
       RowBox[{"Frequency", " ", "Differentiation"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          SuperscriptBox["d", "n"], 
          SuperscriptBox["dw", "n"]], "F", 
         RowBox[{"(", "w", ")"}]}], " ", "=", "  ", 
        RowBox[{"\[ScriptCapitalF]", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "t"}], ")"}], "n"], "U", 
           RowBox[{"(", "t", ")"}]}], ")"}]}]}], "\[IndentingNewLine]"}]},
     {
      StyleBox[
       RowBox[{"Moment", " ", "Theorem"}],
       FontFamily->"Times New Roman",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontVariations->{"StrikeThrough"->False,
       "Underline"->False},
       FontColor->GrayLevel[0]], 
      RowBox[{
       RowBox[{
        RowBox[{
         StyleBox["If",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", 
         SubscriptBox["M", "n"]}], " ", "=", " ", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", 
          RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], " ", 
         RowBox[{
          SuperscriptBox["t", "n"], "U", 
          RowBox[{"(", "t", ")"}], 
          RowBox[{"\[DifferentialD]", "t"}]}]}]}], 
       StyleBox[",",
        FontFamily->"Times New Roman",
        FontSize->12,
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontVariations->{"StrikeThrough"->False,
        "Underline"->False},
        FontColor->GrayLevel[0]], " ", 
       RowBox[{
        RowBox[{
         StyleBox["then",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontVariations->{"StrikeThrough"->False,
          "Underline"->False},
          FontColor->GrayLevel[0]], "  ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"], 
         SubscriptBox["M", "n"]}], " ", "=", " ", 
        RowBox[{"2", "\[Pi]", " ", 
         SuperscriptBox["F", 
          RowBox[{"(", "n", ")"}]], 
         RowBox[{
          RowBox[{"(", "0", ")"}], 
          StyleBox[".",
           FontFamily->"Times New Roman",
           FontSize->12,
           FontWeight->"Plain",
           FontSlant->"Plain",
           FontVariations->{"StrikeThrough"->False,
           "Underline"->False},
           FontColor->GrayLevel[0]]}]}]}]}]}
    }],
   FontWeight->"Plain"]]],
 "  "
}], "Text",
 CellChangeTimes->{{3.4002230804375*^9, 3.400223118640625*^9}}],

Cell[TextData[{
 "\t\t\t\t",
 StyleBox["Table 12.1",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 "  Properties of the Fourier transform."
}], "Text",
 CellChangeTimes->{{3.4002230804375*^9, 3.400223083953125*^9}, 
   3.400223153578125*^9}],

Cell[TextData[{
 StyleBox["Example 12.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "  Show that  ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["t", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "w", "|"}]}]]}]}]]],
 ".  "
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["Solution.", "Text"],

Cell[TextData[{
 "\tUsing the result of Example 12.5 and the symmetry property, we obtain \n\n\
\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "+", " ", 
         SuperscriptBox["w", "2"]}], ")"}]}]], ")"}]}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"|", 
        RowBox[{"-", "t"}], "|"}]}]]}], " ", "=", " ", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", "\[Pi]"}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"|", "t", "|"}]}]]}]}]}]]],
 "\n\nWe use the linearity property and multiply each term by ",
 Cell[BoxData["\[Pi]"]],
 " and get \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     RowBox[{"\[Pi]", 
      FractionBox["1", 
       RowBox[{"\[Pi]", " ", 
        RowBox[{"(", 
         RowBox[{"1", " ", "+", " ", 
          SuperscriptBox["w", "2"]}], ")"}]}]]}], ")"}]}], " ", "=", "  ", 
   RowBox[{"\[Pi]", 
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "t", "|"}]}]]}]}]]],
 ".\n\nThen rewrite this in the form \n\n\t\t",
 Cell[BoxData[
  RowBox[{
   RowBox[{"\[ScriptCapitalF]", 
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       SuperscriptBox["w", "2"]}]], ")"}]}], " ", "=", " ", 
   RowBox[{
    FractionBox["1", "2"], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"|", "t", "|"}]}]]}]}]]],
 " \n\nestablishing the result. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.6.",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
 "Use the result of Example 12.5 and the symmetry property to find the \
Fourier transform.\n",
 StyleBox["Symmetry property.",
  FontColor->RGBColor[0, 0, 1]],
 "  If   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalF]",
     FontSize->14], 
    RowBox[{"(", 
     RowBox[{"U", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{"F", 
    RowBox[{"(", "w", ")"}]}]}]]],
 "  then   ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["\[ScriptCapitalF]",
     FontSize->14], 
    RowBox[{"(", 
     RowBox[{"F", 
      RowBox[{"(", "t", ")"}]}], ")"}]}], "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", "\[Pi]"}]], "U", 
    RowBox[{"(", 
     RowBox[{"-", "w"}], ")"}]}]}]]],
 ".  "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"f", ",", "F", ",", "t", ",", "u", ",", "U", ",", "w"}], "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "t_", "]"}], " ", "=", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       RowBox[{"Abs", "[", "t", "]"}]}]]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "w_", "]"}], "=", 
     FractionBox["1", 
      RowBox[{"\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["w", "2"]}], ")"}]}]]}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", 
     RowBox[{"\[Pi]", " ", 
      RowBox[{"f", "[", "t", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "w_", "]"}], " ", "=", 
     RowBox[{"\[Pi]", " ", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"u", "[", 
       RowBox[{"-", "w"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", 
     "\"\<The known function u[t] and Fourier transform f[w]\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<u[t] = \>\"", ",", 
      RowBox[{"u", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<f[w] = \>\"", ",", 
      RowBox[{"f", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"f", "[", "t", "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"u", "[", 
       RowBox[{"-", "w"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Apply the symmetry property\>\"", "]"}], ";"}],
    " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[w] = \>\"", ",", 
      RowBox[{"F", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"U", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"\[Pi]", " ", 
      RowBox[{"f", "[", "t", "]"}]}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "w_", "]"}], " ", "=", 
     RowBox[{"\[Pi]", " ", 
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"u", "[", 
       RowBox[{"-", "w"}], "]"}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Multiply by \[Pi] for the desired result\>\"", "]"}], 
    ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<F[w] = \>\"", ",", 
      RowBox[{"F", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.39964116521875*^9, 3.399641168640625*^9}}],

Cell[TextData[{
 StyleBox["Aside.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0]],
 " Let us use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  to find the FourierTransform ."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Fm", "[", "w_", "]"}], " ", "=", " ", 
     RowBox[{"FourierTransform", "[", 
      RowBox[{
       RowBox[{"U", "[", "t", "]"}], ",", " ", "t", ",", " ", "\[Omega]"}], 
      "]"}]}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< U[t] = \>\"", ",", 
      RowBox[{"U", "[", "t", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<\>\"", "]"}], ";"}], " ", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Mathematica's version of the Fourier Transform is\>\"",
      "]"}], ";"}], " ", "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[\(F\), \(m\)]\)[w] = \>\"", ",", 
      RowBox[{"Fm", "[", "w", "]"}]}], "]"}], ";"}], " ", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.399641172484375*^9, 3.39964117346875*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["Remark.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]],
 " ",
 StyleBox["Mathematica'",
  FontSlant->"Italic"],
 "s  FourierTransform package does not use the same coefficient involving  ",
 Cell[BoxData["\[Pi]"],
  AspectRatioFixed->True],
 "  as is commonly used in complex analysis."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
   None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/complex.html"], None}],
 FontWeight->"Bold",
 FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2008 John H. Mathews, Russell W. \
Howell",
 BaseStyle->"Hyperlink",
 ButtonData:>{
   URL["http://math.fullerton.edu/mathews/"], None}],
 FontVariations->{"Underline"->True},
 FontColor->RGBColor[0, 1, 0]]], "Text",
 CellChangeTimes->{{3.399623959171875*^9, 3.3996239598125*^9}}]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{973, 606},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "CHAPTER 1"->{
  Cell[568, 21, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"],
  Cell[21940, 795, 334, 9, 29, "Text",
   Evaluatable->False,
   CellTags->"CHAPTER 1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"CHAPTER 1", 58916, 1976}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"],
Cell[905, 32, 115, 2, 29, "Text"],
Cell[1023, 36, 2975, 102, 203, "Text"],
Cell[4001, 140, 2376, 83, 104, "Text"],
Cell[6380, 225, 2832, 89, 142, "Text"],
Cell[9215, 316, 803, 33, 29, "Text"],
Cell[10021, 351, 1499, 56, 108, "Text"],
Cell[11523, 409, 788, 26, 65, "Text"],
Cell[12314, 437, 2995, 109, 104, "Text"],
Cell[15312, 548, 718, 26, 65, "Text"],
Cell[16033, 576, 1315, 46, 149, "Text"],
Cell[17351, 624, 548, 17, 47, "Text"],
Cell[17902, 643, 2939, 106, 268, "Text",
 Evaluatable->False],
Cell[20844, 751, 470, 19, 65, "Text"],
Cell[CellGroupData[{
Cell[21339, 774, 141, 4, 29, "Text",
 Evaluatable->False],
Cell[21483, 780, 280, 7, 29, "Text",
 Evaluatable->False],
Cell[21766, 789, 171, 4, 29, "Text",
 Evaluatable->False],
Cell[21940, 795, 334, 9, 29, "Text",
 Evaluatable->False,
 CellTags->"CHAPTER 1"]
}, Closed]],
Cell[22289, 807, 528, 20, 38, "Text",
 Evaluatable->False],
Cell[22820, 829, 25, 0, 29, "Text"],
Cell[22848, 831, 4654, 143, 287, "Text"],
Cell[CellGroupData[{
Cell[27527, 978, 156, 4, 29, "Text",
 Evaluatable->False],
Cell[27686, 984, 281, 11, 29, "Text"],
Cell[27970, 997, 2856, 76, 323, "Input"],
Cell[30829, 1075, 503, 15, 47, "Text",
 Evaluatable->False],
Cell[31335, 1092, 1913, 53, 280, "Input"],
Cell[33251, 1147, 198, 7, 29, "Text",
 Evaluatable->False],
Cell[33452, 1156, 4089, 110, 445, "Input"],
Cell[37544, 1268, 250, 10, 29, "Text",
 Evaluatable->False],
Cell[37797, 1280, 996, 28, 152, "Input"],
Cell[38796, 1310, 380, 13, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[39191, 1326, 94, 2, 26, "Text"],
Cell[39288, 1330, 8882, 276, 327, "Text"],
Cell[48173, 1608, 251, 8, 29, "Text"],
Cell[48427, 1618, 519, 20, 39, "Text",
 Evaluatable->False],
Cell[48949, 1640, 25, 0, 29, "Text"],
Cell[48977, 1642, 1751, 59, 293, "Text"],
Cell[CellGroupData[{
Cell[50753, 1705, 110, 2, 29, "Text"],
Cell[50866, 1709, 755, 31, 54, "Text"],
Cell[51624, 1742, 3419, 105, 522, "Input"],
Cell[55046, 1849, 250, 10, 29, "Text",
 Evaluatable->False],
Cell[55299, 1861, 995, 28, 152, "Input"],
Cell[56297, 1891, 380, 13, 29, "Text",
 Evaluatable->False]
}, Closed]],
Cell[56692, 1907, 281, 7, 26, "Text"],
Cell[56976, 1916, 292, 7, 29, "Text"],
Cell[57271, 1925, 281, 7, 29, "Text"],
Cell[57555, 1934, 281, 7, 29, "Text"],
Cell[57839, 1943, 249, 5, 29, "Text"],
Cell[58091, 1950, 318, 7, 29, "Text"]
}
]
*)

(* End of internal cache information *)
